#! /usr/bin/python

########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

import ConfigParser
import string
import os

class SMBConfigManager:
	fileName = "/etc/samba/smb.conf"
	#fileName = "./test.conf"
	cfgFile = None
	debug = True

	def __init__(self, debug = False):
		self.debug = debug
		self.fileName = "/etc/samba/smb.conf"


	def loadConfig(self):
		try:
			try:
				self.cfgFile = open(self.fileName, 'r')
                		config = ConfigParser.ConfigParser()
               			config.readfp(self.cfgFile)
               			return config
        		except IOError:
				if self.debug:
					print "Cannot open file " + self.fileName
               			return None  
        		except:
				if self.debug:
					print "Exception Occured!"
               			return None 
		finally:
			if self.cfgFile != None:
				print "Reached Final Block in loadConfig()"
				self.cfgFile.close()
 

	def updateConfig(self,secName, optName, optValue):
		try:
			try:
				config = self.loadConfig()
				if config == None:
					return -1
				if not config.has_section(secName):
					if self.debug:
						print "No Section " + secName + "!"
					return "No Section " + secName + "!"
				self.cfgFile = open(self.fileName, 'w')
				config.set(secName, optName, optValue)
				config.write(self.cfgFile)
				return 0
			except IOError:
				if self.debug:
					print "Cannot open " + self.fileName
				return "Cannot read or write file " + self.fileName 
       			except ConfigParser.NoSectionError:
				if self.debug:
					print "No Section Error!"
				return "No Section Error!" 			
       			except:
               			return -1 
		finally:
			if self.cfgFile != None:
				if self.debug:
					print "Reached Final Block in updateConfig"
			self.cfgFile.close()



	def getSections(self):
        	config = self.loadConfig()
		if config == None:
                        return []

        	sections = config.sections()
		if self.debug:
        		print sections
        	return sections



	def getOptionsBySection(self, secName):
		config = self.loadConfig()
		if (config == None) or (not config.has_section(secName)):
			return []
        	options = config.options(secName)
		if self.debug:
	        	print options
	        return options


	def getOptionValuesBySection(self,secName):
        	config = self.loadConfig()
		if (config == None) or (not config.has_section(secName)):
			return "[No Section " + secName + "]"
        	items = config.items(secName)
		if self.debug:
        		print items
        	return items	
	

	def printConfig(self):
		config = self.loadConfig()
        	print "********************"
        	for sec in config.sections():
                	print "[" + sec + "]"
                	for option in config.options(sec):
                        	print option + " = " + config.get(sec, option)
                	print
        	# end for
        	print "********************"


	def addSection(self, secName):
		try:
			try:
				config = self.loadConfig()
				if (config == None):
					return -1 
                		if config.has_section(secName):
					if self.debug:
						print "Duplicate Section " + secName
                        		return "Duplicate Section " + secName
				config.add_section(secName)
				self.cfgFile = open(self.fileName, 'w')
				config.write(self.cfgFile)
                		if self.debug:
                        		print "Added a new section successfully!" 
                		return 0
			except IOError:
				if self.debug:
					print "Cannot open " + self.fileName
				return "Cannot read or write file " + self.fileName
			except:	
				return -1
		finally:
			if self.cfgFile != None:
				if self.debug:
					print "Reached final block in addSection"
			self.cfgFile.close() 		


	def removeSection(self, secName):
		try:
			try:
				config = self.loadConfig()
				if (config == None):
					return -1 
				if not config.has_section(secName):
					if self.debug:
						print "Non existing Section " + secName
					return "Non existing Section " + secName
				config.remove_section(secName)
				self.cfgFile = open(self.fileName, 'w')
				config.write(self.cfgFile)
				if self.debug:
					print "Remove a section successfully!"
				return 0
			except IOError:
				if self.debug:
					print "Cannot open " + self.fileName
				return "Cannot read or write file " + self.fileName
			except:
				return -1
		finally:
			if self.cfgFile != None:
				if self.debug:
					print "Reached final block in addSection"
			self.cfgFile.close()	
	

	def removeOption(self, secName, option):
		try:
			try:
				config = self.loadConfig()
				if (config == None):
					return -1 
				if not config.has_section(secName):
					if self.debug:
						print "Non existing Section " + secName
					return "Non existing Section " + secName

				if not config.has_option(secName, option):
					if self.debug:
						print "Non existing option %s, inside the section %s." % (option, secName)
					return "Non existing option %s, inside the section %s." % (option, secName)

				config.remove_option(secName, option)
				self.cfgFile = open(self.fileName, 'w')
				config.write(self.cfgFile)
				if self.debug:
					print "Remove a option %s from %s section successfully!" % (option, secName)
					return 0
			except IOError:
				if self.debug:
					print "Cannot open " + self.fileName
				return "Cannot read or write file " + self.fileName
			except:
				return -1
		finally:
			if self.cfgFile != None:
				if self.debug:
					print "reached final block in removeOption!"
			self.cfgFile.close()


# End class definition


if __name__ == "__main__":
	configManager = SMBConfigManager(True)	
	#print configManager.loadConfig()
	#configManager.getOptionsBySection("database")
	#configManager.getSections()
	#configManager.getOptionValuesBySection("database")
	#configManager.printConfig()
	configManager.updateConfig('database', 'url1', 'jdbc://a.b.c.d.e.f.h:')










