#!/usr/bin/python

########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2010
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

import sys
import os
import inspect
import re
from subprocess import Popen
from subprocess import PIPE
import socket
import iamutils
import fcntl
import pwd
from time import *

progname = os.path.basename(sys.argv[0])

# DHCP leases file
leases_file = r'/var/lib/dhcp/db/dhcpd.leases'

# dictionary, keyed by the node's serial numbers
nodes = {}

# dictionary of ip leases, collected from dhcpd.leases file
ip_leases = {}

# mapping of ip's to nodes from our config file
ips_to_nodes = {}

# The primary node 
primary_node = None

# The configuration file
conf_name = '/opt/tivoli/tiam/etc/nodes'
conf_file = None

# The directory this script is located in
scriptdir = os.path.dirname(sys.argv[0])

def ssh_to_node(ip, cmd):
        return str('su iaadmin -c "ssh -o BatchMode=yes '+ip+' sudo '+
                   cmd.replace('"', '\"')
                   +'"')

#def copy_keys_to_new_node(ip):
#        command = ssh_to_node(ip, '/opt/tivoli/tiam/bin/get_ssh_keys.sh')
#        (status,output) = iamutils.run_shell(command,False)
#
#        if status:
#                print output.strip()
#
#        return status

def check_lock_file(ip,check_file_command):
        command = 'su iaadmin -c "ssh -o BatchMode=yes '+ip+' ls '+check_file_command+'"'
        (status,output) = iamutils.run_shell(command,False)

        if status:
                print output.strip()

        return status

#-------------------------------------------------------------------------------
# class describing tiam node. The script will populate the members of the class
# and the final result of the script will be information contained in list of 
# tiam_node objects, saved in XML form
#-------------------------------------------------------------------------------
class tiam_node:
        serial_number = "not defined"

        def __init__(self, serial_number, host_name='', private_ip="0.0.0.0"):
                self.serial_number = serial_number
                self.private_ip = private_ip
                self.host_name = host_name

        def set_serial_number(self, sn): self.serial_number = sn
        def set_private_ip(self, ip): self.private_ip = ip
        def set_host_name(self, host_name) : self.host_name = host_name

        def get_serial_number(self): return self.serial_number
        def get_private_ip(self): return self.private_ip
        def get_host_name(self): return self.host_name

#-------------------------------------------------------------------------------
# Helper class. Temporary holds information about IP lease as the script is 
# parsing dhcpd.leases file.
#-------------------------------------------------------------------------------
class ip_lease:
        verification_state = 'not verified'
        retries_left = 3
        
        def __init__(self, ip, state):
                self.ip = ip
                self.binding_state = state
        
#-------------------------------------------------------------------------------
# Logging related functions
#-------------------------------------------------------------------------------
lineno = (lambda : inspect.currentframe().f_back.f_lineno)
err_header = (lambda n: progname + " (" + str(n) + ")" + ": Error: ")
warning_header = (lambda n: progname + " (" + str(n) + ")" + ": Warning: ")
info_header = (lambda n: progname + " (" + str(n) + ")" + ": Info: ")

#-------------------------------------------------------------------------------
# Function to obtain xSeries serial number from tiam nas node. It will ssh to 
# the node and use linux command line to get the serial number.
# Arguments:
#       ip - ip address of the nas tiam node
# Returns
#       string serial number or null string if was unable to obtain the serial
#       number
#-------------------------------------------------------------------------------
def get_sn_linux_node(ip):
        command = ssh_to_node(ip, '/usr/sbin/dmidecode -s system-serial-number')
        (status,output) = iamutils.run_shell(command,False)
        if not status:
                print("Failed to get serial number from " + ip)
                return ''
        
        return output.strip()

# Write a single node to the configuration file
def write_node(node):
        conf_file.write(node.get_serial_number()+','+node.get_host_name()+','+node.get_private_ip()+"\n")


# Add a node to the cluster.  Set a unique hostname and ensure known_hosts
# files on all nodes are up-to-date     
def add_node(new_node):
        global primary_node
        
        (hostname, aliaslist, ipaddrlist) = socket.gethostbyaddr(new_node.get_private_ip())
        new_node.set_host_name(hostname)

        while not check_lock_file(new_node.get_private_ip(),"/opt/tivoli/tiam/bin/install_complete"):
                print "waiting for GPFS node install to complete"
                sleep(5)

        if not primary_node:
                command = ssh_to_node(new_node.get_private_ip(), '/opt/tivoli/tiam/bin/create_gpfs '+hostname)
                (status, output) = iamutils.run_shell(command)
                primary_node = new_node
        
        nodenum = len(nodes)

        # everybody should be setup now, so do the mmaddnode
        if new_node is not primary_node:
                if nodenum <= 3:
                        quorum_type = 'quorum-manager'
                else:
                        quorum_type = 'quorum'

                if nodenum == 2:
                        specify_secondary = '-s'
                else:
                        specify_secondary = ''

                if ((nodenum & 1) == 0):
                        specify_add_remove_tie_breaker = '-a'
                else:
                        specify_add_remove_tie_breaker = '-r'

                command = ssh_to_node( primary_node.get_private_ip(),
                        ' /opt/tivoli/tiam/bin/add_node_update_tiebreaker.py -q '+quorum_type+
                        ' '+specify_secondary+' '+specify_add_remove_tie_breaker+
                        ' -n '+new_node.get_host_name())
                iamutils.run_shell(command)
        
        write_node(new_node)
        conf_file.flush()

def change_to_static(node):
        command = ssh_to_node(node.get_private_ip(), '/opt/tivoli/tiam/bin/change_bond1_static.sh '+node.get_private_ip())
        iamutils.run_shell(command)

def generate_watchdog_config_file(node):
        command = ssh_to_node(node.get_private_ip(), '/opt/tivoli/tiam/bin/ia_generate_iacluster_config -vvvv')
        iamutils.run_shell(command,False)

def configure_ctdb_cluster():
        command = ssh_to_node(node.get_private_ip(), '/opt/tivoli/tiam/bin/ia_ctdb_cluster_config.sh')
        iamutils.run_shell(command,False)

def update_node_config(node):
	command = ssh_to_node(node.get_private_ip(), '/opt/tivoli/tiam/bin/ia_repair_node_config.py ianode1')
        iamutils.run_shell(command,False)

def get_date_from_remote(ip_address):
        command = ssh_to_node(ip_address, '/bin/date +%s')
        (status,output) = iamutils.run_shell(command)
        return long(output)

def get_date_from_local():
        command = str('date +%s')
        (status,output) = iamutils.run_shell(command)
        return long(output)

def are_times_in_sync(ip_address):
        try:
                if (abs(get_date_from_remote(ip_address)-get_date_from_local()) < 300):
                        return True
                else:
                        return False
        except:
                return False
        
#-------------------------------------------------------------------------------
# MAIN SCRIPT
#-------------------------------------------------------------------------------

# open the leases file for reading and make a list of private and rsa ips.

if not os.path.exists(leases_file):
        sys.stderr.write(err_header(lineno()) 
        + "file " + leases_file + " does not exist")
        sys.exit(1)

# Get the leases file's modified timestamp
leasests = os.stat(leases_file).st_mtime

try:
        if os.path.exists(conf_name):
                # Use the configuration file as a lock
                # so that only one instance runs at a time
                conf_file = open(conf_name,'r+')
                fcntl.flock(conf_file.fileno(),fcntl.LOCK_EX|fcntl.LOCK_NB)
                timestamp = conf_file.readline().strip()
        else:
                conf_file = open(conf_name,'w+')
                fcntl.flock(conf_file.fileno(),fcntl.LOCK_EX|fcntl.LOCK_NB)
except IOError:
        conf_file.close()
        print('Already running')
        syslog.closelog()
        sys.exit(0)

# matches lease line with IP address in dhcpd.leases file
# sample: 'lease 92.168.0.253 {'
pattern_ip = re.compile('^lease (\d+\.\d+\.\d+\.\d+) \{$') 

# matches the binding state line: '  binding state active;'
pattern_state = re.compile('^\s+binding state (\w+);$')

# matches end of lease description: '}' by itself on a line
pattern_end = re.compile('^\}$')

try:
        leases = open(leases_file)

        while 1:
                line = leases.readline()
                if not line: break

                # reset local variables so that values from previous iteration
                # are not used
                ip = ""
                state = ""
                # get the the beginning of ip lease record
                match_ip = pattern_ip.match(line)
                if match_ip:
                        ip = match_ip.group(1)

                        # read till the end of lease record saving relevant information
                        while not pattern_end.match(line):
                                        line = leases.readline()

                                        # get the binding state on the lease
                                        match_state = pattern_state.match(line)
                                        if match_state:
                                                state = match_state.group(1)
        
                        # At this point, an IP lease record has been processed. 
                        # Must have IP and state. uid is optional and will not be
                        # in all lease records
                        if not ip or not state:
                                sys.stderr.write(err_header(lineno()) 
                                + "could not parse lease record. ip: " + ip + " state: " + state)
                                leases.close()
                                sys.exit(1)
          
                        ip_obj = ip_lease(ip, state)
                        ip_leases[ip] = ip_obj

        leases.close()

except IOError, (errno, strerror):
        sys.stderr.write(err_header(lineno()) + "I/O Error(%s): %s" % (errno, strerror))
        leases.close()
        sys.exit(1)

for line in conf_file:
        line = line.strip()

        if not line:
                continue
                
        params = line.split(',')
        node = tiam_node(params[0],params[1],params[2])

        nodes[node.get_serial_number()] = node
        ips_to_nodes[node.get_private_ip()] = node
                
        if not primary_node:
                primary_node = node     

conf_file.seek(0)                       
# conf file begins with last dhcp.lease timestamp
conf_file.write(str(leasests)+"\n")
for node in nodes.values():
        write_node(node)
conf_file.flush()

# Process the list of ip leases obtained from dhcpd.leases file. 
# For each IP, if the binding state is active, attempt to ssh to that IP and obtain
# machine's serial number. If that is successfull, build a node object with serial 
# number and one of the IPs and store it in nodes dictionary. The node object will be
# updated with the second IP address when it comes up in the list
for ip in ip_leases.keys():
        # only look at active leases
        if ip_leases[ip].binding_state != 'active' or ip in ips_to_nodes:
                continue
        
        # copy_keys_to_new_node(ip)
        sn = get_sn_linux_node(ip)
        
        if not sn:
                # If we don't get a serial number something is wrong
                # update the lease timestamp so we'll try again next time
                os.utime(leases_file,(leasests+1,leasests+1))
                continue

        if sn in nodes:
                continue
        else:
                if are_times_in_sync(ip):
                        node = tiam_node(sn)
                        nodes[sn] = node
                else:
                        print('The time on '+ip+' is not in sync with the management server')
                        print('Please correct the time')
                        # update the lease timestamp so we'll try again next time
                        os.utime(leases_file,(leasests+1,leasests+1))
                        continue

        node.set_private_ip(ip)
        
        ips_to_nodes[ip] = node

        add_node(node)

        change_to_static(node)

	generate_watchdog_config_file(node)
	
	configure_ctdb_cluster()

	update_node_config(node)

conf_file.close()
