#!/usr/bin/python

########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

from optparse import OptionParser
import sys
import os
import time
import commands
import logging
import logging.handlers
import copy

LOG_FILENAME = "/var/opt/tivoli/tiam/log/add_node_update_tiebreaker.log"
logMessageTemplate = "%c add_node_update_tiebreaker:"

def write_to_logfile(text_to_log):
    logTime = time.localtime(time.time())
    logMessage = logMessageTemplate + text_to_log
    logMessage = time.strftime(logMessage, logTime)
    my_logger.debug(logMessage)

def write_to_logfile2(command,status,output):
    text_to_log = "command="+command+"\nstatus="+str(status)+"\noutput="+output
    write_to_logfile(text_to_log)

def write_to_logfile3(command,status):
    text_to_log = "command="+command+"\nstatus="+str(status)
    write_to_logfile(text_to_log)

def stop_gpfs_all_nodes():
    count = 0
    while count < 5:
        command = '/usr/lpp/mmfs/bin/mmshutdown -a'
        (status, output) = commands.getstatusoutput(command)
        write_to_logfile2(command,status,output)
        command = '/opt/tivoli/tiam/bin/wd_printnodestates.sh'
        (status, output) = commands.getstatusoutput(command)
        write_to_logfile2(command,status,output)
        if status != 0:
            count = count + 1
            continue
        all_nodes_down = True
        for line1 in output.splitlines():
            line2 = line1.split()
            if line2[2] != 'down':
                all_nodes_down = False
                command = str('ssh '+line2[1]+' /usr/lpp/mmfs/bin/mmshutdown')
                (status, output) = commands.getstatusoutput(command)
                write_to_logfile2(command,status,output)
        if all_nodes_down:
            return (0)
        else:
            count = count + 1

    return (-1)

def wait_for_all_nodes_active():
    count = 0
    while count < 30:
        command = '/opt/tivoli/tiam/bin/wd_printnodestates.sh'
        (status, output) = commands.getstatusoutput(command)
        write_to_logfile2(command,status,output)
        if status != 0:
            return (-1)
        all_nodes_active = True
        for line1 in output.splitlines():
            line2 = line1.split()
            if line2[2] != 'active':
                all_nodes_active = False
        if all_nodes_active:
            return (0)
        else:
            time.sleep(60)
            count = count + 1

def start_gpfs_all_nodes():
    count = 0
    while count < 5:
        command = '/usr/lpp/mmfs/bin/mmstartup -a'
        (status, output) = commands.getstatusoutput(command)
        write_to_logfile2(command,status,output)
        (status) = wait_for_all_nodes_active()
        if status == 0:
            return (0)
        else:
            count = count + 1
            command = '/opt/tivoli/tiam/bin/wd_printnodestates.sh'
            (status, output) = commands.getstatusoutput(command)
            write_to_logfile2(command,status,output)
            if status != 0:
                continue
            for line1 in output.splitlines():
                line2 = line1.split()
                if line2[2] != 'active':
                    command = str('ssh '+line2[1]+' /usr/lpp/mmfs/bin/mmstartup')
                    (status, output) = commands.getstatusoutput(command)
                    write_to_logfile2(command,status,output)
            (status) = wait_for_all_nodes_active()
            if status == 0:
                return (0)

    return (-1)



def do_add_tiebreaker():
    command = '/usr/lpp/mmfs/bin/mmchconfig tiebreakerDisks=gpfs1nsd'
    (status, output) = commands.getstatusoutput(command)
    write_to_logfile2(command,status,output)
    return(status)

def do_remove_tiebreaker():
    command = '/usr/lpp/mmfs/bin/mmchconfig tiebreakerDisks='
    (status, output) = commands.getstatusoutput(command)
    write_to_logfile2(command,status,output)
    return(status)

def do_add_node(quorum_type,hostname):
    command = str('/usr/lpp/mmfs/bin/mmaddnode -N '+hostname+':'+quorum_type)
    (status, output) = commands.getstatusoutput(command)
    write_to_logfile2(command,status,output)
    command1 = str('/usr/lpp/mmfs/bin/mmchlicense server --accept -N all')
    (status, output) = commands.getstatusoutput(command1)
    write_to_logfile2(command1,status,output)
    return(status)

def set_secondary(hostname):
    command = str('/usr/lpp/mmfs/bin/mmchcluster -s '+hostname)
    (status, output) = commands.getstatusoutput(command)
    write_to_logfile2(command,status,output)
    return(status)

def does_gpfs1nsd_exist():
    command = '/usr/lpp/mmfs/bin/mmlsnsd 2> /dev/null | grep gpfs1nsd'
    (status, output) = commands.getstatusoutput(command)
    write_to_logfile2(command,status,output)
    if len(output) > 0:
        return True
    else:
        return False

#-------------------------------------------------------------------------------
# MAIN SCRIPT
#-------------------------------------------------------------------------------

my_logger = logging.getLogger('add_node_update_tiebreaker_logger')
my_logger.setLevel(logging.DEBUG)
handler = logging.handlers.RotatingFileHandler(
              LOG_FILENAME, maxBytes=(10*1024*1024), backupCount=5)
my_logger.addHandler(handler)

write_to_logfile("Begin add_node_update_tiebreaker")

parser = OptionParser()
parser.add_option("-q",dest="quorum_type",
    help="[quorum|quorum-manager]",metavar="quorum_type")
parser.add_option("-a",dest="add_tiebreaker",action="store_true",
    help="add a tie breaker disk",metavar="add_tiebreaker")
parser.add_option("-r",dest="remove_tiebreaker",action="store_true",
    help="remove a tie breaker disk",metavar="remove_tiebreaker")
parser.add_option("-s",dest="secondary",action="store_true",
    help="specify secondary GPFS node",metavar="secondary")
parser.add_option("-n",dest="hostname",
    help="hosname",metavar="hostname")

(options, args) = parser.parse_args()

(status) = stop_gpfs_all_nodes()
if status != 0:
    write_to_logfile("Unable to shutdown GPFS")
    sys.exit(-1)

# In order to support vmware only add the tie breaker if the NSD gpfs1nsd exists
# It will not exist on vmware unless it was manually created
if does_gpfs1nsd_exist():
    if options.add_tiebreaker:
        (status) = do_add_tiebreaker()
        if status != 0:
            write_to_logfile("Unable to add tie breaker")
            sys.exit(-1)

if options.remove_tiebreaker:
    (status) = do_remove_tiebreaker()
    if status != 0:
        write_to_logfile("Unable to remove tie breaker")
        sys.exit(-1)

(status)= do_add_node(options.quorum_type,options.hostname)
if status != 0:
    write_to_logfile("Unable to add node")
    sys.exit(-1)

if options.secondary:
    (status) = set_secondary(options.hostname)
    if status != 0:
        write_to_logfile("Unable to set secondary")
        sys.exit(-1)

(status) = start_gpfs_all_nodes()
if status != 0:
    write_to_logfile("Unable to start GPFS")
    sys.exit(-1)

sys.exit(0)
