#!/bin/bash
#
#******************************************************************************
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp.  2008  All Rights Reserved
#
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -----------------------------------------------------------------------------
# Author: Bryan Jen
# 
#
# 01/25/2011  Greg McBride		17619- Remove disabling CNFS
# =========================================================================

TIAMBIN="/opt/tivoli/tiam/bin"
MMPATH="/usr/lpp/mmfs/bin"
DRLOGPATH="/opt/tivoli/tiam/log/dr"
SCRIPTNAME="cfgsecondary"
iAm=`cat /etc/HOSTNAME`
datestamp=`date +%m%d%Y%H%M%S`
LOGFILE="${DRLOGPATH}/${SCRIPTNAME}.${datestamp}.out"

pingtest() {
  cmd=`ping $1 -c 1`
    if [[ `echo $cmd |grep -i unreachable` ]]; then
      return -1
    else
      return 0
    fi
}

printAndLog() {
  timestamp=`date "+%Y-%m-%d %H:%M:%S"`
  echo "$timestamp [$SCRIPTNAME] $1"
  echo "$timestamp [$SCRIPTNAME] $1" >> $LOGFILE
}


printAndLogErrorExit() {
  timestamp=`date "+%Y-%m-%d %H:%M:%S"`
  echo "$timestamp [$SCRIPTNAME] ERROR($1): $2"
  echo "$timestamp [$SCRIPTNAME] ERROR($1): $2" >> $LOGFILE
  echo "$timestamp [$SCRIPTNAME] Exiting script with rc=$1. Please refer to the logfile @ $LOGFILE"
  echo "$timestamp [$SCRIPTNAME] Exiting script with rc=$1" >> $LOGFILE
  exit $1
}

/bin/mkdir -p $DRLOGPATH
/usr/bin/touch $LOGFILE

if [[ !($iAm =~ "ianode*") ]]; then
   printAndLog "You are attempting to run cfgSecondary on Management Console."
   printAndLog "Please run on Primary Node Server."
   printAndLogErrorExit -1 "Exiting script..."
else
  console="iamconsole1"
  pingtest $console
  pings=$?
  if [[ $pings -ne 0 ]]; then
    printAndLog "ERROR: Cannot ping Management Console."
    printAndLogErrorExit -2 "Exiting..."
    
  else 
    ssh root@${console} touch /opt/tivoli/tiam/etc/DR_SECONDARY

#==============PHASE 1=====================
# 17619- removes CNFS for 2.1 
# Removing GPFS tiebreaker disk
#==========================================
    printAndLog "Preparing GPFS for Secondary Mode"

    if [[ `${MMPATH}/mmlsconfig |grep -i tiebreakerdisks` ]]; then
      output=`${MMPATH}/mmshutdown -a`
   
      sleep 60
      output=`${MMPATH}/mmchconfig tiebreakerdisks=""`

      sleep 40
      output=`${MMPATH}/mmstartup -a`
    fi

    for col in `${MMPATH}/mmlsfs all -T | grep -i "File system attributes for " | awk '{print $5}' | cut -d: -f1`; do
      ${MMPATH}/mmchfs $col -A no
    done

#============REBOOT NODES===============

    printAndLog "Appliance now configured as Secondary role"
    #echo -n "\n\nReboot of nodes needed to activate settings. Reboot now [y/n]?"
    #read reboot
    reboot="y"

    if [[ "$reboot" == "y" ]];then
      for node in `${MMPATH}/mmgetstate -a |grep ianode |awk '{print $2}'`; do
        if [[ $node != $iAm ]]; then
          pingtest $node
          ping=$?
          if [[ $ping == 0 ]]; then
            printAndLog "Rebooting $node..."
            ${TIAMBIN}/ia_powercontrol -c $node
          else
            printAndLog "Unable to reboot $node. Please reboot manually."
          fi
          sleep 60
        fi
      done
      printAndLog "Rebooting $node..."
      ${TIAMBIN}/ia_powercontrol -c $iAm
      printAndLog "Nodes may take several minutes to begin reboot."
      printAndLog "Script will now be ending..."
      exit 0

    else
      printAndLog "Please reboot nodes manually using ia_powercontrol as soon as possible for new configuration to become effective."
    fi
  fi
fi
