#!/bin/sh
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1
# *
# * (C) Copyright IBM Corp. 2011. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Usage: change_bond1_static.sh ip_address
#
# Description: This script is typically called from other scripts, ensuring that it will
#    have the correct command line arguments.  But it is also documented in the node repair
#    instructions, so we need to ensure that it does not make problematic configuration
#    changes if called with no arguments.  In a reapir scenario, this script must be run
#    for the following reason:  The cron job that runs on the iamconsole1 changes
#    the IP to static, but that cron job is disabled at the end of manufacturing. So if you
#    don't run that step the IP won't get set to static, and will be DHCP.
#
# Change Activity
#
# Name           Date         Change ID   Description
# Brad Trubey    01/06/2011   17476       Harden script to prevent config problems when no args passed
################################################################################

set -x

# Ensure that an argument was passed in before proceeding.
if [ "X$1" = "X" ]; then
   echo "This script requires an IP address or hostname as the first argument."
   exit 1
else
   echo "Setting IPADDR in /etc/sysconfig/network/ifcfg-bond1 to $1."
fi

BOND1_FILE=/etc/sysconfig/network/ifcfg-bond1

sed -i "s/^BOOTPROTO=.*$/BOOTPROTO='static'/" $BOND1_FILE
sed -i "s/^IPADDR=.*$/IPADDR='$1'/" $BOND1_FILE
sed -i "s/^NETMASK=.*$/NETMASK='255.255.248.0'/" $BOND1_FILE

exit 0
