#!/bin/bash
#
#******************************************************************************
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp.  2008  All Rights Reserved
#
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -----------------------------------------------------------------------------
# 
# =========================================================================
#
# Name: checkMirrorStatus.sh
#
# Change Log:
#  Date          developer             change
#  08/1/2008     Bryan Jen             Initial script creation
#  03/04/2010    Liming (Michael) Yu   Updated to use hostnames instead of
#                                      ip addresses
#  03/05/2010    Liming (Michael) Yu   Updated print and log messages; updated
#                                      error messages and exit codes
#  05/26/2010    Liming (Michael) Yu   Add date
#
#******************************************************************************


SMCLI="/usr/bin/SMcli"
ret=0

date "+%Y-%m-%d %H:%M:%S"

ssystems=(`cat /home/iaadmin/.tiam/application.properties |grep ds4k |cut -d= -f2`)
if [[ ${#ssystems[@]} -lt 2 ]]; then
  echo "ERROR(1): Invalid or missing data in the applications.properties file. Please correct and retry"
  date "+%Y-%m-%d %H:%M:%S"
  exit 1
fi 

i=0
while [ $i -lt ${#ssystems[@]} ]
do
  if [[ ${ssystems[$i]} =~ "disk_ctrl" ]]; then
    CTRLA=${ssystems[$i]}
  else
    echo "ERROR(2): Either an IP address or a hostname that does not start with \"disk_ctrl\" was found in applications.properties. Please correct and retry"
    date "+%Y-%m-%d %H:%M:%S"
    exit 2
  fi
  if [[ ${ssystems[$(($i+1))]} =~ "disk_ctrl" ]]; then
    CTRLB=${ssystems[$(($i+1))]}
  else
    echo "ERROR(3): Either an IP address or a hostname that does not start with \"disk_ctrl\" was found in applications.properties. Please correct and retry"
    date "+%Y-%m-%d %H:%M:%S"
    exit 3
  fi

  echo -e "\n===============Mirror Status for [${CTRLA} | ${CTRLB}]===============\n"
  LUNS=(`${SMCLI} ${CTRLA} ${CTRLB}  -c "show alllogicaldrives;" |grep -i "logical drive name" | grep -v "Mirror" | cut -d: -f2 | awk '{ print $1 }'`)
  WRITEMODE=(`${SMCLI} ${CTRLA} ${CTRLB}  -c "show storagesubsystem;" | grep -w "Write mode:" | awk '{print $3$4}'`)

  for (( x = 0 ; x < ${#LUNS[@]} ; x++ ));
  do
    #only care about LUNs with ia or util
    if [[ `echo ${LUNS[$x]} |grep -i ia` || `echo ${LUNS[$x]} |grep -i util` ]]; then      
      lunstate=`${SMCLI} ${CTRLA} ${CTRLB} -c "show remoteMirror localLogicalDrive [\"${LUNS[$x]}\"] synchronizationProgress;" |grep -i mirror | cut -d: -f2`
      lunwritemode=${WRITEMODE[$x]}
      consistent=`echo \"$lunwritemode\" |grep -i consistent >/dev/null; echo $?`
      if [ $consistent -eq 0 ]; then
         lunwritemode="Consistent Mirror Group"
      fi

      echo -e "${LUNS[$x]}: $lunstate\t\tWrite mode:\t$lunwritemode "
      if [[ `echo $cmd |grep -i fail` ]]; then
        echo "Checking remote mirror status of ${LUNS[$x]} failed!" 
        ret=$(($ret+1))
      fi
    fi 
  done

  i=$(($i+2))  
done

echo -e "\n=========================Mirror Status Check Complete========================\n"
date "+%Y-%m-%d %H:%M:%S"
exit $ret
