#!/bin/bash
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Filename: cleancores
#
# Component: RAS
#
# Description:
#    This file is the main driver for cleaning up the core files in the /tmp
#    directory, to prevent the filesystem from filling up with core files.  It
#    is scheduled to run daily from cron.
#
# Change history
#   Modifier         Date        CQ Change      Description
#   ---------------------------------------------------------------------------
#   Brad Trubey      12/01/2009  TIAMC00011019  Initial Creation
#------------------------------------------------------------------------------

# Keep the newest one of each type of core
echo "Pruning core files in /tmp"

# Iterate over the unique processes that dumped core
ls /tmp/core.* | cut -d"." -f2 | uniq | while read processname; do
    corefilenameprefix="/tmp/core."$processname"."

    # Figure out the one we want to keep by listing files in order and taking the top one.
    keeper=`ls -t "$corefilenameprefix"* | head -1`

    # Iterate over all of cores for this process except the keeper and delete them
    ls "/tmp/core.$processname."* | grep -v "$keeper" | while read del_processname; do
        echo "`date` Multiple core files from $processname.  Removing oldest: $del_processname"     >> /var/opt/tivoli/tiam/log/prunecore.log
        rm -f "$del_processname"
    done
done


TOTAL_CORES_MAX=7

# Now, keep at most TOTAL_CORES_MAX different cores. Keep the newest
num_kept=0
ls -t /tmp/core.* | while read corefilename; do
    if [ $num_kept -ge $TOTAL_CORES_MAX ]; then
        echo "`date` More than $TOTAL_CORES_MAX core files.  Removing $corefilename"     >> /var/opt/tivoli/tiam/log/prunecore.log
        rm -f "$corefilename"
    fi
    num_kept=$((num_kept+1))
done
