#!/usr/bin/perl

##############################################################
# collect.pl [fsck]                                          #
# Used to get information about customer system              #
#                                                            #
# Version 0.2 ; 2003-04-03                                   #
# Version 0.3 ; 2003-04-24                                   #
# Version 0.4 ; 2003-04-24                                   #
# Version 0.5 ; 2003-10-29                                   #
# Version 0.6 ; 2003-11-03 added fsck parameter, modified    #
#               solaris commandline output                   #
# Version 0.7 ; 2005-11-09 added GPFS output for aix+linux   #
# Version 0.7.1 ; 2007-03-13 added oslevel -r output for aix #
#                            addes /usr/sbin/emgr -l for aix #
#
# IA Customizations:
#   Brad Trubey   08/13/2009   TIAMC00007910  Comment out the "press enter" prompt
#                 to facilitate automation, and change the destination directory.
##############################################################

my $VERSION = "0.7.1";

#######################
#######################
#                     #
# START: BASE SECTION #
#                     #
#######################
#######################


my $ERRORFILENAME = "collect.error";
my $TEMPFILENAME  = "collect.temp";
my $dsm_config;
my $dsm_dir;
my $dsm_dir_default;
my $i;
my $nexttoo;
my $OSid;
my $OSname;
my @outfile;    #ALL collected information is stored in @outfile
my @outtemp;
my $s;

#####################################################################
# the sub errorhandling appends the standard-error-msgs to @outfile #
# it is called after running a shell-command containing the         #
# redirection "2> $ERRORFILENAME"                                   #
#####################################################################

sub errorhandling{
  my $rc  = $?;
  my $return;

  if ($rc != 0) {
    push @outfile, "\n<!-- ERROR OCCURED --><PRE><font color=#ff0000>\n\n";
    push @outfile, "Return code: $rc\n";

    if(open(ERRORFILE, $ERRORFILENAME)){
      push @outfile, <ERRORFILE>;
      close(ERRORFILE);
    }

    push @outfile, "\n<!-- ERROR OCCURED --></font></PRE>\n";
  }

  return $return;
}

print "##############################################################\n";
print "# This script will collect information about your system     #\n";
print "# and writes it to a file called \"collect.data.html\".        #\n";
print "#                                                            #\n";
print "# Please review this file to assure, that no confidential    #\n";
print "# data is transferred to IBM.                                #\n";
print "##############################################################\n";
#print "\nPress ENTER to continue or type \"no\" to abort.\n>";


#chop($s = <STDIN>);
#if($s ne ""){
#  die print "Aborted";
#}


# get name of Operating System
 # expected "AIX", "Linux", "SunOS", "HP-UX", "OSF1", "IRIX", "IRIX64"
chop($OSname = `uname`);

print "found \'$OSname\'\n";
#---



# set $OSid by following table
 # 10 | "AIX"
 # 20 | "Linux"
 # 30 | "SunOS"
 # 40 | "HP-UX"
 # 50 | "OSF1"
 # 60 / "IRIX"
 # 61 | "IRIX64"

SWITCH: {
  if ($OSname eq "AIX")   { $OSid = 10; last SWITCH; }
  if ($OSname eq "Linux") { $OSid = 20; last SWITCH; }
  if ($OSname eq "SunOS") { $OSid = 30; last SWITCH; }
  if ($OSname eq "HP-UX") { $OSid = 40; last SWITCH; }
  if ($OSname eq "OSF1")  { $OSid = 50; last SWITCH; }
  if ($OSname eq "IRIX")  { $OSid = 60; last SWITCH; }
  if ($OSname eq "IRIX64"){ $OSid = 61; last SWITCH; }
  die print "\n Operating System \'$OSname\' not supported!\n";
}
#---



# append html head and instructions to @outfile
push @outfile, "<html>\n<head>\n</head>\n<body>\n\n\n\n";

push @outfile, "\n\n\n<!-- ########################################### --> <h1>\n\n";
push @outfile, "     Instructions\n\n";
push @outfile, "<!-- ########################################### --> </h2><PRE>\n\n";

push @outfile,

"This file contains all information collected by collect.pl. You can view this file either with a text editor or a web-browser.

All executed shell-commands and their output are listed here. If there is output containing confidential data, feel free to delete these lines. Please mark every deletion by adding a line like \"(deleted)\".

Please do not delete any line outsite of \"< !-- OUTPUT -->< PRE>\"  and \"< !-- OUTPUT -->< /PRE>\".


";

push @outfile, "\n</PRE><!-- -------------- --> <hr> <!-- -------------- -->\n";
#---


push @outfile, "\n\n\n<!-- ########################################### -->  <h1> <a name=\"top\">\n\n";
push @outfile, "     Collected Information - Table of contents\n\n";
push @outfile, "<!-- ########################################### -->  </h1><!--\n\n";

# append table of contents for view in text editor to @outfile
push @outfile, "


TSM specific information

-> Installed TSM-Packages and Versions
-> TSM Packages installation accuracy
-> TSM-Client Version
-> environment variables DSM_DIR, DSM_CONFIG, DSM_LOG
-> Content of configuration files dsm.opt and dsm.sys
-> Content of log files dsmerror.log and dsmj.log
-> HSM specific information
-> GPFS specific information

Operating System and Hardware

-> Version of Operating System
-> Bitmode
-> output of ulimit -a
-> File system ( Space and mounted file systems)
-> File system consistency
-> memory usage
-> cpu usage
-> cpu information
-> date of last reboot
-> processes-information
-> installed java-packages
-> java-installations and versions
-> user-information

Operating System specific information

-> Solaris / HP-UX: List of all installed packages
-> Solaris: List of all installed patches
-> Solaris: Kernel messages
-> Solaris: Size of TSM libraries and executables + link
-> Solaris: Settings of network card(s)

---------------------------- -->\n";
#---

# append table of contents for view in webbrowser to @outfile
push @outfile, "\n\n<!-- ------------- The following lines are for view in browser ------------- -->\n\n";

push @outfile, "<a href=\"#TSM\">TSM specific information</a>\n";

push @outfile, "<UL>\n";
push @outfile, "<LI><a href=\"#TSM-Packages\">Installed TSM-Packages and Versions</a></LI>\n";
push @outfile, "<LI><a href=\"#TSM-Packages2\">TSM Packages installation accuracy</a></LI>\n";
push @outfile, "<LI><a href=\"#TSM-Client_Version\">TSM-Client Version</a></LI>\n";
push @outfile, "<LI><a href=\"#environment\">environment variables DSM_DIR, DSM_CONFIG, DSM_LOG</a></LI>\n";
push @outfile, "<LI><a href=\"#tsmconfigfiles\">Content of configuration files dsm.opt and dsm.sys</a></LI>\n";
push @outfile, "<LI><a href=\"#tsmlogfiles\">Content of log files dsmerror.log and dsmj.log</a></LI>\n";
push @outfile, "<LI><a href=\"#hsm\">HSM specific information</a></LI>\n";
push @outfile, "<LI><a href=\"#gpfs\">GPFS specific information</a></LI>\n";
push @outfile, "</UL>\n";

push @outfile, "<a href=\"#Operating_System_and_Hardware\">Operating System and Hardware</a>\n";

push @outfile, "<UL>\n";
push @outfile, "<LI><a href=\"#Version_of_Operating_System\">Version of Operating System</a></LI>\n";
push @outfile, "<LI><a href=\"#Bitmode\">Bitmode</a></LI>\n";
push @outfile, "<LI><a href=\"#output_of_ulimita\">output of ulimit -a</a></LI>\n";
push @outfile, "<LI><a href=\"#File_system1\">File system ( Space and mounted file systems)</a></LI>\n";
push @outfile, "<LI><a href=\"#file_system_consistency\">file system consistency</a></LI>\n";
push @outfile, "<LI><a href=\"#memory_usage\">memory usage</a></LI>\n";
push @outfile, "<LI><a href=\"#cpu_usage\">cpu usage</a></LI>\n";
push @outfile, "<LI><a href=\"#cpu_information\">cpu information</a></LI>\n";
push @outfile, "<LI><a href=\"#date_of_last_reboot\">date of last reboot</a></LI>\n";
push @outfile, "<LI><a href=\"#processes-information\">processes-information</a></LI>\n";
push @outfile, "<LI><a href=\"#java1\">installed java-packages</a></LI>\n";
push @outfile, "<LI><a href=\"#java2\">java-installations and versions</a></LI>\n";
push @outfile, "<LI><a href=\"#user-information\">user-information</a></LI>\n";
push @outfile, "</UL>\n";

push @outfile, "<a href=\"#Operating_System_specific_information\">Operating System specific information</a>\n";

push @outfile, "</a>\n";

push @outfile, "<UL>\n";
push @outfile, "<LI><a href=\"#list_of_all_installed_packages\">Solaris / HP: List of all installed packages</a></LI>\n";
push @outfile, "<LI><a href=\"#list_of_all_installed_patches\">Solaris: List of all installed patches</a></LI>\n";
push @outfile, "<LI><a href=\"#kernel_messages\">Solaris: Kernel messages</a></LI>\n";
push @outfile, "<LI><a href=\"#Size_of_TSM_libraries_and_executables_link\">Solaris: Size of TSM libraries and executables + link</a></LI>\n";
push @outfile, "<LI><a href=\"#Settings_of_network_cards\">Solaris: Settings of network card(s)</a></LI>\n";
push @outfile, "</UL>\n";

push @outfile, "\n<!-- -------------- --> <hr> <!-- -------------- -->\n";
#---


#####################
#####################
#                   #
# END: BASE SECTION #
#                   #
#####################
#####################



###########################
###########################
#                         #
# START: COLLECT SECTIONS #
#                         #
###########################
###########################


#*****************************************
#*****************************************
#**  START: TSM specific information    **
#*****************************************
#*****************************************


push @outfile, "\n\n\n\n<!-- ########################################### --> <a name=\"TSM\"> <h1>\n\n";
push @outfile, "     TSM specific information\n\n";
push @outfile, "<!-- ########################################### -->  </h1>\n\n";


#*********************************************
#*    Installed TSM-Packages and Versions    *
#*********************************************

#################################################
# append all installed TSM-Packages to @outfile #
#################################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"TSM-Packages\"> <h2>\n\n";
push @outfile, "     Installed TSM-Packages and Versions\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting installed TSM-Packages...\n";

SWITCH: {
  if ($OSid == 10 ){                  # AIX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: lslpp -L '*[Tt][Ss][Mm].[Cc][Ll][Ii][Ee][Nn][Tt]*'\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, ` lslpp -L '*[Tt][Ss][Mm].[Cc][Ll][Ii][Ee][Nn][Tt]*'`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: rpm -qa | grep TIVsm\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    @outtemp = `rpm -qa | grep TIVsm`;
    push @outfile, "@outtemp\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    foreach $s (@outtemp){
      push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
      push @outfile, "Executing: rpm -qi $s\n";
      push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

      push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      push @outfile, `rpm -qi $s`."\n";
      push @outfile, "\n<!-- OUTPUT --></PRE>\n";
      push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";
    }

    last SWITCH;
  }
  if ($OSid == 30){                  # SunOS
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: pkginfo -x (Note: only the TIV-packages were added to output-file)\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
       #the following command shows all installed packages
       #there are two lines per package.
       #in the second line you can find the version
      @outtemp = `pkginfo -x`;
      # append every line containing TIVsm and the following line (=version) to @outtemp
      $nexttoo = "";

      foreach $s (@outtemp){
        if($nexttoo){
          push @outfile, $s;
          $nexttoo = 0;
        }
        elsif($s =~ /TIVsm/){
          push @outfile, $s;
          $nexttoo = 1;
        }
      }
      #---
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: pkginfo | grep TIVsm (Note: the output is not added to outfile but processed by the script)\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    #push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    @outtemp = `pkginfo | grep TIVsm`;
    #push @outfile, "@outtemp\n";
    #push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    foreach $s (@outtemp){
      $s = (split(' ', $s))[1];
      push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
      push @outfile, "Executing: pkginfo -l $s\n";
      push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

      push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      push @outfile, `pkginfo -l $s`."\n";
      push @outfile, "\n<!-- OUTPUT --></PRE>\n";
      push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";
    }


    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: swlist TIVsm\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `swlist TIVsm`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: setld -i | grep [Tt][Ii][Vv][Ss][Mm]\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `setld -i | grep [Tt][Ii][Vv][Ss][Mm]`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: versions TSM\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `versions TSM`;
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
}

print "...Done\n";



#*******************************************
#*    TSM Packages installation accuracy   *
#*******************************************

########################################################
# append TSM Packages installation accuracy to @outfile #
#########################################################

push @outfile, "\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"TSM-Packages2\"> <h2>\n\n";
push @outfile, "     TSM Packages installation accuracy\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "checking TSM Packages installation accuracy...\n";

SWITCH: {
  if ($OSid == 10 ){                  # AIX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing:  lslpp -f '*[Tt][Ss][Mm].[Cc][Ll][Ii][Ee][Nn][Tt]*' 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, ` lslpp -f '*[Tt][Ss][Mm].[Cc][Ll][Ii][Ee][Nn][Tt]*' 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: rpm -qa | grep TIVsm  (Note: the output is not added to outfile but processed by the script)\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    @outtemp = `rpm -qa | grep TIVsm`;
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    foreach $s (@outtemp){
      push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
      push @outfile, "Executing: rpm -V $s\n";
      push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

      push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      push @outfile, `rpm -V $s`."\n";
      push @outfile, "\n<!-- OUTPUT --></PRE>\n";
      push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";
    }

    last SWITCH;
  }
  if ($OSid == 30){                  # SunOS
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: pkginfo | grep TIVsm (Note: the output is not added to outfile but processed by the script)\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    @outtemp = `pkginfo | grep TIVsm`;
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    foreach $s (@outtemp){
      $s = (split(' ', $s))[1];
      push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
      push @outfile, "Executing: pkgchk $s 2> $ERRORFILENAME\n";
      push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

      push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      push @outfile, `pkgchk $s 2> $ERRORFILENAME`."\n";
      push @outfile, "\n<!-- OUTPUT --></PRE>\n";
      errorhandling();
      push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";
    }

    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: swlist -l file TIVsm 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `swlist -l file TIVsm 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: setld -i | grep [Tt][Ii][Vv][Ss][Mm] (Note: the output is not added to outfile but processed by the script)\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    @outtemp = `setld -i | grep [Tt][Ii][Vv][Ss][Mm]`;
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    foreach $s (@outtemp){
      $s = (split(' ', $s))[0];
      push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
      push @outfile, "Executing: setld -i $s\n";
      push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

      push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      push @outfile, `setld -i $s`."\n";
      push @outfile, "\n<!-- OUTPUT --></PRE>\n";
      push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";
    }


    last SWITCH;
  }
  if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: versions long TSM\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `versions long TSM`;
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
}

print "...Done\n";

#****************************
#*    TSM-Client Version    *
#****************************

#####################################
# append Client-Version to @outfile #
#####################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"TSM-Client_Version\"> <h2>\n\n";
push @outfile, "     TSM-Client Version\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting TSM BA Client Version...\n";

push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
push @outfile, "Executing: dsmc quit 2> $ERRORFILENAME\n";
push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
push @outfile, `dsmc quit 2> $ERRORFILENAME`."\n";
push @outfile, "\n<!-- OUTPUT --></PRE>\n";
errorhandling();
push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

print "...Done\n";

#************************************************************
#*    environment variables DSM_DIR, DSM_CONFIG, DSM_LOG    *
#************************************************************

########################################################################
# append environment variables DSM_DIR, DSM_CONFIG, DSM_LOG to @outfile #
########################################################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"environment\"> <h2>\n\n";
push @outfile, "     environment variables DSM_DIR, DSM_CONFIG, DSM_LOG\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting environtment variables DSM_OPT, DSM_CONFIG, DSM_LOG...\n";

push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
push @outfile, "Executing (Perl): \$ENV{'DSM_CONFIG'}\n";
push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
push @outfile, "$ENV{'DSM_CONFIG'}\n";
push @outfile, "\n<!-- OUTPUT --></PRE>\n";
push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
push @outfile, "Executing (Perl): \$ENV{'DSM_DIR'}\n";
push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
push @outfile, "$ENV{'DSM_DIR'}\n";
push @outfile, "\n<!-- OUTPUT --></PRE>\n";
push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
push @outfile, "Executing (Perl): \$ENV{'DSM_LOG'}\n";
push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
push @outfile, "$ENV{'DSM_LOG'}\n";
push @outfile, "\n<!-- OUTPUT --></PRE>\n";
push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


print "...Done\n";


#************************************************************
#*    Content of configuration files dsm.opt and dsm.sys    *
#************************************************************

##################################
# content of dsm.opt and dsm.sys #
##################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"tsmconfigfiles\"> <h2>\n\n";
push @outfile, "     Content of configuration files dsm.opt and dsm.sys\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

# save values of $ENV{'DSM_CONFIG'} and $ENV{'DSM_DIR'} in $dsm_config and $dsm_dir
# if these variables are empty, fill them with default values according to OS

  #set default values
SWITCH: {
  if ($OSid == 10 ){                  # AIX
    $dsm_dir_default = "/usr/tivoli/tsm/client/ba/bin";
    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    $dsm_dir_default = "/opt/tivoli/tsm/client/ba/bin";
    last SWITCH;
  }
  if ($OSid == 30){                  # SunOS
    $dsm_dir_default = "/opt/tivoli/tsm/client/ba/bin";
    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    $dsm_dir_default = "/opt/tivoli/tsm/client/ba/bin";
    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    $dsm_dir_default = "/usr/tivoli/tsm/client/ba/bin";
    last SWITCH;
  }
  if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
    $dsm_dir_default = "/usr/tivoli/tsm/client/ba/bin";
    last SWITCH;
  }
}
  #---

$dsm_config = $ENV{'DSM_CONFIG'};
$dsm_dir    = $ENV{'DSM_DIR'};

if($dsm_dir eq ""){
  $dsm_dir = $dsm_dir_default;
}

if($dsm_config eq ""){
  $dsm_config = "$dsm_dir/dsm.opt";
}

#---

#append the content of dsm.opt ($dsm_config) to @outfile
print "reading content of configuration file \"dsm.opt\"...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: cat $dsm_config 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `cat $dsm_config 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

print "...Done\n";
#---



#append the content of file $dsm_dir/dsm.sys to @outfile
print "reading content of configuration file \"dsm.sys\"...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: cat $dsm_dir/dsm.sys 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `cat $dsm_dir/dsm.sys 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

print "...Done\n";
#---

#********************************************************
#*    Content of log files dsmerror.log and dsmj.log    *
#********************************************************

########################################
# content of dsmerror.log and dsmj.log #
########################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"tsmlogfiles\"> <h2>\n\n";
push @outfile, "     Content of log files dsmerror.log and dsmj.log\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

#append the content of $dsm_dir/dsmerror.log to @outfile
print "reading content of log file \"$dsm_dir/dsmerror.log\"...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: cat $dsm_dir/dsmerror.log 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `cat $dsm_dir/dsmerror.log 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

print "...Done\n";
#---

#append the content of file $dsm_dir/dsmj.log to @outfile
print "reading content of log file \"$dsm_dir/dsmj.log\"...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: cat $dsm_dir/dsmj.log 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `cat $dsm_dir/dsmj.log 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

print "...Done\n";
#---

#if $dsm_dir equals $dsm_dir_default, skip the next two commands
if($dsm_dir ne $dsm_dir_default){
  #append the content of $dsm_dir_default/dsmerror.log to @outfile
  print "reading content of default log file \"$dsm_dir_default/dsmerror.log\"...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: cat $dsm_dir_default/dsmerror.log 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `cat $dsm_dir_default/dsmerror.log 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

  print "...Done\n";
  #---


  #append the content of $dsm_dir_default/dsmj.log to @outfile
  print "reading content of default log file \"$dsm_dir_default/dsmj.log\"...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: cat $dsm_dir_default/dsmj.log 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `cat $dsm_dir_default/dsmj.log 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

  print "...Done\n";
  #---
}
#---


#*********************************
#*    HSM specific information   *
#*********************************

################################################
## append HSM specific information to @outfile #
################################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"hsm\"> <h2>\n\n";
push @outfile, "     HSM specific information \n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting HSM specific information...\n";


push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
push @outfile, "Executing: dsmmigquery 2>&1\n";
push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
push @outfile, `dsmmigquery 2>&1`."\n";
push @outfile, "\n<!-- OUTPUT --></PRE>\n";
push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

if(($?==-1) or ($?==32512) ){ # return code: "command not found" or ($?==127) or ($?==256)
  # do nothing
}else{
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing:  dsmmigfs q -detail 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `dsmmigfs q -detail 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: dsmmigfs q -f  2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `dsmmigfs q -f  2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: dsmdf  2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `dsmdf  2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ls -lR /etc/adsm/SpaceMan  2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ls -lR /etc/adsm/SpaceMan  2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: dsmmigquery -o 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `dsmmigquery -o 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: dsmmigquery -mgmt -detail 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `dsmmigquery -mgmt -detail 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";
}

print "...Done\n";


#*********************************
#*    GPFS specific information   *
#*********************************

################################################
## append GPFS specific information to @outfile #
################################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"gpfs\"> <h2>\n\n";
push @outfile, "     GPFS specific information \n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting GPFS specific information...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: /usr/lpp/mmfs/bin/mmfsadm dump version  2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `/usr/lpp/mmfs/bin/mmfsadm dump version  2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";



if(($?==-1) or ($?==32512) ){ # return code: "command not found" or ($?==127) or ($?==256)
  # do nothing
}else{
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: /usr/lpp/mmfs/bin/mmlscluster 2>&1\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `/usr/lpp/mmfs/bin/mmlscluster 2> $ERRORFILENAME`."\n";   # >&1
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing:  /usr/lpp/mmfs/bin/mmlsconfig 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `/usr/lpp/mmfs/bin/mmlsconfig 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: /usr/lpp/mmfs/bin/mmfsadm dump dmapi  2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `/usr/lpp/mmfs/bin/mmfsadm dump dmapi  2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    if ($OSid == 10 ){                  # AIX
        push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
        push @outfile, "Executing: lslpp -l | grep gpfs  2> $ERRORFILENAME\n";
        push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

        push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
        push @outfile, `lslpp -l | grep -E \"mmfs|gpfs\"  2> $ERRORFILENAME`."\n";
        push @outfile, "\n<!-- OUTPUT --></PRE>\n";
        errorhandling();
        push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";
    }

    if ($OSid == 20){                  # Linux
        push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
        push @outfile, "Executing: rpm -qa | grep gpfs   2> $ERRORFILENAME\n";
        push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

        push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
        push @outfile, `rpm -qa | grep gpfs   2> $ERRORFILENAME`."\n";
        push @outfile, "\n<!-- OUTPUT --></PRE>\n";
        errorhandling();
        push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";
    }

}

print "...Done\n";

#***************************************
#***************************************
#**  END: TSM specific information    **
#***************************************
#***************************************


#**********************************************
#**********************************************
#**  START: Operating System and Hardware    **
#**********************************************
#**********************************************


push @outfile, "\n\n\n<!-- ########################################### --> <a name=\"Operating_System_and_Hardware\"><h1>\n\n";
push @outfile, "     Operating System and Hardware\n\n";
push @outfile, "<!-- ########################################### -->  </h1>\n\n";


#************************************
#*  Version of Operating System     *
#*********************+**************

#####################################
# append OS information to @outfile #
#####################################

push @outfile, "\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  <a name=\"Version_of_Operating_System\"> <h2>\n\n";
push @outfile, "     Version of Operating System\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting OS information...\n";

SWITCH: {
  if ($OSid == 10 ){                  # AIX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: uname -a\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `uname -a`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: oslevel -s\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `oslevel -s`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: oslevel\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `oslevel`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";

    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: uname -a\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `uname -a`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: cat /etc/issue\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `cat /etc/issue`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 30){                  # SunOS
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: uname -a\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `uname -a`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: cat /etc/release\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `cat /etc/release`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: uname -a\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `uname -a`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: model\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `model`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: uname -a\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `uname -a`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: uname -a\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `uname -a`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: uname -R\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `uname -R`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
}

print "...Done\n";


#*****************
#*    Bitmode    *
#*****************

###############################
# append bit mode to @outfile #
###############################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"Bitmode\"> <h2>\n\n";
push @outfile, "     Bitmode\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting bit mode...\n";

SWITCH: {
  if ($OSid == 10 ){                  # AIX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ls -la / (Note: the output is not added to outfile but processed by the script) \n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n";
      @outtemp = `ls -la /`;
      foreach $s (@outtemp){
        if($s =~ /unix ->/){
          chop($s);
          if(substr($s,-2) eq "64") {
            push @outfile, "64 Bit\n";
          }
          elsif( (substr($s,-2) eq "mp") or (substr($s,-2) eq "up") ) {
            push @outfile, "32 Bit\n";
          }
          else {
            push @outfile, "(unknown)\n";
          };
        }
      }
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: getconf LONG_BIT\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n";
    push @outfile, `getconf LONG_BIT`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 30){                  # SunOS
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n";
    push @outfile, "Executing: isainfo -b\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n";
    push @outfile, `isainfo -b`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n";
    push @outfile, "Executing: getconf KERNEL_BITS\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n";
    push @outfile, `getconf KERNEL_BITS`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    push @outfile, "\n= always 64 Bit =\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 60){                  #IRIX
    push @outfile, "\n<!-- OUTPUT --><PRE>\n";
    push @outfile, "\n$OSname is always 32 Bit\n\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 61){                  #IRIX64
    push @outfile, "\n<!-- OUTPUT --><PRE>\n";
    push @outfile, "\n$OSname is always 64 Bit\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
}

print "...Done\n";


#*******************************
#*    output of "ulimit -a"    *
#*******************************

##########################################################
# append information returned by "ulimit -a" to @outfile #
##########################################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"output_of_ulimita\"> <h2>\n\n";
push @outfile, "     output of \"ulimit -a\"\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting information returned by \'ulimit -a\'...\n";

SWITCH: {
  if ($OSid == 10 ){                  # AIX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ulimit -a\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ulimit -a`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ulimit -a >&1\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";


    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ulimit -a >&1`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 30){                  # SunOS
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ulimit -a\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ulimit -a`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ulimit -a\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ulimit -a`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ulimit -a\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ulimit -a`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ulimit -a\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ulimit -a`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
}

print "...Done\n";


#*******************************************************
#*    File system ( Space and mounted file systems)    *
#*******************************************************

#######################################################
# append information about the file system to @outfile #
#######################################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"File_system1\"> <h2>\n\n";
push @outfile, "     File system ( Space and mounted file systems)\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";


print "reading file system information...\n";

SWITCH: {
  if ($OSid == 10 ){                  # AIX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: df -k 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `df -k 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: mount 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `mount 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: df -k 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `df -k 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: mount 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `mount 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 30){                  # SunOS
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: df -k 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `df -k 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: mount -p 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `mount -p 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: df -b 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `df -b 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: df> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `df 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: mount 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `mount 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: df -k 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `df -k 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: mount 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `mount 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: df -k 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `df -k 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: mount -p 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `mount -p 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
}

print "...Done\n";


#*********************************
#*    file system consistency    *
#*********************************

################################################
# append file system consistency to @outfile #
################################################

push @outfile, "\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"file_system_consistency\"> <h2>\n\n";
push @outfile, "     file system consistency\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "checking file system consistency...\n";

#print " The following operating will check the consistency of all file\n";
#print " systems. No changes will be done to the system. This operation\n";
#print " might take much time.\n";
#print " Do you want to skip it?\n";
#print " (yes/no)>";

# chop($s = <STDIN>);
if ($ARGV[0]=~/fsck/i) {$s="n";} else {$s="y";} # decide whether to skip fsck or not
if(($s eq "n") or ($s eq "no") or ($s eq "N")){
  SWITCH: {
    if ($OSid == 10 ){                  # AIX
      push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
      push @outfile, "Executing: fsck -n 2> $ERRORFILENAME\n";
      push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

      push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      push @outfile, `fsck -n 2> $ERRORFILENAME`."\n";
      push @outfile, "\n<!-- OUTPUT --></PRE>\n";
      errorhandling();
      push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

      last SWITCH;
    }
    if ($OSid == 20){                  # Linux
      push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
      push @outfile, "Executing: fsck -AN 2> $ERRORFILENAME\n";
      push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

      push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      push @outfile, `fsck -AN 2> $ERRORFILENAME`."\n";
      push @outfile, "\n<!-- OUTPUT --></PRE>\n";
      errorhandling();
      push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

      last SWITCH;
    }
    if ($OSid == 30){                  # SunOS
      push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
      push @outfile, "Executing: fsck -N 2> $ERRORFILENAME\n";
      push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

      push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      push @outfile, `fsck -N 2> $ERRORFILENAME`."\n";
      push @outfile, "\n<!-- OUTPUT --></PRE>\n";
      errorhandling();
      push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

      last SWITCH;
    }
    if ($OSid == 40){                  # HP-UX
      push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
      push @outfile, "Executing: fsck -N 2> $ERRORFILENAME\n";
      push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

      push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      push @outfile, `fsck -N 2> $ERRORFILENAME`."\n";
      push @outfile, "\n<!-- OUTPUT --></PRE>\n";
      errorhandling();
      push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

      last SWITCH;
    }
   if ($OSid == 50){                  # OSF1
      push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
      push @outfile, "Executing: fsck -n 2> $ERRORFILENAME\n";
      push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

      push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      push @outfile, `fsck -n 2> $ERRORFILENAME`."\n";
      push @outfile, "\n<!-- OUTPUT --></PRE>\n";
      errorhandling();
      push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

      last SWITCH;
    }
    if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
      push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
      push @outfile, "Executing: df (Note: the output is not added to outfile but processed by the script)\n";
      push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

      @outtemp = `df`;
      push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

      foreach $s (@outtemp){

        next if ((split(' ', $s))[1] ne "xfs");

        $s = (split(' ', $s))[0];
        push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
        push @outfile, "Executing: xfs_repair -n $s 2> $ERRORFILENAME\n";
        push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

        push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
        #push @outfile, `xfs_repair -n $s 2> $ERRORFILENAME`."\n";
        push @outfile, "\n<!-- OUTPUT --></PRE>\n";
        errorhandling();
        push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";
      }

      last SWITCH;
    }
  }

  print "...Done\n";
}
else{
  push @outfile, "= Skipped =\n";
  push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";
  print "...Skipped\n";
}


#**********************
#*    memory usage    *
#**********************

###################################
# append memory usage to @outfile #
###################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"memory_usage\"> <h2>\n\n";
push @outfile, "     memory usage\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting memory usage...\n";

SWITCH: {
  if ($OSid == 10 ){                  # AIX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: svmon 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `svmon 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: free\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `free`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: cat /proc/meminfo\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `cat /proc/meminfo`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 30){                  # SunOS
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: prstat 2 1";     # > $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `prstat 2 1";                # > $ERRORFILENAME`;
    push @outfile, "\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: top -d 1 -f $TEMPFILENAME (Note: output was modified by script and collect.temp was removed afterwards)\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      `top -d 1 -f $TEMPFILENAME`;

      if(open(TEMPFILE, $TEMPFILENAME)){

        foreach $s (<TEMPFILE>){
          if($s =~ /Memory/){
            push @outfile, $s;
            last;
          }
         }
        close(TEMPFILE);
      }
      `rm $TEMPFILENAME 2> /dev/null`;
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: vmstat -P 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `vmstat -P 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    last SWITCH;
  }
  if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: top -d 1 >&1 (Note: output was modified by script)\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      @outtemp = `top -d 1 >&1`;
      foreach $s (@outtemp){
        if($s =~ /Memory/){
          push @outfile, $s;
          last;
        }
      }
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
}

print "...Done\n";


#*******************
#*    cpu usage    *
#*******************

###############################
# append cpu usage to outfile #
###############################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"cpu_usage\"> <h2>\n\n";
push @outfile, "     cpu usage\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting cpu usage...\n";

push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
push @outfile, "Executing: uptime\n";
push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
push @outfile, `uptime`."\n";
push @outfile, "\n<!-- OUTPUT --></PRE>\n";
push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

print "...Done\n";


#*************************
#*    cpu information    *
#*************************

######################################
# append cpu-information to @outfile #
######################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"cpu_information\"> <h2>\n\n";
push @outfile, "     cpu information\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting cpu-information...\n";

SWITCH: {
  if ($OSid == 10 ){                  # AIX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: lsdev -Cc processor 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `lsdev -Cc processor 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: cat /proc/cpuinfo 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `cat /proc/cpuinfo 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 30){                  # SunOS
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: psrinfo -v";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `psrinfo -v`;
    push @outfile, "\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ioscan -fnC processor 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ioscan -fnC processor 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: psrinfo -v";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `psrinfo -v`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: hinv -c processor 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `hinv -c processor 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
}

print "...Done\n";


#*****************************
#*    date of last reboot    *
#*****************************

################################################
# append date of last reboot to @outfile #
################################################

push @outfile, "\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"date_of_last_reboot\"> <h2>\n\n";
push @outfile, "     date of last reboot\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting date of last reboot...\n";

SWITCH: {
  if ($OSid == 10 ){                  # AIX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: who -b\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `who -b`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: uptime\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `uptime`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 30){                  # SunOS
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: who -b\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `who -b`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: who -b\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `who -b`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: who -b\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `who -b`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: who -b\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `who -b`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
}

print "...Done\n";



#*******************************
#*    processes-information    *
#*******************************

############################################
# append processes-information to @outfile #
############################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"processes-information\"> <h2>\n\n";
push @outfile, "     processes-information\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting processes-information...\n";


SWITCH: {
  if ($OSid == 10 ){                  # AIX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ps -ef\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ps -ef`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ps -ef\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ps -ef`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: top -n 1 -b\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `top -n 1 -b`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 30){                  # SunOS
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ps -ef\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ps -ef`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ps -ef\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ps -ef`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: top -d 1 -n 500 -f $TEMPFILENAME  (Note: $TEMPFILENAME was removed afterwards)\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      `top -d 1 -n 500 -f $TEMPFILENAME`;

      if(open(TEMPFILE, $TEMPFILENAME)){
        push @outfile, <TEMPFILE>;
        close(TEMPFILE);
      }
      `rm $TEMPFILENAME 2> /dev/null`;
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ps -ef\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ps -ef`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ps -ef\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ps -ef`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: top -d 1\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `top -d 1`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
}

print "...Done\n";



#*********************************
#*    installed java-packages    *
#*********************************

##############################################
# append installed java-packaces to @outfile #
##############################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"java1\"> <h2>\n\n";
push @outfile, "     installed java-packages\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting installed java-packages...\n";


SWITCH: {
  if ($OSid == 10 ){                  # AIX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: lslpp -l '*[Jj[Aa][Vv][Aa]*'\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `lslpp -l '*[Jj[Aa][Vv][Aa]*'`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: rpm -qa | grep [Jj][Aa][Vv][Aa]\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `rpm -qa | grep [Jj][Aa][Vv][Aa]`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
 if ($OSid == 30){                  # SunOS
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: pkginfo -x (Note: only the java-packages were added to output-file)\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
       #the following command shows all installed packages
       #there are two lines per package.
       #in the second line you can find the version
      @outtemp = `pkginfo -x`;
      # append every line containing java (not case-sensitive) and the following line to @outtemp
      $nexttoo = "";
      foreach $s (@outtemp){
        if($nexttoo){
          push @outfile, $s;
          $nexttoo = 0;
        }
        elsif($s =~ /[Jj][Aa][Vv][Aa]/){
          push @outfile, $s;
          $nexttoo = 1;
        }
      }
      #---
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: swlist | grep [Jj][Aa][Vv][Aa]\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `swlist | grep [Jj][Aa][Vv][Aa]`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: setld -i | grep [Jj][Aa][Vv][Aa]\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `setld -i | grep [Jj][Aa][Vv][Aa]`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: versions > $TEMPFILENAME (Note: only the java-packages were added to output-file and $TEMPFILENAME was removed afterwards)\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
      `versions > $TEMPFILENAME`;

      if(open(TEMPFILE, $TEMPFILENAME)){
        foreach $s (<TEMPFILE>){
          if($s =~ /[Jj][Aa][Vv][Aa]/){
            push @outfile, $s;
          }
         }
        close(TEMPFILE);
      }
      `rm $TEMPFILENAME 2> /dev/null`;
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
}

print "...Done\n";


#****************************************
#*    java-installations and version    *
#****************************************

######################################################
# append java-installations and versions to @outfile #
######################################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"java2\"> <h2>\n\n";
push @outfile, "     java-installations and versions\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting java-versions...\n";

push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
push @outfile, "Executing: java -version 2>&1\n";
push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
push @outfile, `java -version 2>&1`."\n";
push @outfile, "\n<!-- OUTPUT --></PRE>\n";
push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

#find all files named "java" in directorys /usr/java*
push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
push @outfile, "Executing: find /usr/java* -name java (Note: the output is not added to outfile but processed by the script)\n";
push @outfile, "\n<!-- COMMAND --></b></PRE>\n";
push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

@outtemp = `find /usr/java* -name java`;

foreach $s (@outtemp){
  chop($s);
  #execute only, if there is /bin/java in path
  if($s =~ /bin\/java/){
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: $s -version 2>&1\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `$s -version 2>&1`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";
  }
}

print "...Done\n";

#**************************
#*    user-information    *
#**************************

#######################################
# append user-information to @outfile #
#######################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"user-information\"> <h2>\n\n";
push @outfile, "     user-information\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting user-information...\n";

push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
push @outfile, "Executing: cat /etc/passwd\n";
push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
push @outfile, `cat /etc/passwd`."\n";
push @outfile, "\n<!-- OUTPUT --></PRE>\n";
push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
push @outfile, "Executing: cat /etc/group\n";
push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
push @outfile, `cat /etc/group`."\n";
push @outfile, "\n<!-- OUTPUT --></PRE>\n";
push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

print "...Done\n";

#********************************************
#********************************************
#**  END: Operating System and Hardware    **
#********************************************
#********************************************


#******************************************************
#******************************************************
#**  START: Operation System specific information    **
#******************************************************
#******************************************************

push @outfile, "\n\n\n\n<!-- ########################################### --> <a name=\"Operating_System_specific_information\"><h1>\n\n";
push @outfile, "     Operation System specific information\n\n";
push @outfile, "<!-- ########################################### -->  </h1>\n\n";


######################################################################################
# the following lines collect different information depending on which OS is running #
######################################################################################

SWITCH: {
  if ($OSid == 10 ){                  # AIX
    print "getting list of all installed interim fixes...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: /usr/sbin/emgr -l\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `/usr/sbin/emgr -l`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    print "...Done\n";

    print "getting HACMP version if installed...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: lslpp -l cluster.license 'rsct.*.hacmp'\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `lslpp -l cluster.license \'rsct.*.hacmp\' 2>&1`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    print "...Done\n";

    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    push @outfile, "No $OSname specific information is needed.\n";
    push @outfile, "\n<!-- -------------- --> <br> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    # nothing to do

    last SWITCH;
  }
  if ($OSid == 30){                  # SunOS
    push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"list_of_all_installed_packages\"> <h2>\n\n";
    push @outfile, "     list of all installed packages\n\n";
    push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

    print "getting list of all installed packages...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: pkginfo -x\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `pkginfo -x`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    print "...Done\n";


    push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"list_of_all_installed_patches\"> <h2>\n\n";
    push @outfile, "     list of all installed patches\n\n";
    push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

    print "getting list of all installed patches...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: patchadd -p\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `patchadd -p`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    print "...Done\n";


    push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"kernel_messages\"> <h2>\n\n";
    push @outfile, "     kernel messages\n\n";
    push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

    print "reading kernel messages...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: cat /var/adm/messages*\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `cat /var/adm/messages*`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    print "...Done\n";


    push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"Size_of_TSM_libraries_and_executables_link\"> <h2>\n\n";
    push @outfile, "     Size of TSM libraries and executables + link\n\n";
    push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

    print "reading size of TSM libraries and executables...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ls -lR /opt/tivoli/tsm/client\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ls -lR /opt/tivoli/tsm/client`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    print "...Done\n";


    print "checking links to TSM...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ls -l /usr/lib/libApiDS.so 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ls -l /usr/lib/libApiDS.so 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";


    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: ls -l /usr/lib/sparcv9/libApiDS64.so 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `ls -l /usr/lib/sparcv9/libApiDS64.so 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    print "...Done\n";

    push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"Settings_of_network_cards\"> <h2>\n\n";
    push @outfile, "     Settings of network card(s)\n\n";
    push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

    print "checking settings of network card(s)...\n";

      push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
      push @outfile, "Executing: ifconfig -a | grep \"^hme|^qfe\" | cut -f1 -d: | uniq (Note: the output is not added to outfile but processed by the script)\n";  #egrep?
      push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

      # Get the list of hme or qfe interfaces on this machine.
      @outtemp = `ifconfig -a | grep "^hme|^qfe" | cut -f1 -d: | uniq`; # egrep?

      push @outfile, "\n<!-- -------------- --> <hr> <!-- -------------- -->\n";

      foreach $s (@outtemp){
        # Since we only grep'd for qfe and hme above, we know that the prefix is 3 chars long.
        my $type = substr($s,0,3);
        my $instance = substr($s,3,1);

        # Query for 10-Mbit or 100-Mbit, and half or full duplex.

        push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
        push @outfile, "Executing: ndd -get /dev/$type link_speed (Note: the output was modified by the script)\n";
        $s = `ndd -get /dev/$type link_speed`;
        push @outfile, "\n<!-- COMMAND --></b></PRE>\n";
        push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
        SWITCH: {
          if ($s == 0 ){ $s = "10-Mbit"; last SWITCH; }
          if ($s == 1 ){ $s = "100-Mbit"; last SWITCH; }
          $s = "$s (Unexpected value)"
        }
        push @outfile, "speed=$s\n";
        push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";


        push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
        push @outfile, "Executing: ndd -get /dev/$type link_mode (Note: the output was modified by the script)\n";
        $s = `ndd -get /dev/$type link_mode`;
        push @outfile, "\n<!-- COMMAND --></b></PRE>\n";
        push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
        SWITCH: {
          if ($s == 0 ){ $s = "half duplex"; last SWITCH; }
          if ($s == 1 ){ $s = "full duplex"; last SWITCH; }
          $s = "$s (Unexpected value)"
        }
        push @outfile, "mode=$s\n";
        push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";


        push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
        push @outfile, "Executing: ndd -get /dev/$type link_status (Note: the output was modified by the script)\n";
        $s = `ndd -get /dev/$type link_status`;
        push @outfile, "\n<!-- COMMAND --></b></PRE>\n";
        push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
        SWITCH: {
          if ($s == 0 ){ $s = "down"; last SWITCH; }
          if ($s == 1 ){ $s = "up"; last SWITCH; }
          $s = "$s (Unexpected value)"
        }
        push @outfile, "status=$s\n";
        push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";


        push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
        push @outfile, "Executing: ndd -get /dev/$type link_autoneg_cap (Note: the output was modified by the script)\n";
        $s = `ndd -get /dev/$type link_autoneg_cap`;
        push @outfile, "\n<!-- COMMAND --></b></PRE>\n";
        push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
        SWITCH: {
          if ($s == 0 ){ $s = "autonegotiation off"; last SWITCH; }
          if ($s == 1 ){ $s = "autonegotiation on"; last SWITCH; }
          $s = "$s (Unexpected value)"
        }
        push @outfile, "autoneg=$s\n";
        push @outfile, "\n<!-- OUTPUT --></PRE>\n";

        push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";
      }

    print "...Done\n";

    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"list_of_all_installed_packages\"> <h2>\n\n";
    push @outfile, "     list of all installed packages\n\n";
    push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

    print "getting list of all installed packages...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: swlist\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `swlist`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    print "...Done\n";

    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    push @outfile, "No $OSname specific information is needed.\n";
    push @outfile, "\n<!-- -------------- --> <br> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
    push @outfile, "No $OSname specific information is needed.\n";
    push @outfile, "\n<!-- -------------- --> <br> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
}

#****************************************************
#****************************************************
#**  END: Operation System specific information    **
#****************************************************
#****************************************************

#########################
#########################
#                       #
# END: COLLECT SECTIONS #
#                       #
#########################
#########################




########################
########################
#                      #
# START: FINAL SECTION #
#                      #
########################
########################



#########################################
# write @outfile to file "collect.data" #
#########################################

print "writing information to file \"collect.data.html\"...\n";

# collect.data.html should renamed to collect.data.$OSname.html for testing purposes
open(OUTFILE, ">/var/log/IBM_HSM/collect.data.html") or die print "file error!\n";
print OUTFILE @outfile;
close(OUTFILE);

print "...Done\n";


# remove temporary errorfile
print "removing temporary file \"$ERRORFILENAME\"...\n";
`rm $ERRORFILENAME 2> /dev/null`;
print "...Done\n";

print "Complete!\n";


######################
######################
#                    #
# END: FINAL SECTION #
#                    #
######################
######################

exit 0;

#############################################################################
#                    END OF SCRIPT                                          #
#############################################################################








# the following lines are samples how to extend the script




# sample for a universal collect section

#*******************************************
#*    < topic >    *
#*******************************************

################################################
# append information about <topic> to @outfile #
################################################

push @outfile, "\n\n\n\n<!-- +++++++++++++++++++++++++++++++++++++++++++ --> <a name=\"topic\"> <h2>\n\n";
push @outfile, "     < topic >\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

print "getting information about <topic>...\n";

    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: command\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `command`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    push @outfile, "\n<!-- -------------- --> <hr> <!-- -------------- -->\n";

print "...Done\n";

# END: sample for a universal collect section




# sample for a special collect section

#*******************************
#*    <topic>    *
#*******************************

################################################
# append information about <topic> to @outfile #
################################################

push @outfile, "\n<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  <h2>\n\n";
push @outfile, "     <topic>\n\n";
push @outfile, "<!-- +++++++++++++++++++++++++++++++++++++++++++ -->  </h2>\n";

push @outfile, "\n== <topic> ==\n\n";

print "getting information about <topic>...\n";

SWITCH: {
  if ($OSid == 10 ){                  # AIX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: command 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `command 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 20){                  # Linux
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: command 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `command 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 30){                  # SunOS
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: command 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `command 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 40){                  # HP-UX
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: command 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `command 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if ($OSid == 50){                  # OSF1
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: command 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `command 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
  if (($OSid == 60) or ($OSid == 61)){                  #IRIX / IRIX64
    push @outfile, "\n<!-- COMMAND --><PRE><b>\n\n";
    push @outfile, "Executing: command 2> $ERRORFILENAME\n";
    push @outfile, "\n<!-- COMMAND --></b></PRE>\n";

    push @outfile, "\n<!-- OUTPUT --><PRE>\n\n";
    push @outfile, `command 2> $ERRORFILENAME`."\n";
    push @outfile, "\n<!-- OUTPUT --></PRE>\n";
    errorhandling();
    push @outfile, "\n<!-- -------------- --> <a href=\"#top\">[Jump to top]</a><hr> <!-- -------------- -->\n";

    last SWITCH;
  }
}

print "...Done\n";

# END: sample for a special collect section
