#!/usr/bin/env python

########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#
# drutils.py
#
#
# Utility script that contains common functionalities used in DR
#
#
# Change Log:
# 03/04/2010  Liming (Michael) Yu   Added printAndLog, printAndLogErrorExit,
#                                   checkFilepath, and isSecondary; changed
#                                   existing drutil functions respectively
#


import commands
import os
import string
import sys
import time


mcHostName = "iamconsole1"
MMFSBIN = "/usr/lpp/mmfs/bin"
TIAMBIN = "/opt/tivoli/tiam/bin"
TIAMUTIL = "/tiam_utility"
SCRIPTNAME = "drutils"
logfilepath = TIAMUTIL + "/iamrecovery.log"


def grabFiles():
   logfile = open(logfilepath, "a", 0)
   printAndLog(SCRIPTNAME, logfile, "Enter grabFiles()")

   printAndLog(SCRIPTNAME, logfile, "Copying mctarfiles from mc to " + TIAMUTIL)
   cmd = "scp root@" + mcHostName + ":" + TIAMBIN + "/mc_tarfiles/* " + TIAMUTIL + "/backup/console/ 1>/dev/null"
   retVal = os.system(cmd)
   output = commands.getoutput(cmd)
   
   if retVal != 0:
     logfile.write(output+"\n")
     printAndLogErrorExit(SCRIPTNAME, logfile, logfilepath, "\"" + cmd + "\" returned with rc=" + str(retVal) + "; either " + mcHostName + " is incorrect, or " + mcHostName + ":" + TIAMBIN + "/mc_tarfiles is invalid, or /tiam_utility is invalid", 1)

   printAndLog(SCRIPTNAME, logfile, "Exit grabFiles() with rc=0")
   logfile.close()
   return 0;


def putFilesBack():
   logfile = open(logfilepath, "a", 0)
   printAndLog(SCRIPTNAME, logfile, "Enter putFilesBack()")

   printAndLog(SCRIPTNAME, logfile, "Copying mctarfiles from " + TIAMUTIL +" to mc")
   cmd = "scp " + TIAMUTIL + "/backup/console/mcconfig* root@" + mcHostName + ":/tmp/ 1>/dev/null"
   retVal = os.system(cmd)
   output = commands.getoutput(cmd)
   
   if retVal != 0:
     logfile.write(output+"\n")
     printAndLogErrorExit(SCRIPTNAME, logfile, logfilepath, "\"" + cmd + "\" returned with rc=" + str(retVal) + "; either " + mcHostName + " is incorrect, or " + mcHostName + ":" + TIAMBIN + "/mc_tarfiles is invalid, or /tiam_utility is invalid", 1)

   printAndLog(SCRIPTNAME, logfile, "Exit putFilesBack() with rc=0")
   logfile.close()
   return 0;


def isMasterGPFSNode():
    iAm = commands.getoutput("hostname")
    iAm = iAm.strip()
    
    pri = commands.getoutput(MMFSBIN + "/mmlscluster |grep -i primary | cut -d: -f2")
    pri = pri.strip()
    sec = commands.getoutput(MMFSBIN + "/mmlscluster |grep -i secondary | cut -d: -f2")
    sec = sec.strip()

    if iAm == pri:
      active = commands.getoutput(MMFSBIN + "/mmgetstate |grep -i active")
      if len(active) == 0:
        return False
      else:
        return True
    elif iAm == sec:
      active = commands.getoutput(MMFSBIN + "/mmgetstate -N " + pri + " |grep -i active")

      if len(active) == 0:
        return True
      else:
        return False
    else:
      return False


def locateRecoveryLun():
  cmd = "cat /proc/partitions |grep \"dm-\" |grep 30720 | awk '{ print $4 }'"
  RecDisk = commands.getoutput(cmd)
  if RecDisk == None:
    return "0"
  else:
    return RecDisk


def printAndLog(scriptname, logfile, message):
  date = time.localtime(time.time())
  logmessage = "%y-%m-%d %H:%M:%S [" + scriptname + "] " + message
  logmessage = time.strftime(logmessage, date)
  #print logmessage
  os.system("echo -e \""+logmessage+"\"")
  logfile.write(logmessage+"\n")


def printAndLogErrorExit(scriptname, logfile, logfilepath, message, errorcode):
  date = time.localtime(time.time())
  logmessage = "%y-%m-%d %H:%M:%S [" + scriptname + "] ERROR(" + str(errorcode) + "): " + message
  logmessage = time.strftime(logmessage, date)
  #print logmessage
  os.system("echo -e \""+logmessage+"\"")
  logfile.write(logmessage+"\n")
  logmessage = "%y-%m-%d %H:%M:%S [" + scriptname + "] Exiting script with rc=" + str(errorcode) + ". Please refer to the logfile @ " + logfilepath
  logmessage = time.strftime(logmessage, date)
  #print logmessage
  os.system("echo -e \""+logmessage+"\"")
  logfile.write(logmessage+"\n")
  logfile.close()
  os._exit(errorcode) 


def checkFilepath(filepath):
   lsCommand = "ls " + filepath
   output = commands.getoutput(lsCommand)
   if output.find("No such file or directory") == -1:
      return True 
   else:
      return False
