#!/bin/bash
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Description:
#    grablogs.sh is a replacement for IBM Director's grablogs.sh script, which has a bug
#       that prevents it from running smcli commands.  Other than the invocation of smcli,
#       this script is identical to the Director script.  Once the Director script is fixed,
#       this script should be removed, and ia_run_grablogs.sh should be modified to point
#       to the real Director script.
#
# Syntax:
#    grablogs.sh
#
# Results:
#    Creation of output in /tmp/dirlogs-datestamp
#
# Change history
#   Modifier      Date         CQ Change       Description
#   -----------------------------------------------------------------------------------
#   Brad Trubey   08/07/2009   TIAMC00007910   initial creation
# *************************************************************************************

if [ -n "$1" ]
then
    if [ -d "$1"  ]
    then
        TARGETDIR=$1
    else
        echo "Usage: grablogs <target_directory>"
        exit 33
    fi
else
    TARGETDIR="/tmp"
fi

DATEVAL=`date +%m-%d-%y`
FOLDERNAME=$TARGETDIR/dirlogs-$DATEVAL
rm -rf $FOLDERNAME
mkdir $FOLDERNAME

cp -R /opt/ibm/director/log/*             $FOLDERNAME
cp -R /opt/ibm/director/lwi/logs/*        $FOLDERNAME
cp -R /opt/ibm/director/tpm/config/logs/* $FOLDERNAME
cp -R /opt/ibm/director/lwi/runtime/log/* $FOLDERNAME
cp    /var/log/dirinst.log                $FOLDERNAME
cp    /opt/ibm/director/lwi/runtime/core/javacore*.txt $FOLDERNAME 2>/dev/null
cp    /opt/ibm/director/lwi/runtime/core/heapdump*.phd $FOLDERNAME 2>/dev/null

mkdir $FOLDERNAME/eccbase
cp -R /opt/ibm/director/lwi/runtime/core/workspace/.metadata/.plugins/com.ibm.usmi.services.updates.acquisition.eccbase/ecc $FOLDERNAME/eccbase 1>/dev/null 2>&1

mkdir $FOLDERNAME/agent-diagnostics

mkdir $FOLDERNAME/agent-diagnostics/CASLogs
cp -R /opt/ibm/director/agent/logs/* $FOLDERNAME/agent-diagnostics/CASLogs 1>/dev/null 2>&1
cp -R /opt/ibm/director/agent/log/* $FOLDERNAME/agent-diagnostics/CASLogs 1>/dev/null 2>&1

mkdir $FOLDERNAME/agent-diagnostics/CASInstallLogs
cp -R /opt/ibm/director/agent/runtime/agent/logs/* $FOLDERNAME/agent-diagnostics/CASInstallLogs 1>/dev/null 2>&1

mkdir $FOLDERNAME/agent-diagnostics/CIMLogs
cp -R /opt/ibm/icc/cimom/logs/* $FOLDERNAME/agent-diagnostics/CIMLogs 1>/dev/null 2>&1


cd $FOLDERNAME/agent-diagnostics


ifconfig -a > ifconfig_out.txt
netstat -an > netstat_out.txt

# ****comment out cli commands now*****
#../../smcli lsmeps>cli_lsmeps.txt
#if [ $? -ne 0 ]
#then exit
#fi

#for i in `awk '{if($1=="OID:")  print $2}' cli_lsmeps.txt`
#do
#  ../../smcli lssystem $i > lssystem_$i.txt
#done

#for i in `awk '{if($1=="GUID:")  print $2}' cli_lsmeps.txt`
#do
#  ../../smcli lssystemdb $i > lssystemdb_$i.txt
#done

cd ../..

# Defect 7910: The current working directory by the time this script gets to this line
# is "/tmp", which causes the "./smcli" commands to fail.  Director has been notified
# of this bug, but until a fix is available IA will use a custom copy of the script which
# fully qualifies the path to the smcli application.
#./smcli lssys -l         >  $FOLDERNAME/smcli-output.txt
#./smcli lsevtlog -l     >> $FOLDERNAME/smcli-output.txt
/opt/ibm/director/bin/smcli lssys -l         >  $FOLDERNAME/smcli-output.txt
/opt/ibm/director/bin/smcli lsevtlog -l     >> $FOLDERNAME/smcli-output.txt

# ***grab agentmanager logs ****
mkdir $FOLDERNAME/agentmanager-logs
cp -R /opt/ibm/director/lwi/runtime/agentmanager/logs/* $FOLDERNAME/agentmanager-logs 1>/dev/null 2>&1


echo ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
echo IBM Director 6.1 logs are archived in $FOLDERNAME.
echo Please use a zip tool to compress this folder, and then delete the contents.
echo ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
