#! /usr/bin/env python 
########################################################## {COPYRIGHT-TOP} ###
# IBM Confidential
#
# Licensed Materials - Property of IBM
#          
# 5608-IAF - IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008, 2009, All Rights Reserved
#          
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been deposited
# with the U.S. Copyright Office
#
########################################################## {COPYRIGHT-END} ###

import sys
import os
import getopt
import logging
from ia_compliance_security_util import *

def usage():
	print '\nUsages:'
	print 'iaESAPatchInstall -a thepackagename '
	print 'OR'
	print 'iaESAPatchInstall -a -d debug option thepackagename '
	print 'OR'
	print 'iaESAPatchInstall thepackagename '


def main():
	mode, debuglevel, packageName = checkOptions()
	#print mode
	#print debuglevel
	#print packageName
	#get logger
	iaESAPatchInstallLog = IAESAPatchInstallLogger("iaESAPatchInstall")
	iaESAPatchInstallLogger = iaESAPatchInstallLog.getIAESAPatchInstallLog()
	iaESAPatchInstallLog.setLoggerLevel(debuglevel)
	
	#check the pack is existing or not. The package name contain path. 
	#If no path, then assume the default path is /home/iaadmin
	if not os.path.isfile(packageName):
		print "The package %s does not exist!" %(packageName)
		iaESAPatchInstallLogger.error("The package %s does not exist!" %(packageName))
		sys.exit(1)
	
	#Seperate path, package name
	packagepath = os.getcwd()
	packagename = packageName
	
	packageName = os.path.abspath(packagename)
	index = packageName.rfind("/")
	if (index != -1):
		packagepath = packageName[0:index+1]
		packagename = packageName[index+1:]
	#end if
		
	#Factory
	#print packagepath
	#print packagename
	#print mode
	print "Start......"
	iaESAPatchInstallLogger.info("Start......")
	installManager = ESAPatchInstallerManager(mode, packagepath, packagename)
	installManager.install()
	for handler in installManager.listOfHandlers:
		if (handler and handler.isAlive()):
			handler.join(300) # 5 minutes should be enough?
	#end for
	
	print "End......"
	iaESAPatchInstallLogger.info("End......")
	
	#main loop
	#print status
	#while (not done):
	#	sleep
	#end while
	return 0
#end if

def checkOptions():
	optionDebugValues = ["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]
	try:
		opts, args = getopt.getopt(sys.argv[1:], "ad:")
		#print opts
		#print args
	except getopt.GetoptError, err:
		print str(err)
		usage()
		sys.exit(1)	
	
	if len(opts) > 2:
		print "Wrong option!"
		usage()
		sys.exit(1)
	# ...
	 
	mode = ""
	debuglevel = "ERROR"
	packageName = ""
	for o, a in opts:
		if o == "-a":
			mode = "-a"
		if o == "-d":
			if a in optionDebugValues:
				debuglevel = a
			else:
				print "Missed or wrong debug option value, must enter the one of following values for debug option!"
				print optionDebugValues
				usage()
				sys.exit(1)
	#end for
		
	if len(args) < 1:
		print "Missed patch name!"
		usage()
		sys.exit(1)
	# ...
	
	packageName = args[0]
	
	return (mode, debuglevel, packageName)
#end def

if __name__ == "__main__":
	main()
