#!/bin/bash
#
#******************************************************************************
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp.  2010  All Rights Reserved
#
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -----------------------------------------------------------------------------
#
# =========================================================================
#
# Name: ia_cfg_storagesubsystem.sh
#
# Change Log:
#  Date          Developer        Defect         Description
#  Feb 7, 2010   Robert Guthrie                  Initial script creation
#  Mar 2, 2010   Laura Bell                      Remove call to mapLuns.sh (not needed for config of new storage)
#  04/23/2010    Brad Trubey      TIAMC00013107  move logs to location where they will get collected
#  10/27/2010    Brad Trubey      TIAMC00015805  don't use datestamp in log name, use ".log" extension
#  11/09/2010    Brad Trubey      TIAMC00016579  improve error logging and reporting
#  12/02/2010     Del Ence          TIAMC00016008  Preserve return code from ia_storage_common.sh 
#******************************************************************************

mkdir -p /var/opt/tivoli/tiam/log
LOGFILE="/var/opt/tivoli/tiam/log/ia_cfg_storagesubsystem.log"

usage() {
  echo " ia_cfg_storagesubsystem.sh -a <ipaddress> -b <ipaddress>"
  echo "       -a                 IP Address of controller A"
  echo "       -b                 IP Address of controller B"
  echo "       -h                 help/usage information"
  echo " "
  echo "    eg.   ia_cfg_storagesubsystem.sh -a 172.31.0.100 -b 172.31.0.101"
  return 0
}

fail() {
  echo "Configuration FAILED."     | tee -a $LOGFILE
  echo "Please check $LOGFILE for more information"     | tee -a $LOGFILE

  exit 1
}

# Script requires exactly 4 parameters in a specific order.
if [ $# != 4 ]; then
  usage
  exit 0
else
  if [ "$1" = "-a" ]; then
      CTRLA=$2
  else
      usage
      exit 0
  fi

  if [ "$3" = "-b" ]; then
      CTRLB=$4
  else
      usage
      exit 0
  fi
fi


# SMcli commands must be run as root
if [ `whoami` == "root" ]; then
   echo "=======Start Script $0 `date`=====" >> $LOGFILE
   $(cd $(dirname "$0") ; pwd -P)/ia_storage_common.sh $1 $2 $3 $4 -l $LOGFILE -n
   rc=$?
   echo "Configuration complete.  Please see $LOGFILE for additional details"     | tee -a $LOGFILE
   exit $rc
else
   echo "You must be root (or use sudo) to run this script."     | tee -a $LOGFILE
   fail
fi


