#!/bin/bash
#
#******************************************************************************
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp.  2008  All Rights Reserved
#
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -----------------------------------------------------------------------------
# 
# =========================================================================
# 
# Name: ia_check_mc_tunnel.sh 
#
# Change Log:
#  Date           developer               change
#  02/22/2010     Liming (Michael) Yu     Initial script creation
#
#******************************************************************************


DRLOG="/opt/tivoli/tiam/log/dr"
TIAMBIN="/opt/tivoli/tiam/bin"

SCRIPTNAME="ia_check_mc_tunnel.sh"
LOGFILE="${DRLOG}/ia_check_mc_tunnel.out"


pingtest() {
  cmd=`ping $1 -c 1`
  if [[ `echo $cmd |grep -i unreachable` || `echo $cmd |grep -i "0 received"` ]]; then
    return -1
  else
    return 0
  fi
}


printAndLog() {
  timestamp=`date "+%Y-%m-%d %H:%M:%S"`
  logsize=`ls -l $LOGFILE | awk '{print $5}'`
  if [[ $logsize -ge 10485760 ]]; then
    echo "$timestamp [$SCRIPTNAME] Log file exceeded 10MB, Log wrapped." > $LOGFILE
  fi
  echo "$timestamp [$SCRIPTNAME] $1"
  echo "$timestamp [$SCRIPTNAME] $1" >> $LOGFILE
}


printAndLogErrorExit() {
  timestamp=`date "+%Y-%m-%d %H:%M:%S"`
  echo "$timestamp [$SCRIPTNAME] ERROR($1): $2"
  echo "$timestamp [$SCRIPTNAME] ERROR($1): $2" >> $LOGFILE
  echo "$timestamp [$SCRIPTNAME] Exiting script with rc=$1. Please refer to the logfile @ $LOGFILE"
  echo "$timestamp [$SCRIPTNAME] Exiting script with rc=$1" >> $LOGFILE
  exit $1
}


#======= beginning of the main function =======

ls /opt/tivoli/tiam/etc/DR_ENABLED > /dev/null 2>&1
result=$?
if [ $result != 0 ]; then
  exit 0
fi

#=== STEP1: ping test ===
pingtest dr_remote_mc
pings=$?
if [ $pings != 0 ]; then
  printAndLog "Can not ping dr_remote_mc"
  
  ls /opt/tivoli/tiam/etc/DR_SECONDARY > /dev/null 2>&1
  result=$?
  if [ $result == 0 ]; then
    printAndLogErrorExit 1 "Current appliance is secondary. Allowing primary appliance to reestablish the ssh tunnel connection between the two paired management consoles"
  fi

  #Current appliance is primary
  tries=0
  out=`sudo $TIAMBIN/ia_cfgermpair -enable`
  result=$?
  tries=$((tries+1))
  while [ $result != 0 ]
  do
    printAndLog "Attempt#$tries: ia_cfgermpair failed and exited with rc=$result and the following output:"
    echo $out
    echo $out >> $LOGFILE
    if [ $tries == 3 ]; then
      printAndLogErrorExit 2 "ia_cfgermpair failed 3 times"
    else
      out=`sudo $TIAMBIN/ia_cfgermpair -enable`
      result=$?
      tries=$((tries+1))
    fi
  done

  printAndLog "Successfully reestablished the ssh tunnel connection between the two paired management consoles"
  exit 0
fi

#=== STEP2: ssh root@dr_remote_mc test ===
ssh root@dr_remote_mc echo > /dev/null 2>&1
result=$?
if [ $result != 0 ]; then
  printAndLogErrorExit 3 "Can not ssh root@dr_remote_mc. The ssh root keys are most likely broken and need to be manually fixed."
fi

#GOOD: can ping dr_remote_mc and ssh root@dr_remote_mc
exit 0
