#!/bin/sh
########################################################## {COPYRIGHT-TOP} ###
# IBM Confidential
#
# Licensed Materials - Property of IBM
#
# 5608-IAF - IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008, 2010, All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been deposited
# with the U.S. Copyright Office
#
########################################################## {COPYRIGHT-END} ###

#echo $SSH_ORIGINAL_COMMAND
CMD=(`echo $SSH_ORIGINAL_COMMAND | awk {'print $1'}` )
ARGUMENT=`echo $SSH_ORIGINAL_COMMAND | awk '{for(i=2;i<=NF;i++) {printf("%s ",$i)}}'`
CMD_PREFIX=""

if [ "$CMD" = "sudo" ]; then
   CMD_PREFIX="sudo "
   CMD=(`echo $SSH_ORIGINAL_COMMAND | awk {'print $2'}` )
   ARGUMENT=`echo $SSH_ORIGINAL_COMMAND | awk '{for(i=3;i<=NF;i++) {printf("%s ",$i)}}'`
fi

#Check command allowed
if [  -z "$CMD" ]; then
   echo "ssh to cluster nodes as iaadmin is not allowed."
   exit 1
fi

export PATH=$PATH:/opt/tivoli/tiam/bin:/usr/sbin
commandAllowed=`ia_compliance_security_check_commands_allowedfrommc.py $CMD`

if [ $commandAllowed -eq 0 ]; then
   echo "The command $CMD is not allowed to run!"
   exit 1
fi

#echo "$CMD_PREFIX"
#echo "$CMD"
#echo "$ARGUMENT"
#echo -e `$CMD_PREFIX $CMD $ARGUMENT`

case "$CMD" in
   "esapatchinstall")
      echo `ia_compliance_security_install_esapatch_from_remote.py $ARGUMENT`
      ;;
   "esapatchuninstall")
      echo `ia_compliance_security_uninstall_esapatch_from_remote.py $ARGUMENT`
      ;;
   "/usr/lpp/mmfs/bin/mmgetstate" | "mmgetstate")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/bin/echo" | "echo")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/restoreConfigFiles" | "restoreConfigFiles")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_recovery_healthcheck.sh" | "ia_recovery_healthcheck.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/activateRecoverySite" | "activateRecoverySite")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_cfgsecondary.sh" | "ia_cfgsecondary.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/cfgSecondary.sh" | "cfgSecondary.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_trace.py" | "ia_trace.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/getiamlogs.py" | "getiamlogs.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/copyiamlogs.py" | "copyiamlogs.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_logcollector.py" | "ia_logcollector.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/nodecollector.py" | "nodecollector.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/pushLogCollectionToMC.sh" | "pushLogCollectionToMC.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/copyRASlogs.sh" | "copyRASlogs.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_service.py" | "ia_service.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_run_dsa.sh" | "ia_run_dsa.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_run_grablogs.sh" | "ia_run_grablogs.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_run_hsmcollect.sh" | "ia_run_hsmcollect.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_run_gpfssnap.sh" | "ia_run_gpfssnap.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_run_middleware.sh" | "ia_run_middleware.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_iss.sh" | "ia_iss.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_dir_agent.sh" | "ia_dir_agent.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_configure_common_agent.sh" | "ia_configure_common_agent.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/checkNode.sh" | "checkNode.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/network_health.sh" | "network_health.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/bin/date" | "date")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/usr/lpp/mmfs/bin/mmtracectl" | "mmtracectl")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/usr/lpp/mmfs/bin/mmlscluster" | "mmlscluster")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_kdump_switch" | "ia_kdump_switch")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_force_ssh_key_regen" | "ia_force_ssh_key_regen")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_get_connected_nfs_hosts.sh" | "ia_get_connected_nfs_hosts.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_get_connected_cifs_hosts.sh" | "ia_get_connected_cifs_hosts.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_get_recent_nfs_hosts.sh" | "ia_get_recent_nfs_hosts.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_backup_config_tsm_server.py" | "ia_backup_config_tsm_server.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_set_tsmnode_pw.sh" | "ia_set_tsmnode_pw.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_backup_start_scheduler.sh" | "ia_backup_start_scheduler.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_backup_stop_scheduler.sh" | "ia_backup_stop_scheduler.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_restore_from_tsm.py" | "ia_restore_from_tsm.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_backup_getlogs.sh" | "ia_backup_getlogs.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/usr/bin/dsmdf" | "dsmdf" | "/usr/sbin/nfsstat" | "nfsstat")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/verify_node_local" | "verify_node_local")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/verify_ports" | "verify_ports")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/mb_display_location.py" | "mb_display_location.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/mb_create_collection_dir.py" | "mb_create_collection_dir.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_update_nodes_file.py" | "ia_update_nodes_file.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_hsm_reconcile.sh" | "ia_hsm_reconcile.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_find_luns.py" | "ia_find_luns.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/add_disks.py" | "add_disks.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/usr/bin/ls" | "ls")
      if [ "$ARGUMENT" = "/opt/tivoli/tiam/bin/install_complete " ]; then
        $SSH_ORIGINAL_COMMAND
      else
        echo "The command $SSH_ORIGINAL_COMMAND is not allowed to run!"
        exit 1
      fi
   ;;
   "/usr/sbin/dmidecode")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/create_gpfs")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/change_bond1_static.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/bin/date" | "date")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_generate_iacluster_config")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_ctdb_cluster_config.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_repair_node_config.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/get_ssh_keys.sh")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/add_node_update_tiebreaker.py")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_registry_add_user")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_registry_remove_user")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_registry_modify_user")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_registry_query_user")
      $SSH_ORIGINAL_COMMAND
   ;;
   "/opt/tivoli/tiam/bin/ia_registry_get_defaults")
      $SSH_ORIGINAL_COMMAND
   ;;
   *)
      echo "The command $SSH_ORIGINAL_COMMAND is not allowed to run."
      exit 1
      ;;
esac
