#!/usr/bin/env python
########################################################## {COPYRIGHT-TOP} ###
# IBM Confidential
#
# Licensed Materials - Property of IBM
#
# 5608-IAF - IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008, 2010, All Rights Reserved
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been deposited
# with the U.S. Copyright Office
#
########################################################## {COPYRIGHT-END} ###

import threading
from syslog import *
import zipfile
import logging
from logging import *
from time import *
from datetime import date
from datetime import datetime

import sys, string, os, subprocess
import re
import ConfigParser
from xml.dom.minidom import parse, parseString
#added for fix defect 14915
from threading import Lock

"""
The class ComplianceSecurityException provide general compliance security service.
"""
class ComplianceSecurityException(Exception):
    IA_ESA_PATCH_INSTALL_ERROR = "IA_ESA_PATCH_INSTALL_ERROR:"
    def __init__(self, message):
        nameOfNode = getHostInfo()
        self.strerror = ComplianceSecurityException.IA_ESA_PATCH_INSTALL_ERROR + message + " on NODE=%sNODE" %(nameOfNode)
    def __str__(self):
        return strerror
#end class

class ArchivePackageHandleException(ComplianceSecurityException):
    def __init__(self, message):
        self.strerror = ComplianceSecurityException.strerror + "---"
    def __str__(self):
        return strerror
#end class

"""
The ArchivePackageHandler class will extract zip file.
"""
class ArchivePackageHandler:
    #The path will be closed path /a/b/
    PATCH_INSTALL_PREFIX = "esapatch-"
    def __init__(self, theArchivePath, theArchiveName):
        self.archivePath = theArchivePath
        self.archiveName = theArchiveName
        self.iaESAPatchInstallLogger = IAESAPatchInstallLogger("ArchivePackageHandler").getIAESAPatchInstallLog()

    def extractArchive(self):
        if not zipfile.is_zipfile(self.archivePath + self.archiveName):
            #syslog(LOG_ERR, "The file is not in zip format!")
            self.iaESAPatchInstallLogger.error("The file is not in zip format!")
        #end if

        """
        The temporary path for installing esa patch.
        The temporary path is in prefix "esapatch-" with the month-day-year.
        """
        #tempPath =     "esapatch-" + (date.today()).strftime("%m-%d-%Y") + "/"
        tempPath =  ArchivePackageHandler.PATCH_INSTALL_PREFIX + (date.today()).strftime("%m-%d-%Y") + "/"
        unzipcmd = "unzip -o -d " + (self.archivePath + tempPath)  + "  " + (self.archivePath + self.archiveName)
        #print unzipcmd
        self.iaESAPatchInstallLogger.debug(unzipcmd)
        exitcode, output = callsyscmd (unzipcmd)
        #print exitcode

        if exitcode != 0:
            #syslog(LOG_ERR, unzipcmd + " failed!")
            self.iaESAPatchInstallLogger.error(unzipcmd + " failed!")
            raise ComplianceSecurityException(unzipcmd + " failed!")
        #end if

        return (self.archivePath + tempPath)
    #end def
#end class

"""
The class GPGSignatureHandler verify GPF signature, enforce signature expiration.
"""
class GPGSignatureHandler:
    EXPIRED_TIME = 24 * 3600
    #The path will be closed path /a/b/
    def __init__(self, thePath):
        self.pathForFileVerify = thePath
        self.iaESAPatchInstallLogger = IAESAPatchInstallLogger("GPGSignatureHandler").getIAESAPatchInstallLog()
        #print self.pathForFileVerify
    #end def

    def verifySignatureExpiration(self, pathofzipsigned):
        print "verifySignatureExpiration"
    #end define

    def validateSignatureOfPatch(self):
        for file in os.listdir(self.pathForFileVerify):
            #print file
            self.iaESAPatchInstallLogger.debug(file)
            if not file.endswith("sig"):
                zipfile = file
                sigfile = file + ".sig"
                #print "zip file is:" + zipfile
                self.iaESAPatchInstallLogger.debug("zip file is:" + zipfile)
                #print "signature file is:" + sigfile
                self.iaESAPatchInstallLogger.debug("signature file is:" + sigfile)

                if not os.path.isfile(self.pathForFileVerify + sigfile):
                    errstr = "Missed signature file %s for %s" %(sigfile,zipfile)
                    raise ComplianceSecurityException(errstr)
                #end if

                gpgcmd = "gpg --homedir /opt/tivoli/tiam/etc/keys/ --verify " + self.pathForFileVerify+sigfile + " " + self.pathForFileVerify+zipfile
                #print gpgcmd
                self.iaESAPatchInstallLogger.debug(gpgcmd)
                exitcode, output = callsyscmd (gpgcmd)
                #print output
                self.iaESAPatchInstallLogger.debug(output)
                #print exitcode

                if exitcode !=0:
                    #syslog("Failed to verify signature! --- " + gpgcmd)
                    self.iaESAPatchInstallLogger.error("Failed to verify signature! --- " + gpgcmd)
                    raise ComplianceSecurityException("Failed to verify signature for file %s" %(zipfile))
                #end if

                #Calculate time
                strtime = ""
                for line in output:
                    m = re.search('Signature made', line)
                    #print m
                    if (m <> None):
                        startIndexDate = m.end()
                        if(startIndexDate != -1):
                            endIndexDate = re.search('using', line).start()
                            if endIndexDate != -1:
                                strtime = line[startIndexDate+1:endIndexDate].strip()
                                break
                            #end if
                        #end if
                    #end if
                #end for

                #print strtime
                if strtime == "":
                    #syslog("Failed to verify signature! --- " + gpgcmd)
                    self.iaESAPatchInstallLogger.error("Failed to verify signature! --- " + gpgcmd)
                    raise ComplianceSecurityException("Date Missed in Signature")
                #end if

                timeOfSignature =  mktime(strptime(strtime.strip(), "%a %b %d %H:%M:%S %Y %Z"))
                if (time() - timeOfSignature) > GPGSignatureHandler.EXPIRED_TIME:
                    raise ComplianceSecurityException("Signature of Patch Was Expired!")
                #end if
            #end if
        #end for
        return True
    #end def
#end class

"""
The class EnableRootAutorityHandler will enable root authority for user iaadmin and also allow customer to execute service script.
"""
class EnableRootAutorityHandler:
    def __init__(self):
        self.iaESAPatchInstallLogger = IAESAPatchInstallLogger("EnableRootAutorityHandler").getIAESAPatchInstallLog()
        pass
    #end def

    #Check whether berootauthority is existing, then verify signature again.
    def invokeBerootauthority(self, path):
        #print path
        self.iaESAPatchInstallLogger.debug(path)
        if not os.path.isfile(path+"berootauthority"):
            #it is just for copy services ability
            print "Service Mode"
            self.iaESAPatchInstallLogger.debug("Service Mode")
            #if not isMCNode():
            self.invokeServiceScript(path)
        else:
            #it enables root authority
            chmodcmd = "chmod u+rx " + path+"berootauthority"
            exitcode, output = callsyscmd(chmodcmd)
            if exitcode != 0:
                self.iaESAPatchInstallLogger.error("Failed to change mode for berootauthority!")
                raise ComplianceSecurityException("Failed to change mode for berootauthority!")
            #end if

            berootcmd = path+"berootauthority"
            exitcode, output = callsyscmd(berootcmd)
            # print exitcode
            #Execute beroot
            if exitcode != 0:
                #syslog(LOG_ERR, "Failed to invoke berootauthority!")
                self.iaESAPatchInstallLogger.error("Failed to invoke berootauthority!")
                raise ComplianceSecurityException("Failed to enable root authority")
            #end if
        #end if
    #end def

    def revokerootauthority(self):
        try:
            #1.Remove usdoers
            cmd = "cat /etc/sudoers | sed '/iaadmin ALL= (ALL) NOPASSWD: ALL/d' > /etc/sudoers.new"
            #print cmd
            self.iaESAPatchInstallLogger.debug(cmd)
            exitcode, output = callsyscmd(cmd)
            #print exitcode
            backupcmd = "cp -f /etc/sudoers /etc/sudoers.bak"
            #print backupcmd
            self.iaESAPatchInstallLogger.debug(backupcmd)
            exitcode, output = callsyscmd(backupcmd)
            #print exitcode
            replacecmd = "cp -f /etc/sudoers.new /etc/sudoers"
            #print replacecmd
            self.iaESAPatchInstallLogger.debug(replacecmd)
            exitcode, output = callsyscmd(replacecmd)
            #print exitcode
            #2.Remove cron
            rmcmd = "sed -i '\/opt\/tivoli\/tiam\/bin\/iaESAPatchUninstall.py/d' /etc/cron.d/esapatch "
            self.iaESAPatchInstallLogger.debug(rmcmd)
            exitcode, output = callsyscmd(rmcmd)
            #backupcmd = "cp -f /etc/crontab /etc/crontab.bak"
            #exitcode, output = callsyscmd(backupcmd)
            #replacecmd = "cp -f /etc/crontab.new /etc/crontab"
            #exitcode, output = callsyscmd(replacecmd)
            #removeCrontabcmd = "/etc/init.d/cron restart; sleep 5s; /etc/init.d/cron restart"
            #elf.iaESAPatchInstallLogger.debug(removeCrontabcmd)
            #exitcode, output = callsyscmd(removeCrontabcmd)
        except Exception, ex:
            #syslog(LOG_ERR, "Failed to reinvoke root authority!")
            self.iaESAPatchInstallLogger.error("Failed to reinvoke root authority!")
            raise ComplianceSecurityException("Failed to reinvoke root authority!")
    #end def

    def invokeServiceScript(self, filepath):
        cfgFile = None
        try:
            try:
                #get servicescript from patch.ini
                cfgFile = open(filepath + "patch.ini", 'r')
                config = ConfigParser.ConfigParser()
                config.readfp(cfgFile)
                servicescript = ""
                try:
                    servicescript = config.get("Configure", "servicescript")
                except ConfigParser.NoOptionError, ex:
                    self.iaESAPatchInstallLogger.error("No service script!")
                #end try
                #print servicescript
                self.iaESAPatchInstallLogger.debug(servicescript)
                if (servicescript != "") and os.path.isfile(filepath + servicescript):
                    chmodcmd = "chmod u+rx " + filepath + servicescript
                    exitcode, output = callsyscmd(chmodcmd)
                    if exitcode != 0:
                        self.iaESAPatchInstallLogger.error("Failed to change mode for servicescript!")
                        raise ComplianceSecurityException("Failed to change mode for servicescript!")
                    #end if

                    servicecmd = filepath + servicescript
                    exitcode, output = callsyscmd(servicecmd)
                    self.iaESAPatchInstallLogger.debug("Invoked service scripts %s!" % (servicecmd))
                    # print exitcode
                    if exitcode != 0:
                        #syslog(LOG_ERR, "Failed to invoke berootauthority!")
                        self.iaESAPatchInstallLogger.error("Failed to invoke service scripts %s!" % (servicecmd))
                        raise ComplianceSecurityException("Failed to invoke service scripts!")
                    #end if
                #end if
            except Exception, ex:
                print ex
                #syslog(LOG_ERR, ex.strerror)
                self.iaESAPatchInstallLogger.error(ex.strerror)
                raise
        finally:
            if cfgFile != None:
                cfgFile.close()
    #end if
#end class

"""
The ESAPatchInstaller is parent class of ESAPatchMCInstaller.
"""
class ESAPatchInstaller(threading.Thread):
    MCIP = "iamconsole1"
    def __init__(self):
        threading.Thread.__init__(self)
        self.iaESAPatchInstallLogger = IAESAPatchInstallLogger("ESAPatchInstaller").getIAESAPatchInstallLog()
        #self.bMCNode = isMCNode()
        pass
    #end def

    def installpatch(self):
        pass

    def run(self):
        try:
            if self.isInstall:
                self.installpatch()
            else:
                self.uninstallpatch()
            #end if
        except ComplianceSecurityException, ex:
            if not isMCNode():
                print ex.strerror #cannot remove it
            self.iaESAPatchInstallLogger.error(ex.strerror)

        #Copy install log to MC
        nameOfNode = getHostInfo()
        #print nameOfNode
        self.iaESAPatchInstallLogger.debug("Node: " + nameOfNode)
        if not isMCNode():
            installlogcmd = "scp /opt/tivoli/tiam/log/iaesapatchinstall-*.log root@%s:/opt/tivoli/tiam/log/" % (ESAPatchInstaller.MCIP)
            #print installlogcmd
            self.iaESAPatchInstallLogger.debug(installlogcmd)
            exitcode, output = callsyscmd(installlogcmd)
            if exitcode != 0:
                self.iaESAPatchInstallLogger.error("Failed to copy the log to MC!")
            #end if
        #end if
    #end def

    def setInstall(self, beInstall):
        self.isInstall = beInstall
    #end def

    #This function will do the following thing and will be used by local and remote install
    def installPatchOnLocal(self, path, nameofpatch):
        nameOfNode = getHostInfo()
        try:
            self.doinstall(path, nameofpatch)
        except ComplianceSecurityException, ex:
            #clean up
            self.removeInstallDirectory()
            print "------Failed to install patch on %s node! " %(nameOfNode)
            self.iaESAPatchInstallLogger.error("------Failed to install patch on %s node! " %(nameOfNode))
            exitcode = logtoaudit("INSTALL_ESA_PATCH", "Failure")
            if exitcode != 0:
                self.iaESAPatchInstallLogger.error("Failed to write audit log on %s node! " %(nameOfNode))
                syslog(LOG_ERR, "Compliance---Failed to install patch on %s node! " %(nameOfNode))
            #end if
            raise
        except:
            #clean up
            self.removeInstallDirectory()
            print "------Failed to install patch on %s node! " %(nameOfNode)
            self.iaESAPatchInstallLogger.error("------Failed to install patch on %s node! " %(nameOfNode))
            exitcode = logtoaudit("INSTALL_ESA_PATCH", "Failure")
            if exitcode != 0:
                self.iaESAPatchInstallLogger.error("Failed to write audit log on %s node! " %(nameOfNode))
                syslog(LOG_ERR, "Compliance---Failed to install patch on %s node! " %(nameOfNode))
            #end if
            raise
        #enf exception

        print "------Finished install patch on %s node! " %(nameOfNode)
        self.iaESAPatchInstallLogger.debug("------Finished install patch on %s node! " %(nameOfNode))
        exitcode = logtoaudit("INSTALL_ESA_PATCH", "Success")
        if exitcode != 0:
            self.iaESAPatchInstallLogger.error("Failed to write audit log on %s node! " %(nameOfNode))
            syslog(LOG_INFO, "Compliance---Installed patch on %s node! " %(nameOfNode))
        #end if
    #end def

    def doinstall(self, thePathOfPatch, theNameOfPatch):
        #clean up
        rmcmd = "rm -Rf -d " + thePathOfPatch + "esapatch-*"
        #print rmcmd
        self.iaESAPatchInstallLogger.debug(rmcmd)
        exitcode, output = callsyscmd(rmcmd)

        #create ArchivePackageHandler
        #1. extract orignal zip file under thePathOfPatch
        #print "Old---" + thePathOfPatch
        #print theNameOfPatch
        archiveHandler = ArchivePackageHandler(thePathOfPatch, theNameOfPatch)
        tempPath = archiveHandler.extractArchive()
        self.iaESAPatchInstallLogger.debug(tempPath)

        #write this path
        self.saveInstalltionInfo(tempPath)

        #create GPGSignatureHandler
        #2. verify signature of zip of extracted
        #print tempPath
        gpgSignature = GPGSignatureHandler(tempPath)
        gpgSignature.validateSignatureOfPatch()

        #3.check serial number is matching to the node or not
        #print "****" + tempPath
        self.checkSerialNumber(tempPath)

        #4. Before enable root authority, check iaESAPatchUninstall.py
        if os.path.isfile(tempPath+"berootauthority"):
            if not os.path.isfile(tempPath+"iaESAPatchUninstall.py"):
                raise ComplianceSecurityException("Missed iaESAPatchUninstall.py!")
            #end if
        #end if

        #enable root: create EnableRootAutorityHandler
        #5. Enable root authority
        enableRootAuthorityHandler = EnableRootAutorityHandler()
        enableRootAuthorityHandler.invokeBerootauthority(tempPath)

        #6. Copy iaESAPatchUninstall.py to /opt/tivoli/tiam/bin
        if os.path.isfile(tempPath+"iaESAPatchUninstall.py"):
            cpcmd = "cp -f " + tempPath + "iaESAPatchUninstall.py" + " /opt/tivoli/tiam/bin"
            #print cpcmd
            self.iaESAPatchInstallLogger.debug(cpcmd)
            exitcode, output = callsyscmd(cpcmd)
            # print exitcode
            if exitcode != 0:
                #syslog(LOG_ERR, "Failed to copy iaESAPatchUninstall.py!")
                self.iaESAPatchInstallLogger.error("Failed to copy iaESAPatchUninstall.py!")
                raise ComplianceSecurityException("Failed to copy iaESAPatchUninstall.py")
            #end if

            chmodcmd = "chmod u+rx " + " /opt/tivoli/tiam/bin/iaESAPatchUninstall.py"
            exitcode, output = callsyscmd(chmodcmd)
            if exitcode != 0:
                self.iaESAPatchInstallLogger.error("Failed to change mode for iaESAPatchUninstall.py!")
                raise ComplianceSecurityException("Failed to change mode for iaESAPatchUninstall.py!")
            #end if
        #end if

        #7. Copy iapasswdreset.py to /opt/tivoli/tiam/bin
        if os.path.isfile(tempPath+"iapasswdreset.py"):
            cpcmd = "cp -f " + tempPath + "iapasswdreset.py" + " /opt/tivoli/tiam/bin"
            self.iaESAPatchInstallLogger.debug(cpcmd)
            exitcode, output = callsyscmd(cpcmd)
            # print exitcode
            if exitcode != 0:
                self.iaESAPatchInstallLogger.error("Failed to copy iapasswdreset.py!")
                raise ComplianceSecurityException("Failed to copy iapasswdreset.py")
            #end if

            chmodcmd = "chmod u+rx " + " /opt/tivoli/tiam/bin/iapasswdreset.py"
            exitcode, output = callsyscmd(chmodcmd)
            if exitcode != 0:
                self.iaESAPatchInstallLogger.error("Failed to change mode for iapasswdreset.py!")
                raise ComplianceSecurityException("Failed to change mode for iapasswdreset.py!")
            #end if
        #end if

        #8. schedule cron job
        self.scheduleCronJob()
    #end if

    def checkSerialNumber(self, filepath):
        cfgFile = None
        try:
            try:
                #1. get serial number from patch.ini
                cfgFile = open(filepath + "patch.ini", 'r')
                config = ConfigParser.ConfigParser()
                config.readfp(cfgFile)
                serialNumber = ""
                try:
                    serialNumber = config.get("Configure", "serial")
                except ConfigParser.NoOptionError, err:
                    self.iaESAPatchInstallLogger.error("The serial number missed from patch")
                    raise ComplianceSecurityException("The serial number missed from patch")
                #print serialNumber
                self.iaESAPatchInstallLogger.debug(serialNumber)
                #2. get serial number from /opt/ISS/ISS_MTMS.xml
                dom = parse("/opt/ISS/ISS_MTMS.xml")
                machine = dom.getElementsByTagName("machine")[0]
                serialnumberNode = machine.getElementsByTagName("serial")[0]
                nodeSerialNumber = (serialnumberNode.childNodes[0]).data
                #print nodeSerialNumber
                self.iaESAPatchInstallLogger.debug(nodeSerialNumber)
                if serialNumber != nodeSerialNumber:
                    #syslog(LOG_ERR, "The serial number mismatched between node and patch")
                    self.iaESAPatchInstallLogger.error("The serial number mismatched between node and patch")
                    raise ComplianceSecurityException("The serial number mismatched between node and patch")
                #end if
                return True
            except Exception, ex:
                #print ex
                #syslog(LOG_ERR, ex.strerror)
                self.iaESAPatchInstallLogger.error(ex.strerror)
                raise
        finally:
            if cfgFile != None:
                cfgFile.close()
    #end def

    def scheduleCronJob(self):
        try:
            #get current time(minute, hours)
            dt = datetime.now()  #Changed to use local time.
            cronJob = "\"%i %i * * * root /opt/tivoli/tiam/bin/iaESAPatchUninstall.py\"" %(dt.minute, dt.hour)

            #Get local timezone info
            if daylight == 1:
                self.iaESAPatchInstallLogger.debug("DST is enabled in this machine")
                strtime = ""
                zdumpcmd = "zdump -v /etc/localtime | grep " + str(dt.year) + " | grep isdst=0 | grep 59:59"
                self.iaESAPatchInstallLogger.debug(zdumpcmd)
                exitcode, output = callsyscmd(zdumpcmd)
                if exitcode == 0:
                    self.iaESAPatchInstallLogger.debug(output)
                    zdumpoutput = output[0]
                    m = re.search('UTC =', output[0])
                    #print m
                    if (m <> None):
                        startIndexDate = m.end()
                        if(startIndexDate != -1):
                            endIndexDate = re.search('isdst=0', zdumpoutput).start()
                            if endIndexDate != -1:
                                strtime = zdumpoutput[startIndexDate+1:endIndexDate].strip()
                                self.iaESAPatchInstallLogger.debug("Local timezone info=" + strtime)
                            #end if
                        #end if
                    #end if
                    #print strtime
                    if strtime != "":
                        ltimezone = strptime(strtime.strip(), "%a %b %d %H:%M:%S %Y %Z")
                        self.iaESAPatchInstallLogger.debug("Current month=" + str(dt.month) + "," + "Current day=" + str(dt.day) + "," + "Current hour=" + str(dt.hour))
                        self.iaESAPatchInstallLogger.debug("DST month=" + str(ltimezone.tm_mon) + "," + "DST day=" + str(ltimezone.tm_mday) + "," + "DST hour=" + str(ltimezone.tm_hour))
                        if ((ltimezone.tm_mon == dt.month) and (ltimezone.tm_mday == dt.day + 1) and (ltimezone.tm_hour + 1 == dt.hour)):
                            cronJob = "\"%i %i * * * root /opt/tivoli/tiam/bin/iaESAPatchUninstall.py\"" %(dt.minute, dt.hour + 1)
                        #endif
                    #end if
                #endif
            #endif daylight == 1:

            #print cronJob
            self.iaESAPatchInstallLogger.debug(cronJob)

            cmd = "rm -f /etc/cron.d/esapatch; /bin/echo %s >> /etc/cron.d/esapatch " %(cronJob)
            #print cmd
            self.iaESAPatchInstallLogger.debug(cmd)
            exitcode, output = callsyscmd(cmd)
            #print exitcode

            #croncmd = "/etc/init.d/cron restart; sleep 5s; /etc/init.d/cron restart"
            #print croncmd
            #self.iaESAPatchInstallLogger.debug(croncmd)
            #exitcode, output = callsyscmd(croncmd)
        except Exception, ex:
            print ex
            #self.iaESAPatchInstallLogger.error(ex.strerror)
            raise
            #print ex.strerror
    #def

    #This function will do the following thing and will be used by local and remote install
    def uninstallPatchOnLocal(self):
        self.douninstall()
        print "------Finished uninstall patch on local node! "
        self.iaESAPatchInstallLogger.debug("------Finished uninstall patch on local node!")
        exitcode = logtoaudit("UNINSTALL_ESA_PATCH", "Success")
        if exitcode != 0:
            self.iaESAPatchInstallLogger.error("Failed to write audit log on local node!")
            syslog(LOG_ERR, "Compliance---Uninstalled patch on local node!")
        #end if
    #end def

    #This function will schedule a cron jon to remove SSH session which may turn into root after unistall ESA
    def scheduleRemoveSSHCronJob(self):
        try:
            #get current time(minute, hours)
            dt = datetime.utcnow()
            cronJob = "\"*/2 * * * * root /opt/tivoli/tiam/bin/ia_compliance_security_remove_ssh_session.py\""
            #print cronJob
            self.iaESAPatchInstallLogger.debug(cronJob)
            cmd = "/bin/echo %s >> /etc/cron.d/esapatch " %(cronJob)
            #print cmd
            self.iaESAPatchInstallLogger.debug(cmd)
            exitcode, output = callsyscmd(cmd)
            #print exitcode
            #croncmd = "/etc/init.d/cron restart; sleep 5s; /etc/init.d/cron restart"
            #print croncmd
            #self.iaESAPatchInstallLogger.debug(croncmd)
            #exitcode, output = callsyscmd(croncmd)
        except Exception, ex:
            print ex
            self.iaESAPatchInstallLogger.error(ex.strerror)
            raise
            #print ex.strerror
    #def

    def douninstall(self):
        #clean up
        self.removeInstallDirectory()
        #Revoke root authority
        EnableRootAutorityHandler().revokerootauthority()
        #Schedule cron jon to remove ssh seesion
        self.scheduleRemoveSSHCronJob()
    #end if

    #This function write installation directory to file for unstalling use
    def saveInstalltionInfo(self, pathofinstall):
        cfgFile = None
        try:
            try:
                cfgFile = file("/home/iaadmin/.iaesapatchinstall", 'w')
                cfgFile.write("InstallPath=" + pathofinstall)
                self.iaESAPatchInstallLogger.info("InstallPath=" + pathofinstall)
            except Exception, ex:
                #syslog(LOG_ERR, ex.strerror)
                self.iaESAPatchInstallLogger.error(ex.strerror)
                raise
        finally:
            if cfgFile != None:
                cfgFile.close()
    #end def

    #This function write installation directory to file for unstalling use
    def getInstalltionInfo(self):
        cfgFile = None
        try:
            try:
                cfgFile = file("/home/iaadmin/.iaesapatchinstall", 'r')
                path = cfgFile.readline()
                #print path
                self.iaESAPatchInstallLogger.debug(path)
                return path
            except Exception, ex:
                #syslog(LOG_ERR, ex.strerror)
                self.iaESAPatchInstallLogger.error(ex.strerror)
                raise
        finally:
            if cfgFile != None:
                cfgFile.close()
    #end def

    #remove install idrectory
    def removeInstallDirectory(self):
        #1. clean up.
        #remove directory created during installation
        installPath = self.getInstalltionInfo()
        m = re.search('InstallPath=', installPath)
        #print m
        if (m <> None):
            startIndex = m.end()
            if(startIndex != -1):
                dir = installPath[startIndex:]
            #end if
        #end if

        #rmcmd = "rm -Rf -d " + ArchivePackageHandler.PATCH_INSTALL_PREFIX + "*"
        rmcmd = "rm -Rf -d " + dir
        #print rmcmd
        exitcode, output = callsyscmd(rmcmd)

        #2. remove iapasswdreset.py,
        #if os.path.isfile("/opt/tivoli/tiam/bin/iapasswdreset.py"):
        #    delcmd = "rm -f /opt/tivoli/tiam/bin/iapasswdreset.py"
        #    self.iaESAPatchInstallLogger.debug(delcmd)
        #    exitcode, output = callsyscmd(delcmd)
            # print exitcode
        #    if exitcode != 0:
        #        self.iaESAPatchInstallLogger.error("Failed to delete iapasswdreset.py!")
        #        raise ComplianceSecurityException("Failed to deelte iapasswdreset.py")
            #end if
        #end if
    #end def
#end class

"""
THe class ESAPatchMCInstaller provide installation on MC.
"""
class ESAPatchMCInstaller(ESAPatchInstaller):
    def __init__(self, theSourceHost, theTargetHost, thePathOfPatch, theNameOfPatch, theInstallMode, beInstall):
        #threading.Thread.__init__(self)
        super(ESAPatchInstaller,self).__init__()
        self.sourceHost = theSourceHost
        self.targetHost = theTargetHost
        self.pathOfPatch = thePathOfPatch
        self.nameOfPatch = theNameOfPatch
        self.installMode = theInstallMode
        self.listOfNodesHandler = []
        self.isInstall = beInstall
        self.iaESAPatchInstallLogger = IAESAPatchInstallLogger("ESAPatchMCInstaller").getIAESAPatchInstallLog()

    def installpatch(self):
        #install MC
        self.installPatchOnLocal(self.pathOfPatch, self.nameOfPatch)

        #print "***" + self.installMode
        if self.installMode != "-a":
            return

        #2. get nodes IP from /var/lib/dhcp/db
        #2. Do not use dhcp.leases.
        #cmd = "cat /var/lib/dhcp/db/dhcpd.leases | grep -E \"[[:space:]][0-9]*\.[0-9]*\.[0-9]*\.[0-9]*([[:space:]])\" | awk '{print $2}'"
        #exitcode, output = callsyscmd(cmd)

        #Use default nodes
        defaultNodes = ["ianode1", "ianode2", "ianode3"]
        for node in defaultNodes:
            #print node
            if self.isTheNodePingable(node):
                anothergpfsNode = ESAPatchNodeInstaller(ESAPatchInstaller.MCIP, node, self.pathOfPatch, self.nameOfPatch, self.isInstall)
                anothergpfsNode.start()
                self.listOfNodesHandler.append(anothergpfsNode)
            else:
                #print "Cannot ping node %s" % (node)
                self.iaESAPatchInstallLogger.debug("Cannot ping node %s" % (node) )
            #end if
        #end for

        for handler in self.listOfNodesHandler:
            if (handler and handler.isAlive()):
                handler.join(300)
        #end for

    #end def

    def uninstallpatch(self):
        #1. uninstall MC
        self.uninstallPatchOnLocal()

        #2. get nodes IP from /var/lib/dhcp/db
        #2. Do not use dhcp.leases.
        #cmd = "cat /var/lib/dhcp/db/dhcpd.leases | grep -E \"[[:space:]][0-9]*\.[0-9]*\.[0-9]*\.[0-9]*([[:space:]])\" | awk '{print $2}'"
        #exitcode, output = callsyscmd(cmd)

        #Use default nodes
        defaultNodes = ["ianode1", "ianode2", "ianode3"]
        for node in defaultNodes:
            #print node
            self.iaESAPatchInstallLogger.debug(node)
            if self.isTheNodePingable(node):
                anothergpfsNode = ESAPatchNodeInstaller(ESAPatchInstaller.MCIP, node, "", "", self.isInstall)
                anothergpfsNode.setInstall(False)
                anothergpfsNode.start()
                self.listOfNodesHandler.append(anothergpfsNode)
            else:
                #print "Cannot ping node %s" % (node)
                self.iaESAPatchInstallLogger.debug("Cannot ping node %s" % (node) )
            #end if
        #end for

        for handler in self.listOfNodesHandler:
            if (handler and handler.isAlive()):
                handler.join(300)
        #end for
    #end def

    def isTheNodePingable(self, theNode):
        exitcode, output = callsyscmd("ping -c 1 " + theNode)
        #print exitnode
        if exitcode != 0:
            return False
        #end if
        return True
    #end
#end class

class ESAPatchNodeInstaller(ESAPatchInstaller):
    def __init__(self, theSourceHost, theTargetHost, thePathOfPatch, theNameOfPatch, beInstall):
        #threading.Thread.__init__(self)
        super(ESAPatchInstaller,self).__init__()
        self.sourceHost = theSourceHost
        self.targetHost = theTargetHost
        self.pathOfPatch = thePathOfPatch
        self.nameOfPatch = theNameOfPatch
        self.isInstall = beInstall
        self.iaESAPatchInstallLogger = IAESAPatchInstallLogger("ESAPatchNodeInstaller").getIAESAPatchInstallLog()

    def installpatch(self):
        if self.sourceHost == "localhost":
            self.installPatchOnLocal(self.pathOfPatch, self.nameOfPatch)
        else:
            self.installPatchOnRemote(self.sourceHost, self.targetHost, self.pathOfPatch, self.nameOfPatch)
        #end if
    #end def

    def installPatchOnRemote(self, theSourceHost, theTargetHost, thePathOfPatch, theNameofPatch):
        #scp patch to local from remote
        #ssh iaadmin@targetHost installPatch(path, nameofpatch)
        #print "Remote"
        installcmd = "sudo -u iaadmin ssh iaadmin@%s esapatchinstall %s %s %s %s %s " %(theTargetHost, theSourceHost, theTargetHost, thePathOfPatch, theNameofPatch, IAESAPatchInstallLogger.DEBUG_LEVEL_STR)
        #print installcmd
        self.iaESAPatchInstallLogger.debug(installcmd)
        exitcode, output = callsyscmd(installcmd)
        hasError = False
        error = output[0]
        m = re.search('IA_ESA_PATCH_INSTALL_ERROR', error)
        if (m <> None):
            exitcode = -1

        if exitcode == 0:
            print "------Finished install patch on remote node %s!" %(theTargetHost)
            self.iaESAPatchInstallLogger.debug("------Finished install patch on remote node %s!" %(theTargetHost))
            exitcode = logtoaudit("INSTALL_ESA_PATCH", "Success")
            if exitcode != 0:
                self.iaESAPatchInstallLogger.error("Failed to write audit log on %s node! " %(theTargetHost))
                syslog(LOG_INFO, "Compliance---Installed patch on remote node %s!" %(theTargetHost))
            #end if
        else:
            print "------Failed to install patch on remote node %s!" %(theTargetHost)
            self.iaESAPatchInstallLogger.debug("------Failed to install patch on remote node %s!" %(theTargetHost))
            exitcode = logtoaudit("INSTALL_ESA_PATCH", "Failure")
            if exitcode != 0:
                self.iaESAPatchInstallLogger.error("Failed to write audit log on %s node! " %(theTargetHost))
                syslog(LOG_ERR, "Compliance---Failed to install patch on remote node %s!" %(theTargetHost))
            #end if
            # raise ComplianceSecurityException("Failed to install patch on %s" %(theTargetHost))
        #end if
    #end def

    def uninstallpatch(self):
        if self.sourceHost == "localhost":
            self.uninstallPatchOnLocal()
        else:
            self.uninstallPatchOnRemote(self.sourceHost, self.targetHost)
        #end if
    #end def

    def uninstallPatchOnRemote(self, theSourceHost, theTargetHost):
        #scp patch to local from remote
        #ssh iaadmin@targetHost installPatch(path, nameofpatch)
        #print "Remote"
        installcmd = "sudo -u iaadmin ssh iaadmin@%s esapatchuninstall %s %s %s " %(theTargetHost, theSourceHost, theTargetHost, IAESAPatchInstallLogger.DEBUG_LEVEL_STR)
        #print installcmd
        self.iaESAPatchInstallLogger.debug(installcmd)
        exitcode, output = callsyscmd(installcmd)
        #print exitcode
        if exitcode == 0:
            print "------Finished uninstall patch on remote node %s!" %(theTargetHost)
            self.iaESAPatchInstallLogger.debug("------Finished uninstall patch on remote node %s!" %(theTargetHost))
            exitcode = logtoaudit("INSTALL_ESA_PATCH", "Success")
            if exitcode != 0:
                #print exitcode
                self.iaESAPatchInstallLogger.error("Failed to write audit log on %s node! " %(theTargetHost))
                syslog(LOG_INFO, "Compliance---Uninstalled patch on remote node %s!" %(theTargetHost))
            #end if
        else:
            print "------Failed to uninstall patch on remote node %s!" %(theTargetHost)
            self.iaESAPatchInstallLogger.debug("------Failed to uninstall patch on remote node %s!" %(theTargetHost))
            exitcode = logtoaudit("INSTALL_ESA_PATCH", "Failture")
            if exitcode != 0:
                self.iaESAPatchInstallLogger.error("Failed to write audit log on %s node! " %(theTargetHost))
                syslog(LOG_ERR, "Compliance---Failed to uninstall patch on remote node %s!" %(theTargetHost))
            #end if
            raise ComplianceSecurityException("Failed to install patch on %s" %(theTargetHost))
        #end if
    #end def
#end class


class ESAPatchInstallerManager:
    def __init__(self, theInstallMode, thePathOfPatch, theNameOfPatch):
        #print "init"
        self.mode = theInstallMode
        self.pathOfPatch = thePathOfPatch
        self.nameOfPatch = theNameOfPatch
        self.currentNodeHostName = ESAPatchInstaller.MCIP
        self.listOfHandlers = []
        self.iaESAPatchInstallLogger = IAESAPatchInstallLogger("ESAPatchInstallerManager")
        self.isMCNode = True
        #must have host name
        try:
            self.isMCNode = isMCNode()
            self.currentNodeHostName = getHostInfo()
        except ComplianceSecurityException, ex:
            print "Failed to get host name or IP address"
            iaESAPatchInstallLogger.error("Failed to get host name or IP address")
        #check two thing?
        #1. is /opt/tivoli/tiam/bin/iaESAPatchInstall.py,iaESAPatchUnistall.py in /etc/sudoers
        #2. is /home/iaadmin/.ssh/authorized_keys there?
        self.iaESAPatchInstallLogger = IAESAPatchInstallLogger("ESAPatchInstallerManager").getIAESAPatchInstallLog()
    #end def

    def createInstaller(self):
        #print "create installer: " + typenode
        if self.isMCNode:
            #1. install MC local
            mcNode = ESAPatchMCInstaller("localhost", "localhost", self.pathOfPatch, self.nameOfPatch, self.mode, True)
            mcNode.start()
            self.listOfHandlers.append(mcNode)
        else:
            #install self
            #1. install self local
            #Create ESAPatchNodeInstaller thread
            gpfsNode = ESAPatchNodeInstaller("localhost", "localhost", self.pathOfPatch, self.nameOfPatch, True)
            gpfsNode.start()
            self.listOfHandlers.append(gpfsNode)

            #will ignore -a on nodes.
            if self.mode != "-a":
                return
    #end def

    def createUninstaller(self):
        #print "create installer: " + typenode
        if self.isMCNode:
            #1. install MC local
            mcNode = ESAPatchMCInstaller("localhost", "localhost", "", "", "-a", False)
            mcNode.start()
            self.listOfHandlers.append(mcNode)
        else:
            #install self
            #1. install self local
            #Create ESAPatchNodeInstaller thread
            gpfsNode = ESAPatchNodeInstaller("localhost", "localhost", "", "", False)
            gpfsNode.start()
            self.listOfHandlers.append(gpfsNode)
    #end def

    def install(self):
        self.createInstaller()
    #end def

    def uninstall(self):
        self.createUninstaller()
    #end def
#end class


#Logger class
class IAESAPatchInstallLogger:
    LOG_FILENAME_PREFIX = "/opt/tivoli/tiam/log/iaesapatchinstall-"
    DEBUG_LEVEL = ERROR
    DEBUG_LEVEL_STR = "ERROR"

    def __init__(self, nameOfLogger):
        self.logger = logging.getLogger(nameOfLogger)
        self.logger.setLevel(IAESAPatchInstallLogger.DEBUG_LEVEL)
        self.fileName = IAESAPatchInstallLogger.LOG_FILENAME_PREFIX + getHostInfo() + "-" + (date.today()).strftime("%m-%d-%Y") + ".log"
        self.handler = logging.FileHandler(self.fileName)
        self.formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
        self.handler.setFormatter(self.formatter)
        self.logger.addHandler(self.handler)
    #end def

    def getIAESAPatchInstallLog(self):
        return self.logger
    #end def

    def setLoggerLevel(self, theDebugLevel):
        #print debugLevel
        if theDebugLevel in ["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]:
            if theDebugLevel == "DEBUG":
                IAESAPatchInstallLogger.DEBUG_LEVEL = logging.DEBUG
                IAESAPatchInstallLogger.DEBUG_LEVEL_STR = "DEBUG"
            elif theDebugLevel == "INFO":
                IAESAPatchInstallLogger.DEBUG_LEVEL = logging.INFO
                IAESAPatchInstallLogger.DEBUG_LEVEL_STR = "INFO"
            elif theDebugLevel == "WARNING":
                IAESAPatchInstallLogger.DEBUG_LEVEL = logging.WARNING
                IAESAPatchInstallLogger.DEBUG_LEVEL_STR = "WARNING"
            elif theDebugLevel == "ERROR":
                IAESAPatchInstallLogger.DEBUG_LEVEL = logging.ERROR
                IAESAPatchInstallLogger.DEBUG_LEVEL_STR = "ERROR"
            elif theDebugLevel == "CRITICAL":
                IAESAPatchInstallLogger.DEBUG_LEVEL = logging.CRITICAL
                IAESAPatchInstallLogger.DEBUG_LEVEL_STR = "CRITICAL"
        #end if
    #end def
#end clas


#Added lock to protect os.waitpid call that python has bug
mylock = Lock()
def callsyscmd(cmd):
    """
    all cmd and return status output as a list of lines
    """

    TRACE_LINES = 10

    process = None
    exitcode = -1
    mylock.acquire()
    try:
        process = subprocess.Popen(cmd, stdout=subprocess.PIPE,stderr=subprocess.STDOUT, shell=True)
        pid, exitcode = os.waitpid(process.pid, 0)
    except Exception, ee:
        syslog(LOG_ERR, str(ee))
    #end try

    mylock.release() # release lock, no matter what

    output = process.stdout.readlines()
    #print output

    """
    if exitcode == 0:
        for line in output:
            print line[len(line)-1]
    """

    if (exitcode != 0):
        lnr = 0
        for line in output:
            if lnr > TRACE_LINES:
                break
            syslog(LOG_ERR, line)
            lnr += 1
    return exitcode, output
#end def


def getHostInfo():
    exitcode, output = callsyscmd("hostname")
    if exitcode != 0:
        #syslog(LOG_ERR, "Failed to get host name!")
        raise ComplianceSecurityException("Failed to get host name!")
    #end if
    if len(output) ==0 :
        #syslog(LOG_ERR, "Empty host nmae!")
        raise ComplianceSecurityException("Failed to get host name!")
    #end if
    #print "Host Name is: " + output[0].strip()
    return output[0].strip()
#end def

def isSSHCommandAllowedFromMC(theCommand):
    ALLOWED_COMMANDS = ["esapatchinstall", "esapatchuninstall", \
    "/usr/lpp/mmfs/bin/mmgetstate", "mmgetstate", \
    "/bin/echo", "echo", \
    "/opt/tivoli/tiam/bin/restoreConfigFiles", "restoreConfigFiles", \
    "/opt/tivoli/tiam/bin/ia_recovery_healthcheck.sh", "ia_recovery_healthcheck.sh", \
    "/opt/tivoli/tiam/bin/activateRecoverySite", "activateRecoverySite", \
    "/opt/tivoli/tiam/bin/ia_cfgsecondary.sh", "ia_cfgsecondary.sh", \
    "/opt/tivoli/tiam/bin/cfgSecondary.sh", "cfgSecondary.sh", \
    "/opt/tivoli/tiam/bin/ia_trace.py", "ia_trace.py", \
    "/opt/tivoli/tiam/bin/mb_create_collection_dir.py", "mb_create_collection_dir.py", \
    "/opt/tivoli/tiam/bin/mb_display_location.py", "mb_display_location.py", \
    "/opt/tivoli/tiam/bin/ia_logcollector.py", "ia_logcollector.py", \
    "/opt/tivoli/tiam/bin/nodecollector.py", "nodecollector.py", \
    "/opt/tivoli/tiam/bin/ia_force_ssh_key_regen", "ia_force_ssh_key_regen", \
    "/opt/tivoli/tiam/bin/network_health.sh", "network_health.sh", \
    "/opt/tivoli/tiam/bin/pushLogCollectionToMC.sh", "pushLogCollectionToMC.sh", \
    "/opt/tivoli/tiam/bin/copyRASlogs.sh", "copyRASlogs.sh", \
    "/opt/tivoli/tiam/bin/ia_service.py", "ia_service.py", \
    "/opt/tivoli/tiam/bin/ia_run_dsa.sh", "ia_run_dsa.sh", \
    "/opt/tivoli/tiam/bin/ia_run_grablogs.sh", "ia_run_grablogs.sh", \
    "/opt/tivoli/tiam/bin/ia_run_hsmcollect.sh", "ia_run_hsmcollect.sh", \
    "/opt/tivoli/tiam/bin/ia_run_gpfssnap.sh", "ia_run_gpfssnap.sh", \
    "/opt/tivoli/tiam/bin/ia_run_middleware.sh", "ia_run_middleware.sh", \
    "/opt/tivoli/tiam/bin/ia_iss.sh", "ia_iss.sh", \
    "/opt/tivoli/tiam/bin/ia_dir_agent.sh", "ia_dir_agent.sh", \
    "/opt/tivoli/tiam/bin/ia_configure_common_agent.sh", "ia_configure_common_agent.sh", \
    "/opt/tivoli/tiam/bin/checkNode.sh", "checkNode.sh", \
    "/bin/date", "date", \
    "/usr/lpp/mmfs/bin/mmtracectl", "mmtracectl", \
    "/usr/lpp/mmfs/bin/mmlscluster", "mmlscluster", \
    "/opt/tivoli/tiam/bin/ia_kdump_switch", "ia_kdump_switch", \
    "/opt/tivoli/tiam/bin/ia_update_nodes_file.py", "ia_update_nodes_file.py", \
    "/opt/tivoli/tiam/bin/ia_restore_from_tsm.py", "ia_restore_from_tsm.py", \
    "/opt/tivoli/tiam/bin/ia_backup_config_tsm_server.py", "ia_backup_config_tsm_server.py", \
    "/opt/tivoli/tiam/bin/ia_backup_start_scheduler.sh", "ia_backup_start_scheduler.sh", \
    "/opt/tivoli/tiam/bin/ia_backup_stop_scheduler.sh", "ia_backup_stop_scheduler.sh", \
    "/opt/tivoli/tiam/bin/ia_backup_getlogs.sh", "ia_backup_getlogs.sh", \
    "/opt/tivoli/tiam/bin/ia_set_tsmnode_pw.sh", "ia_set_tsmnode_pw.sh", \
    "/opt/tivoli/tiam/bin/ia_get_connected_nfs_hosts.sh", "ia_get_connected_nfs_hosts.sh", \
    "/opt/tivoli/tiam/bin/ia_get_connected_cifs_hosts.sh", "ia_get_connected_cifs_hosts.sh", \
    "/usr/bin/dsmdf", "dsmdf", "/usr/sbin/nfsstat", "nfsstat", \
    "/opt/tivoli/tiam/bin/ia_hsm_reconcile.sh", "ia_hsm_reconcile.sh", \
    "/opt/tivoli/tiam/bin/ia_find_luns.py", "ia_find_luns.py", \
    "/opt/tivoli/tiam/bin/add_disks.py", "add_disks.py", \
    "/opt/tivoli/tiam/bin/ia_get_recent_nfs_hosts.sh", "ia_get_recent_nfs_hosts.sh", \
    "/opt/tivoli/tiam/bin/verify_node_local", "verify_node_local", \
    "/opt/tivoli/tiam/bin/verify_ports", "verify_ports", \
    "/usr/bin/ls", "ls", \
    "/usr/sbin/dmidecode", \
    "/opt/tivoli/tiam/bin/create_gpfs", \
    "/opt/tivoli/tiam/bin/change_bond1_static.sh", \
    "/bin/date", \
    "/opt/tivoli/tiam/bin/ia_generate_iacluster_config", \
    "/opt/tivoli/tiam/bin/ia_ctdb_cluster_config.sh", \
    "/opt/tivoli/tiam/bin/ia_repair_node_config.py", \
    "/opt/tivoli/tiam/bin/add_node_update_tiebreaker.py", \
    "/opt/tivoli/tiam/bin/get_ssh_keys.sh" ]

    if theCommand in ALLOWED_COMMANDS:
        return True
    else:
        return False
    #end of
#end if

def logtoaudit(action, result):
    """function for writing to the IAM audit log"""
    cmd = 'iam_log_insert -c esapatch -a -t IAM_EVENT_EXT_' + action
    cmd += ' -l "result=%s"' % (result)
    exitcode, output = callsyscmd(cmd)
    return exitcode

def isMCNode():
    cmd = "cat /etc/hosts | grep [[:space:]]iamconsole1 | awk '{print $1}'"
    syslog(LOG_INFO, cmd + " From function isMCNode")
    exitcode, output = callsyscmd(cmd)
    syslog(LOG_INFO, str(output) + " From function isMCNode")
    if exitcode != 0:
        syslog(LOG_ERR, str(exitcode) + " From function isMCNode")
        raise ComplianceSecurityException("Failed to get the ip address of iamconsole1 from /etc/hosts!")
    #end if
    ipofmc = output[0].strip()
    syslog(LOG_INFO, "IP=" + str(ipofmc) + " From function isMCNode")
    cmd = "cat /etc/sysconfig/network/ifcfg-bond1 | grep IPADDR"
    exitcode, output = callsyscmd(cmd)
    syslog(LOG_INFO, cmd + " exitcode=" + str(exitcode) + " output=" + str(output) + " From function isMCNode")
    if exitcode != 0:
        syslog(LOG_ERR, str(exitcode) + " From function isMCNode")
        raise ComplianceSecurityException("Failed to get the private ip address of node!")
    #end if
    #print "Host Name ip is: " + output[0].strip()
    m = re.search(ipofmc, output[0])
    syslog(LOG_INFO, "m = re.search(ipofmc, output[0]) " + str(m) + " From function isMCNode")
    #print m
    if (m <> None):
        return True
    #end if
    return False
#end def
