#!/bin/bash
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Description:
#    ia_dir_change_userpassword.sh changes the password for a user that is a member of a valid IBM Director group
#
#    The format requires an input of the username.  It validates that the user is a member
#    of one of the valid groups for Director, and then calls the passwd command.
#
# Syntax:
#    ia_dir_change_user_password.sh -u user_name
#
# Results:
#  The password for the given IBM Director user will be changed
#
# Change history
#   Modifier      Date         CQ Change       Description
#   -----------------------------------------------------------------------------------
#   Brad Trubey   07/09/2009   TIAMC00007027   renamed to conform to IA convention
# *************************************************************************************


user=""

# Source the RAS functions for logging utilities
. /opt/tivoli/tiam/bin/ras_functions
rc_reset
create_new_log_file dir_users

#  Usage: error "error message"
error() {
   ras_log $1
   echo "$0: $1"
   echo "Try '$0 -h' for more information."
   exit 1
}

#Output helpful information regarding how to use the function and its parameters
help() {
   echo "usage:  $0 -u <user>"
   echo "where:"
   echo "   -u Specify the Director user to be modified."
   exit 0
}

#Check user to ensure is member of allowed director group
check_groups() {

   in_groups="0"

   for i in `groups $1 | cut -f2 -d':'`; do
      if [ $i = "iadiradmin" ] || [ $i = "smmgr" ] || [ $i = "smmon" ] || [ $i = "smuser" ] ; then
         in_groups="1"
      elif [ $1 = "smadmin" ] ; then
         in_groups="2"
      fi
   done

   return ${in_groups}
}

ras_log "ia_dir_change_user_password.sh invoked to modify user password"

# Get the user and group
while getopts ":hu:" optchar ; do
   case $optchar in
   u) user=$OPTARG
      ;;
   h) help
      ;;
   *) error "Invalid option"
      ;;
   esac
done



# Ensure that we got a user
if [ "${user}" == "" ] ; then
   error "No user specified"
fi


# Ensure that we are not trying to change password for iaadmin
if [ "${user}" == "iaadmin" ] ; then
   error "Attempt to change password for iaadmin.  Do not use this function to change the password for iaadmin."
fi

#Check to see if the username is part of a legal IBM Director group
check_groups ${user}
grp_check=$?
if (( ${grp_check} != "1" )) ; then
   error "${user} is not a member of a legal IBM Director group."
fi


# change the user password
echo "You will now be asked to enter the new password for the user: ${user}"
passwd ${user}
rc=$?

#Make sure that we were able to change the password
if (( $rc != "0" )) ; then
   error "Could not set password for user: ${user}"
fi

#If we get this far, everything worked
echo "Successfully set password for user: ${user}"

exit $rc


