#!/bin/bash
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Description:
#    ia_dir_delete_user.sh removes userids from IBM Director groups
#
#    The format requires an input of the username.  It validates that the user is a valid member
#    of an IBM Director group.
#
# Syntax:
#    ia_dir_delete_user.sh -u user_name
#
# Results:
#    Removal of the userid as a member of the Director group specified and removal of userid
#
# Change history
#   Modifier      Date         CQ Change       Description
#   -----------------------------------------------------------------------------------
#   Brad Trubey   07/09/2009   TIAMC00007027   renamed to conform to IA convention
# *************************************************************************************


rem_user=""

# Source the RAS functions for logging utilities
. /opt/tivoli/tiam/bin/ras_functions
rc_reset
create_new_log_file dir_users

#  Usage: error "error message"
error() {
   ras_log $1
   echo "$0: $1"
   echo "Try '$0 -h' for more information."
   exit 1
}

#Output helpful information regarding how to use the function and its parameters
help() {
   echo "usage:  $0 -u <user>"
   echo "where:"
   echo "   -u Specify the director user to be removed."
   exit 0
}

#Check user to ensure is member of allowed director group
check_groups() {

   in_groups="0"

   for i in `groups $1 | cut -f2 -d':'`; do
      if [ $i = "iadiradmin" ] || [ $i = "smmgr" ] || [ $i = "smmon" ] || [ $i = "smuser" ] ; then
         in_groups="1"
      elif [ $1 = "smadmin" ] ; then
         in_groups="2"
      fi
   done

   return ${in_groups}
}


ras_log "ia_dir_delete_user.sh invoked to remove specified userid"

# Get the user and group
while getopts ":hu:" optchar ; do
   case $optchar in
   u) rem_user=$OPTARG
      ;;
   h) help
      ;;
   *) error "Invalid option"
      ;;
   esac
done

ras_log "User is ${rem_user}"


# Ensure that we got a user
if [ "${rem_user}" == "" ] ; then
   error "No user specified"
fi

# Ensure that we are not trying to remove iaadmin
if [ "${rem_user}" == "iaadmin" ] ; then
   error "Attempt to remove iaadmin"
fi

# Validate the group as one of the groups allowable, note we allow removal of a user from
#   smadmin even though we do not allow adding a user to that group
check_groups ${rem_user}
grp_check=$?
if (( ${grp_check} != "1" )) && (( ${grp_check} != "2" )) ; then
   error "${rem_user} is not a member of a legal IBM Director group."
fi


rc=0

# Remove the user
userdel -r ${rem_user}

rc=$?

ras_log "Attempted to remove user: ${rem_user} from group: ${dir_group} rc is $rc"
if !(( $rc == 0 )); then
   ras_log "Remove user failed with return code $rc"
   error "Remove user failed"
fi

if (( $rc == 0 )); then
   echo "Successfully removed user: ${rem_user}"
fi

exit $rc


