#!/bin/bash
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Filename: ia_dir_server.sh
#
# Component: RAS
#
# Description:
#    This file contains a bash script for start, stop, status and reset of the IBM Director Server.
#
#  Usage:
#      ia_dir_server.sh start|stop|status
#      start: Starts the Director Server
#      stop: Stops the Director Server
#      status: Get the status of the Director Server
#      reset: Resets the Director Server to original install values
#
# Change history
#   Modifier      Date         CQ Change       Description
#   -----------------------------------------------------------------------------------
#   Del Ence      06/25/2009   TIAMC00007006   Initial creation
#   Brad Trubey   07/09/2009   TIAMC00007027   renamed to conform to IA convention
#  Del Ence         02/19/2010    TIAMC00011525   Updated so that error message is easier to read
# *************************************************************************************

USAGE="Usage: $0 start|stop|status|reset"
CMD="$1"

# include ras_functions
. /opt/tivoli/tiam/bin/ras_functions
. /opt/tivoli/tiam/bin/dir_functions
rc_reset

# log the actions taken by this script
create_new_log_file ia_dir_server

# Validate the agent commands as one of the following  start|stop|status
case "${CMD}" in
   "start" | "stop" | "status" | "reset" )
     ras_log "Valid server command found : ${CMD}";;
   "" ) ras_log -v "Error, server command not provided.\n$USAGE"
      exit 1;;
   *) ras_log -v "Error, invalid server command \"${CMD}\".\n$USAGE"
      exit 1;;
esac

ras_log "Running Director server '${CMD}' command."

if [ "${CMD}" == "start" ]; then
    start_director
    rc=$?
elif [ "${CMD}" == "stop" ]; then
    stop_director
    rc=$?
elif [ "${CMD}" == "status" ]; then
    status_director
    rc=$?
elif [ "${CMD}" == "reset" ]; then
    reset_director
    rc=$?
fi

exit $rc
