#!/bin/bash
#
#******************************************************************************
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp.  2008  All Rights Reserved
#
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -----------------------------------------------------------------------------
# 
# =========================================================================
# 
# Name: ia_ermresume.sh 
#
# Change Log:
#  Date           developer               change
#  02/03/2010     Liming (Michael) Yu     Initial script creation
#  04/30/2010     Liming (Michael) Yu     13214: move gathering of SSNAME to
#                                         where we make create remoteMirror call
#  05/20/2010     Liming (Michael) Yu     13737: added writeConsistency=TRUE
#                                         for async
#
#******************************************************************************


DRLOG="/opt/tivoli/tiam/log/dr"

SCRIPTNAME="ia_ermresume"
SMCLI="/usr/bin/SMcli"
datestamp=`date +%m%d%Y%H%M%S`
LOGFILE="${DRLOG}/ia_ermresume.${datestamp}.out"


usage() {
  echo " ia_ermresume.sh "
  echo "              -h                 help/usage information"
  echo " "
  echo "    eg.   ia_ermresume.sh"
  return 0
}


log() {
  timestamp=`date "+%Y-%m-%d %H:%M:%S"`
  echo "$timestamp [$SCRIPTNAME] $1" >> $LOGFILE
}


printAndLog() {
  timestamp=`date "+%Y-%m-%d %H:%M:%S"`
  echo "$timestamp [$SCRIPTNAME] $1"
  echo "$timestamp [$SCRIPTNAME] $1" >> $LOGFILE
}


printAndLogErrorExit() {
  timestamp=`date "+%Y-%m-%d %H:%M:%S"`
  echo "$timestamp [$SCRIPTNAME] ERROR($1): $2"
  echo "$timestamp [$SCRIPTNAME] ERROR($1): $2" >> $LOGFILE
  echo "$timestamp [$SCRIPTNAME] Exiting script with rc=$1. Please refer to the logfile @ $LOGFILE"
  echo "$timestamp [$SCRIPTNAME] Exiting script with rc=$1" >> $LOGFILE
  exit $1
}


resumeERM() {
  log "Enter resumeERM()"

  #determine the writeMode
  hasMirror=0
  currentWritemode="None"
  DSNAME=`${SMCLI} ${CTRLA} ${CTRLB} -c "show storagesubsystem summary;" | grep -i "PROFILE FOR STORAGE SUBSYSTEM" | cut -d: -f2 | awk '{ print $1 }'`

  LUNS=(`${SMCLI} ${CTRLA} ${CTRLB}  -c "show alllogicaldrives;" |grep -i "logical drive name" | grep -v "Mirror" | cut -d: -f2 | awk '{ print $1 }'`)
  WRITEMODE=(`${SMCLI} ${CTRLA} ${CTRLB}  -c "show storagesubsystem;" | grep -w "Write mode:" | awk '{print $3$4}'`)

  if [ ${#WRITEMODE[*]} -eq 0 ]; then
    hasMirror=0
  else
    for (( x = 0 ; x < ${#LUNS[@]} ; x++ ));
    do
      hasMirror=1
      printAndLog "Setting write mode for ${LUNS[$x]} to Consistent Mirror Group."
      cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set remoteMirror localLogicalDrive[\"${LUNS[$x]}\"] writeOrder=preserved writeMode=asynchronous;"`
      result=`echo $?`
        if [ $result != 0 ]; then
          echo $cmd >> $LOGFILE
          printAndLog "Setting ${LUNS[$x]} failed!"
        fi

    done
  fi
  if [ $hasMirror == 0 ]; then
    printAndLog "All of the mirrors are removed! Selecting to recreate all of the mirrors in Consistent Mirror Group"
  fi


  for LUNNAME in ${LUNS[@]};
  do
    #we only care about ia or util luns for resuming
    if [[ `echo $LUNNAME | grep -i ia` || `echo $LUNNAME | grep -i util` ]]; then
      if [ $hasMirror == 0 ]; then
        SSNAME=`${SMCLI} ${MIRRORCTRLA} ${MIRRORCTRLB} -c "show storagesubsystem summary;" | grep -i "PROFILE FOR STORAGE SUBSYSTEM" | cut -d: -f2 | awk '{ print $1 }'`
        result=`echo $?`
        if [ $result != 0 ]; then
          echo $SSNAME >> $LOGFILE
          printAndLogErrorExit 4 "SMcli command to obtain SSNAME failed! Please check the storage subsystem on the secondary site"
        fi

        printAndLog "Pairing $LUNNAME to $LUNNAME on $SSNAME in Consistent Mirror Group"
        cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "create remoteMirror primary=\"$LUNNAME\" secondary=\"$LUNNAME\" remoteStorageSubsystemName=\"$SSNAME\" autoResync=disabled writeOrder=preserved writeMode=asynchronous;"`
        result=`echo $?`
        if [ $result != 0 ]; then
          echo $cmd >> $LOGFILE
          printAndLog "Pairing $LUNNAME failed!"
        fi
      
      else
        cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "show remoteMirror localLogicalDrive[\"$LUNNAME\"] synchronizationProgress;"`
        result=`echo $?`

        #mirror is broken, create a new mirror
        if [ $result != 0 ]; then
          printAndLog "The remote mirror for $LUNNAME was removed, repairing mirrored pair."
          echo $cmd >> $LOGFILE

          SSNAME=`${SMCLI} ${MIRRORCTRLA} ${MIRRORCTRLB} -c "show storagesubsystem summary;" | grep -i "PROFILE FOR STORAGE SUBSYSTEM" | cut -d: -f2 | awk '{ print $1 }'`
          result=`echo $?`
          if [ $result != 0 ]; then
            echo $SSNAME >> $LOGFILE
            printAndLogErrorExit 4 "SMcli command to obtain SSNAME failed! Please check the storage subsystem on the secondary site"
          fi

          printAndLog "Pairing $LUNNAME to $LUNNAME on $SSNAME in Consistent Mirror Group"
          cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "create remoteMirror primary=\"$LUNNAME\" secondary=\"$LUNNAME\" remoteStorageSubsystemName=\"$SSNAME\" autoResync=disabled writeOrder=preserved writeMode=asynchronous;"`
          result=`echo $?`
          if [ $result != 0 ]; then
            echo $cmd >> $LOGFILE
            printAndLog "Pairing $LUNNAME failed!"
          fi

          continue
        fi
      fi
    fi
  done
  printAndLog "Resuming remote mirror for Consistent Mirror Group on $DSNAME"
  cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "resume remoteMirror primary [\"${LUNS[0]}\"] writeConsistency=TRUE;"`
  result=`echo $?`
  if [ $result != 0 ]; then
     echo $cmd >> $LOGFILE
     printAndLog "Resuming remote mirror for Consistent Mirror Group on $DSNAME failed!"
  fi
         
  log "Exit resumeERM() with rc=0"
}


#======= beginning of the main function =======

ls $DRLOG > /dev/null 2>&1
rc=$?
if [ $rc -ne 0 ]; then
  mkdir $DRLOG
fi

printAndLog "Starting the ERM resume on all logical drives"

CTRLA=""
CTRLB=""

while [ "$1" != "" ]
do
  case $1 in
  -h | -? | --help )
    usage
    exit
    ;;
  * )
    printAndLogErrorExit -1 "Invalid input parameter. Please enter ia_ermresume.sh --help to see the usage"
  esac
done

ls /opt/tivoli/tiam/etc/DR_ENABLED > /dev/null 2>&1
rc=$?
if [ $rc -ne 0 ]; then
  printAndLogErrorExit 0 "Cannot resume ERM if DR is not enabled"
else
  ls /opt/tivoli/tiam/etc/DR_SECONDARY > /dev/null 2>&1
  rc=$?
  if [ $rc -eq 0 ]; then
    printAndLogErrorExit 0 "Cannot resume ERM if running on DR secondary"
  fi
fi

ssystems=(`cat /home/iaadmin/.tiam/application.properties |grep ds4k |cut -d= -f2`)
if [[ ${#ssystems[@]} -lt 2 ]]; then
  printAndLogErrorExit 1 "Invalid or missing data in applications.properties"
fi 

ctrlCount=0
while [ $ctrlCount -lt ${#ssystems[@]} ]
do
  if [[ ${ssystems[$ctrlCount]} =~ "disk_ctrl" ]]; then
    CTRLA=${ssystems[$ctrlCount]}
    NUMBER=`echo ${ssystems[$ctrlCount]} |cut -d_ -f3 |awk '{print $1}'`
    LETTER=`echo ${ssystems[$ctrlCount]} |cut -d_ -f4 |awk '{print $1}'`
    MIRRORCTRLA="mirror_ctrl_${NUMBER}_${LETTER}"
  else
    printAndLogErrorExit 2 "Either an IP address or a hostname that does not start with \"disk_ctrl\" was found in applications.properties. Please correct and retry"
  fi

  if [[ ${ssystems[$(($ctrlCount+1))]} =~ "disk_ctrl" ]]; then
    CTRLB=${ssystems[$(($ctrlCount+1))]}
    NUMBER=`echo ${ssystems[$ctrlCount+1]} |cut -d_ -f3 |awk '{print $1}'`
    LETTER=`echo ${ssystems[$ctrlCount+1]} |cut -d_ -f4 |awk '{print $1}'`
    MIRRORCTRLB="mirror_ctrl_${NUMBER}_${LETTER}"
  else
    printAndLogErrorExit 3 "Either an IP address or a hostname that does not start with \"disk_ctrl\" was found in applications.properties. Please correct and retry"
  fi

  resumeERM

  ctrlCount=$(($ctrlCount+2))  
done

timestamp=`date "+%Y-%m-%d %H:%M:%S"`
echo "$timestamp [$SCRIPTNAME] ERM has been successfully resumed on all logical drives"
echo "$timestamp [$SCRIPTNAME] ERM has been successfully resumed on all logical drives" >> $LOGFILE
/opt/tivoli/tiam/bin/checkMirrorStatus.sh
echo "$timestamp [$SCRIPTNAME] Exiting script with rc=0. Please refer to the logfile @ $LOGFILE"
echo "$timestamp [$SCRIPTNAME] Exiting script with rc=0" >> $LOGFILE
exit 0
