#!/usr/bin/python

########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2010
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

import sys
import os
import time
import commands
import logging
import logging.handlers
import copy

LOG_FILENAME = "/var/opt/tivoli/tiam/log/ia_find_luns.log"
logMessageTemplate = "%c ia_find_luns:"

rescan_scsi_cmd = "/bin/rescan-scsi-bus.sh -l"
multipath_cmd = "/sbin/multipath"

def ssh_to_node(ip):
        return str('ssh -o BatchMode=yes '+ip)

def write_to_logfile(text_to_log):
    logTime = time.localtime(time.time())
    logMessage = logMessageTemplate + text_to_log
    logMessage = time.strftime(logMessage, logTime)
    my_logger.debug(logMessage)

def write_to_logfile2(command,status,output):
    text_to_log = "command="+command+"\nstatus="+str(status)+"\noutput="+output
    write_to_logfile(text_to_log)

def write_to_logfile3(command,status):
    text_to_log = "command="+command+"\nstatus="+str(status)
    write_to_logfile(text_to_log)

def run_commands_on_node(hostname):
    command = str(ssh_to_node(hostname)+' '+rescan_scsi_cmd)
    (status,output) = commands.getstatusoutput(command)
    write_to_logfile2(command,status,output)
    if status != 0:
        return(status)

    command = str(ssh_to_node(hostname)+' '+multipath_cmd)
    (status,output) = commands.getstatusoutput(command)
    write_to_logfile2(command,status,output)
    if status != 0:
        return(status)

    return(status)

def verify_all_nodes_up():
    hostname_list = list()
    (status, output) = commands.getstatusoutput('/opt/tivoli/tiam/bin/wd_printnodestates.sh')
    if status != 0:
        return (status,hostname_list)
    total_nodes = len(output.splitlines())
    for line1 in output.splitlines():
        line2 = line1.split()
        if line2[2] != 'active':
            return (-1,hostname_list)
        else:
            hostname_list.append(line2[1])

    return (0,hostname_list)

def fail():
    print "Failed to find LUNs"
    print "     Please check "+LOG_FILENAME+" for more information"
    sys.exit(1)

#-------------------------------------------------------------------------------
# MAIN SCRIPT
#-------------------------------------------------------------------------------

my_logger = logging.getLogger('ia_find_luns_logger')
my_logger.setLevel(logging.DEBUG)
handler = logging.handlers.RotatingFileHandler(
              LOG_FILENAME, maxBytes=(10*1024*1024), backupCount=5)
my_logger.addHandler(handler)

(status,hostname_list) = verify_all_nodes_up()
if status == 0:
    write_to_logfile("completed verify_all_nodes_up")
    write_to_logfile("scanning for new LUNs on the following nodes: "+str(hostname_list))

    for hostname in hostname_list:
        (status) = run_commands_on_node(hostname)
        if (status != 0):
            write_to_logfile("unable to find LUNs on node: "+str(hostname))
            fail()
else:
    write_to_logfile("One or more GPFS nodes are down")
    fail()

print "SUCCESS. For details see the log file: "+LOG_FILENAME
sys.exit(0)
