#!/bin/bash
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Description:
#    ia_getalldates.sh attempts to get the current date from every node in the
#    appliance, as close to each other as possible.  This can be useful for problem
#    determination.
#
# Syntax:
#    ia_getalldates.sh
#
# Results:
#    Datestamps are dumped to stdout
#
# Change history
#   Modifier      Date         CQ Change       Description
#   -----------------------------------------------------------------------------------
#   Brad Trubey   12/11/2009   TIAMC00009878   Original version
#   Brad Trubey   02/09/2010   TIAMC00011770   Added date formatting to show timezone.
#   Brad Trubey   06/11/2010   TIAMC00013770   Remove unneeded English text from main path
# *************************************************************************************

chuser=""
if [ `whoami` != "iaadmin" ] ; then
  chuser="sudo -u iaadmin"
fi

# Get time from MC node
echo "iamconsole1: `date +%F%t%T%t%Z%:z`"

# Get time from GPFS nodes
nodeCnt=`grep ",ianode" /opt/tivoli/tiam/etc/nodes | wc -l`
for (( x=1; x<=$nodeCnt; x++ ))
do
  pingRC=`ping ianode${x} -c 2 | grep error | wc -l`
  if [ 0 -eq $pingRC ] ; then
    echo "ianode${x}:     `$chuser ssh iaadmin@ianode${x} date +%F%t%T%t%Z%:z`"
  else
    echo "Cannot contact node ianode${x}"
  fi
done

# Get time from RSM node
pingRC=`ping iarsm1 -c 2 | grep error | wc -l`
if [ 0 -eq $pingRC ] ; then
  echo "iarsm1:      `ssh iarsm1 date +%F%t%T%t%Z%:z`"
else
  echo "Cannot contact node iarsm1"
fi

