#!/bin/sh
########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Workload Manager
# *
# * FILE NAME:       ia_getnodeaddress.sh
# *
# * DESCRIPTION:     Provides a mechanism to obtain the various
# *                  network addresses associated with IA nodes
# *                  based on the node hostname on the internal
# *                  private network in the appliance.
# *
# * AUTHOR:          Michael A. Richmond
# *                  IBM Almaden Research Center
# *                  mar@almaden.ibm.com
# *
# ****************************************************************************
# */
# ----------------------------------------------------------------------------
# ----------------------------------------------------------------------------
#               Change Log
#               ----------
#  02 Oct 2008  Initial version.
#
#  29 Oct 2008  Fixed bug related to node101 being defined in
#               /etc/hosts breaking lookup for node1
#
#  08 Nov 2008  Fixed bug caused by changes to contents of 
#               /etc/hosts file generated by installation scripts.
#
#  03 Mar 2009  Updated to match changes in naming conventions in
#               /etc/hosts file for IA appliance.
#
#

# Configure shell variables
. `dirname $BASH_SOURCE`/mw_environment.sh

#DEBUG=1         	# DEBUG on
DEBUG=0         	# DEBUG off

operation=""
node_name=""

print_help()
{
    echo "" 1>&2
    echo "usage:    $0 [-internal|-external|-pwrctl] <node_name>" 1>&2
    echo "" 1>&2
    echo "where:" 1>&2
    echo "          -internal    prints the internal network ip for <node_name>" 1>&2
    echo "          -external    prints the external network ip for <node_name>" 1>&2
    echo "          -pwrctl      prints the power control hardware ip for <node_name>" 1>&2
    echo "" 1>&2
    echo "Note: The '-external' operation is not currently implemented." 1>&2
    echo "" 1>&2
    exit 1
}


parse_args()
{
    case ${1} in
        -internal)
            operation="internal"
            ;;
        -external)
            operation="external"
            ;;
        -pwrctl)
            operation="pwrctl"
            ;;
        *)
            echo "error: unknown operation specified" 1>&2
            operation="help"
            ;;
    esac

    node_name=${2}
}

HOSTSFILE=/etc/hosts
get_ip_from_etchosts()
{
    node_ip=`cat ${HOSTSFILE} | awk '{print $1 " " $2}' | grep "[[:space:]]${node_name}$" | cut -d ' ' -f 1`

    if [ -z ${node_ip} ]; then
        echo "error: unable to find ip for node '${node_name}'" 1>&2
        exit 1
    fi

    echo ${node_ip}
}

get_pwrctl_ip()
{
    PWRCTLPREFIX="pwrctl-"
    pwrctl_ip=`cat ${HOSTSFILE} | awk '{print $1 " " $2}' | grep "[[:space:]]${PWRCTLPREFIX}${node_name}$" | cut -d ' ' -f 1`

    if [ -z ${pwrctl_ip} ]; then
        echo "error: unable to find power control hardware ip for node '${node_name}'" 1>&2
        exit 1
    fi

   echo "${pwrctl_ip}"
}


if [ "$#" != "2" ]; then
    print_help $0
fi

parse_args $@

if [ ${DEBUG} -eq 1 ]; then
    echo "[DEBUG] operation=${operation}"
    echo "[DEBUG] node_name=${node_name}"
fi

case ${operation} in
    internal)
	get_ip_from_etchosts
        ;;
#    external)
#	get_ip_from_etchosts
#        ;;
    pwrctl)
	get_pwrctl_ip
        ;;
    help)
        print_help $0
        ;;
    *)
        echo "error: encounted unimplemented operation" 1>&2
        ;;
esac
