#!/bin/bash
#
#******************************************************************************
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp.  2010 All Rights Reserved
#
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -----------------------------------------------------------------------------
#
# =========================================================================
#
# Name: ia_mes_storagesubsystem.sh
#
# Change Log:
#  Date          Developer        Defect         Description
#  Feb 7, 2010   Robert Guthrie                  Initial script creation
#  04/23/2010    Brad Trubey      TIAMC00013107  move logs to location where they will get collected
#  10/27/2010    Brad Trubey      TIAMC00015805  don't use datestamp in log name, use ".log" extension
#  12/02/2010     Del Ence          TIAMC00016008  Preserve return code from other scripts if non zero then exit with that value
#******************************************************************************

mkdir -p /var/opt/tivoli/tiam/log
LOGFILE="/var/opt/tivoli/tiam/log/ia_mes_storagesubsystem.log"

usage() {
  echo " ia_mes_storagesubsystem.sh -a <ipaddress> -b <ipaddress>"
  echo "       -a                 IP Address of controller A"
  echo "       -b                 IP Address of controller B"
  echo "       -h                 help/usage information"
  echo " "
  echo "    eg.   ia_mes_storagesubsystem.sh -a 172.31.0.100 -b 172.31.0.101"
  return 0
}

# ************************************************************************
# ************************************************************************
# Function: fail
# - send the configuration failure message to stdout
# - In (optional): $1: return code to use when exiting script
# ************************************************************************
# ************************************************************************
fail() {
  echo "Configuration FAILED."     | tee -a $LOGFILE
  echo "Please check $LOGFILE for more information"     | tee -a $LOGFILE
  
  if [ -n "$1" ]; then
    exit $1
  else
    exit 1
  fi
}

# Script requires exactly 4 parameters in a specific order.
if [ $# != 4 ]; then
  usage
  exit 0
else
  if [ "$1" = "-a" ]; then
      CTRLA=$2
  else
      usage
      exit 0
  fi

  if [ "$3" = "-b" ]; then
      CTRLB=$4
  else
      usage
      exit 0
  fi
fi

if [[ $CTRLA =~ "disk_ctrl" ]] || [[ $CTRLA =~ "mirror_ctrl" ]]; then
  CTRLA=`cat /etc/hosts | grep $CTRLA |awk '{print $1}'`
fi

if [[ $CTRLB =~ "disk_ctrl" ]] || [[ $CTRLB =~ "mirror_ctrl" ]]; then
  CTRLB=`cat /etc/hosts | grep $CTRLB |awk '{print $1}'`
fi

# SMcli commands must be run as root
if [ `whoami` == "root" ]; then
    echo "=======Start Script $0 `date`=====" >> $LOGFILE
    $(cd $(dirname "$0") ; pwd -P)/ia_storage_common.sh -a $CTRLA -b $CTRLB -l $LOGFILE -m
    rc=$?
    if [ $rc -ne 0 ]; then
        fail $rc
    fi

    echo "First stage complete.  Adding host ports"     | tee -a $LOGFILE
    $(cd $(dirname "$0") ; pwd -P)/ia_addhostports.sh -a $CTRLA -b $CTRLB
    rc=$?
    if [ $rc -ne 0 ]; then
        fail $rc
    fi

    echo "Second stage complete.  Mapping LUNs"     | tee -a $LOGFILE
    $(cd $(dirname "$0") ; pwd -P)/mapLuns.sh -a $CTRLA -b $CTRLB -m
    rc=$?
    if [ $rc -ne 0 ]; then
        fail $rc
    fi
else
   echo "You must be root (or use sudo) to run this script."     | tee -a $LOGFILE
   fail
fi

echo "Configuration complete.  Please see $LOGFILE for additional details"     | tee -a $LOGFILE
exit 0


