#! /bin/bash

########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2009
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

# Configure shell variables
. `dirname $BASH_SOURCE`/mw_environment.sh

logPath="/opt/log/CTJID/mmfs"
mkdir -p $logPath

IIAExit_quorum_loss_log="$logPath/IIAExit_quorum_loss"
IIAExit_quorum_loss_log_rotated="$logPath/IIAExit_quorum_loss.rotated"

upgradeNotificationFile="/opt/tivoli/tiam/var/upgradeInProgress"

tail -n 65536 $IIAExit_quorum_loss_log > $IIAExit_quorum_loss_log_rotated
mv $IIAExit_quorum_loss_log_rotated $IIAExit_quorum_loss_log

/bin/echo `/bin/date` ": Quorum Loss Detected." >> $IIAExit_quorum_loss_log

#Don't reboot if this is in upgrade mode. Upgrade handles reboots.

# Check if the upgrade notification file exists.
if [ ! -e "$upgradeNotificationFile" ]; then
    b_exists=0
else
    b_exists=1
fi
if [ $b_exists -eq 1 ]; then
    /bin/echo `/bin/date` ": Upgrade in progress, ignoring quorum loss and not issuing reboot." >> $IIAExit_quorum_loss_log
    exit 0
fi

is_secondary_output=`/opt/tivoli/tiam/bin/isSecondary.py`
is_secondary_rc=$?
/bin/echo `/bin/date` ": isSecondary output: '" $is_secondary_output "'" >> $IIAExit_quorum_loss_log
if [ $is_secondary_rc -eq 1 ]; then
    /bin/echo `/bin/date` ": System is a secondary system, ignoring quorum loss and not issuing reboot." >> $IIAExit_quorum_loss_log
    /bin/echo `/bin/date` ": Exiting" >> $IIAExit_quorum_loss_log
    exit 0
fi

/bin/echo `/bin/date` ": Reboot required" >> $IIAExit_quorum_loss_log

my_hostname=`hostname`

/opt/tivoli/tiam/bin/ia_administrativeleave -o $my_hostname > /dev/null 2>&1
if [ $? -eq 0 ] ; then
    /bin/echo `/bin/date` ": $my_hostname is on administrative leave, so not issuing reboot." >> $IIAExit_quorum_loss_log
    /bin/echo `/bin/date` ": Exiting" >> $IIAExit_quorum_loss_log
    exit 0
fi

reboot_cmd="/opt/tivoli/tiam/bin/ia_powercontrol -vvv -r $my_hostname"

/bin/echo `/bin/date` ": Rebooting self ($my_hostname) using command '$reboot_cmd'" >> $IIAExit_quorum_loss_log

reboot_output=`$reboot_cmd 2>&1`
reboot_rc=$?

/bin/echo `/bin/date` ": Command '$reboot_cmd' returned output '$reboot_output' and return code $reboot_rc" >> $IIAExit_quorum_loss_log

/bin/echo `/bin/date` ": Exiting" >> $IIAExit_quorum_loss_log
