#!/bin/sh
#
#******************************************************************************
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp.  2008  All Rights Reserved
#
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -----------------------------------------------------------------------------
# 
# =========================================================================
# 
# Name: ia_recovery_healthcheck.sh
#
# Change Log:
#  Date          developer              change
#  11/17/2009    Liming (Michael) Yu    Initial script creation
#  11/17/2009    Liming (Michael) Yu    Parse output to verify health of the
#                                       system (10754)
#  02/22/2010    Liming (Michael) Yu    Implemented phase 1 and 2
#  04/11/2010	 Bryan Jen		12789: Update mmgetstate code to retry 3 more times
#
#******************************************************************************


MMFSBIN="/usr/lpp/mmfs/bin"
TIAMBIN="/opt/tivoli/tiam/bin"
COLLECTIONS_FILE_DIR="/tiam_utility/config"
COLLECTIONS_FILE=$COLLECTIONS_FILE_DIR"/collections.middleware.xml"


usage() {
  echo " ia_recovery_healthcheck.sh"
  echo "              -h                 help/usage information"
  echo " "
  echo "    eg.   ia_recovery_healthcheck.sh"
  return 0
}


PHASE="none"

while [ "$1" != "" ]
do
  case $1 in
  -p )
    if [ "$2" == "1" ]; then
      PHASE=1
    elif [ "$2" == "2" ]; then
      PHASE=2
    else
      echo "Invalid input parameter for recovery healthcheck phase"
      exit -1
    fi
    shift;shift
    ;;
  -h | -? | --help )
    usage
    exit
    ;;
  * )
    echo "Invalid input parameter. Please enter ia_recovery_healthcheck.sh --help to see the usage" 
    exit -2
  esac
done

echo "========================================================"
echo "RESULT FROM mmgetstate -a"
echo "========================================================"
$MMFSBIN/mmgetstate -a
mmgetstateOut=`$MMFSBIN/mmgetstate -a`
mmgetstateResult=`echo $?`
if [ $mmgetstateResult -eq 0 ]; then
  echo $mmgetstateOut | grep -i unknown 1>/dev/null
  unknownNodeResult=`echo $?`
  count=0
  while [ $count -lt 4 ]
  do
    if [ $unknownNodeResult -eq 0 ]; then
      echo "Node(s) in unknown state. Waiting 15 seconds..."
      sleep 15
      count=$count+1
      mmgetstateOut=`$MMFSBIN/mmgetstate -a`
      echo $MMFSBIN/mmgetstate -a | grep -i unknown 1>/dev/null
      unknownNodeResult=`echo $?`
    else
      echo "Node(s) no longer in unknown state."
      break
    fi
  done
  if [ $unknownNodeResult -eq 0 ]; then
    mmgetstateResult=1
  fi 

  echo $mmgetstateOut | grep -i down 1>/dev/null
  downNodeResult=`echo $?`
  if [ $downNodeResult -eq 0 ]; then
    mmgetstateResult=1
  fi

  echo $mmgetstateOut | grep -i arbitrating 1>/dev/null
  arbitratingNodeResult=`echo $?`
  if [ $arbitratingNodeResult -eq 0 ]; then
    mmgetstateResult=1
  fi
fi
numNodes=`echo $mmgetstateOut | awk {'print $(NF-2)'}` 
echo ""

echo "========================================================"
echo "RESULT FROM mmlsmount for all GPFS filesystems mounted"
echo "========================================================"
mmlsfsallOut=`$MMFSBIN/mmlsfs all`
mmlsmountResult=`echo $?`

if [ $PHASE == 1 ]; then
  $MMFSBIN/mmlsmount /dev/tiam_utility -L
  mmlsmountColOut=`$MMFSBIN/mmlsmount /dev/tiam_utility -L`
  mmlsmountColResult=`echo $?`
  if [ $mmlsmountColResult -ne 0 ]; then
    mmlsmountResult=2
    break
  fi
  echo $mmlsmountColOut | grep -i "mounted on $numNodes" 1>/dev/null
  allmountedColResult=`echo $?`
  if [ $allmountedColResult -ne 0 ]; then
    mmlsmountResult=2
    break
  fi

else
  if [ $mmlsmountResult -eq 0 ]; then
    for col in `$MMFSBIN/mmlsfs all | grep -i "File system attributes for " | awk {'print $5'} | cut -d : -f 1`; do
      $MMFSBIN/mmlsmount $col -L
      mmlsmountColOut=`$MMFSBIN/mmlsmount $col -L`
      mmlsmountColResult=`echo $?`
      if [ $mmlsmountColResult -ne 0 ]; then
        mmlsmountResult=2
        break
      fi

      echo $mmlsmountColOut | grep -i "mounted on $numNodes" 1>/dev/null
      allmountedColResult=`echo $?`
      if [ $allmountedColResult -ne 0 ]; then
        mmlsmountResult=2
        break
      fi
    done
  fi
fi
echo ""

if [ $PHASE != 1 ]; then
  echo "========================================================"
  echo "RESULT FROM workloadmanager.sh -status"
  echo "========================================================"
  skipwlm=0
  collections=`/opt/tivoli/tiam/bin/wlm_enumeratecollections.sh $COLLECTIONS_FILE`
  for collection in $collections
  do
    enabled=`/opt/tivoli/tiam/bin/mw_print_xml_field collection/enabled $collection/utility/config/collection.xml`
    if [ $enabled == "false" ]; then
      echo "$collection is suspended"
      skipwlm=1
    fi
  done
  
  if [ $skipwlm -eq 1 ]; then
    echo "Skipping call to workloadmanager.sh -status"
    echo ""
  else
    $TIAMBIN/workloadmanager.sh -status
    wlmOut=`$TIAMBIN/workloadmanager.sh -status`
    wlmResult=`echo $?`
    if [ $wlmResult -eq 0 ]; then
      echo $wlmOut | grep "NODE ID=" 1>/dev/null
      wlmStartup=`echo $?`
      if [ $wlmStartup -ne 0 ]; then
        wlmResult=3
      fi

      echo $wlmOut | grep MANAGING_COLLECTIONS=\"false\" 1>/dev/null
      managingCollectionsFalse=`echo $?`
      if [ $managingCollectionsFalse -eq 0 ]; then
        wlmResult=3
      fi

      echo $wlmOut | grep MANAGER_RUNNING=\"false\" 1>/dev/null
      managerRunningFalse=`echo $?`
      if [ $managerRunningFalse -eq 0 ]; then
        wlmResult=3
      fi

      echo $wlmOut | grep "TYPE=\"symmetric\" MANAGER_RUNNING=\"true\" RUNNING=\"false\"" 1>/dev/null
      symmetricRunningFalse=`echo $?`
      if [ $symmetricRunningFalse -eq 0 ]; then
        wlmResult=3
      fi

      numCol=`echo $wlmOut | grep "COLLECTION MOUNT=" | wc -l`
      numTsmSingleton=`echo $wlmOut | grep "NAME=\"TSM\" TYPE=\"singleton\" MANAGER_RUNNING=\"true\" RUNNING=\"true\"" | wc -l`
      if [ $numTsmSingleton -ne $numCol ]; then
        #wlmResult=3
        echo "TSM is NOT running on 1 or more collections."
      fi

      #in the future, may need to handle other singletons in addition to tsm
    fi
    echo ""
  fi
fi

echo "========================================================"
echo "SUMMARY FOR ia_recovery_healthcheck.sh"
echo "========================================================"

if [ $PHASE == 1 ]; then
  if [ $mmgetstateResult -eq 0 ]; then
    echo "MMGETSTATE: pass"
  else
    echo "MMGETSTATE: fail"
  fi

  if [ $mmlsmountResult -eq 0 ]; then
    echo "MMLSMOUNT: pass"
  else
    echo "MMLSMOUNT: fail"
  fi

  if [ $mmgetstateResult -eq 0 -a $mmlsmountResult -eq 0 ]; then
    echo "HEALTH: good"
    exit 0
  else
    exitCode=""
    if [ $mmgetstateResult -ne 0 ]; then
      exitCode=$mmgetstateResult
    fi
    if [ $mmlsmountResult -ne 0 ]; then
      exitCode=$exitCode$mmlsmountResult
    fi
    echo "HEALTH: bad"
    exit $exitCode
  fi

else
  if [ $mmgetstateResult -eq 0 ]; then
    echo "MMGETSTATE: pass"
  else
    echo "MMGETSTATE: fail"
  fi

  if [ $mmlsmountResult -eq 0 ]; then
    echo "MMLSMOUNT: pass"
  else
    echo "MMLSMOUNT: fail"
  fi

  if [ $skipwlm -eq 1 ]; then
    if [ $mmgetstateResult -eq 0 -a $mmlsmountResult -eq 0 ]; then
      echo "HEALTH: good"
      exit 0
    else
      exitCode=""
      if [ $mmgetstateResult -ne 0 ]; then 
        exitCode=$mmgetstateResult
      fi
      if [ $mmlsmountResult -ne 0 ]; then
        exitCode=$exitCode$mmlsmountResult
      fi
      echo "HEALTH: bad"
      exit $exitCode
    fi
  
  else
    if [ $wlmResult -eq 0 ]; then
      echo "WLMSTATUS: pass"
    else
      echo "WLMSTATUS: fail"
    fi

    if [ $mmgetstateResult -eq 0 -a $mmlsmountResult -eq 0 -a $wlmResult -eq 0 ]; then
      echo "HEALTH: good"
      exit 0
    else
      exitCode=""
      if [ $mmgetstateResult -ne 0 ]; then 
        exitCode=$mmgetstateResult
      fi
      if [ $mmlsmountResult -ne 0 ]; then
        exitCode=$exitCode$mmlsmountResult
      fi
      if [ $wlmResult -ne 0 ]; then
        exitCode=$exitCode$wlmResult
      fi
      echo "HEALTH: bad"
      exit $exitCode
    fi
  fi 
fi
