#!/usr/bin/env python

########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008,2010
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#
# ia_repair_node_config.py
#
#
# Script that takes the most recent backed up tar file located in the tiam_utility
# GPFS filesystem and restores node-based config files back to their
# original locations
#
# If the optional node parameter is given, the config files from that node
# will be restored to the current node.
#
# Parameters: node (optional)
#

import commands
import os
import time
import filepathChecker
import tiam_util
import drutils
import sys
import string

iAm = commands.getoutput("/usr/lpp/mmfs/bin/mmgetstate | grep ianode |awk '{print $2}'")

if len(sys.argv) == 2:
	nodeName = sys.argv[1]
else:
	nodeName = iAm

logMessageTemplate = "%y:%m:%d:%H:%M:%S restoreConfigFiles:" + iAm + ":"

if iAm != nodeName:
	logMessageTemplate += "(from " + nodeName + "):"

logTime = time.localtime(time.time())
logMessage = logMessageTemplate + " enter script\n"
logMessage = time.strftime(logMessage, logTime)

logfile = open('/tiam_utility/iamrecovery.log', 'a')
logfile.write(logMessage)

#check tiam_utility existence
if filepathChecker.checkFilepath("/tiam_utility/backup") == False:
   print "Cannot find /tiam_utility/backup/ path"
   os._exit(99)

#figure out what the most recent backed up tar file is
print "Locating IA config backup..."
cmd = "ls /tiam_utility/backup/node/configfiles_" + nodeName + "*"
output = commands.getoutput(cmd)

#tar file was never backed up
if output.find("No such file or directory") != -1:   
   logTime = time.localtime(time.time())
   logMessage = logMessageTemplate + " no tar files exist, tar file was never backed up\n"
   logMessage = time.strftime(logMessage, logTime)
   print "ERROR:"
   print logMessage
   print "Exiting Script"
   logfile.write(logMessage)
   logTime = time.localtime(time.time())
   logMessage = logMessageTemplate + " exit script\n\n"
   logMessage = time.strftime(logMessage, logTime)
   logfile.write(logMessage)
   logfile.close()
   os._exit(99)

#tar file(s) exist
tarfiles = output.split('\n')
tarfileLatest = tarfiles[len(tarfiles)-1]

print "Repairing config files from:\n" + tarfileLatest
command = "tar xvPf " + tarfileLatest + " 1>/dev/null"
output = commands.getoutput(command)
if len(output) > 0:
  logTime = time.localtime(time.time())
  logMessage = logMessageTemplate + " \"" + command + "\" returned with the following output:\n" + output + "\n"
  logMessage = time.strftime(logMessage, logTime)
  print "ERROR:"
  print logMessage
  print "Exiting Script"
  logfile.write(logMessage)
  logTime = time.localtime(time.time())
  logMessage = logMessageTemplate + " exit script\n\n"
  logMessage = time.strftime(logMessage, logTime)
  logfile.write(logMessage)
  logfile.close()
  os._exit(99)

output = commands.getoutput("/usr/lpp/mmfs/bin/mmlsfs all -T |grep tiam |grep \"\-T\" |awk '{print $2}'")
if len(output) == 0:
  print "Could not find any collection mount points"
else:
  mountpts = output.split('\n')
  for m in range(0,len(mountpts)):
    path = mountpts[m]
    if path.find("tiam_utility") == -1:
      cmd = "mkdir -p /meta" + path + "/meta"
      os.system(cmd) 
      print "Repairing /meta"

logTime = time.localtime(time.time())
logMessage = logMessageTemplate + " exit script\n\n"
logMessage = time.strftime(logMessage, logTime)
logfile.write(logMessage)
logfile.close()
print "\n\nConfig of " + iAm + " successfully completed"
os._exit(0)
