#!/bin/bash
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Description:
#    ia_run_dsa.sh is a wrapper script which invokes the DSA tool for collecting system
#       information.  This script runs only on the MC node.
#
# Syntax:
#    sudo ia_run_dsa.sh
#
# Results:
#    Creation of output in /var/log/IBM_Support, which is then copied to /var/opt/tivoli/tiam/bin
#
# Change history
#   Modifier      Date         CQ Change       Description
#   -----------------------------------------------------------------------------------
#   Brad Trubey   07/09/2009   TIAMC00007027   renamed to conform to IA convention
#   Brad Trubey   08/13/2009   TIAMC00007910   Update script to run in IA secure environment
#   Brad Trubey   10/01/2009   TIAM000009523   Change destination directory for collected data
# *************************************************************************************

SOURCE_DIR=/var/log/IBM_Support
BASE_DEST_DIR=/home/iaadmin/logs/`hostname`
DEST_DIR=$BASE_DEST_DIR/IBM_Support

# Create a fresh destination directory
rm -Rf   $SOURCE_DIR
mkdir -p $SOURCE_DIR

# Run the collect command
cd /opt/IBM/DSA
./collectall -b

# Move the results to the MC iaadmin home dir
rm -Rf    $DEST_DIR
mkdir -p  $BASE_DEST_DIR
chmod 755 $BASE_DEST_DIR
mv $SOURCE_DIR $BASE_DEST_DIR
chown -R iaadmin:users /home/iaadmin/logs
echo "Log files are located on the Management Console node under directory $DEST_DIR"
