#!/bin/bash
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Description:
#    ia_run_guilogs.sh is a wrapper script which runs log collection commands for collecting
#       problem determination information for the IA GUI.  This script runs only
#       on the MC node.
#
# Syntax:
#    sudo ia_run_guilogs.sh
#
# Results:
#    Creation of output in /tmp, which is then copied under /home/iaadmin/logs/hostname/IA_GUI
#
# Change history
#   Modifier      Date         CQ Change       Description
#   -----------------------------------------------------------------------------------
#   Brad Trubey   06/28/2010   TIAM000013770   Script creation
# *************************************************************************************

SOURCE_DIR=/tmp
BASE_DEST_DIR=/home/iaadmin/logs/`hostname`
DEST_DIR=$BASE_DEST_DIR/IA_GUI

# Run the collect command
/opt/tivoli/tiam/bin/zipguilogs.sh

# Check to see if there are any results
if [ "$(ls -A $SOURCE_DIR)/tiamgui-logs*" ]
then
    # Move the results to the MC iaadmin home dir
    rm -Rf    $DEST_DIR
    mkdir -p  $DEST_DIR
    chmod 755 $DEST_DIR

    mv $SOURCE_DIR/tiamgui-logs* $DEST_DIR
    chown -R iaadmin:users /home/iaadmin/logs
    echo "Log files are located on the Management Console node under directory $DEST_DIR"
else
    # Return code 14 indicates that no storage controllers were found, and will trigger a warning message from ia_service.py
    echo "IA GUI logs were not created."
    exit 1
fi

