#!/bin/bash
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Description:
#    ia_run_storage.sh is a wrapper script which runs log collection commands for collecting
#       problem determination information for the storage switches.  This script runs only
#       on the MC node.
#
# Syntax:
#    sudo ia_run_storage.sh
#
# Results:
#    Creation of output in /var/log/storage, which is then copied under /var/opt/tivoli/tiam/log/IBM_Storage
#
# Change history
#   Modifier      Date         CQ Change       Description
#   -----------------------------------------------------------------------------------
#   Brad Trubey   09/03/2009   TIAMC00008787   Initial creation of script
#   Brad Trubey   10/01/2009   TIAM000009523   Change destination directory for collected data
#   Brad Trubey   01/15/2010   TIAM000011505   Use $SOURCE_DIR variable for SMcli command
#   Brad Trubey   07/09/2010   TIAM000013770   Set return code to trigger ia_service warning message
# *************************************************************************************

SOURCE_DIR=/var/log/IBM_Storage
BASE_DEST_DIR=/home/iaadmin/logs/`hostname`
DEST_DIR=$BASE_DEST_DIR/IBM_Storage

# Create a fresh destination directory
rm -Rf   $SOURCE_DIR
mkdir -p $SOURCE_DIR

# Run the collect command
for i in `SMcli -d | grep iastorage | cut -f1`
do echo "Collecting logs for storage subsystem $i"
    SMcli -n $i -c "save storageSubsystem supportData file=\"$SOURCE_DIR/$i.zip\";"
done

# Check to see if there are any results
if [ "$(ls -A $SOURCE_DIR)" ]
then
    # Move the results to the MC iaadmin home dir
    rm -Rf    $DEST_DIR
    mkdir -p  $BASE_DEST_DIR
    chmod 755 $BASE_DEST_DIR

    mv $SOURCE_DIR $BASE_DEST_DIR
    chown -R iaadmin:users /home/iaadmin/logs
    echo "Log files are located on the Management Console node under directory $DEST_DIR"
else
    # Return code 14 indicates that no storage controllers were found, and will trigger a warning message from ia_service.py
    echo "No storage controllers were found on this appliance."
    exit 14
fi

