#! /usr/bin/env python
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Solr Server
# *
# * FILE NAME:       inxc_processDeletes.py
# *
# * DESCRIPTION:     Called from the ingest coordinator, feeds a list
# *                  of deletes to the indexbroker
# *
# * AUTHOR:          K.W.Brannon
# *                  IBM Almaden Research Center
# *                  kbrannon@us.ibm.com
# *
# *
# ****************************************************************************
# */


import os, sys
import getopt
from ssm_defines import *
from ssm_common  import *
from inxc_logmsgs import *

def usage(logger, errmsg):
    umsg = "usage: " + sys.argv[0] +" -m collectionMountPoint -f filelist \n"
    if (logger != None):
        logger.LogMsg(INXC_LOGMSG_USAGE, (errmsg,umsg))
        logger.TraceMsg("Usage Error msg: %s" %(errmsg))
        logger.TraceMsg("Usage: %s" %(umsg))
    else:
        sys.stdout.write("Error: " +errmsg)
        sys.stdout.write(umsg)
    sys.exit(1)
    
#Must have two arguments, the collection mount point and filelist
mountpt = None
filelist = None
try:
    opts, args = getopt.getopt(sys.argv[1:],"m:f:")
except getopt.GetoptError, err:
    pmsg = str(err)
    logger = None
    usage(logger,pmsg)

for opt, arg in opts:
    if opt in ("-m"):
        mountpt = arg.rstrip('/')
    elif opt in ("-f"):
        filelist = arg
    else:
        pmsg = "unhandled option"
        logger = None
        usage(logger,pmsg)
        
#check that mountpt is a directory
if mountpt == None or not os.path.isdir( mountpt):
    msg = "collectionMountPoint must be a fully qualified directory"
    logger = None
    usage(logger, msg)
        
cdotxml = str("%s%s" %(mountpt,SSM_CDOTXML_RMNT))
parsed_cdotxml = ssm_nl_parse_xmlfile(cdotxml)
if parsed_cdotxml != None:
    loglevel = ssm_nl_get_loglevel(parsed_cdotxml, cdotxml)
    if loglevel == None:
        loglevel = SSM_LOG_DEFAULT_LOGLEVEL
    tracelevel = ssm_nl_get_tracelevel(parsed_cdotxml, cdotxml)
    if tracelevel == None:
        tracelevel = SSM_LOG_DEFAULT_TRACELEVEL
    logger = ssm_nl_get_logger(SSM_LOG_INXC_DELETE, mountpt, 
                               loglevel, tracelevel)
    if (logger != None):
        pass
    else:
        msg = str("Error in %s, cannot get logger" %(sys.argv[0]))
        sys.stdout.write(msg)
        sys.exit(1)
else:
    msg = str("Error in %s, parsing %s" %(sys.argv[0],cdotxml))
    sys.stdout.write(msg)
    sys.exit(1)                     

euid = os.geteuid()
if euid != SSM_ROOTUID:
    msg = "This script must be run as root"
    usage(logger, msg)

#check that filelist is a file
if filelist == None or not os.path.isfile( filelist):
    msg = "delete filelist must exist: " +str(filelist)
    usage(logger, msg)

#check that indexbroker is enabled
logger.TraceMsg("checking that indexbroker is enabled")
cmd = str("%s/wlm_controlindexbroker.sh -getenabledstate --mountpoint=%s"
          %(SSM_IA_INSTALL_BIN,mountpt))
rc = ssm_run_cmd(logger,cmd)
if rc == 1:
    logger.TraceMsg("indexbroker is enabled, so process deletes")
    cmd = str("%s/inxc_feedIndexBroker.py -m %s -f %s --doDeletes "
               %(SSM_IA_INSTALL_BIN, mountpt, filelist))
    ret = ssm_run_cmd(logger, cmd)
    logger.TraceMsg("return code = %s from %s" %(ret, cmd))
    sys.exit(ret)
elif rc == 0:
    logger.TraceMsg("indexbroker not enabled, skipped indexbroker processing")
    sys.exit(0)
else:
    msg = str("problem getting indexbroker enabledstate for %s" %(mountpt))
    usage(logger, msg)
    sys.exit(1)
