#! /usr/bin/env python
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Solr Server
# *
# * FILE NAME:       inxc_processIgests.py
# *
# * DESCRIPTION:     Called from the document manager, feeds a list
# *                  of inserts/updates to the indexbroker
# *
# * AUTHOR:          K.W.Brannon
# *                  IBM Almaden Research Center
# *                  kbrannon@us.ibm.com
# *
# *
# ****************************************************************************
# */


import os, sys
import getopt
from ssm_defines import *
from ssm_common  import *
from inxc_logmsgs import *

def usage(logger, errmsg):
    umsg = "usage: " + sys.argv[0] +" -m collectionMountPoint -f filelist \n"
    if (logger != None):
        logger.LogMsg(INXC_LOGMSG_USAGE, (errmsg,umsg))
        logger.TraceMsg("Usage Error msg: %s" %(errmsg))
        logger.TraceMsg("Usage: %s" %(umsg))
    else:
        sys.stdout.write("Error: " +errmsg)
        sys.stdout.write(umsg)
    sys.exit(1)

#Must have two arguments, the collection mount point and filelist
#Plus an optional argument, specifying if are in retroactive policy apply mode
mountpt = None
filelist = None
retroactive_policy = False
try:
    opts, args = getopt.getopt(sys.argv[1:],"m:f:t")
except getopt.GetoptError, err:
    pmsg = str(err)
    logger = None
    usage(logger, pmsg)

for opt, arg in opts:
    if opt in ("-m"):
        mountpt = arg.rstrip('/')
    elif opt in ("-f"):
        filelist = arg
    elif opt in ("-t"):
        retroactive_policy = True
    else:
        pmsg = "unhandled option"
        logger = None
        usage(logger,pmsg)
        
#check that mountpt is a directory
if mountpt == None or not os.path.isdir( mountpt):
    msg = "collectionMountPoint must be a fully qualified directory"
    logger = None
    usage(logger, msg)

cdotxml = str("%s%s" %(str(mountpt),SSM_CDOTXML_RMNT))
parsed_cdotxml = ssm_nl_parse_xmlfile(cdotxml)
if parsed_cdotxml != None:
    loglevel = ssm_nl_get_loglevel(parsed_cdotxml, cdotxml)
    tracelevel = ssm_nl_get_tracelevel(parsed_cdotxml, cdotxml)
    logger = ssm_nl_get_logger(SSM_LOG_INXC_INGEST, mountpt, 
                               loglevel, tracelevel)
    if (logger != None):
        #get indexlevel, indexmode
        indexlvl = ssm_get_valueFromXmlfile(logger, SSM_C_EL_INDEXLEVEL, 
                                            parsed_cdotxml, cdotxml)
        indexmode = ssm_get_valueFromXmlfile(logger, SSM_C_EL_INDEXMODE,
                                                 parsed_cdotxml, cdotxml)
    else:
        msg = str("Error in %s, cannot get logger" %(sys.argv[0]))
        sys.stdout.write(msg)
        sys.exit(1)
else:
    msg = str("Error in %s, parsing collection.xml\n" %(sys.argv[0]))
    sys.stdout.write(msg)
    sys.exit(1)                     

euid = os.geteuid()
if euid != SSM_ROOTUID:
    msg = "This script must be run as root"
    usage(logger,msg)

#check that filelist is a file
if filelist == None or not os.path.isfile( filelist):
    msg = "filelist for ingests must exist: " +str(filelist)
    usage(logger, msg)

#check the indexmode - index new files only for indexmode=indexandsearch
#                      and indexlevel ne 3 and not in retroactive policy mode
if str(indexmode) == "indexandsearch" and SSM_INDEX_LEVEL[indexlvl] != 'no_index' and retroactive_policy == False:
    logger.TraceMsg("indexmode is %s and indexlevel is %s, call indexbroker"
                     %(indexmode,indexlvl))
    cmd = str("%s/inxc_feedIndexBroker.py -m %s -f %s --doUpdates "
               %(SSM_IA_INSTALL_BIN, mountpt, filelist))
    logger.TraceMsg("about to run cmd: %s" %(cmd))
    ret = ssm_run_cmd(logger, cmd)
    sys.exit(ret)
else:
    logger.TraceMsg("indexmode:%s indexlevel:%s retroactive_policy:%s, skipped indexbroker processing for %s" %(str(indexmode), str(indexlvl), str(retroactive_policy),str(filelist)))
    sys.exit(0)
