#! /usr/bin/env python
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Change Activity
#
# Name           Date         Change ID     Description
# Brad Trubey    09/30/2010   TIAMC00015849 Initial Version in CCRC
################################################################################

import getopt, sys, os, pickle
from tiam_util import *
from logcollector import *


def picklename(mountpt):
    return mountpt + "/logcollection_info/nodes.pickle"

def read_info( filename):
    collectorlist = []
    try:
        f = open( filename, "r")
        collectorlist = pickle.load( f)
        f.close()
        logprint( "collectorlist restored from %s" % filename)
    except:
        logprint( "collectorlist not restored from %s" % filename)
    return collectorlist


def load_info():
    pickle_tmp  = picklename( "/tmp")
    if os.path.isfile( pickle_tmp):
        return read_info( pickle_tmp)
    else:
        return []


def main():
    totalpos = 0
    totalmax = 0
    latesttime = 0
    latestnode = "unknown"
    latestaction = "unknown"
    totalprogress = 0
    collectorlist = load_info()

    #get progress info
    for collector in collectorlist:
        logprint("get progress from %s" % collector.node)
        progpos, progmax, progtime, progaction = collector.progress( )
        totalpos += progpos
        totalmax += progmax
        #get last known activity
        if progtime > latesttime:
            latestnode = collector.node
            latestaction = progaction

    if totalmax != 0:
        totalprogress = totalpos * 100 / totalmax

    returnmsg()
    logprint( "progress=" + str( totalprogress))


if __name__ == "__main__":
    do_main( main)
