#! /usr/bin/env python
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Change Activity
#
# Name           Date         Change ID     Description
# Brad Trubey    07/12/2010   TIAMC00014566 Initial Version in CCRC
# Brad Trubey    10/29/2010   TIAMC00015805 Move LC variables from MC to RAS
################################################################################

import getopt, sys, os, time, stat, pwd
from tiam_util import *

logc_config = {
    "ia_commands"          : "/opt/tivoli/tiam/etc/ia_commands.txt",
    "ia_logfiles"          : "/opt/tivoli/tiam/etc/ia_logfiles.txt",
    "ia_cleanup"           : "/opt/tivoli/tiam/etc/ia_cleanup.txt",
    "logc_size_compress"   : 1024,               # files larger than this will get compressed
    "logc_size_cutoff"     : 4096,               # files larger than this will be skipped
    "logc_count_compress"  : 2000,               # directories with more files than this will get tarred and gzipped
    "logc_count_cutoff"    : 4000,               # no more than this many files will get collected from a directory
    "logc_timeout"         : 1200,               # default timeout (in seconds) for log collection is 20 minutes
    "logc_long_timeout"    : 3600 * 24,          # max time is a day if "-a on" is used
    "logc_always_collect"  : [ "/tiam_utility/log/CTJID/", "/opt/log/CTJID/", "/tmp/core", "/root/install.log"],
   }

def get_logc_config():
    return logc_config

def security_ok( filename):
    mode = stat.S_IMODE( os.lstat( filename)[ stat.ST_MODE])
    num_uid = os.stat( filename)[ stat.ST_UID]
    uid = pwd.getpwuid( num_uid)[0]
    num_gid = os.stat( filename)[ stat.ST_GID]
    gid = pwd.getpwuid( num_gid)[0]

    if mode != 420 or num_uid != 0 or num_gid != 0:
        logprint( "mode = %s / uid = %s / gid = %s / num_uid = %d / num_gid = %d" %
                  (str( mode), uid, gid, num_uid, num_gid))
        return False

    return True


def read_list( filename):
    result = []

    if not( os.path.isfile( filename)):
        logprint( "%s not found" % filename)
        return result

    if not( security_ok( filename)):
        logprint( "ignoring %s due to security problems" % filename)
        return result

    try:
        f = open( filename, "r")
        for line in f:
            sline = line.strip()
            if (len(sline) > 1) and (sline[0] != "#"):
                result.append( sline)
        f.close()
    except IOError:
        pass

    return result


def instance_running( startmarker, endmarker):
    now = time.time()
    timeint = int( now)
    long_timeout = get_logc_config()["logc_long_timeout"]
    #check if other instance has written a new start marker recently
    if get_marker_time( startmarker) > get_marker_time( endmarker):
        if now - get_marker_time( startmarker) < long_timeout:
            pid = get_marker_pid( startmarker)
            cmd = "ps aux | grep %d" % pid
            for line in syscallreadhide( cmd, ""):
                parts = re.split( "[ \t]+", line.strip())
                if int( parts[ 1]) == pid:
                    return True
    return False


def delete_ok( item):

    savelist = [
        "/tmp/logcollection_node",
        "/tmp/logcollection",
        "/tiam_utility/logcollection_node",
        "/tiam_utility/logcollection"
        ]

    for pattern in savelist:
        plen = len( pattern)
        if item[:plen] == pattern:
            logprint( "don't delete %s" % item)
            return False

    return True


def save_filter( inlist):
    outlist = []

    for item in inlist:
        if delete_ok( item):
            outlist.append( item)

    return outlist


def do_ia_cleanup( cronmode = False):

    #info is always in /tmp
    tmp = "/tmp"
    infodir = tmp + "/logcollection_info"
    startmarker = infodir + "/begin.txt"
    endmarker   = infodir + "/end.txt"
    runninginfo = infodir + "/info.txt"

    #check for recent ia_logcollector
    if cronmode:
        now = time.time()
        timeint = int( now)
        cleanup_timeout = get_logc_config()["logc_long_timeout"] * 3 / 2
        if now - get_marker_time( startmarker) < cleanup_timeout:
            msg = "ia_logcollector has been running in the last %d hours!"
            msg = msg % (cleanup_timeout / 3600)
            logprint( msg)
            return

    #try to read cleanup file
    filename = get_logc_config()["ia_cleanup"]
    cleanuplist = read_list( filename)
    if len( cleanuplist) == 0:
        cleanuplist = [
            "/var/mmfs/gen/internaldump.*",
            "/tmp/gpfs.snapOut/all.*.tar",
            "/tmp/dirlogs*"
            ]

    #save your own stuff
    if not( cronmode):
        cleanuplist = save_filter( cleanuplist)

    #delete
    for filedesc in cleanuplist:
        syscall_try( "rm -rf %s" % filedesc)
