#!/bin/bash
#
#******************************************************************************
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp.  2008-2010  All Rights Reserved
#
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -----------------------------------------------------------------------------
#
# =========================================================================
#
# Name: mapLuns.sh
#
# Change Log:
#
#   1.0     4/16/09     Bryan Jen     Script creation.
#   1.1     2/19/10     Robert Guthrie MES support
#  04/23/2010    Brad Trubey         TIAMC00013107  move logs to location where they will get collected
#  11/09/2010    Brad Trubey         TIAMC00016579  improve error logging and reporting
#
#******************************************************************************

SMCLI="/usr/bin/SMcli"
mkdir -p /var/opt/tivoli/tiam/log
LOGFILE="/var/opt/tivoli/tiam/log/mapLuns.log"

usage() {
  echo " mapLuns.sh -a <ipaddress> -b <ipaddress> [-n|-m]"
  echo "       -a                 IP Address of controller A"
  echo "       -b                 IP Address of controller B"
  echo "       -n                 completely replace LUN mapping"
  echo "       -m                 only map currently unmapped LUNs"
  echo "       -h                 help/usage information"
  echo " "
  echo "    eg.  mapLuns.sh -a 172.31.0.100 -b 172.31.0.101 -n"
  return 0
}

if [ $# != 5 ]; then
  usage
  exit 0
else
  if [ "$1" = "-a" ]; then
      CTRLA=$2
  else
      usage
      exit 1
  fi

  if [ "$3" = "-b" ]; then
      CTRLB=$4
  else
      usage
      exit 1
  fi

  if [ "$5" = "-n" ] || [ "$5" = "-m" ]; then
    if [ "$5" = "-n" ]; then
      CONFIG_NEW=1
      CONFIG_MES=0
    else
      CONFIG_NEW=0
      CONFIG_MES=1
    fi
  else
    usage
    exit 1
  fi
fi

case $CTRLA in
  *00 )
    offset=0 ;;
  *02 )
    offset=33 ;;
  *04 )
    offset=66 ;;
  * )
    offset=0 ;;
esac


if [ `whoami` == "root" ]; then
   echo "=======Start Script $0 `date`=====" >> $LOGFILE
   if [ $CONFIG_NEW -eq 1 ]; then
     ${SMCLI} ${CTRLA} ${CTRLB}  -c "remove allLogicalDrives lunMapping;"
   fi

   RC=0

   for lun in `${SMCLI} ${CTRLA} ${CTRLB}  -c "show alllogicaldrives;" |grep -i "logical drive name" | cut -d: -f2 |awk '{print $1}'`;
   do
     echo "Processing LUN $lun" >> $LOGFILE

     luntype=`echo $lun |cut -d_ -f1`
     lunmapped=`${SMCLI} ${CTRLA} ${CTRLB}  -c "show storageSubsystem lunMappings;" |grep $lun`

     if [ $luntype == "utilfs" ]; then
       if [ -z "$lunmapped" ]; then
         echo "LUN $lun is not mapped." >> $LOGFILE
         echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
         cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=0 host=\"iagroup\";" ` >> $LOGFILE
         RC=$?
         if [[ `echo $cmd |grep -i fail` ]]; then
           echo "LUN Mapping FAILED" >> $LOGFILE
           echo $cmd >> $LOGFILE
         fi
       else
         echo "LUN $lun is already mapped." >> $LOGFILE
       fi

     elif [ $luntype == "iarecovery" ]; then
       if [ -z "$lunmapped" ]; then
         echo "LUN $lun is not mapped." >> $LOGFILE
         echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
         cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=99 host=\"iagroup\";" ` >> $LOGFILE
         RC=$?
         if [[ `echo $cmd |grep -i fail` ]]; then
           echo "LUN Mapping FAILED" >> $LOGFILE
           echo $cmd >> $LOGFILE
         fi
       else
         echo "LUN $lun is already mapped." >> $LOGFILE
       fi

     else
       encid=`echo $lun | cut -d_ -f2`

       if [ $encid == "85" ]; then
         arrayid=`echo $lun |cut -d_ -f3`
         if [ $arrayid == "1" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 1 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE
           fi
         elif [ $arrayid == "2" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 2 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE
           fi
         else
           echo "LUN $lun is mapped already." >> $LOGFILE
         fi
       elif [ $encid == "0" ]; then
         arrayid=`echo $lun |cut -d_ -f3`
         if [ $arrayid == "1" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 3 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE

           fi
         elif [ $arrayid == "2" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 4 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE

           fi
         else
           echo "LUN $lun is in an unknown format." >> $LOGFILE
         fi
       elif [ $encid == "1" ]; then
         arrayid=`echo $lun |cut -d_ -f3`
         if [ $arrayid == "1" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 5 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE

           fi
         elif [ $arrayid == "2" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 6 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE

           fi
         else
           echo "LUN $lun is in an unknown format." >> $LOGFILE
         fi
       elif [ $encid == "2" ]; then
         arrayid=`echo $lun |cut -d_ -f3`
         if [ $arrayid == "1" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 7 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE

           fi
         elif [ $arrayid == "2" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 8 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE

           fi
         else
           echo "LUN $lun is in an unknown format." >> $LOGFILE
         fi
       elif [ $encid == "3" ]; then
         arrayid=`echo $lun |cut -d_ -f3`
         if [ $arrayid == "1" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 9 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE

           fi
         elif [ $arrayid == "2" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 10 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE

           fi
         else
           echo "LUN $lun is in an unknown format." >> $LOGFILE
         fi
       elif [ $encid == "4" ]; then
         arrayid=`echo $lun |cut -d_ -f3`
         if [ $arrayid == "1" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 11 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE

           fi
         elif [ $arrayid == "2" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 12 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE

           fi
         else
           echo "LUN $lun is in an unknown format." >> $LOGFILE
         fi
       elif [ $encid == "5" ]; then
         arrayid=`echo $lun |cut -d_ -f3`
         if [ $arrayid == "1" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 13 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE

           fi
         elif [ $arrayid == "2" ]; then
           if [ -z "$lunmapped" ]; then
             echo "LUN $lun is not mapped." >> $LOGFILE
             echo "Setting LUN-to-Host mapping to IA Host Group" >> $LOGFILE
             lunnum=$(( 14 + $offset ))
             cmd=`${SMCLI} ${CTRLA} ${CTRLB} -c "set logicaldrive[\"$lun\"] logicalUnitNumber=$lunnum host=\"iagroup\";" ` >> $LOGFILE
             RC=$?
             if [[ `echo $cmd |grep -i fail` ]]; then
               echo "LUN Mapping FAILED" >> $LOGFILE
               echo $cmd >> $LOGFILE
             fi
           else
             echo "LUN $lun is already mapped." >> $LOGFILE

           fi
         else
           echo "LUN $lun is in an unknown format." >> $LOGFILE
         fi

       else
         echo "LUN $lun unknown" >> $LOGFILE

       fi
     fi

   done
   echo "=======End Script `date`=====" >> $LOGFILE
   echo "Configuration complete.  Please see $LOGFILE for additional details"     | tee -a $LOGFILE
else
   echo "You must be root (or use sudo) to run this script."     | tee -a $LOGFILE
fi

exit $RC
