#!/bin/sh
########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2010
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Workload Manager
# *
# * FILE NAME:       mw_abortdocumentexpirer.sh
# *
# * DESCRIPTION:     Kills the document expirer for a given collection
# *                  on the node where it is run
# *
# * USAGE:           mw_abortdocumentexpirer.sh --mountpoint=<collection_mountpoint>
# *
# * EXAMPLE:         mw_abortdocumentexpirer.sh --mountpoint=/tiam/col1
# *
# * AUTHOR:          Mark A. Smith
# *                  mark1smi@us.ibm.com
# *
# * HISTORY:         This file was added for 13740
# *
# ****************************************************************************
# */

# Configure shell variables
. `dirname $BASH_SOURCE`/mw_environment.sh

# The collection mount point (e.g. /tiam/col1)
COLLECTIONMNTPOINT=""

# Locations of files and executables required for iam_document_expirer
DOCUMENTEXPIRER_NAME=iam_document_expirer
DOCUMENTEXPIRER_BIN=/opt/tivoli/tiam/bin/$DOCUMENTEXPIRER_NAME

# Usage:
# doStop full_path_of_process_to_kill
function doStop_iam_document_expirer()
{
  running_pid_list=`/bin/ps -C \`basename $DOCUMENTEXPIRER_BIN\` -f | tail +2 | sed 's/ -d / /g' | tr -s ' ' | sed 's/^[ ]//g' | cut -d' ' -f 2`

  for pid in $running_pid_list
  do
    process_env=`/bin/ps -p $pid -f e | tail +2 | tr -s ' ' | sed 's/^[ ]//g' `

    teststr=${process_env/$DOCUMENNTEXPIRER_BIN $COLLECTIONMNTPOINT/}
    if [ "$teststr" != "$process_env" ]; then
        echo "the pid for a document expirer for $COLLECTIONMNTPOINT is $pid"
        kill_process $pid SIGKILL
    fi
  done
}

# Kill a process
#
# Usage:
# kill_process PID SIGNAL
function kill_process() {
  local pid=$1
  local signal=$2
  /bin/kill -$signal $pid
}

function parse_args()
{
  for arg in $@
  do
    case ${arg} in
      --mountpoint=*)
        COLLECTIONMNTPOINT=`echo ${arg} | cut -d = -f 2`
        # Strip any trailing '/'
        COLLECTIONMNTPOINT=${COLLECTIONMNTPOINT%/}
        ;;
    esac	
  done

  if [ -z "${COLLECTIONMNTPOINT}" ]; then
    echo "error: mountpoint not specified on command line"
    exit -1
  fi
}

parse_args $@

# Kill the document expirer
doStop_iam_document_expirer
exit 0
