#!/bin/sh
########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Workload Manager
# *
# * FILE NAME:       mw_abortmmapplypolicy.sh
# *
# * DESCRIPTION:     Kills the mmapplypolicy, tsapolicy, and iam_document_manager
# *                  instances for a given collection on the node where it is run
# *
# * USAGE:           mw_abortmmapplypolicy.sh --mountpoint=<collection_mountpoint>
# *
# * EXAMPLE:         mw_abortmmapplypolicy.sh --mountpoint=/tiam/col1
# *
# * AUTHOR:          Ryan Minniear
# *                  rjminniear@us.ibm.com
# *
# ****************************************************************************
# */

# Configure shell variables
. `dirname $BASH_SOURCE`/mw_environment.sh

[ $1 ] || exit -1
# The collection mount point (e.g. /tiam/col1)
COLLECTIONMNTPOINT=""

# Locations of files and executables required for mmapplypolicy
MMAPPLYPOLICY_NAME=mmapplypolicy
MMAPPLYPOLICY_BIN=/usr/lpp/mmfs/bin/$MMAPPLYPOLICY_NAME

# Locations of files and executables required for tsapolicy
TSAPOLICY_NAME=tsapolicy
TSAPOLICY_BIN=/usr/lpp/mmfs/bin/$TSAPOLICY_NAME

MMHELPAPOLICY_NAME=mmhelp-apolicy
MMHELPAPOLICY_BIN=/usr/lpp/mmfs/bin/$MMHELPAPOLICY_NAME

# Locations of files and executables required for iam_document_manager
DOCUMENTMANAGER_NAME=iam_document_manager
DOCUMENTMANAGER_BIN=/opt/tivoli/tiam/bin/$DOCUMENTMANAGER_NAME

# Kill the given process(es) associated with the collection
#
# Usage:
# doStop full_path_of_process_to_kill
function doStop_iam_document_manager()
{
  running_pid_list=`/bin/ps -C \`basename $DOCUMENTMANAGER_BIN\` -f | tail +2 | sed 's/ -d / /g' | tr -s ' ' | sed 's/^[ ]//g' | cut -d' ' -f 2`

  for pid in $running_pid_list
  do
    process_env=`/bin/ps -p $pid -f e | tail +2 | tr -s ' ' | sed 's/^[ ]//g' `

    for env_var in $process_env
    do
      teststr=${env_var/--mount=$COLLECTIONMNTPOINT/}
      if [ "$teststr" != "$env_var" ]; then
          echo "the pid for a document manager for $COLLECTIONMNTPOINT is $pid"
          kill_process $pid SIGKILL
      fi

    done
  done
}

function doStop_mmapplypolicy()
{
  running_pid_list=`/bin/ps -C \`basename $MMAPPLYPOLICY_BIN\` -f | tail +2 | sed 's/ -d / /g' | tr -s ' ' | sed 's/^[ ]//g' | cut -d' ' -f 2`
  for pid in $running_pid_list
  do
    process_env=`/bin/ps -p $pid -f e | tail +2 | tr -s ' ' | sed 's/^[ ]//g' `
    teststr=${process_env/$MMAPPLYPOLICY_BIN $COLLECTIONMNTPOINT/}
    if [ "$teststr" != "$process_env" ]; then
        echo "the pid for mmapplypolicy for collection $COLLECTIONMNTPOINT is $pid"
        kill_process $pid SIGKILL
    fi
  done
}

function doStop_tsapolicy()
{
  running_pid_list=`/bin/ps -C \`basename $TSAPOLICY_BIN\` -f | tail +2 | sed 's/ -d / /g' | tr -s ' ' | sed 's/^[ ]//g' | cut -d' ' -f 2`
  for pid in $running_pid_list
  do
    process_env=`/bin/ps -p $pid -f e | tail +2 | tr -s ' ' | sed 's/^[ ]//g' `
    teststr=${process_env/$TSAPOLICY_BIN $COLLECTIONMNTPOINT/}
    if [ "$teststr" != "$process_env" ]; then
        echo "the pid for tsapolicy for collection $COLLECTIONMNTPOINT is $pid"
        kill_process $pid SIGKILL
    fi
  done
}

function doStop_mmhelpapolicy()
{
  running_pid_list=`/bin/ps -C \`basename $MMHELPAPOLICY_NAME\` -f | tail +2 | sed 's/ -d / /g' | tr -s ' ' | sed 's/^[ ]//g' | cut -d' ' -f 2`
  for pid in $running_pid_list
  do
    process_env=`/bin/ps -p $pid -f e | tail +2 | tr -s ' ' | sed 's/^[ ]//g' `
    teststr=${process_env/-s $COLLECTIONMNTPOINT/}
    if [ "$teststr" != "$process_env" ]; then
        echo "the pid for mmhelp-apolicy for collection $COLLECTIONMNTPOINT is $pid"
        kill_process $pid SIGKILL
    fi
  done
}


# Kill a process
#
# Usage:
# kill_process PID SIGNAL
function kill_process() {
  local pid=$1
  local signal=$2
  /bin/kill -$signal $pid
}

function parse_args()
{
  for arg in $@
  do
    case ${arg} in
      --mountpoint=*)
        COLLECTIONMNTPOINT=`echo ${arg} | cut -d = -f 2`
        # Strip any trailing '/'
        COLLECTIONMNTPOINT=${COLLECTIONMNTPOINT%/}
        ;;
    esac	
  done

  if [ -z "${COLLECTIONMNTPOINT}" ]; then
    echo "error: mountpoint not specified on command line"
  fi
}

parse_args $@

# Kill mmapplypolicy, tsapolicy, and iam_document_manager instances
# Kill in this order so that new processes are not spawned that might be missed
doStop_mmapplypolicy
doStop_tsapolicy
doStop_mmhelpapolicy
doStop_iam_document_manager
