#!/bin/sh
########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Workload Manager
# *
# * FILE NAME:       mw_check_fs_mounted.sh
# *
# * DESCRIPTION:     Check that the current node has gpfs filesystems mounted.
# *                  Optional parameters allow caller to specify filesystems
# *                  When called with no parameters, it uses /etc/fstab
# *
# *                  Returns: 
# *                       0 for success (all mounted)
# *                       -1 for failure  (at least 1 not mounted)
# *
# * AUTHOR:          Mark A. Smith
# *                  IBM Almaden Research Center
# *                  mark1smi@us.ibm.com
# *
# ****************************************************************************
# */
# ----------------------------------------------------------------------------
# ----------------------------------------------------------------------------
#               Change Log
#               ----------
#  19 Sep 2008  Initial version.
#

# Configure shell variables
. `dirname $BASH_SOURCE`/mw_environment.sh

function find_mounted_filesystems()
{
	mounted_filesystems=`/bin/mount | grep "type gpfs " | awk {'print $3'}`
}

function find_defined_filesystems()
{
	defined_filesystems=`/bin/cat /etc/fstab | awk {'if($3=="gpfs") { print $2 } '}`
}

function is_mounted()
{
	local fs=$1
	for mounted_fs in $mounted_filesystems; do
		if [ "$fs" == "$mounted_fs" ]; then
			return 1
		fi
	done
	return 0
}

#if no arguments, check all gpfs filesystems
if [ $# -eq 0 ]; then
	find_defined_filesystems
	if [ "$defined_filesystems" == "" ]; then
		echo "Error: no filesystems defined or unable to read /etc/fstab"
		exit -1
	fi
else
	defined_filesystems=$@
fi
exit_code=0
find_mounted_filesystems
for defined_fs in $defined_filesystems; do
	is_mounted $defined_fs
	b_is_mounted=$?
	if [ $b_is_mounted -eq 1 ]; then
		echo "$defined_fs mounted."
	else
		echo "$defined_fs not mounted or not gpfs."
		exit_code=-1
	fi
done
exit $exit_code
