#!/bin/sh
########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2010
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Log Collector
# *
# * FILE NAME:       mw_gatherlogs.sh
# *
# * DESCRIPTION:     Gathers middleware logs for the collection
# *
# * AUTHOR:          Mark A. Smith
# *                  IBM Almaden Research Center
# *                  mark1smi@almaden.ibm.com
# *
# ****************************************************************************
# */

# Configure shell variables
. `dirname $BASH_SOURCE`/mw_environment.sh

COLLECTIONMNTPOINT=""
OPERATION=""
LOGFILE=""
MINIMUM="false"

parse_args()
{
	for arg in $@
	do
		case ${arg} in
			--minimum)
				MINIMUM="true"
				;;
			--logfile=*)
				LOGFILE=`echo ${arg} | cut -d = -f 2`
				;;
			*)
		esac	
	done

	if [ -z "${LOGFILE}" ]; then
		echo "error: logfile not specified on command line"
		OPERATION="help"
	fi

}

printHelp()
{
	echo "usage:  $0 [--minimum] [--logfile=<logfilename> (will be in tar.gz format)] "
	echo "where:"
	echo "	--minimum             collect only the minimum logs required (for speed)"
	echo "	--logfile             the desired output log filename"
}


parse_args $@

if [ "$OPERATION" == "help" ]; then
	printHelp
	exit -1
fi

if [ $MINIMUM == "true" ]; then
	echo "Generating minimum middleware logs to file '$LOGFILE'"
else
	echo "Generating middleware logs to file '$LOGFILE'"
fi

echo "Clearing old file '$LOGFILE'"
rm -rf "$LOGFILE" 2>&1 >/dev/null
if [ $MINIMUM == "true" ]; then
	mmdsh -N all /opt/tivoli/tiam/bin/mw_generate_nodespecific_logs.sh --minimum
else
	mmdsh -N all /opt/tivoli/tiam/bin/mw_generate_nodespecific_logs.sh
fi

tar -cvzf "$LOGFILE" /tiam_utility/log/CTJID

exit 0
