#!/bin/sh
########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2010
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Log Collector
# *
# * FILE NAME:       mw_gatherlogs.sh
# *
# * DESCRIPTION:     Gathers node-specific middleware logs for the collection
# *
# * AUTHOR:          Mark A. Smith
# *                  IBM Almaden Research Center
# *                  mark1smi@almaden.ibm.com
# *
# ****************************************************************************
# */

# Configure shell variables
. `dirname $BASH_SOURCE`/mw_environment.sh

MINIMUM="false"

parse_args()
{
        for arg in $@
        do
                case ${arg} in
                        --minimum)
                                MINIMUM="true"
                                ;;
                        *)
                esac
        done
}

printHelp()
{
        echo "usage:  $0 [--minimum]"
        echo "where:"
        echo "  --minimum             collect only the minimum logs required (for speed)"
}


parse_args $@

if [ "$OPERATION" == "help" ]; then
        printHelp
        exit -1
fi

if [ $MINIMUM == "true" ]; then
        echo "Generating node-specific minimum middleware logs"
else
        echo "Generating node-specific middleware logs"
fi


UNIQUENODEID=`/opt/tivoli/tiam/bin/mw_print_unique_nodeid`
LOGDIR="/tiam_utility/log/CTJID/lc/$UNIQUENODEID"

echo "Clearing old logs"
rm -rf "$LOGDIR" > /dev/null 2>&1
mkdir -p "$LOGDIR"

echo "Producing command output"
#Grab some output from helpful commands
echo "Generating administrative leave information"
ia_administrativeleave -l > "$LOGDIR/adminleave" 2>&1
echo "Generating Workload Manager status information"
workloadmanager.sh -status > "$LOGDIR/wlm_status" 2>&1
echo "Generating mmgetstate information"
mmgetstate -a > "$LOGDIR/mmgetstate" 2>&1
echo "Generating mmlscluster information"
mmlscluster > "$LOGDIR/mmlscluster" 2>&1
echo "Generating core file information"
ls -l /tmp/*core* > "$LOGDIR/cores" 2>&1

if [ "$MINIMUM" != "true" ]; then
	#Make this better. Figure out dynamically which nodes are in the cluster.
	echo "Generating power control information"
	ia_powercontrol -s ianode1 > "$LOGDIR/powercontrol" 2>&1
	echo "" > "$LOGDIR/powercontrol"
	echo "--------------------------------------" > "$LOGDIR/powercontrol"
	echo "" > "$LOGDIR/powercontrol"
	ia_powercontrol -s ianode2 >> "$LOGDIR/powercontrol" 2>&1
	echo "" > "$LOGDIR/powercontrol"
	echo "--------------------------------------" > "$LOGDIR/powercontrol"
	echo "" > "$LOGDIR/powercontrol"
	ia_powercontrol -s ianode3 >> "$LOGDIR/powercontrol" 2>&1
	echo "" > "$LOGDIR/powercontrol"
	echo "--------------------------------------" > "$LOGDIR/powercontrol"
	echo "" > "$LOGDIR/powercontrol"
	ia_powercontrol -s iarsm1 >> "$LOGDIR/powercontrol" 2>&1
	echo "" > "$LOGDIR/powercontrol"
	echo "--------------------------------------" > "$LOGDIR/powercontrol"
	echo "" > "$LOGDIR/powercontrol"
	ia_powercontrol -s iamconsole1 >> "$LOGDIR/powercontrol" 2>&1
fi


echo "Copying local logs"
#Copy some local logs
mkdir -p "$LOGDIR/opt/log/CTJID"
cp -r /opt/log/CTJID/* "$LOGDIR/opt/log/CTJID/"

if [ "$MINIMUM" != "true" ]; then
	mkdir -p "$LOGDIR/tmp/tiam"
	cp -r /tmp/tiam/* "$LOGDIR/tmp/tiam/"
fi

mkdir -p "$LOGDIR/tmp/tiam_utility"
cp -r /tmp/tiam_utility/* "$LOGDIR/tmp/tiam_utility/"

exit 0
