#!/bin/bash
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Filename: setDATrace.sh
#
# Component: RAS
#
# Description:
#    This file contains a bash script for setting the trace level of the IBM Director Agent
#    component. It maps the Director Agent trace capabilities into min/mid/max/disable,
#    to match the IA Trace Config utility design.
#
#  Usage:
#      setDATrace.sh min|mid|max|disable
#      min: basic tracing only
#      mid: same as min
#      max: full tracing
#      disable: no trace
#
# Change history
#   Modifier                     Date                     CQ Change
#   ---------------------------------------------------------------------------
#   Linda Benhase             7/19/2009                   TIAMC00007393
#      Remove rc_reset, it's been deprecated and replace with rc=0.
#   Del Ence                     9/02/2010                   TIAMC00015056
#      Updated to use 'lwilog.sh -refresh' instead of stopping and restarting director agent.
#
# *************************************************************************************

USAGE="Usage: $0 trace_level\n   trace_level values: min|mid|max|disable"
LEVEL="$1"

# include ras_functions
. /opt/tivoli/tiam/bin/ras_functions
. /opt/tivoli/tiam/bin/dir_functions
rc=0

# log the actions taken by this script
create_new_log_file setDATrace

# Validate the trace levels as one of the following [min,mid,max,disable]
case "${LEVEL}" in
   "min" | "mid" | "max" | "disable" )
     ras_log "Valid trace level found : ${LEVEL}";;
   "" ) ras_log -v "Error, trace level not provided $USAGE"
      exit 1;;
   *) ras_log -v "Error, invalid trace level ${LEVEL} $USAGE"
      exit 1;;
esac

ras_log "Setting trace level to ${LEVEL}"


if [ "${LEVEL}" == "min" ]; then
    ras_log -v "Setting trace level to ${LEVEL}"
    execute_and_log cp /opt/tivoli/tiam/etc/agentLogging.min /opt/ibm/director/agent/conf/overrides/logging.properties
    rc=$?
elif [ "${LEVEL}" == "mid" ]; then
    ras_log -v "Setting trace level to ${LEVEL}"
    execute_and_log cp /opt/tivoli/tiam/etc/agentLogging.mid /opt/ibm/director/agent/conf/overrides/logging.properties
    rc=$?
elif [ "${LEVEL}" == "max" ]; then
    ras_log -v "Setting trace level to ${LEVEL}"
    execute_and_log cp /opt/tivoli/tiam/etc/agentLogging.max /opt/ibm/director/agent/conf/overrides/logging.properties
    rc=$?
elif [ "${LEVEL}" == "disable" ]; then
    ras_log -v "Setting trace level to ${LEVEL}"
    execute_and_log cp /opt/tivoli/tiam/etc/agentLogging.disable /opt/ibm/director/agent/conf/overrides/logging.properties
    rc=$?
fi

# Check return code
if [[ $rc -ne 0 ]]; then
  ras_log -v "Unable to set trace level to ${LEVEL}, please see log file for more information."
else
  ras_log -v "Trace level set to ${LEVEL}."
fi

# Now update the logging and tracing levels  by refreshing the tracing settings from updated properties files
execute_and_log /opt/ibm/director/agent/bin/lwilog.sh -refresh
rc=$?

exit $rc
