#!/bin/bash
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Filename: setNFSTrace.sh
#
# Component: RAS
#
# Description:
#    This file contains a bash script for setting the trace level of the NFS server.
#    It maps the NFS server trace capabilities into min/mid/max/disable, to match the
#    IA Trace Config utility design.
#
#  Usage:
#      setNFSTrace.sh min|mid|max|disable
#      min: basic tracing only
#      mid: same as min
#      max: full tracing
#      disable: no trace
#
# *************************************************************************************

USAGE="Usage: $0 trace_level\n   trace_level values: min|mid|max|disable"
LEVEL="$1"
rc=0

# include ras_functions
. /opt/tivoli/tiam/bin/ras_functions
rc_reset

# log the actions taken by this script
create_new_log_file setNFSTrace

# Validate the trace levels as one of the following [min,mid,max,disable]
case "${LEVEL}" in
   "min" | "mid" | "max" | "disable" )
     ras_log "Valid trace level found : ${LEVEL}";;
   "" ) ras_log -v "Error, trace level not provided $USAGE"
      exit 1;;
   *) ras_log -v "Error, invalid trace level ${LEVEL} $USAGE"
      exit 1;;
esac

ras_log "Setting trace level to ${LEVEL}"

if [ "${LEVEL}" == "min" ]; then
    ras_log "Setting trace level to ${LEVEL}"
    ras_log "echoing 0 to /proc/sys/sunrpc/nfsd_debug"
    echo 0 > /proc/sys/sunrpc/nfsd_debug

elif [ "${LEVEL}" == "mid" ]; then
    ras_log "Setting trace level to ${LEVEL}"
    ras_log "echoing 32 to /proc/sys/sunrpc/nfsd_debug"
    echo 32 > /proc/sys/sunrpc/nfsd_debug

elif [ "${LEVEL}" == "max" ]; then
    ras_log "Setting trace level to ${LEVEL}"
    ras_log "echoing 32767 to /proc/sys/sunrpc/nfsd_debug"
    echo 32767 > /proc/sys/sunrpc/nfsd_debug

elif [ "${LEVEL}" == "disable" ]; then
    ras_log "Setting trace level to ${LEVEL}"
    ras_log "echoing 0 to /proc/sys/sunrpc/nfsd_debug"
    echo 0 > /proc/sys/sunrpc/nfsd_debug
fi

# Check return code
if [[ $rc -ne 0 ]]; then
  ras_log -v "Unable to set trace level to ${LEVEL}, please see log file for more information."
else
  ras_log -v "Trace level set to ${LEVEL}."
fi

exit $rc
