#!/bin/bash
# *************************************************************************************
# * Licensed Materials - Property of IBM
# * IBM Information Archive 2.1.0.0.efix_1
# *
# * (C) Copyright IBM Corp. 2008, 2009, 2010. All Rights Reserved
# *
# * US Government Users Restricted Rights - Use, duplication or
# * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# *
# * All files within this archive are protected by IBM's copyright.
# *************************************************************************************
#
# Filename: setSLESTrace.sh
#
# Component: RAS
#
# Description:
#    This file contains a bash script for setting the trace level of the SLES operating system.
#    It maps the SLES operating system trace capabilities into min/mid/max/disable, to match the
#    IA Trace Config utility design.
#
#  Usage:
#      setSLESTrace.sh min|mid|max|disable
#      min: basic tracing only
#      mid: same as min
#      max: full tracing
#      disable: no trace
#
# *************************************************************************************

USAGE="Usage: $0 trace_level\n   trace_level values: min|mid|max|disable"
LEVEL="$1"
rc=0
CONFIG_TO_DIR="/etc/syslog-ng"
CONFIG_FROM_DIR="/opt/tivoli/tiam/etc"
CONFIG_FILE="syslog-ng.conf.in"

# include ras_functions
. /opt/tivoli/tiam/bin/ras_functions
rc_reset

# log the actions taken by this script
create_new_log_file setSLESTrace

# Validate the trace levels as one of the following [min,mid,max,disable]
case "${LEVEL}" in
   "min" | "mid" | "max" | "disable" )
     ras_log "Valid trace level found : ${LEVEL}";;
   "" ) ras_log -v "Error, trace level not provided $USAGE"
      exit 1;;
   *) ras_log -v "Error, invalid trace level ${LEVEL} $USAGE"
      exit 1;;
esac

ras_log "Setting trace level to ${LEVEL}"

cp ${CONFIG_FROM_DIR}/${CONFIG_FILE}.${LEVEL} ${CONFIG_TO_DIR}/${CONFIG_FILE}
rc=$?
# Check return code on copy
if [[ $rc -ne 0 ]]; then
  ras_log -v "Unable to set trace level to ${LEVEL}, unable to copy trace config file ${CONFIG_TO_DIR}/${CONFIG_FILE}."
  exit 1
else
  ras_log -v "Successfully copied trace config file ${CONFIG_TO_DIR}/${CONFIG_FILE} for level ${LEVEL}."
fi

# Compile the syslog-ng process.
ras_log -v "Compiling new syslog-ng.conf.in"
SuSEconfig
rc=$?
# Check return code
if [[ $rc -ne 0 ]]; then
  ras_log -v "Unable to compile syslog-ng.conf.in, please see log file for more information."
  exit 1
else
  ras_log -v "Successfully compiled syslog-ng.conf.in."
fi

# Kill the syslogd process.  You need to kill it before you can start again
ras_log -v "Restarting syslog-ng"
kill -1 `pidof syslog-ng`
rc=$?
# Check return code
if [[ $rc -ne 0 ]]; then
  ras_log -v "Unable to restart syslog-ng, please see log file for more information."
  exit 1
else
  ras_log -v "Successfully restarted syslog-ng."
fi

# Kill the klogd process.  You need to kill it before you can start again
ras_log -v "Killing klogd"
kill -1 `pidof klogd`
rc=$?
# Check return code
if [[ $rc -ne 0 ]]; then
  ras_log -v "Unable to kill klogd, please see log file for more information."
  exit 1
else
  ras_log -v "Successfully killed klogd."
fi

sleep 5

# Set trace levels as one of the following [min,mid,max,disable]
case "${LEVEL}" in
   "min")
      K_LEVEL=4;;
   "mid")
      K_LEVEL=5;;
   "max")
      K_LEVEL=8;;
   "disable" )
      K_LEVEL=1;;
   *) ras_log -v "Error, invalid trace level ${LEVEL} $USAGE"
      exit 1;;
esac

# Start the syslogd process.
ras_log -v "Starting klogd"
klogd -c ${K_LEVEL}
rc=$?
# Check return code
if [[ $rc -ne 0 ]]; then
  ras_log -v "Unable to start klogd, please see log file for more information."
else
  ras_log -v "Successfully started klogd."
fi

exit $rc
