#! /usr/bin/env python
########################################################## {COPYRIGHT-TOP} ###
# IBM Confidential
#  
# Licensed Materials - Property of IBM
#  
# 5608-IAF - IBM Information Archive (IIA)
#  
# Copyright IBM Corporation 2008, 2009, All Rights Reserved
#  
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been deposited 
# with the U.S. Copyright Office
# 
########################################################## {COPYRIGHT-END} ###
#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Solr Server Manager
# *
# * FILE NAME:       ssm_common.py
# *
# * DESCRIPTION:     Collection of common functions for the Solr Server Mgr
# *                  mainly to access collection.xml, collections.xml
# *
# * AUTHOR:          K.W.Brannon
# *                  IBM Almaden Research Center
# *                  kbrannon@us.ibm.com
# *
# *
# ****************************************************************************
# */
import os
import sys
import subprocess
import shlex
import re
from datetime import *
from time import *
from xml.dom.minidom import parse           # xml file parser
from ssm_defines import *
from ssm_logmsgs import *

# ------------------------------------
# Function to remove old files from a directory and its subdirectories
# ------------------------------------
def RemoveOldestFiles( logger, dirname, maxMB=None, maxFiles=None, fnprefix=None):

   if dirname.endswith( "/" ):
      dirname = dirname[ :-1 ]
   if maxMB != None:
      maxMB = maxMB * 1024 * 1024

   # Collect names of all files and directories in tree rooted at dirname
   sflist    = []
   dirlist   = []
   for root,dirs,files in os.walk( dirname ):
      for f in files:
         fn = root + "/" + f
         try:
            statinfo = os.stat( fn )
         except:
            continue
         if fnprefix != None and f.startswith(fnprefix):
            sflist.append( ( statinfo.st_ctime, statinfo.st_size, fn ) )
      for d in dirs:
         dirlist.append( root + "/" + d )

   # Start with newest files, add size & count, remove files after threshold
   st_size   = 0
   num_files = 0
   sflist.sort( reverse=True )

   for f in sflist:
      num_files += 1
      st_size   += f[ 1 ]

      if ( ( maxMB  != None and st_size > maxMB ) or   \
           ( maxFiles != None and num_files > maxFiles ) ):

         try:
            os.remove( f[ 2 ] )
         except OSError, ( errno, strerror ):
            if logger != None:
                msg = str("errno: %s strerror: %s f[2]: %s" 
                          %( str(errno), str(strerror), str(f[ 2 ]) ) )
                logger.LogMsg( SSM_LOGMSG_SYS_ERR, (msg) )
            else:
                sys.stdout.write("OSError from os.remove in RemoveOldestFiles")

   # Attempt to remove subdirectories lowest first (will succeed on empty ones)
   dirlist.sort( reverse=True )
   for d in dirlist:
      try:
         os.removedirs( d )
      except:
         continue


if SSM_IA_INSTALL_LIB not in sys.path:
    sys.path.append(SSM_IA_INSTALL_LIB)
from iamiddleware.ialogging import IALogger

def ssm_nl_get_logger(subcomponent, mountpt, loglevel, trclvl):
    tracelevel = ("0", "3") [trclvl != "0"]
    guid = ssm_nl_get_guid()
    if (guid != None and loglevel != None and tracelevel != None):
        logger = IALogger(SSM_LOG_PATH, SSM_LOG_IN, mountpt, guid,
                    "%s.%d" % (subcomponent, os.getpid()),
                    SSM_LOG_INLOG, "%(asctime)s %(message)s", loglevel,
                    SSM_LOG_INTRACE, "%(asctime)s %(process)d  %(message)s",
                    tracelevel, SSM_LOG_SIZE, SSM_LOG_BACKUPS, False, False)
	logPath = "%s/%s/%s/%s/%s/%s/" % (SSM_LOG_PATH, "CTJID", SSM_LOG_IN, mountpt, guid, "ffdc")

       	RemoveOldestFiles( logger, logPath, maxMB=100, maxFiles=100, fnprefix=subcomponent)
	logPath = "%s/%s/%s/%s/%s/%s/" % (SSM_LOG_PATH, "CTJID", SSM_LOG_IN, mountpt, guid, "logs")
       	RemoveOldestFiles( logger, logPath, maxMB=100, maxFiles=100, fnprefix=subcomponent )
        logger.LogMsg(SSM_LOGMSG_START,(subcomponent,loglevel,tracelevel))
        logger.TraceMsg("starting %s logger at log:%s trace:%s"
                         %(subcomponent,loglevel,tracelevel))

        return logger
    else:
        msg = str("Error creating logger for index subcomponent %s, mntpt:%s"
                  %(subcomponent,mntpt))
        sys.stdout.write(msg)
        return None

def ssm_parse_fusemetafile(logger,xmlfile):
    logger.LogMsg(SSM_LOGMSG_INFO,str("About to open xml file: %s" %(xmlfile)))
    try: 
        fo = open(xmlfile, "r")
        dom = parse(fo)
        logger.LogMsg(SSM_LOGMSG_INFO,str("Successfully parsed xml file: %s as %s" %(xmlfile, str(dom.toxml()))))
        fo.close()
        return dom
    except:
        logger.LogMsg(SSM_LOGMSG_PARSE,(xmlfile))
        logger.TraceMsg("Error parsing xml file: %s" %(xmlfile))
        return None
    
def ssm_parse_xmlfile(logger,xmlfile):
    logger.LogMsg(SSM_LOGMSG_INFO,str("About to parse xml file: %s" %(xmlfile)))
    try: 
        dom = parse(xmlfile)
        logger.LogMsg(SSM_LOGMSG_INFO,str("Successfully parsed xml file: %s" %(xmlfile)))
        return dom
    except:
        logger.LogMsg(SSM_LOGMSG_PARSE,(xmlfile))
        logger.TraceMsg("Error parsing xml file: %s" %(xmlfile))
        return None
    
def ssm_run_cmd(logger, cmd):
    #run a command and return the return code
    logger.LogMsg(SSM_LOGMSG_INFO,str("ssm_run_cmd, about to run command: %s " %cmd))
    rc,stdout = ssm_run_cmdStdout(logger, cmd)
    return rc

def ssm_run_cmdStdout(logger, cmd):
    #run a command and return the return code and stdout
    args = shlex.split(cmd)
    logger.LogMsg(SSM_LOGMSG_INFO,str("ssm_run_cmdStdout, about to run command: %s as args=%s "
                    %(cmd,str(args))))
    process = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False)
    stdoutdata, stderrdata = process.communicate()
    rc = process.returncode
    if (rc != 0):
        logger.LogMsg(SSM_LOGMSG_CMDRC, (rc,cmd))
        logger.LogMsg(SSM_LOGMSG_CMDSTDOUT, (stdoutdata))
        logger.LogMsg(SSM_LOGMSG_CMDSTDERR, (stderrdata))
        logger.TraceMsg("Return code running command: %s rc: %d stdout: %s stderr: %s"
                         %(cmd, rc, stdoutdata, stderrdata))
    else:
        logger.LogMsg(SSM_LOGMSG_ICMDRC, (rc,cmd))
        logger.LogMsg(SSM_LOGMSG_ICMDSTDOUT, (stdoutdata))
        logger.LogMsg(SSM_LOGMSG_ICMDSTDERR, (stderrdata))
    return rc, stdoutdata

def ssm_run_cmdStdout_stdin(logger, cmd, Stdin):
    #run a command specifying stdin and return the return code and stdout
    args = shlex.split(cmd)
    logger.LogMsg(SSM_LOGMSG_INFO,str("ssm_run_cmdStdout, about to run command: %s as args=%s with stdin=%s "
                    %(cmd,str(args),Stdin)))
    process = subprocess.Popen(args, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False)
    process.stdin.write(Stdin)
    stdoutdata, stderrdata = process.communicate()
    rc = process.returncode
    if (rc != 0):
        logger.LogMsg(SSM_LOGMSG_CMDRC, (rc,cmd))
        logger.LogMsg(SSM_LOGMSG_CMDSTDOUT, (stdoutdata))
        logger.LogMsg(SSM_LOGMSG_CMDSTDERR, (stderrdata))
        logger.TraceMsg("Return code running command: %s rc: %d stdout: %s stderr: %s"
                         %(cmd, rc, stdoutdata, stderrdata))
    else:
        logger.LogMsg(SSM_LOGMSG_ICMDRC, (rc,cmd))
        logger.LogMsg(SSM_LOGMSG_ICMDSTDOUT, (stdoutdata))
        logger.LogMsg(SSM_LOGMSG_ICMDSTDERR, (stderrdata))
    return rc, stdoutdata

def ssm_get_ipnumberFromName(logger, name):
    logger.TraceMsg("Getting IPnumber from IPname %s" %(name))
    cmd = str("/usr/bin/awk -v ipname=%s {'if($2==ipname){print $1}'} /etc/hosts"
             %(name))
    rc, out = ssm_run_cmdStdout(logger, cmd)
    if rc == 0:
        ipnum = out.strip()
        logger.LogMsg(SSM_LOGMSG_INFO,str("Found IPnumber %s from IPname %s" %(ipnum, name)))
        return ipnum
    else:
        logger.TraceMsg("Error finding IPnumber from IPname %s" %(name))
        return None 
   
def ssm_get_valueFromXmlfile(logger, element, parsed_xml, xmlfile):
    logger.LogMsg(SSM_LOGMSG_INFO,str("Getting value for element %s in %s "
                    %(element,xmlfile)))
    try:
        value = parsed_xml.getElementsByTagName(element)[0].childNodes[0].data
        logger.LogMsg(SSM_LOGMSG_INFO,str("For element %s found value=%s"
                        %(element,str(value))))
        return value
    except IndexError:
        #not necessarilyan error if no value
        logger.LogMsg(SSM_LOGMSG_INFO,str("IndexError for element: %s in %s"
                        %(element,xmlfile)))
        return None
    except:
        logger.LogMsg(SSM_LOGMSG_PARSE_EL, (xmlfile,element))
        logger.TraceMsg("Error parsing %s for element: %s "
                        %(xmlfile,element))
        return None
    
def ssm_get_solrValueFromCdotxml(logger, element, parsed_cdotxml, cdotxml):
    logger.LogMsg(SSM_LOGMSG_INFO,str("Getting value for solr element %s in %s "
                    %(element,cdotxml)))
    try:
        solrdom = parsed_cdotxml.getElementsByTagName(SSM_C_EL_SOLR)[0]
        try:
            value = solrdom.getElementsByTagName(element)[0].childNodes[0].data
            logger.LogMsg(SSM_LOGMSG_INFO,str("For solr element %s found value=%s in %s"
                        %(element,value,cdotxml)))
            return str(value)
        except IndexError:
            logger.LogMsg(SSM_LOGMSG_NOELEMENT, (element,cdotxml))
            logger.TraceMsg("Error: IndexError for element: %s in %s"
                            %(element,cdotxml))
            return None
        except:
            logger.LogMsg(SSM_LOGMSG_PARSE, (cdotxml))
            logger.TraceMsg("Error: parsing for element: %s in %s"
                            %(element,cdotxml))
            return None
    except IndexError:
        logger.LogMsg(SSM_LOGMSG_NOELEMENT, (SSM_C_EL_SOLR,cdotxml))
        logger.TraceMsg("Error: IndexError for element: %s in %s"
                        %(SSM_C_EL_SOLR,cdotxml))
        return None
    except:
        logger.LogMsg(SSM_LOGMSG_PARSE, (cdotxml))
        logger.TraceMsg("Error: parsing for element: %s in %s"
                        %(SSM_C_EL_SOLR,cdotxml))
        return None
    
def ssm_get_archiveminersFrom_Collxml(logger, parsed_cdotxml, cdotxml):
    logger.LogMsg(SSM_LOGMSG_INFO,str("Getting archive miner groups from %s "
                    %(cdotxml)))
    try:
        minerdom = parsed_cdotxml.getElementsByTagName(SSM_C_EL_MINERGROUPS)[0]
        try:
            #get all the miner groups
            element = SSM_C_MINER_EL_GROUP
            grouplist = None
            n = 0
            for gd in minerdom.getElementsByTagName(element):
                g = str(gd.childNodes[0].data)
                if n == 0:
                    grouplist = [g]
                else:
                    grouplist.append(g)
                n = n + 1    
            return grouplist
        except IndexError:
            logger.LogMsg(SSM_LOGMSG_NOELEMENT, (element,cdotxml))
            logger.TraceMsg("Error: IndexError for element: %s in %s"
                            %(element,cdotxml))
            return None
        except:
            logger.LogMsg(SSM_LOGMSG_PARSE, (cdotxml))
            logger.TraceMsg("Error: parsing for element: %s in %s"
                            %(element,cdotxml))
            return None
    except IndexError:
        element = SSM_C_EL_MINERGROUPS
        logger.LogMsg(SSM_LOGMSG_NOELEMENT, (element,cdotxml))
        logger.TraceMsg("Error: IndexError  for element: %s in %s"
                        %(element,cdotxml))
        return None
    except:
        element = SSM_C_EL_MINERGROUPS
        logger.LogMsg(SSM_LOGMSG_PARSE, (cdotxml))
        logger.TraceMsg("Error: parsing for element: %s in %s"
                        %(element,cdotxml))
        return None
    
def ssm_nl_parse_xmlfile(xmlfile):
    #no logging, used to get the logger, in testing scripts
    try:
        fdom = parse(xmlfile)
        return fdom
    except:
        sys.stdout.write("Error cannot parse %s" %(xmlfile))
        return None
    
def ssm_nl_get_tracelevel(parsed_cdotxml, cdotxml):
    #no logging - used to get the logger
    try:
        element = SSM_C_EL_TRACELEVEL
        value = parsed_cdotxml.getElementsByTagName(element)[0].childNodes[0].data
        return value
    except:
        msg = str("cannot find %s in %s" %(element,cdotxml))
        sys.stdout.write(msg)
        return None
   
def ssm_nl_get_loglevel(parsed_cdotxml, cdotxml):
    #no logging - used to get the logger
    try:
        element = SSM_C_EL_LOGLEVEL
        value = parsed_cdotxml.getElementsByTagName(element)[0].childNodes[0].data
        return value
    except IndexError:
        msg = str("cannot find %s in %s" %(element,cdotxml))
        sys.stdout.write(msg)
        return None
    
def ssm_nl_get_guid():
    #no logging - used to get the logger
    cmd = SSM_GUID_CMD
    process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False)
    stdoutdata, stderrdata = process.communicate()
    rc = process.returncode
    if (rc != 0):
        msg = "Error: ssm_getGUID, cannot get unique nodeid"
        sys.stdout.write(msg)
        return None
    else:
        guid = stdoutdata.strip()
        return guid

def ssm_nl_get_valueFromXmlfile(element, parsed_xml, xmlfile):
    #no logging - used in testing scripts
    try:
        value = parsed_xml.getElementsByTagName(element)[0].childNodes[0].data
        return value
    except IndexError:
        #not necessarilyan error if no value
        print ("IndexError for element: %s in %s" %(element,xmlfile))
        return None
    except:
        print("Error parsing %s for element %s " %(xmlfile, element))
        return None
    
def ssm_nl_get_jettyport(parsed_cdotxml, cdotxml):
    #no logging - used in statistics, testing scripts
    jettyport = ssm_nl_get_solrValueFromCdotxml(SSM_SOLR_EL_JETTYPORT,
                                                parsed_cdotxml, cdotxml)
    return jettyport

def ssm_nl_get_jettyipname(parsed_cdotxml, cdotxml):
    #no logging - used in statistics, testing scripts
    jettyipname = ssm_nl_get_solrValueFromCdotxml(SSM_SOLR_EL_VIRTUAL_JETTYIP, 
                                                  parsed_cdotxml, cdotxml)
    return jettyipname
  
def ssm_nl_get_solrValueFromCdotxml(element, parsed_cdotxml, cdotxml):
    #no logging - used in statistics, testing scripts
    value = None
    try:
        solrdom = parsed_cdotxml.getElementsByTagName(SSM_C_EL_SOLR)[0]
        try:
            value = solrdom.getElementsByTagName(element)[0].childNodes[0].data
            return str(value)
        except IndexError:
            print("IndexError for element: %s in %s" %(element,cdotxml))
            return None
        except:
            print("Error: parsing for element: %s in %s" %(element,cdotxml))
            return None
    except IndexError:
        print("Error: IndexError for element: %s in %s"
              %(SSM_C_EL_SOLR,cdotxml))
        return None
    except:
        print("Error: parsing for element: %s in %s"
              %(SSM_C_EL_SOLR,cdotxml))
        return None

def ssm_nl_run_cmd(cmd):
    #no logging - used in statistics, testing scripts
    #run a command and return the return code
    rc = subprocess.call(cmd, shell=True)
    return rc
 
def ssm_nl_run_cmdStdout(cmd):
    #no logging - used in statistics, testing scripts
    #run a command and return the return code and stdout
    process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True)
    stdoutdata, stderrdata = process.communicate()
    rc = process.returncode
    return rc, stdoutdata
