#! /usr/bin/env python

########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Solr Server Manager
# *
# * FILE NAME:       ssm_config_common.py
# *
# * DESCRIPTION:     Functions to initialize/manage solr configuration:
#                    directory structure, solr schema, solr cores  
# *
# * AUTHOR:          K.W.Brannon
# *                  IBM Almaden Research Center
# *                  kbrannon@us.ibm.com
# *
# *
# ****************************************************************************
# */


from ssm_defines import *
from ssm_common import *

def ssm_get_currentCoreid(logger, mntpt):
    #get the current solr coreid from the core file
    logger.TraceMsg("Getting the current coreid for collection %s" %(mntpt))
    ccf = str("%s%s" %(mntpt,SSM_SOLR_CURRENT_COREID_RMNT))
    parsed_ccf = ssm_parse_xmlfile(logger, ccf)
    if (parsed_ccf != None):
        coreid = ssm_get_valueFromXmlfile(logger, SSM_CC_EL_COREID, parsed_ccf, ccf)
    else:
        coreid = None
    logger.TraceMsg("Returning current coreid: %s for collection %s"
                    %(str(coreid),mntpt))
    return coreid

def ssm_set_currentCoreid(logger, mntpt, curCoreid):
    #set the current solr coreid from the core file
    logger.TraceMsg("Setting the current coreid for collection %s" %(mntpt))
    currentCoreFile = str("%s%s" %(mntpt, SSM_SOLR_CURRENT_COREID_RMNT))
    tmp_currentCoreFile = str("%s%s%s" %(mntpt, SSM_SOLR_CURRENT_COREID_RMNT,"-tmp"))
    #write the current core file
    ccf = open(tmp_currentCoreFile, "w")
    line = str('<?xml version="1.0" encoding="UTF-8"?>\n')
    ccf.write(line)
    line = str('<%s>%s</%s>\n' %(SSM_CC_EL_COREID, curCoreid, SSM_CC_EL_COREID))
    ccf.write(line)
    ccf.close()
    cmd = str("mv %s %s" %(tmp_currentCoreFile, currentCoreFile))
    rc,stdout = ssm_run_cmdStdout(logger, cmd)
    logger.TraceMsg("Wrote current coreid: %s into %s"
                    %(str(curCoreid), currentCoreFile))
    return 0

def ssm_init_core(logger, mntpt, coreName):
    #Done only during initial configuration
    logger.TraceMsg("Add core %s for collection %s" %(coreName, mntpt))
    cmd = str("mkdir -p %s%s/%s/%s"
              %(mntpt,SSM_INITSOLR_CORES_DIR_RMNT,coreName,SSM_SOLR_CORE_DATA_DIR))
    ret = ssm_run_cmd(logger, cmd)
    if (ret == 0):
        cmd = str("ln -fs %s%s/conf  %s%s/%s/conf"
                  %(mntpt,SSM_SOLR_CONFIG_RMNT,mntpt,SSM_INITSOLR_CORES_DIR_RMNT,coreName))
        ret = ssm_run_cmd(logger, cmd)
        if (ret == 0):
            logger.TraceMsg("Added core %s for collection %s returning rc: %s"
                            %(coreName, mntpt, ret))
    if (ret != 0):
        logger.LogMsg(SSM_LOGMSG_ADDCORE, (coreName,mntpt))
    return ret

def ssm_add_newIndexingCore(logger, mntpt):
    logger.TraceMsg("Initializing new indexing core for collection %s"
                    %(mntpt))
    cmd = str("mkdir -p %s%s/%s"
              %(mntpt, SSM_SOLR_CORES_INITNEWCORE_DIR_RMNT, SSM_SOLR_CORE_DATA_DIR))
    ret = ssm_run_cmd(logger, cmd)
    if (ret == 0):
        cmd = str("ln -fs  %s%s/conf  %s%s/conf"
                  %(mntpt, SSM_SOLR_CONFIG_RMNT, mntpt,
                    SSM_SOLR_CORES_INITNEWCORE_DIR_RMNT))
        ret = ssm_run_cmd(logger, cmd)
    corelist = ssm_get_corelist(logger, mntpt)
    maxcoreid = ssm_get_maxCoreid(logger, mntpt, corelist)
    newcoreid = int(maxcoreid) + 1
    newcorename = SSM_INDEX_CORE_NAME +str(newcoreid)
    cmd = str("mv %s%s %s%s/%s"
              %(mntpt, SSM_SOLR_CORES_INITNEWCORE_DIR_RMNT, mntpt,
                SSM_SOLR_CORES_DIR_RMNT, newcorename))
    rc = ssm_run_cmd(logger, cmd)
    return str(newcoreid)

def ssm_set_shardEntry(logger, mntpt, corelist, jettyip, jettyport):
    #add a <shard> entry to solconfig.xml for all cores in this IA collection
    solrconfigdotxml = mntpt +SSM_SOLRCONFIGDOTXML_RMNT
    base_solrconfigdotxml = SSM_SOLR_BASE_SOLRCONFIGDOTXML
    #get guid
    rc,stdout = ssm_run_cmdStdout(logger, SSM_GUID_CMD)
    if rc == 0:
        guid = stdout.strip()
    else:
        msg = str("cannot get guid for %s " %mntpt)
        return 1 
    solrconfigdotxml_edit = solrconfigdotxml + "_edit_" +guid
    try:
        sxmlr  = open(base_solrconfigdotxml, "r")
    except: 
        msg = str("could not open %s " %base_solrconfigdotxml)
        logger.Trace(msg)
        logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
        return 1
    try:
       sxmlw = open(solrconfigdotxml_edit, "w")
    except:
       msg = str("open failed for %s " %(solrconfigdotxml_edit))
       logger.Trace(msg)
       logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
       try:
           sxmlr.close()
       except:
           pass
       return 1
    line = sxmlr.readline()
    #shards element looks like:
    #<str name="shards">ip:port/solr/coreN,ip:port/solr/coreM</str>
    #had to use ipnumber and not ipname, always rewrite entire shards line
    while line:
        sline = line.strip()
        res = re.match('<str name="shards">(.*)</str>',sline)
        if res == None:
            sxmlw.write(line)
        else:
            #set shards for all cores
            shards_line = str('       <str name="shards">')
            count = 0
            for coreName in corelist:
                res = re.match('core(.*)',coreName)
                if res == None:
                   pass
                else:
                   count = count + 1
                   if count == 1:
                      shards_line = str("%s%s:%s/solr/%s"
                                        %(shards_line, jettyip,jettyport,coreName))
                   else:
                      shards_line = str("%s,%s:%s/solr/%s"
                                        %(shards_line, jettyip,jettyport,coreName))
            shards_line = str("%s</str>\n" %(shards_line))
            sxmlw.write(shards_line)
        line = sxmlr.readline()
    try:
        sxmlw.flush()
        sxmlw.close()
        sxmlr.close()
    except:
        pass
    cmd = str("mv %s %s" %(solrconfigdotxml_edit, solrconfigdotxml))
    ret = ssm_run_cmd(logger, cmd)
    if ret == 0:
        logger.TraceMsg("Success in generating new solrconfig.xml file, %s"
                        %solrconfigdotxml)
        return 0
    else:
        msg = str("could not replace existing %s with %s"
                  %(solrconfigdotxml, solrconfigdotxml_edit))
        logger.TraceMsg(msg)
        logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
        return 1

def ssm_set_solrdotxmlEntries(logger, mntpt, corelist):
    #add the list of solr cores to base solr.xml
    basesolrdotxml = SSM_SOLR_BASE_SOLRDOTXML
    solrdotxml = mntpt +SSM_SOLRDOTXML_RMNT
    try:
        sxmlr  = open( basesolrdotxml, "r")
    except:
        logger.TraceMsg("open of %s failed" %(basesolrdotxml))
        sxmlw.close()
        return 1
    #get guid
    rc,stdout = ssm_run_cmdStdout(logger, SSM_GUID_CMD)
    if rc == 0:
        guid = stdout.strip()
    else:
        msg = str("cannot get guid for %s " %mntpt)
        return 1 
    solrdotxml_edit = str("%s%s%s" %(solrdotxml,"_edit_",guid))
    try:
        sxmlw = open(solrdotxml_edit, "w")
    except:
        msg = str("open failed for solr.xml to edit, " +solrdotxml_edit)
        logger.TraceMsg(msg)
        logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
        return 1
    line = sxmlr.readline()
    while line:
        sline = line.strip()
        if sline == "<core":
            sxmlw.write(line)
            line = sxmlbak.readline()
            sxmlw.write(line)
            sline = line.strip()
        elif sline == "</cores>":
            for coreName in corelist:
                instDir = mntpt +SSM_SOLR_CORES_DIR_RMNT +"/" +coreName
                dataDir = instDir +"/" +SSM_SOLR_CORE_DATA_DIR
                sxmlw.write("    <core\n")
                sxmlw.write('        name="%s"\n' % (coreName))
                sxmlw.write('        instanceDir="%s"\n' % (instDir))
                sxmlw.write('        dataDir="%s">\n' % (dataDir))
                sxmlw.write("    </core>\n")
            sxmlw.write(line)
        else:
           sxmlw.write(line)
        line = sxmlr.readline()
    sxmlw.flush()
    sxmlw.close()
    sxmlr.close()
    cmd = str("mv %s %s" % (solrdotxml_edit, solrdotxml))
    ret = ssm_run_cmd(logger, cmd)
    if ret == 0:
        logger.TraceMsg("Success in generating new solr.xml, %s"
                        %solrdotxml)
        return 0
    else:
        msg = str("Error in replacing %s with new version, %s"
                  %(solrdotxml,solrdotxml_edit))
        logger.TraceMsg(msg)
        logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
        cmd = "rm %s" %solrdotxml_edit
        ret = ssm_run_cmd(cmd)
        return 1

def ssm_load_newCore(logger, mntpt, coreName, jettyip, jettyport):
    #this is not supported yet:  solr/admin/cores?action=LOAD&core=coreName
    #so use CREATE instead:
    #  solr/admin/cores?action=CREATE&name=coreName&instanceDir=idir&config=cnf&schema=sc&dataDir=dd
    #look for following response:
    #<lst name="responseHeader"><int name="status">0</int><int name="QTime">224</int></lst>
    instanceDir = str("%s%s/%s" %(mntpt,SSM_SOLR_CORES_DIR_RMNT,coreName))
    dataDir = instanceDir +"/" +SSM_SOLR_CORE_DATA_DIR
    config = instanceDir +"/conf/solrconfig.xml" 
    schema = instanceDir +"/conf/schema.xml"
    cmd = str('curl %s "http://%s:%s/solr/admin/cores?action=CREATE&name=%s&instanceDir=%s&config=%s&schema=%s&dataDir=%s"' %(SSM_CURL_OPTS,jettyip,jettyport,coreName,instanceDir,config,schema,dataDir))
    rc, msg = ssm_run_cmdStdout(logger, cmd)
    if rc == 0:
        res = re.match('(.*)<int name="status">0</int>(.*)',msg,re.DOTALL)
        if res == None:
            return 1
        else: 
            return 0
    else:
        return rc

def ssm_load_queryCore(logger, mntpt, jettyip, jettyport):
    #send solr/admin/cores?action=RELOAD&core=COREID for querycore  
    #look for following response:
    #<lst name="responseHeader"><int name="status">0</int><int name="QTime">224</int></lst>
    coreName = SSM_QUERY_CORE_NAME
    cmd = str('curl %s "http://%s:%s/solr/admin/cores?action=RELOAD&core=%s"'
              %(SSM_CURL_OPTS,jettyip,jettyport,coreName))
    rc, msg = ssm_run_cmdStdout(logger, cmd)
    if rc == 0:
         res = re.match('(.*)<int name="status">0</int>(.*)',msg,re.DOTALL)
         if res == None:
             return 1
         else: 
             print "reloaded " +coreName
    else:
         return rc
    return 0

def ssm_load_indexCores(logger, mntpt, corelist, jettyip, jettyport):
    #send solr/admin/cores?action=RELOAD&core=COREID for each indexing core
    #look for following response:
    #<lst name="responseHeader"><int name="status">0</int><int name="QTime">224</int></lst>
    for coreName in corelist:
        res = re.match('core(.*)',coreName)
        if res == None:
           pass
        else:
           cmd = str('curl %s "http://%s:%s/solr/admin/cores?action=RELOAD&core=%s"'
                     %(SSM_CURL_OPTS,jettyip,jettyport,coreName))
           rc, msg = ssm_run_cmdStdout(logger, cmd)
           if rc == 0:
                res = re.match('(.*)<int name="status">0</int>(.*)',msg,re.DOTALL)
                if res == None:
                    return 1
                else: 
                    print "reloaded " +coreName
           else:
                return rc
    return 0

def ssm_init_indexConfig(logger, mntpt):
    ret = 0
    #add solr configuration files under mntpt/index/initializing-solr/config
    cmd = "mkdir -p " +mntpt +SSM_INITSOLR_CONFIG_RMNT
    ret = ssm_run_cmd(logger, cmd)
    cmd = "mkdir -p " +mntpt +SSM_INITSOLR_HOME_RMNT
    ret = ssm_run_cmd(logger, cmd)
    cmd = "mkdir -p " +mntpt +SSM_INITSOLR_CORES_DIR_RMNT
    ret = ssm_run_cmd(logger, cmd)
    cmd = "ln -fs " +SSM_SOLR_JARS +" " +mntpt +SSM_INITSOLR_HOME_RMNT +"/lib"
    ret = ssm_run_cmd(logger, cmd)
    if not os.path.isdir(mntpt +SSM_INITSOLR_CONFIG_RMNT +"/conf"):
        cmd = str("cp -pr %s %s%s/conf" %(SSM_SOLR_CONF, mntpt, SSM_INITSOLR_CONFIG_RMNT))
        ret = ssm_run_cmd(logger, cmd)
    cmd = str("cp -p %s %s%s" %(SSM_SOLR_BASE_SOLRDOTXML, mntpt, SSM_INITSOLRDOTXML_RMNT))
    ret = ssm_run_cmd(logger, cmd)
    ret = ssm_init_core(logger, mntpt, SSM_QUERY_CORE_NAME)
    core1 = SSM_INDEX_CORE_NAME +"1"
    ret = ssm_init_core(logger, mntpt, core1)
    return ret

def ssm_get_numDocs(logger, mntpt, coreName, jettyip, jettyport):
    #send solr/admin/cores?action=STATUS&core=coreName
    #look for following response:
    #<int name="numDocs">NNNNN</int>
    cmd = str('curl %s "http://%s:%s/solr/admin/cores?action=STATUS&core=core%s"' %(SSM_CURL_OPTS,jettyip,jettyport,coreName))
    rc, out = ssm_run_cmdStdout(logger, cmd)
    if rc == 0:
       res = re.match('(.*)<int name="numDocs">(.*)</int>(.*)',out,re.DOTALL)
       if res == None:
           return None
       else:
           nd = out.split('<int name="numDocs">')[1]
           numDocs = nd.split('</int>')[0]
           return numDocs 
    return None

def ssm_cleanup_initializingSolr(logger, mntpt):
    #clean up in case initialization terminated prematurely
    #rm -rf  index/initializing-solr
    cmd = str("rm -rf %s%s" %(mntpt, SSM_INITSOLR_INDEX_DIR_RMNT))
    rc = ssm_run_cmd(logger, cmd)
    return rc

def ssm_cleanup_initializingCore(logger, mntpt):
    #clean up in case initialization terminated prematurely
    #rm -rf  index/solr/solrCores/initializing-core
    cmd = str("rm -rf %s%s" %(mntpt, SSM_SOLR_CORES_INITNEWCORE_DIR_RMNT))
    rc = ssm_run_cmd(logger, cmd)
    return rc

def ssm_cleanup_updatelock(logger, mntpt):
    #clean up in case update terminated prematurely
    #rmdir  index/solr/updatLock
    lockfile = str("%s%s" %(mntpt, SSM_LOCK_UPDATE_LOCK_RMNT))
    logger.TraceMsg("if present, cleanup the updatelock %s" %lockfile)
    cleanup = True
    ret = ssm_release_lock(logger, lockfile, cleanup)
    if ret == SSM_LOCK_RELEASED_LOCK:
        rc = 0
    else:
        rc = 1
    return rc

def ssm_cleanup_solrNotHealthy_signal(logger, mntpt):
    #clean up during solr startup
    #rmdir  index/solr/solrNotHealthy
    lockfile = str("%s%s" %(mntpt, SSM_LOCK_SOLRNOTHEALTHY_RMNT))
    logger.TraceMsg("if present, cleanup the solrNotHealthy signal, %s" %lockfile)
    cleanup = True
    ret = ssm_release_lock(logger, lockfile, cleanup)
    if ret == SSM_LOCK_RELEASED_LOCK:
        logger.TraceMsg("removed the solrNotHealthy signal, %s" %lockfile)
        rc = 0
    else:
        logger.TraceMsg("error releasing the solrNotHealthy signal, %s" %lockfile)
        rc = 1
    return rc

def ssm_set_solrNotHealthy_signal(logger, mntpt):
    lockfile = str("%s%s" %(mntpt, SSM_LOCK_SOLRNOTHEALTHY_RMNT))
    logger.TraceMsg("if not present, create the solrNotHealthy signal, %s" %lockfile)

    ret = ssm_get_lock(logger, lockfile)
    if ret == SSM_LOCK_ALREADY_LOCKED or ret == SSM_LOCK_GOT_LOCK:
        logger.TraceMsg("created the solrNotHealthy signal, %s" %lockfile)
        return 0
    else:
        logger.TraceMsg("error creating the solrNotHealthy signal, %s" %lockfile)
        return 1

def ssm_create_solrConfig(logger, mntpt, indexlvl, parsed_cdotxml, cdotxml):
    #1  make sure index fileset exists (so do not create index as plain directory)
    #2  cleanup prior create
    #3  cleanup update lock
    #4  init:
    #   mkdir index/initializing-solr
    #   mkdir index/initializing-solr/config
    #   copy config over including solrHome
    #   mkdir index/initializing-solr/solrCores
    #   add /queryCore under initializing-solr (and dataDir, conf)
    #   add /core1 under initializing-solr (and dataDir, conf)
    #5  mv initializing-solr to solr
    #6  set entries for list(core1, queryCore) to solr.xml
    #7  set shard entry for list(core1, queryCore) in solrconfig.xml
    #8  reconcile schema
    #9  set "1" in index/solr/currentcoreid
 
    #get collection device from mntpt
    collname = None
    cmd = str("awk -v colmount=%s '{ if ($2==colmount) { print $1 } }' /etc/fstab" %(mntpt))    
    ret, collname = ssm_run_cmdStdout(logger, cmd)
    if (ret != 0 ):
        #no device name
        logger.LogMsg(SSM_LOGMSG_PARSE_EL,(cdotxml, SSM_C_EL_COLLNAME))
        logger.TraceMsg("Cannot get device name from %s" %(cmd))
        return SSM_CREATE_ERROR
    collname = collname.strip()
    cmd = str("%s/mmlsfileset %s %s" %(SSM_MMFSBIN, collname, SSM_INDEX_FILESET))
    ret = ssm_run_cmd(logger, cmd)
    if (ret != 0):
        msg = str("Missing index fileset for collection %s" %(collname))
        logger.LogMsg(SSM_LOGMSG_SYS_ERR, (msg))
        logger.TraceMsg(msg)
        return SSM_CREATE_ERROR
    cmd = str("mkdir -p %s%s" %(mntpt, SSM_INITSOLR_INDEX_DIR_RMNT))
    ret = ssm_run_cmd(logger, cmd)
    if (ret != 0):
        msg = str("Error creating directory %s%s"  %(mntpt, SSM_INITSOLR_INDEX_DIR_RMNT))
        logger.LogMsg(SSM_LOGMSG_SYS_ERR, (msg))
        logger.TraceMsg(msg)
        return SSM_CREATE_ERROR
    try:
        rc = SSM_CREATE_ERROR
        ret = ssm_cleanup_initializingSolr(logger, mntpt)
        ret = ssm_cleanup_initializingCore(logger, mntpt)
        ret = ssm_cleanup_updatelock(logger, mntpt)
        ret = ssm_init_indexConfig(logger, mntpt)
        cmd = str("mv %s%s %s%s"
                  %(mntpt, SSM_INITSOLR_INDEX_DIR_RMNT, mntpt, SSM_SOLR_INDEX_DIR_RMNT))
        ret = ssm_run_cmd(logger,cmd)
        corelist = ssm_get_corelist(logger, mntpt)
        logger.TraceMsg("found initial corelist: %s" %(str(corelist)))
        ret = ssm_set_solrdotxmlEntries(logger, mntpt, corelist)
        if parsed_cdotxml != None:
            jettyipname = ssm_get_solrValueFromCdotxml(logger, SSM_SOLR_EL_VIRTUAL_JETTYIP, 
                                                   parsed_cdotxml, cdotxml)
            jettyip = ssm_get_ipnumberFromName(logger, jettyipname)
            jettyport = ssm_get_solrValueFromCdotxml(logger, SSM_SOLR_EL_JETTYPORT, parsed_cdotxml, cdotxml)
            ret = ssm_set_shardEntry(logger, mntpt, corelist, jettyip, jettyport)
        else:
            pass
            #this is a new collection, set the shards on startup
        ret = ssm_reconcile_schema(logger, mntpt,indexlvl)
        rc =  SSM_CREATE_SUCCESS
    finally:
        return rc

def ssm_update_solrConfig(logger, mntpt, indexlvl, jettyip, jettyport,
                          createnewcore, starting):
    #Called from:
    #    1) indexing controller - create new core
    #       no need to wait on the lock since once lock is released
    #       next call will create the new core
    #    2) via wlm update
    #       must wait for the lock
    #    3) via wlm start
    #       should not be locked
    #1. get update lock
    #2. if createnewcore == true, create solrCores/initializing-core
    #                             create conf/dataDir
    #                             coreN = .currentcore + 1
    #                             mv initializing-core to coreN
    #3  get list(cores) from solrCores/coreN's and queryCore
    #4  set entries for list(cores) to solr.xml
    #5  set shard entry for list(cores) in solrconfig.xml
    #6  reconcile schema
    #7  set "maxcorenum" in index/solr/currentcore.xml
    #8  release lock
    #get update lock
    lockfile = str("%s%s" %(mntpt, SSM_LOCK_UPDATE_LOCK_RMNT))
    cleanup = True
    if starting == True:
        ret = ssm_release_lock(logger, lockfile, cleanup)
    else:
        ret = ssm_release_expired_lock(logger, lockfile, cleanup)
    ret = ssm_get_lock(logger, lockfile)
    if ret == SSM_LOCK_ALREADY_LOCKED or ret == SSM_LOCK_ERROR:
        return SSM_UPDATE_LOCKED
    try:
        rc = SSM_UPDATE_ERROR
        if createnewcore == True:
            ret = ssm_cleanup_initializingCore(logger, mntpt)
            ret = ssm_add_newIndexingCore(logger, mntpt)
        corelist = ssm_get_corelist(logger, mntpt)
        maxcoreid = ssm_get_maxCoreid(logger, mntpt, corelist)
        ret = ssm_set_solrdotxmlEntries(logger, mntpt, corelist)
        ret = ssm_set_shardEntry(logger, mntpt, corelist, jettyip, jettyport)
        ret = ssm_reconcile_schema(logger, mntpt, indexlvl)
        if createnewcore == True:
            newcorename = SSM_INDEX_CORE_NAME +str(maxcoreid)
            ssm_load_newCore(logger, mntpt, newcorename, jettyip, jettyport)
            ssm_load_queryCore(logger, mntpt, jettyip, jettyport)
        else:
            if (starting == True):
                #starting the server - cannot reload the cores
                pass
            else:
                ssm_load_indexCores(logger, mntpt, corelist, jettyip, jettyport)
                ssm_load_queryCore(logger, mntpt, jettyip, jettyport)
        ret = ssm_set_currentCoreid(logger, mntpt, maxcoreid)
        cleanup = False
        ret = ssm_release_lock(logger, lockfile, cleanup)
        rc =  SSM_UPDATE_SUCCESS
    finally:
        cleanup = True
        ret = ssm_release_lock(logger, lockfile, cleanup)
    return rc

def ssm_get_mffields(logger, mntpt):
    #write out solr schema xml for all fields of 
    #type "system" or "user" in metafile.xml
    mfdotxml = mntpt + SSM_MFDOTXML_RMNT
    logger.TraceMsg("In ssm_get_mffields, getting system/user fields from %s"
                 %(mfdotxml))
    mfdom = ssm_parse_xmlfile(logger, mfdotxml)
    try:
        newxml = ""
        fnodes = mfdom.getElementsByTagName("fields")
        for fields in fnodes:
            fl = fields.childNodes
            for field in fl:
                if field.hasAttributes() == True:
                    attr = field.attributes
                    nmax = attr.length
                    n = 0
                    ft = ""
                    t = ""
                    while n < nmax:
                        a = attr.item(n)
                        if a.name == "field_type":
                            ft = a.value
                        elif a.name == "type":
                            t = a.value.lower()
                        n = n + 1
                    if ft == "user" or ft == "system":
                        #Write out Solr schema field definition
                        solrType = SSMMF_MAPTYPES[t]
                        if solrType == SSMMF_TYPE_TEXT:
                            newxml = str('%s<field name="%s" type="%s" indexed="true" stored="true" multivalued="true" required="false" />\n' %(newxml,field.nodeName,solrType))
                        else:
                            newxml = str('%s<field name="%s" type="%s" indexed="true" stored="true" required="false" />\n' %(newxml,field.nodeName,solrType))    
                else:
                    pass
    except:
        logger.LogMsg(SSM_LOGMSG_PARSE,(mfdotxml))
        newxml = None
    if newxml == "":
        newxml = None
    logger.TraceMsg("new xml for user fields: %s " %(str(newxml)))
    return newxml

def ssm_get_mfuserfields(logger, parsed_mfdotxml, mfdotxml):
    #get list of all system/user metafile field names from metafile.xml
    logger.TraceMsg("Parsing %s for user field names/types" %(mfdotxml))
    uf_list = []
    mfdom = parsed_mfdotxml
    try:
        fnodes = mfdom.getElementsByTagName("fields")
        for fields in fnodes:
            num_uf = 0
            fl = fields.childNodes
            for field in fl:
                if field.hasAttributes() == True:
                    attr = field.attributes
                    nmax = attr.length
                    n = 0
                    ft = ""
                    t = ""
                    while n < nmax:
                        a = attr.item(n)
                        if a.name == "field_type":
                            ft = a.value
                        elif a.name == "type":
                            t = a.value.lower()
                        n = n + 1
                    if ft == "user": 
                        if num_uf == 0:
                            uf_list = [[str(field.nodeName),str(t)]]
                        else:
                            uf_list.append([str(field.nodeName),str(t)])
                        num_uf = num_uf + 1
                else:
                    pass
        logger.TraceMsg("Finished parsing %s for user field names/types"
                        %(mfdotxml))
        logger.TraceMsg("Found user field names/types: %s" %(str(uf_list)))
    except:
        logger.LogMsg(SSM_LOGMSG_PARSE,(mfdotxml))
        logger.TraceMsg("Error parsing %s for user field names/types"
                        %(mfdotxml))
        uf_list = None
    return uf_list

def ssm_reconcile_schema(logger, mntpt, indexlvl):
    logger.TraceMsg("About to reconcile schema for collection: %s at indexlevlel: %s"
                    %(mntpt, indexlvl))
    metafile = mntpt + SSM_MFDOTXML_RMNT
    logger.TraceMsg("get all the system and user fields for %s" %mntpt)
    mf_fields_xml = ssm_get_mffields(logger, mntpt)
    if mf_fields_xml != None:
        logger.TraceMsg("For %s found system, user fields: %s"
                        %(mntpt,str(mf_fields_xml)))
    else:
        msg = str("metafile.xml is missing, %s" %metafile)
        logger.TraceMsg(msg)
        logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
        return 1
    rec = "extracted content field"
    if SSM_INDEX_LEVEL[indexlvl] != "index_and_store_metadata_index_content" \
       and \
       SSM_INDEX_LEVEL[indexlvl] != "index_and_store_metadata_plus_content":
        logger.TraceMsg("No need to reconcile %s" %(rec))
        reconcile_extractedContent = False
    else:
        reconcile_extractedContent = True
    base_solrschema = SSM_SOLR_BASE_SOLRSCHEMA
    solrschema = mntpt +SSM_SCHEMA_RMNT
    #get guid
    rc,stdout = ssm_run_cmdStdout(logger, SSM_GUID_CMD)
    if rc == 0:
        guid = stdout.strip()
    else:
        msg = str("cannot get guid for %s " %mntpt)
        return 1
    try:
       base_schema  = open( base_solrschema, "r")
    except:
        msg = str("open failed for schema.xml, " %base_solrschema)
        logger.TraceMsg(msg)
        logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
        return 1
    solrschema_edit = solrschema +"_edit_" +guid 
    try:
       new_schema = open(solrschema_edit, "w")
    except:
       msg = str("open failed for schema.xml, " %solrschema_edit)
       logger.TraceMsg(msg)
       logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
       return 1
    el = SSM_SCHEMA_EL_CONTENT
    inside_mff = False
    line = base_schema.readline()
    while line:
        sline = line.strip()
        if inside_mff == False:
           if sline == "<!-- Information Archive Metafile Fields START -->":
               new_schema.write(line)
               inside_mff = True
               newxml = ssm_get_mffields(logger, mntpt)
               if newxml == None:
                   return 1
               else:
                   new_schema.write(newxml)
           else:
               if reconcile_extractedContent == True:
                   res = re.match('<field name="%s"(.*)/>'%(el), sline)
                   if res == None:
                       new_schema.write(line)
                   else:
                       if SSM_INDEX_LEVEL[indexlvl] == "index_and_store_metadata_index_content":
                           value = ' type="text" indexed="true" stored="false" multiValued="true"'
                       elif SSM_INDEX_LEVEL[indexlvl] == "index_and_store_metadata_plus_content":
                           value = ' type="text" indexed="true" stored="true" multiValued="true"'
                       new_schema.write('     <field name="%s"%s/>\n' %(el, value))
               else:
                   new_schema.write(line)
        else:
           if sline == "<!-- Information Archive Metafile Fields END -->":
              inside_mff = False
              new_schema.write(line)
        line = base_schema.readline()
    new_schema.flush()
    base_schema.close()
    new_schema.close()
    cmd = str("mv %s %s " %(solrschema_edit, solrschema))
    ret = ssm_run_cmd(logger, cmd)
    if ret == 0:
        logger.TraceMsg("finished reconciling schema %s" %solrschema)
        return 0
    else:
        msg = str("could not replace existing schema file %s " %solrschema)
        logger.TraceMsg(msg)
        logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
        cmd = str("rm %s" %solrschema_edit)
        rc = ssm_run_cmd(logger, cmd)
        return 1

def ssm_get_lock(logger, lockfile):
    logger.TraceMsg("try creating lock directory: %s " %lockfile)
    try: 
        os.mkdir(lockfile)
        rc = SSM_LOCK_GOT_LOCK
        logger.TraceMsg("created lock directory: %s " %lockfile)
    except OSError:
        rc = SSM_LOCK_ALREADY_LOCKED
        logger.TraceMsg("lock directory: %s already exists" %lockfile)
    except:
        rc = SSM_LOCK_ERROR
        msg = str("error creating lock directory: %s" %lockfile)
        logger.TraceMsg(msg)
        logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
    return rc

def ssm_release_lock(logger, lockfile, cleanup):
    logger.TraceMsg("try removing lock directory: %s cleanup=%s" 
                    %(lockfile,str(cleanup)))
    try:
        os.rmdir(lockfile)
        rc = SSM_LOCK_RELEASED_LOCK
        logger.TraceMsg("removed lock directory: %s " %lockfile)
    except OSError:
        rc = SSM_LOCK_DIR_OSERROR
        msg = str("error removing lock directory: %s directory does not exist or is not empty"
                   %lockfile)
        logger.TraceMsg(msg)
        if cleanup == False:
            logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
    except:
        rc = SSM_LOCK_ERROR
        msg = str("error removing lock directory: %s" %lockfile)
        logger.TraceMsg(msg)
        logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
    return rc
         
def ssm_release_expired_lock(logger, lockfile, cleanup):
    logger.TraceMsg("removing expired lock directory: %s " 
                    %(lockfile))
    try:
        mtime = int(os.path.getmtime(lockfile))
        exptime = mtime + SSM_LOCK_EXPIRATION_INTERVAL
        current_time = int(mktime(localtime()))
        if current_time > exptime:
            try:
                os.rmdir(lockfile)
                rc = SSM_LOCK_RELEASED_LOCK
                logger.TraceMsg("removed expired lock directory: %s " %lockfile)
            except OSError:
                rc = SSM_LOCK_DIR_OSERROR
                msg = str("error removing expired lock directory: %s directory does not exist or is not empty"
                          %lockfile)
                logger.TraceMsg(msg)
                if cleanup == False:
                    logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
            except:
                rc = SSM_LOCK_ERROR
                msg = str("error removing lock directory: %s" %lockfile)
                logger.TraceMsg(msg)
                logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
        else:
            rc = SSM_LOCK_ALREADY_LOCKED
    except OSError:
        rc = SSM_LOCK_DIR_OSERROR
        msg = str("no expired lock directory: %s directory does not exist "
                  %lockfile)
        logger.TraceMsg(msg)
        if cleanup == False:
            logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
    except:
        rc = SSM_LOCK_ERROR
        msg = str("error getting mtime for lock directory: %s" %lockfile)
        logger.TraceMsg(msg)
        logger.LogMsg(SSM_LOGMSG_SYS_ERR, msg)
    return rc

def ssm_get_corelist(logger, mntpt):
    try:
        corelist = os.listdir(mntpt +SSM_SOLR_CORES_DIR_RMNT)
        logger.TraceMsg("found list of cores: %s in collection %s "
                        %(str(corelist), mntpt))
        return corelist
    except:
        msg = str("Error - found no cores for collection %s" %(mntpt))
        logger.TraceMsg(msg)
        logger.LogMsg(SSM_LOGMSG_SYS_ERR, (msg))
        return None

def ssm_get_maxCoreid(logger, mntpt, corelist):
    maxcore = 0
    for coreName in corelist:
        core = coreName.strip()
        if core.startswith(SSM_INDEX_CORE_NAME) == True:
            coreid = int(core.lstrip(SSM_INDEX_CORE_NAME))
            maxcore = max(maxcore, coreid)
    logger.TraceMsg("Found max core: %s in collection %s" %(maxcore, mntpt))
    return str(maxcore)

