#! /usr/bin/env python

########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Solr Server 
# *
# * FILE NAME:       ssm_createCollection.py
# *
# * DESCRIPTION:     Initialize indexing config for a new collection
# *                  or for an existing collection with indexlevel = 3
# *
# * AUTHOR:          K.W.Brannon
# *                  IBM Almaden Research Center
# *                  kbrannon@us.ibm.com
# *
# *
# ****************************************************************************
# */

import sys, os, subprocess
import getopt
from ssm_defines   import *
from ssm_common    import *
from ssm_config_common import *

def usage(logger, errmsg):
    umsg = "usage: " + sys.argv[0] +" -m collectionMountPoint -l indexingLevel\n"
    umsg = umsg +"          allowed values for indexingLevel :\n"
    l = sorted(list(SSM_INDEX_LEVEL.keys()))
    for val in l:
        umsg = umsg +"              " +str(val) +'\t' +"(" +str(SSM_INDEX_LEVEL[val]) +")\n"
    if (logger != None):
        logger.LogMsg(SSM_LOGMSG_USAGE, (errmsg, umsg))
        logger.TraceMsg("Usage Error msg: %s" %(errmsg))
        logger.TraceMsg("Usage: %s" %(umsg))
    else:
        sys.stdout.write("Error: %s \n" %errmsg)
        sys.stdout.write(umsg)
    sys.exit(1)
       
euid = os.geteuid()
if euid != SSM_ROOTUID:
    pmsg = str("This script must be run as root")
    usage(logger, pmsg)
#Must have two arguments, the collection mount point
#and the indexing level
mountpt = None
indexlvl = None
logger = None
try:
    opts, args = getopt.getopt(sys.argv[1:],"m:l:h")
except getopt.GetoptError, err:
    usage(logger, str(err))
for opt, arg in opts:
    if opt in ("-m"):
        mountpt = arg.rstrip('/')
    elif opt in ("-l"):
        indexlvl = arg
    elif opt in ("-h"):
        msg = ""
        usage(logger,msg)
    else:
        msg = "unhandled option"
        usage(logger, msg)
        
#check that mountpt is a directory
if mountpt == None or not os.path.isdir(mountpt):
    pmsg = str("collectionMountPoint, %s must be a fully qualified directory"
               %(str(mountpt)))
    logger = None
    usage(logger, pmsg)

cdotxml = str("%s%s" %(mountpt, SSM_CDOTXML_RMNT))
if os.path.isfile(cdotxml):
    parsed_cdotxml = ssm_nl_parse_xmlfile(cdotxml)
    if parsed_cdotxml == None:
        msg = str("Error in %s, parsing %s" %(sys.argv[0],cdotxml))
        sys.stdout.write(msg)
        sys.exit(1)
    loglevel = ssm_nl_get_loglevel(parsed_cdotxml,cdotxml)
    if loglevel == None:
        loglevel = SSM_LOG_DEFAULT_LOGLEVEL
    tracelevel = ssm_nl_get_tracelevel(parsed_cdotxml,cdotxml)
    if tracelevel == None:
        tracelevel = SSM_LOG_DEFAULT_TRACELEVEL
else:
    loglevel = SSM_LOG_DEFAULT_LOGLEVEL
    tracelevel = SSM_LOG_DEFAULT_TRACELEVEL
logger = ssm_nl_get_logger(SSM_LOG_SSM, mountpt, loglevel, tracelevel) 
if (logger != None):
    pass
else:
    msg = str("Error in %s, cannot get logger" %(sys.argv[0]))
    sys.stdout.write(msg)
    sys.exit(1)

euid = os.geteuid()
if euid != SSM_ROOTUID:
    pmsg = str("This script must be run as root")
    usage(logger, pmsg)
    
if indexlvl == None or not indexlvl in SSM_INDEX_LEVEL:
    pmsg = str("Incorrect value for indexlevel: %s" %(str(indexlvl)))
    print "pmsg:" +pmsg
    usage(logger, pmsg)

msg = str("calling ssm_managConfig.py with doCreate option for %s indexlvl:%s"
          %(mountpt, indexlvl))
logger.TraceMsg(msg)
cmd = str('%s/ssm_manageConfig.py -m %s -l %s --doCreate' %(SSM_IA_INSTALL_BIN,mountpt,indexlvl))
rc, stdoutdata = ssm_run_cmdStdout(logger, cmd)
msg = str("rc=%s for ssm_managConfig.py with doCreate option for %s indexlvl:%s"
          %(rc, mountpt, indexlvl))
logger.TraceMsg(msg)
sys.exit(rc)
