#! /usr/bin/env python
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Solr Server
# *
# * FILE NAME:       ssm_getTikaHealthy.py
# *
# * DESCRIPTION:     Get server status for Tika by extractOnly 
# *
# * AUTHOR:          K.W.Brannon
# *                  IBM Almaden Research Center
# *                  kbrannon@us.ibm.com
# *
# *
# ****************************************************************************
# */


import os, sys
import getopt
from ssm_defines import *
from ssm_common  import *
SSM_TEST_PDF = "/opt/tivoli/tiam/lib/index/solr/IBM_IA.pdf"

def usage():
    msg = "usage: " + sys.argv[0] +" -m collectionMountPoint "
    print msg
    sys.exit(1)

#Must have one argument, the collection mount point
mountpt = ""
try:
    opts, args = getopt.getopt(sys.argv[1:],"m:")
except getopt.GetoptError, err:
    print str(err)
    usage()

for opt, arg in opts:
    if opt in ("-m"):
        mountpt = arg
    else:
        msg = "unhandled option"
        print msg
        usage()

#check that mountpt is a directory
if not os.path.isdir( mountpt):
    msg = "collectionMountPoint must be a fully qualified directory"
    print msg
    usage()

cdotxml = mountpt +SSM_CDOTXML_RMNT
parsed_cdotxml = ssm_nl_parse_xmlfile(cdotxml)
jettyip = ssm_nl_get_jettyipname(parsed_cdotxml, cdotxml)
jettyport = ssm_nl_get_jettyport(parsed_cdotxml, cdotxml)
lvl = ssm_nl_get_valueFromXmlfile(SSM_C_EL_INDEXLEVEL,
                                   parsed_cdotxml, cdotxml)

SSM_INDEX_LEVEL = {'3': 'no_index',
                   '4': 'index_and_store_metadata_only',
                   '5': 'index_and_store_metadata_index_content',
                   '6': 'index_and_store_metadata_plus_content'}

if SSM_INDEX_LEVEL[lvl] == 'index_and_store_metadata_index_content' or \
   SSM_INDEX_LEVEL[lvl] == 'index_and_store_metadata_plus_content':

    cmd = "curl " +SSM_CURL_OPTS +' "http://' +jettyip +":" +jettyport +"/solr/core1/update/extract/?extractOnly=true&stream.file=" +SSM_TEST_PDF +'"'

    os.system(cmd)
else:
    print "archiving"
