#! /usr/bin/env python
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Solr Server
# *
# * FILE NAME:       ssm_level_statistics.py
# *
# * DESCRIPTION:     Get number of documents indexed per index level
# *                  Return to stdout for the ingest coordinator
# *
# * AUTHOR:          K.W.Brannon
# *                  IBM Almaden Research Center
# *                  kbrannon@us.ibm.com
# *
# *
# ****************************************************************************
# */


import os, sys
import getopt
from ssm_defines import *
from ssm_common  import *

def usage(pmsg):
    umsg = "\nusage: " + sys.argv[0] +" -m collectionMountPoint \n"
    sys.stdout.write("Error: " +pmsg)
    sys.stdout.write(umsg)
    sys.exit(1)

#Must have one argument, the collection mount point
mountpt = ""
try:
    opts, args = getopt.getopt(sys.argv[1:],"m:")
except getopt.GetoptError, err:
    pmsg = str(err)
    usage(pmsg)

for opt, arg in opts:
    if opt in ("-m"):
        mountpt = arg.rstrip('/')
    else:
        pmsg = "unhandled option"
        usage(pmsg)

#check that mountpt is a directory
if not os.path.isdir( mountpt):
    pmsg = "collectionMountPoint must be a fully qualified directory"
    usage(pmsg)
    
euid = os.geteuid()
if euid != SSM_ROOTUID:
    pmsg = "This script must be run as root"
    usage(pmsg)

cdotxml = str("%s%s" %(mountpt,SSM_CDOTXML_RMNT))
parsed_cdotxml = ssm_nl_parse_xmlfile(cdotxml)
if parsed_cdotxml != None:
    jettyname = ssm_nl_get_jettyipname(parsed_cdotxml, cdotxml)
    jettyport = ssm_nl_get_jettyport(parsed_cdotxml, cdotxml)
else:
    msg = str("Error in %s, parsing %s\n" %(sys.argv[0],cdotxml))
    sys.stdout.write(msg)
    sys.exit(1)                     

if (jettyname != None and jettyport != None):
    #This query searches for all indexed files at the various indexing levels
    #Reponse looks like <result name="response" numFound="0" start="0"/>
    levelfield = SSMMF_FIELD_NAME['SSMMF_INDEXLEVEL']
    output = ""
    ret = 0
    l = sorted(list(SSM_INDEX_LEVEL.keys()))
    for lvl in l:
         if SSM_INDEX_LEVEL[lvl] == 'no_index':
              pass
         else:
              cmd = str('curl %s "http://%s:%s/solr/%s/select?&q=%s:%s&qt=distributed&start=0&rows=0"' %(SSM_CURL_OPTS,jettyname,jettyport,SSM_QUERY_CORE_NAME,levelfield,lvl))
              rc, response = ssm_nl_run_cmdStdout(cmd)
              if rc == 0:
                  match_pred = str('(.*)<result name="response" numFound=(.*)')
                  res = re.match(match_pred,response,re.DOTALL)
                  if res == None:
                      sys.stdout.write("Getting index level statistics, no match for %s \n   in Solr response:\n %s" %(match_pred,response))
                      ret = max(ret, 1)
                  else:
                      nf = response.split("numFound=")[1]
                      numDocs = nf.split('"')[1].strip()
                      output = str('%slevel\t%s\t%s\n' %(output, lvl, numDocs))
                      ret = max(ret, 0)
              else:
                  sys.stdout.write("Error running cmd: %s" %cmd)
    if ret == 0:
         sys.stdout.write(output)
else:
    msg = str("Error in %s, parsing %s for jettyip jettyport\n" 
               %(sys.argv[0],cdotxml))
    sys.stdout.write(msg)
    ret = 1
sys.exit(ret)


