#! /usr/bin/env python
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Solr Server
# *
# * FILE NAME:       ssm_postDir.py
# *
# * DESCRIPTION:     Post files in a directory directly to the current core
#                    of a solr server, bypassing the indexbroker
# *
# * AUTHOR:          K.W.Brannon
# *                  IBM Almaden Research Center
# *                  kbrannon@us.ibm.com
# *
# *
# ****************************************************************************
# */

#NOTE THIS IS A SCRIPT USED FOR TESTING

import os, sys
import getopt
import stat
import md5
from datetime import *
from ssm_defines import *
from ssm_common  import *

def usage():
    msg = "usage: " + sys.argv[0] +" -m collectionMountPoint -d directory"
    print msg
    sys.exit(1)

#Must have two arguments, the collection mount point and directory
mountpt = ""
try:
    opts, args = getopt.getopt(sys.argv[1:],"m:d:")
except getopt.GetoptError, err:
    print str(err)
    usage()

for opt, arg in opts:
    if opt in ("-m"):
        mountpt = arg
    elif opt in ("-d"):
        dir = arg.rstrip('/')
    else:
        msg = "unhandled option"
        print msg
        usage()

#check that mountpt is a directory
if not os.path.isdir( mountpt):
    msg = "collectionMountPoint must be a fully qualified directory"
    print msg
    usage()

#check that dir is a directory
if not os.path.isdir( dir):
    msg = "directory to be posted  must be a fully qualified directory"
    print msg
    usage()

cdotxml = mountpt +SSM_CDOTXML_RMNT
parsed_cdotxml = ssm_nl_parse_xmlfile(cdotxml)
jettyip = ssm_nl_get_jettyipname(parsed_cdotxml, cdotxml)
jettyport = ssm_nl_get_jettyport(parsed_cdotxml, cdotxml)
ccf = mountpt +SSM_SOLR_CURRENT_COREID_RMNT
parsed_ccf = ssm_nl_parse_xmlfile(ccf)
coreid = ssm_nl_get_valueFromXmlfile(SSM_CC_EL_COREID, parsed_ccf, ccf)
baseSolrURL = str("http://%s:%s/solr/core%s" %(jettyip, jettyport, coreid))

indexlevel = ssm_nl_get_valueFromXmlfile(SSM_C_EL_INDEXLEVEL, 
                                         parsed_cdotxml, cdotxml)
epoch = ssm_nl_get_solrValueFromCdotxml(SSM_SOLR_EL_EPOCHNUM, 
                                         parsed_cdotxml, cdotxml)
for name in os.listdir(dir):
    #print "name: " +name
    file = dir +"/" +name
    if os.path.isfile(file):
        #print "file is: " +file
        statout = os.stat(file)
        filesize = str(statout[stat.ST_SIZE]) 
        owner =  str(statout[stat.ST_UID])
        group = str(statout[stat.ST_GID])
        inode = str(statout[stat.ST_INO])
        genid = str(statout[stat.ST_DEV])
        m = md5.new(str(file +str(inode) +str(genid)))
        docid = m.hexdigest()
        d = datetime.utcnow()
        indxtime = str("%04i-%02i-%02iT%02i:%02i:%02iZ" %(d.year,d.month,d.day,d.hour,d.minute,d.second))
        if SSM_INDEX_LEVEL[indexlevel] == 'no_index':
            print("current index level is no_Index")
            sys.exit(1)
        elif SSM_INDEX_LEVEL[indexlevel] == 'index_and_store_metadata_only':
            URL = str('%s/update -H "Content-Type: text/xml" --data-binary'
                      %baseSolrURL)
            URL = str("%s'<add> <doc>" %URL)
            URL = str('%s<field name="%s">%s</field>.'%(URL,"_SYSTEM_INdocid_",docid)) 
            URL = str('%s<field name="%s">%s</field>.'%(URL,"_SYSTEM_pathname_",file)) 
            URL = str('%s<field name="%s">%s</field>.'%(URL,"_SYSTEM_owner_",owner)) 
            URL = str('%s<field name="%s">%s</field>.'%(URL,"_SYSTEM_primary_group_",group)) 
            URL = str('%s<field name="%s">%s</field>.'%(URL,"_SYSTEM_filesize_",filesize)) 
            URL = str('%s<field name="%s">%s</field>.'%(URL,"_SYSTEM_INcoreid_",coreid)) 
            URL = str('%s<field name="%s">%s</field>.'%(URL,"_SYSTEM_INepoch_",epoch)) 
            URL = str('%s<field name="%s">%s</field>.'%(URL,"_SYSTEM_INlevel_",indexlevel)) 
            URL = str('%s<field name="%s">%s</field>.'%(URL,"_SYSTEM_INtime_",indxtime)) 
            URL = str('%s<field name="%s">%s</field>.'%(URL,"_SYSTEM_inode_number_",inode)) 
            URL = str('%s<field name="%s">%s</field>.'%(URL,"_SYSTEM_genid_",genid)) 
            URL = str("%s</doc></add>'"%(URL)) 
        else:
            URL = str(baseSolrURL +"/update/extract?stream.file=" +file 
                      +"\&literal._SYSTEM_INdocid_=" +docid 
                      +"\&literal._SYSTEM_pathname_=" +file 
                      +"\&literal._SYSTEM_owner_=" +owner 
                      +"\&literal._SYSTEM_primary_group_=" +group 
                      +"\&literal._SYSTEM_filesize_=" +filesize 
                      +"\&literal._SYSTEM_INcoreid_=" +coreid 
                      +"\&extractOnly=false"
                      +"\&literal._SYSTEM_INepoch_=" +epoch 
                      +"\&literal._SYSTEM_INlevel_=" +indexlevel 
                      +"\&literal._SYSTEM_INtime_=" +indxtime 
                      +"\&literal._SYSTEM_inode_number_=" +inode 
                      +"\&literal._SYSTEM_genid_=" +genid)
        cmd = "curl " +URL
        print "cmd is: " +cmd
        os.system(cmd)

commit = "curl " +baseSolrURL +"/update --data-binary '<commit/>' -H 'Content-type:text/xml;charset=utf-8'"
print "commit: " +commit
os.system(commit)
