#!/bin/bash
#
#******************************************************************************
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp.  2008  All Rights Reserved
#
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -----------------------------------------------------------------------------
# 
# =========================================================================
# 
#
# Change Log:
#  Date           developer             change
#  02/01/2010     Bryan Jen             Initial script creation
#  03/12/2010     Liming (Michael) Yu   switchLunRoles() - filtered out all
#                                       luns that are not ia or util
#  03/13/2010     Liming (Michael) Yu   Updated print and log messages; updated
#                                       error messages and exit codes
#
#******************************************************************************


SMCLI="/usr/bin/SMcli"
TIAMBIN="/opt/tivoli/tiam/bin"
MMPATH="/usr/lpp/mmfs/bin"
DRLOGPATH="/opt/tivoli/tiam/log/dr/"
SCRIPTNAME="switchERM"
iAm=`cat /etc/HOSTNAME`
datestamp=`date +%m%d%Y%H%M%S`
LOGFILE="${DRLOGPATH}/${SCRIPTNAME}.${datestamp}.out"


pingtest() {
  cmd=`ping $1 -c 1`
  if [[ `echo $cmd |grep -i unreachable` ]]; then
    return -1
  else
    return 0
  fi
}


log() {
  timestamp=`date "+%Y-%m-%d %H:%M:%S"`
  echo "$timestamp [$SCRIPTNAME] $1" >> $LOGFILE
}


printAndLog() {
  timestamp=`date "+%Y-%m-%d %H:%M:%S"`
  echo "$timestamp [$SCRIPTNAME] $1"
  echo "$timestamp [$SCRIPTNAME] $1" >> $LOGFILE
}


printAndLogErrorExit() {
  timestamp=`date "+%Y-%m-%d %H:%M:%S"`
  echo "$timestamp [$SCRIPTNAME] ERROR($1): $2"
  echo "$timestamp [$SCRIPTNAME] ERROR($1): $2" >> $LOGFILE
  echo "$timestamp [$SCRIPTNAME] Exiting script with rc=$1. Please refer to the logfile @ $LOGFILE"
  echo "$timestamp [$SCRIPTNAME] Exiting script with rc=$1" >> $LOGFILE
  exit $1
}


switchLunRoles() {
  log "Enter switchLunRoles()"
  
  for lun in `$SMCLI $1 $2 -c "show alllogicaldrives;" |grep -i "logical drive name" | cut -d: -f2 |awk '{ print $1 }' | grep -vi mirror`;
  do
    printAndLog "Switching $lun to primary role"
    cmd=`${SMCLI} $1 $2 -c "set remoteMirror locallogicaldrive [\"$lun\"] role=primary;"`
    result=`echo $?`
    if [ $result != 0 ]; then
      echo $cmd >> $LOGFILE
      printAndLogErrorExit 5 "Failed to switch $lun to primary role!"
    fi
  done

  log "Exit switchLunRoles() with rc=0"
}


checkSync() {
  log "Enter checkSync()"

  for LUNNAME in `${SMCLI} $1 $2 -c "show alllogicaldrives;" |grep -i "logical drive name" | grep -v "Mirror" | cut -d: -f2 | awk '{ print $1 }'`
  do
    #only care about LUNs with ia or util
    if [[ `echo $LUNNAME |grep -i ia` || `echo $LUNNAME |grep -i util` ]]; then
      cmd=`${SMCLI} $1 $2 -c "show remoteMirror localLogicalDrive [\"$LUNNAME\"] synchronizationProgress;"`
      result=`echo $?`
      if [ $result != 0 ]; then
        echo $cmd >> $LOGFILE
        printAndLogErrorExit 3 "$LUNNAME does not have a remote mirror!" 
      elif [[ `echo $cmd |grep -i synchronizing` ]]; then
        printAndLogErrorExit 4 "$LUNNAME is still synchronizing"
      fi
    fi
  done

  log "Exit checkSync() with rc=0"
}


#======= beginning of the main function =======

ls $DRLOGPATH > /dev/null 2>&1
rc=$?
if [ $rc -ne 0 ]; then
  mkdir $DRLOGPATH
fi

printAndLog "Started ERM role switch"

ctrls=(`cat /home/iaadmin/.tiam/application.properties |grep disk_ctrl | cut -d= -f2`)

for (( n=0; n < ${#ctrls[*]}; n=n+2 ))
do
  ctrla=${ctrls[n]}
  ctrlb=${ctrls[n+1]}
  printAndLog "Pinging $ctrla"
  pingtest $ctrla
  pings=$?
  if [ $pings -eq 0 ]; then
    printAndLog "Pinging $ctrlb"
    pingtest $ctrlb
    pings=$?
    if [ $pings -eq 0 ]; then
      $SMCLI -A $ctrla $ctrlb 
      printAndLog "Verifying LUNs are not synchronizing"
      checkSync $ctrla $ctrlb   
      switchLunRoles $ctrla $ctrlb
    else
      printAndLogErrorExit 2 "Can not ping $ctrlb"
    fi
  else
    printAndLogErrorExit 1 "Can not ping $ctrla"
  fi
done

timestamp=`date "+%Y-%m-%d %H:%M:%S"`
echo "$timestamp [$SCRIPTNAME] Successfully performed ERM role switch"
echo "$timestamp [$SCRIPTNAME] Successfully performed ERM role switch" >> $LOGFILE
echo "$timestamp [$SCRIPTNAME] Exiting script with rc=0. Please refer to the logfile @ $LOGFILE"
echo "$timestamp [$SCRIPTNAME] Exiting script with rc=0" >> $LOGFILE
exit 0
