#!/bin/bash
#
#******************************************************************************
#  Licensed Materials - Property of IBM
#
#  (C) Copyright IBM Corp.  2008  All Rights Reserved
#
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#
# -----------------------------------------------------------------------------
# 
# =========================================================================
# 
# Name: unCfgERM.sh
#
# Change Log:
#  Date          developer             change
#  08/1/2008     Bryan Jen             Initial script creation
#  03/05/2010    Liming (Michael) Yu   Updated print and log messages; updated
#                                      error messages and exit codes
#
#******************************************************************************


DRLOG="/opt/tivoli/tiam/log/dr"

SCRIPTNAME="unCfgERM"
SMCLI="/usr/bin/SMcli"
datestamp=`date +%m%d%Y%H%M%S`
LOGFILE="${DRLOG}/unCfgERM.${datestamp}.out"


usage() {
  echo " unCfgERM.sh"
  echo "       -h                 help/usage information"
  echo " "
  echo "    eg.   unCfgERM.sh"
  return 0
}


pingtest() {
  cmd=`ping $1 -c 1`
  if [[ `echo $cmd |grep -i unreachable` ]]; then
    return -1
  else
    return 0
  fi
}


log() {
  timestamp=`date "+%Y-%m-%d %H:%M:%S"`
  echo "$timestamp [$SCRIPTNAME] $1" >> $LOGFILE
}


printAndLog() {
  timestamp=`date "+%Y-%m-%d %H:%M:%S"`
  echo "$timestamp [$SCRIPTNAME] $1"
  echo "$timestamp [$SCRIPTNAME] $1" >> $LOGFILE
}


printAndLogErrorExit() {
  timestamp=`date "+%Y-%m-%d %H:%M:%S"`
  echo "$timestamp [$SCRIPTNAME] ERROR($1): $2"
  echo "$timestamp [$SCRIPTNAME] ERROR($1): $2" >> $LOGFILE
  echo "$timestamp [$SCRIPTNAME] Exiting script with rc=$1. Please refer to the logfile @ $LOGFILE"
  echo "$timestamp [$SCRIPTNAME] Exiting script with rc=$1" >> $LOGFILE
  exit $1
}


unpairLUNs() {
  log "Enter unpairLUNs()"

  for lun in `${SMCLI} $1 $2 -c "show alllogicaldrives;" |grep -i "logical drive name" | cut -d: -f2 |awk '{ print $1 }' | grep -vi mirror`;
  do
    printAndLog "Unpairing $lun to $lun on $1 | $2"
    cmd=`${SMCLI} $1 $2 -c "remove remoteMirror localLogicalDrive [\"$lun\"];"`
    result=`echo $?`
    if [ $result != 0 ]; then
      if [ $result == 16 ]; then
        printAndLog "Remote mirror on $lun already removed"
      else
        echo $cmd >> $LOGFILE
        printAndLogErrorExit 5 "Unpairing $lun failed!"
      fi
    fi
  done

  log "Exit unpairLUNs() with rc=0"
}


checkSync() {
  log "Enter checkSync()"

  for LUNNAME in `${SMCLI} $1 $2 -c "show alllogicaldrives;" |grep -i "logical drive name" | grep -v "Mirror" | cut -d: -f2 | awk '{ print $1 }'`
  do
    #only care about LUNs with ia or util
    if [[ `echo $LUNNAME |grep -i ia` || `echo $LUNNAME |grep -i util` ]]; then
      cmd=`${SMCLI} $1 $2 -c "show remoteMirror localLogicalDrive [\"$LUNNAME\"] synchronizationProgress;"`
      result=`echo $?`
      if [ $result != 0 ]; then
        echo $cmd >> $LOGFILE
        printAndLog "$LUNNAME does not have a remote mirror!" 
      elif [[ `echo $cmd |grep -i synchronizing` ]]; then
        printAndLogErrorExit 4 "$LUNNAME is still synchronizing"
      fi
    fi
  done

  log "Exit checkSync() with rc=0"
}


#======= beginning of the main function =======

ls $DRLOG > /dev/null 2>&1
rc=$?
if [ $rc -ne 0 ]; then
  mkdir $DRLOG
fi

printAndLog "Started unconfiguring ERM"

while [ "$1" != "" ]
do
  case $1 in
  -h | -? | --help )
    usage
    exit
    ;;
  * )
    printAndLogErrorExit -1 "Invalid input parameter. Please enter unCfgERM.sh --help to see the usage"
  esac
done

ctrls=(`cat /home/iaadmin/.tiam/application.properties |grep disk_ctrl | cut -d= -f2`)

for (( n=0; n < ${#ctrls[*]}; n=n+2 ))
do
  ctrla=${ctrls[n]}
  ctrlb=${ctrls[n+1]}
  printAndLog "Pinging $ctrla"
  pingtest $ctrla
  pings=$?
  if [ $pings -eq 0 ]; then
    printAndLog "Pinging $ctrlb"
    pingtest $ctrlb
    pings=$?
    if [ $pings -eq 0 ]; then
      $SMCLI -A $ctrla $ctrlb 
      printAndLog "Verifying LUNs are not synchronizing"
      checkSync $ctrla $ctrlb   
      unpairLUNs $ctrla $ctrlb
    else
      printAndLogErrorExit 2 "Can not ping $ctrlb"
    fi
  else
    printAndLogErrorExit 1 "Can not ping $ctrla"
  fi
done

timestamp=`date "+%Y-%m-%d %H:%M:%S"`
echo "$timestamp [$SCRIPTNAME] ERM has been successfully unconfigured"
echo "$timestamp [$SCRIPTNAME] ERM has been successfully unconfigured" >> $LOGFILE
echo "$timestamp [$SCRIPTNAME] Exiting script with rc=0. Please refer to the logfile @ $LOGFILE"
echo "$timestamp [$SCRIPTNAME] Exiting script with rc=0" >> $LOGFILE
exit 0
