#!/usr/bin/python

########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###
#
# Change Activity
#
# Name           Date         Change ID   Description
# Brad Trubey    01/06/2011   17476       Return non-zero when script fails
################################################################################

import sys
import os
import time
import commands
import logging
import logging.handlers
import copy
import drutils

LOG_FILENAME = "/var/opt/tivoli/tiam/log/ssh_regen.log"
logMessageTemplate = "%c update_ssh_keys:"

ninety_days = (90*24*3600)

root_timestamp_file    = "/opt/tivoli/tiam/config/last_root_ssh_key_regen"
iaadmin_timestamp_file = "/opt/tivoli/tiam/config/last_iaadmin_ssh_key_regen"

generate_root = "ssh-keygen -q -f /root/.ssh/root_id_rsa -t rsa -N \"\""
generate_node_mc = "ssh-keygen -q -f /home/iaadmin/.ssh/node_mc_id_rsa -t rsa -N \"\""
generate_rsm = "ssh-keygen -q -f /home/iaadmin/.ssh/rsm_id_rsa -t rsa -N \"\""

def scp_root_public(hostname):
    return("scp -o StrictHostKeyChecking=no /root/.ssh/root_id_rsa.pub root@"+hostname+":/root/.ssh/root_id_rsa.pub")
def scp_node_mc_public(hostname):
    return("scp -o StrictHostKeyChecking=no /home/iaadmin/.ssh/node_mc_id_rsa.pub root@"+hostname+":/home/iaadmin/.ssh/node_mc_id_rsa.pub")
scp_rsm_public = "scp -o StrictHostKeyChecking=no /home/iaadmin/.ssh/rsm_id_rsa.pub root@iarsm1:/home/iaadmin/.ssh/rsm_id_rsa.pub"

def scp_root_private(hostname):
    return("scp -o StrictHostKeyChecking=no /root/.ssh/root_id_rsa root@"+hostname+":/root/.ssh/root_id_rsa")
def scp_node_mc_private(hostname):
    return("scp -o StrictHostKeyChecking=no /home/iaadmin/.ssh/node_mc_id_rsa root@"+hostname+":/home/iaadmin/.ssh/node_mc_id_rsa")
scp_rsm_private = "scp -o StrictHostKeyChecking=no /home/iaadmin/.ssh/rsm_id_rsa root@iarsm1:/home/iaadmin/.ssh/rsm_id_rsa"

def scp_node_authorized_keys(hostname):
    return("scp -o StrictHostKeyChecking=no /home/iaadmin/.ssh/new_node_authorized_keys root@"+hostname+":/home/iaadmin/.ssh/new_authorized_keys")
def scp_mc_authorized_keys(hostname):
    return("scp -o StrictHostKeyChecking=no /home/iaadmin/.ssh/new_mc_authorized_keys root@"+hostname+":/home/iaadmin/.ssh/new_authorized_keys")
scp_rsm_authorized_keys = "scp -o StrictHostKeyChecking=no /home/iaadmin/.ssh/new_rsm_authorized_keys root@iarsm1:/home/iaadmin/.ssh/new_authorized_keys"

chmod_root_public = "chmod 444 /root/.ssh/root_id_rsa.pub"
chmod_node_mc_public = "chmod 444 /home/iaadmin/.ssh/node_mc_id_rsa.pub"
chmod_rsm_public = "chmod 444 /home/iaadmin/.ssh/rsm_id_rsa.pub"

chmod_root_private = "chmod 400 /root/.ssh/root_id_rsa"
chmod_node_mc_private = "chmod 400 /home/iaadmin/.ssh/node_mc_id_rsa"
chmod_rsm_private = "chmod 400 /home/iaadmin/.ssh/rsm_id_rsa"

iaadmin_allow_write_authorized_keys = "chmod +w /home/iaadmin/.ssh/authorized_keys"

chmod_root_authorized_keys = "chmod 444 /root/.ssh/authorized_keys"
chmod_iaadmin_authorized_keys = "chmod 444 /home/iaadmin/.ssh/authorized_keys"


move_root_public = "mv /root/.ssh/root_id_rsa.pub /root/.ssh/id_rsa.pub"
move_node_mc_public = "mv /home/iaadmin/.ssh/node_mc_id_rsa.pub /home/iaadmin/.ssh/id_rsa.pub"
move_rsm_public = "mv /home/iaadmin/.ssh/rsm_id_rsa.pub /home/iaadmin/.ssh/id_rsa.pub"

move_root_private = "mv /root/.ssh/root_id_rsa /root/.ssh/id_rsa"
move_node_mc_private = "mv /home/iaadmin/.ssh/node_mc_id_rsa /home/iaadmin/.ssh/id_rsa"
move_rsm_private = "mv /home/iaadmin/.ssh/rsm_id_rsa /home/iaadmin/.ssh/id_rsa"

append_root = "cat /root/.ssh/root_id_rsa.pub >> /root/.ssh/authorized_keys"
append_iaadmin = "cat /home/iaadmin/.ssh/new_authorized_keys >> /home/iaadmin/.ssh/authorized_keys"

restrict_root = "cp -p /root/.ssh/id_rsa.pub /root/.ssh/authorized_keys"
restrict_iaadmin = "mv /home/iaadmin/.ssh/new_authorized_keys /home/iaadmin/.ssh/authorized_keys"

rm_root_private = "rm -f /root/.ssh/root_id_rsa"
rm_node_mc_private = "rm -f /home/iaadmin/.ssh/node_mc_id_rsa"
rm_rsm_private = "rm -f /home/iaadmin/.ssh/rsm_id_rsa"

rm_root_public = "rm -f /root/.ssh/root_id_rsa.pub"
rm_node_mc_public = "rm -f /home/iaadmin/.ssh/node_mc_id_rsa.pub"
rm_rsm_public = "rm -f /home/iaadmin/.ssh/rsm_id_rsa.pub"

rm_new_node_authorized_keys = "rm -f /home/iaadmin/.ssh/new_node_authorized_keys"
rm_new_mc_authorized_keys = "rm -f /home/iaadmin/.ssh/new_mc_authorized_keys"
rm_new_rsm_authorized_keys = "rm -f /home/iaadmin/.ssh/new_rsm_authorized_keys"

chown_iaadmin = "chown -R iaadmin:users /home/iaadmin/.ssh"

ssh_to_rsm = "ssh root@iarsm1 -o StrictHostKeyChecking=no"

def write_to_logfile(text_to_log):
    logTime = time.localtime(time.time())
    logMessage = logMessageTemplate + text_to_log
    logMessage = time.strftime(logMessage, logTime)
    my_logger.debug(logMessage)

def write_to_logfile2(command,status,output):
    text_to_log = "command="+command+"\nstatus="+str(status)+"\noutput="+output
    write_to_logfile(text_to_log)

def write_to_logfile3(command,status):
    text_to_log = "command="+command+"\nstatus="+str(status)
    write_to_logfile(text_to_log)

def has_icw_been_run():
    try:
        (status,output) = commands.getstatusoutput('grep \"^IPADDR=\'\'\" /etc/sysconfig/network/ifcfg-bond0')
        if status == 0:
            return False
        else:
            return True
    except:
        return False

def is_local_node_master():
    status = drutils.isMasterGPFSNode()
    if status != True:
        return (-1,"not master node")
    (status2, output2) = commands.getstatusoutput("/opt/tivoli/tiam/bin/mw_print_local_gpfs_nodehostname")
    if status2 != 0:
        return (status2,"mw_print_local_gpfs_nodehostname returned non zero")

    output2 = output2.strip()
    return (0,output2)

def check_90_days(timestamp_file):
    exists = os.path.isfile(timestamp_file)
    if not exists:
        return(0)
    last_regen_mtime = os.stat(timestamp_file).st_mtime
    current_time = time.time()
    delta = (current_time-last_regen_mtime)
    if delta < ninety_days:
        write_to_logfile("less than 90 days has elapsed")
        return(1)
    else:
        write_to_logfile("more than 90 days has elapsed")

    return(0)

def verify_all_nodes_up():
    hostname_list = list()
    (status, output) = commands.getstatusoutput('/opt/tivoli/tiam/bin/wd_printnodestates.sh')
    if status != 0:
        return (status,hostname_list)
    total_nodes = len(output.splitlines())
    for line1 in output.splitlines():
        line2 = line1.split()
        if line2[2] != 'active':
            return (-1,hostname_list)
        else:
            hostname_list.append(line2[1])

    return (0,hostname_list)

def generate_new_key_root():
    command = str(rm_root_private+" ; "+
        rm_root_public+" ; "+
        generate_root+" ; "+
        chmod_root_public+" ; "+
        chmod_root_private)
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    return(status)

def generate_new_key_node_mc():
    command = str(rm_node_mc_private+" ; "+
        rm_node_mc_public+" ; "+
        generate_node_mc+" ; "+
        chmod_node_mc_public+" ; "+
        chmod_node_mc_private+" ; "+
        chown_iaadmin)
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    return(status)

def generate_new_key_rsm():
    command = str(rm_rsm_private+" ; "+
        rm_rsm_public+" ; "+
        generate_rsm+" ; "+
        chmod_rsm_public+" ; "+
        chmod_rsm_private+" ; "+
        chown_iaadmin)
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    return(status)

def allow_write_rsm():
    command = str(ssh_to_rsm+" \""+
                "chmod +w /home/iaadmin/.ssh/*"+"\"")
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    return(0)

def copy_new_keys_root(pri,hostname_list):
    for hostname in hostname_list:
        if hostname != pri:
            command = str(scp_root_public(hostname))
            (status,output) = commands.getstatusoutput(command)
            if status != 0:
                write_to_logfile2(command,status,output)
                return(status)
            command = str(scp_root_private(hostname))
            (status,output) = commands.getstatusoutput(command)
            if status != 0:
                write_to_logfile2(command,status,output)
                return(status)
            command = str("ssh -o StrictHostKeyChecking=no "+hostname+" \""+
                                chmod_root_public+" ; "+
                                chmod_root_private+"\"")
            (status,output) = commands.getstatusoutput(command)
            if status != 0:
                write_to_logfile2(command,status,output)
                return(status)
    return (0)

def copy_new_keys_iaadmin(pri,hostname_list):
    for hostname in hostname_list:
        if hostname != pri:
            command = str(scp_node_mc_public(hostname))
            (status,output) = commands.getstatusoutput(command)
            if status != 0:
                write_to_logfile2(command,status,output)
                return(status)
            command = str(scp_node_mc_private(hostname))
            (status,output) = commands.getstatusoutput(command)
            if status != 0:
                write_to_logfile2(command,status,output)
                return(status)
            command = str("ssh "+hostname+" \""+
                chmod_node_mc_public+" ; "+
                chmod_node_mc_private+" ; "+
                chown_iaadmin+"\"")
            (status,output) = commands.getstatusoutput(command)
            if status != 0:
                write_to_logfile2(command,status,output)
                return(status)

    command = str(scp_rsm_public)
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)
    command = str(scp_rsm_private)
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)
    command = str(ssh_to_rsm+" \""+
        chmod_rsm_public+" ; "+
        chmod_rsm_private+" ; "+
        chown_iaadmin+"\"")
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    return (0)

def verify_dr_tunnel():
    commands.getoutput("ssh root@iamconsole1 ls /opt/tivoli/tiam/etc/DR_ENABLED")
    rc = commands.getoutput("echo $?")
    if rc == "0":
        write_to_logfile("checking DR tunnel")
        out = commands.getoutput("ssh root@iamconsole1 /opt/tivoli/tiam/bin/ia_check_mc_tunnel.sh")
        rc = commands.getoutput("echo $?")
        if rc != "0":
            write_to_logfile(out)
            return (1)

    return (0)

def replace_keys_root(hostname_list):
    commands.getoutput("ssh root@iamconsole1 ls /opt/tivoli/tiam/etc/DR_ENABLED")
    rc = commands.getoutput("echo $?")
    if rc == "0":
        write_to_logfile("dr enabled - transferring ssh key to dr_remote_mc")
        #do this before move_root_public "mv /root/.ssh/root_id_rsa.pub /root/.ssh/id_rsa.pub" because this changes the root ssh key for this MC
        out = commands.getoutput("ssh root@iamconsole1 /opt/tivoli/tiam/bin/xferRemoteMCSshKey")
        rc = commands.getoutput("echo $?")
        if rc != "0":
            write_to_logfile(out)
            return (1)

    for hostname in hostname_list:
        command = str("ssh -o StrictHostKeyChecking=no "+hostname+" \""+
            move_root_public+" ; "+
            move_root_private+"\"")
        (status,output) = commands.getstatusoutput(command)
        if status != 0:
            write_to_logfile2(command,status,output)
            return(status)
    return (0)

def replace_keys_iaadmin(hostname_list):
    for hostname in hostname_list:
        command = str("ssh "+hostname+" \""+
            move_node_mc_public+" ; "+
            move_node_mc_private+" ; "+
            chown_iaadmin+"\"")
        (status,output) = commands.getstatusoutput(command)
        if status != 0:
            write_to_logfile2(command,status,output)
            return(status)

    command = str(ssh_to_rsm+" \""+
        move_rsm_public+" ; "+
        move_rsm_private+" ; "+
        chown_iaadmin+"\"")
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    command = str(rm_rsm_private+" ; "+
                rm_rsm_public)
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    return (0)

def build_new_node_authorized_keys():
    command = str("echo -n command= > /home/iaadmin/.ssh/new_node_authorized_keys"+" ; "+
        "echo -n '\"' >> /home/iaadmin/.ssh/new_node_authorized_keys"+" ; "+
        "echo -n /opt/tivoli/tiam/bin/ia_compliance_security_sshcmdrouter.sh >> /home/iaadmin/.ssh/new_node_authorized_keys"+" ; "+
        "echo -n '\" ' >> /home/iaadmin/.ssh/new_node_authorized_keys"+" ; "+
        "cat /home/iaadmin/.ssh/node_mc_id_rsa.pub >> /home/iaadmin/.ssh/new_node_authorized_keys")
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    return(0)

def build_new_mc_authorized_keys():
    command = str("cat /home/iaadmin/.ssh/node_mc_id_rsa.pub > /home/iaadmin/.ssh/new_mc_authorized_keys")
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)
    command = str("cat /home/iaadmin/.ssh/rsm_id_rsa.pub >> /home/iaadmin/.ssh/new_mc_authorized_keys")
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

def build_new_rsm_authorized_keys():
    command = str("echo -n command= > /home/iaadmin/.ssh/new_rsm_authorized_keys"+" ; "+
        "echo -n '\"' >> /home/iaadmin/.ssh/new_rsm_authorized_keys"+" ; "+
        "echo -n /opt/tivoli/tiam/bin/ia_compliance_security_sshcmdrouter.sh >> /home/iaadmin/.ssh/new_rsm_authorized_keys"+" ; "+
        "echo -n '\" ' >> /home/iaadmin/.ssh/new_rsm_authorized_keys"+" ; "+
        "cat /home/iaadmin/.ssh/node_mc_id_rsa.pub >> /home/iaadmin/.ssh/new_rsm_authorized_keys")


    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)
    command = str("cat /home/iaadmin/.ssh/rsm_id_rsa.pub >> /home/iaadmin/.ssh/new_rsm_authorized_keys")
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

def append_authorized_keys_root(hostname_list):
    for hostname in hostname_list:
        command = str("ssh -o StrictHostKeyChecking=no "+hostname+" \""+
            append_root+" ; "+
            chmod_root_authorized_keys+"\"")
        (status,output) = commands.getstatusoutput(command)
        if status != 0:
            write_to_logfile2(command,status,output)
            return(status)

    return (0)

def append_authorized_keys_iaadmin(hostname_list):
    build_new_node_authorized_keys()
    build_new_mc_authorized_keys()
    build_new_rsm_authorized_keys()

    for hostname in hostname_list:
        if hostname == 'iamconsole1':
            command = str(scp_mc_authorized_keys(hostname))
            (status,output) = commands.getstatusoutput(command)
            if status != 0:
                write_to_logfile2(command,status,output)
                return(status)
            command = str("ssh "+hostname+" \""+
                append_iaadmin+" ; "+
                chmod_iaadmin_authorized_keys+" ; "+
                chown_iaadmin+"\"")
            (status,output) = commands.getstatusoutput(command)
            if status != 0:
                write_to_logfile2(command,status,output)
                return(status)
        else:
            command = str(scp_node_authorized_keys(hostname))
            (status,output) = commands.getstatusoutput(command)
            if status != 0:
                write_to_logfile2(command,status,output)
                return(status)
            command = str("ssh "+hostname+" \""+
                append_iaadmin+" ; "+
                chmod_iaadmin_authorized_keys+" ; "+
                chown_iaadmin+"\"")
            (status,output) = commands.getstatusoutput(command)
            if status != 0:
                write_to_logfile2(command,status,output)
                return(status)

    command = str(scp_rsm_authorized_keys)
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    command = str(ssh_to_rsm+" \""+
        iaadmin_allow_write_authorized_keys+" ; "+
        append_iaadmin+" ; "+
        chmod_iaadmin_authorized_keys+" ; "+
        chown_iaadmin+"\"")
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    return (0)

def restrict_authorized_keys_root(hostname_list):
    for hostname in hostname_list:
        if hostname == "iamconsole1":
            commands.getoutput("ssh root@iamconsole1 ls /opt/tivoli/tiam/etc/DR_ENABLED")
            rc = commands.getoutput("echo $?")
            if rc == "0":
                write_to_logfile("dr enabled - setting up authorized_keys on both mc")
                out = commands.getoutput("ssh root@iamconsole1 /opt/tivoli/tiam/bin/setupLocalMCAuthKeys")
                rc = commands.getoutput("echo $?")
                if rc != "0":
                  write_to_logfile(out)
                  return (1)
                restrict_root_mc = "cp -p /tmp/authorized_keys_tmp /root/.ssh/authorized_keys"
                command = str("ssh -o StrictHostKeyChecking=no "+hostname+" \""+
                    restrict_root_mc+" ; "+
                    chmod_root_authorized_keys+"\"")
                (status,output) = commands.getstatusoutput(command)
                commands.getoutput("ssh root@iamconsole1 rm /tmp/authorized_keys_tmp")
                if status != 0:
                    write_to_logfile2(command,status,output)
                    return(status)
            else:
                command = str("ssh -o StrictHostKeyChecking=no "+hostname+" \""+
                    restrict_root+" ; "+
                    chmod_root_authorized_keys+"\"")
                (status,output) = commands.getstatusoutput(command)
                if status != 0:
                    write_to_logfile2(command,status,output)
                    return(status)
        else:
            command = str("ssh -o StrictHostKeyChecking=no "+hostname+" \""+
                restrict_root+" ; "+
                chmod_root_authorized_keys+"\"")
            (status,output) = commands.getstatusoutput(command)
            if status != 0:
                write_to_logfile2(command,status,output)
                return(status)

    return (0)

def restrict_authorized_keys_iaadmin(hostname_list):
    for hostname in hostname_list:
        command = str("ssh "+hostname+" \""+
            restrict_iaadmin+" ; "+
            chmod_iaadmin_authorized_keys+" ; "+
            chown_iaadmin+"\"")
        (status,output) = commands.getstatusoutput(command)
        if status != 0:
            write_to_logfile2(command,status,output)
            return(status)

    command = str(ssh_to_rsm+" \""+
        iaadmin_allow_write_authorized_keys+" ; "+
        restrict_iaadmin+" ; "+
        chmod_iaadmin_authorized_keys+" ; "+
        chown_iaadmin+"\"")
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    command = str(rm_new_node_authorized_keys+" ; "+
        rm_new_mc_authorized_keys+" ; "+
        rm_new_rsm_authorized_keys)
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    return (0)

def chmod_ssh_rsm():
    command = str(ssh_to_rsm+" \""+
        "chmod 400 /home/iaadmin/.ssh/id_rsa"+" ; "+
        "chmod 444 /home/iaadmin/.ssh/id_rsa.pub"+" ; "+
        "chmod 444 /home/iaadmin/.ssh/authorized_keys"+" ; "+
        "chmod 644 /home/iaadmin/.ssh/known_hosts"+"\"")
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    return(0)

def update_90_days(timestamp_file):
    command = str("touch "+timestamp_file)
    (status,output) = commands.getstatusoutput(command)
    if status != 0:
        write_to_logfile2(command,status,output)
        return(status)

    return(0)

def regenerate_iaadmin(hostname_list):
    (status) = generate_new_key_node_mc()
    if status != 0:
        write_to_logfile3("generate_new_key_node_mc",status)
        return(status)
    write_to_logfile("completed generate_new_key_node_mc")

    (status) = generate_new_key_rsm()
    if status != 0:
        write_to_logfile3("generate_new_key_rsm",status)
        return(status)
    write_to_logfile("completed generate_new_key_rsm")

    (status) = allow_write_rsm()
    if status != 0:
        write_to_logfile3("allow_write_rsm",status)
        return(status)
    write_to_logfile("completed allow_write_rsm")

    (status) = copy_new_keys_iaadmin(pri,hostname_list)
    if status != 0:
        write_to_logfile3("copy_new_keys_iaadmin",status)
        return(status)
    write_to_logfile("completed copy_new_keys")

    (status) = append_authorized_keys_iaadmin(hostname_list)
    if status != 0:
        write_to_logfile3("append_authorized_keys_iaadmin",status)
        return(status)
    write_to_logfile("completed append_authorized_keys")

    (status) = replace_keys_iaadmin(hostname_list)
    if status != 0:
        write_to_logfile3("replace_keys_iaadmin",status)
        return(status)
    write_to_logfile("completed replace_keys")

    (status) = restrict_authorized_keys_iaadmin(hostname_list)
    if status != 0:
        write_to_logfile3("restrict_authorized_keys_iaadmin",status)
        return(status)
    write_to_logfile("completed restrict_authorized_keys")

    (status) = chmod_ssh_rsm()
    if status != 0:
        write_to_logfile3("chmod_ssh_rsm",status)
        return(status)
    write_to_logfile("completed chmod_ssh_rsm")

    (status) = update_90_days(iaadmin_timestamp_file)
    if status != 0:
        write_to_logfile3("update_90_days",status)
        return(status)
    write_to_logfile("completed update_90_days")

    return(0)

def regenerate_root(hostname_list):
    (status) = generate_new_key_root()
    if status != 0:
        write_to_logfile3("generate_new_key_root",status)
        return(status)
    write_to_logfile("completed generate_new_key_root")

    (status) = copy_new_keys_root(pri,hostname_list)
    if status != 0:
        write_to_logfile3("copy_new_keys_root",status)
        return(status)
    write_to_logfile("completed copy_new_keys_root")

    (status) = append_authorized_keys_root(hostname_list)
    if status != 0:
        write_to_logfile3("append_authorized_keys_root",status)
        return(status)
    write_to_logfile("completed append_authorized_keys_root")

    (status) = replace_keys_root(hostname_list)
    if status != 0:
        write_to_logfile3("replace_keys_root",status)
        return(status)
    write_to_logfile("completed replace_keys_root")

    (status) = restrict_authorized_keys_root(hostname_list)
    if status != 0:
        write_to_logfile3("restrict_authorized_keys_root",status)
        return(status)
    write_to_logfile("completed restrict_authorized_keys_root")

    (status) = update_90_days(root_timestamp_file)
    if status != 0:
        write_to_logfile3("update_90_days",status)
        return(status)
    write_to_logfile("completed update_90_days")

    return(0)

#-------------------------------------------------------------------------------
# MAIN SCRIPT
#-------------------------------------------------------------------------------

my_logger = logging.getLogger('ssh_regen_logger')
my_logger.setLevel(logging.DEBUG)
handler = logging.handlers.RotatingFileHandler(LOG_FILENAME, maxBytes=(10*1024*1024), backupCount=5)
my_logger.addHandler(handler)

(status,pri) = is_local_node_master()
if status != 0:
    write_to_logfile("This node is not the master GPFS server")
    sys.exit(1)
write_to_logfile("completed is_local_node_master "+pri)

if not has_icw_been_run():
    write_to_logfile("The ICW has not been run yet")
    sys.exit(1)
write_to_logfile("completed has_icw_been_run")

exitcode1=0
exitcode2=0

(status) = check_90_days(root_timestamp_file)
if status == 0:
    (status,hostname_list) = verify_all_nodes_up()
    if status == 0:
        # We don't want the primary and secondary appliance to regenerate they keys at the same time
        NODE99_IP=commands.getoutput("cat /etc/hosts | grep pwrctl-ianode99 | awk '{print $1}'")
        if NODE99_IP == "172.30.1.199":
            time.sleep(300)

        write_to_logfile("completed verify_all_nodes_up")

        (status) = verify_dr_tunnel()
        if status == 0:
            hostname_list.append("iamconsole1")
            hostname_list.append("iarsm1")
            write_to_logfile("regnerating root SSH keys on the following nodes: "+str(hostname_list))
            exitcode1 = regenerate_root(hostname_list)
        else:
            write_to_logfile("The DR tunnel is down")
            exitcode1=1
    else:
        write_to_logfile("One or more GPFS nodes are down")
        exitcode1=1
else:
    write_to_logfile("Less than 90 days have elapsed since the last regeneration of the root SSH keys")
    exitcode1=1

(status) = check_90_days(iaadmin_timestamp_file)
if status == 0:
    (status,hostname_list2) = verify_all_nodes_up()
    if status == 0:
        write_to_logfile("completed verify_all_nodes_up")
        hostname_list2.append("iamconsole1")
        temp_list = copy.deepcopy(hostname_list2)
        temp_list.append("iarsm1")
        write_to_logfile("regnerating iaadmin SSH keys on the following nodes: "+str(temp_list))
        exitcode2 = regenerate_iaadmin(hostname_list2)
    else:
        write_to_logfile("One or more GPFS nodes are down")
        exitcode2=1
else:
    write_to_logfile("Less than 90 days have elapsed since the last regeneration of the iaadmin SSH keys")
    exitcode2=1

sys.exit(exitcode1+exitcode2)
