#!/bin/sh
########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Workload Manager
# *
# * FILE NAME:       wd_printnodestates.sh
# *
# * DESCRIPTION:     Prints the current state of all nodes defined as
# *                  members of the GPFS cluster.
# *
# * AUTHOR:          Michael A. Richmond
# *                  IBM Almaden Research Center
# *                  mar@almaden.ibm.com
# *
# ****************************************************************************
# */
# ----------------------------------------------------------------------------
# ----------------------------------------------------------------------------
#               Change Log
#               ----------
#  19 Sep 2008  Initial version.
#
#  09 Oct 2008  Updated to include GPFS node ID in the report.
#
#  10 Oct 2008  Updated to fix bug with nodes not being reported when
#               they are in states other than "active" or "down".
#
#  21 Jul 2009  Updated to return exit code obtained from mmgetstate
#               command.
#
#  12 Jan 2010  Updated return exit code to zero in the case mmgetstate
#               outputs a node in the unknown state
#

# Configure shell variables
. `dirname $BASH_SOURCE`/mw_environment.sh

MMGETSTATE="/usr/lpp/mmfs/bin/mmgetstate"
VALID_GPFS_STATES='active|arbitrating|down|unknown'

if [ ! -x "${MMGETSTATE}" ]; then
    echo "${MMGETSTATE} not installed"
    exit 1
fi

mmgetstate_output=`${MMGETSTATE} -a`
mmgetstate_result_code=$?

if [ ${mmgetstate_result_code} != 0 ]; then
    if [[ $mmgetstate_output == *unknown* ]]; then
        mmgetstate_result_code=0
    else 
        echo "${mmgetstate_output}"
        exit ${mmgetstate_result_code}
    fi
fi

echo "${mmgetstate_output}" | egrep ${VALID_GPFS_STATES} | tr -s ' '

exit ${mmgetstate_result_code}
