#!/bin/sh
########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Workload Manager
# *
# * FILE NAME:       wlm_basiccontrolcommon.sh
# *
# * DESCRIPTION:     Shared functions and variables used by some
# *                  wlm_control* scripts.
# *                  This script is not intended to be executed
# *                  from the command line.
# *
# * AUTHOR:          Michael Richmond
# *                  IBM Almaden Research Center
# *                  mar@almaden.ibm.com
# *
# *                  Mark A. Smith
# *                  IBM Almaden Research Center
# *                  mark1smi@us.ibm.com
# *
# ****************************************************************************
# */

if [ `basename $0` = "wlm_basiccontrolcommon.sh" ]; then
    script_name=`basename $0`
    echo "error: The script '$script_name' is not intended to be executed"
    echo "       directly on the command line. This script only provides"
    echo "       functions common to other IIA scripts."
    exit 127
fi


# Configure shell variables
. `dirname $BASH_SOURCE`/mw_environment.sh

# Read the common control errors
. `dirname $BASH_SOURCE`/wlm_controlerrors.sh


OPERATION=""

parse_args()
{
	for arg in $@
	do
		case ${arg} in
			--test)
				TEST="true"
				;;
			-start)
				if [ -z "${OPERATION}" ]; then
					OPERATION="start"
				fi
				;;
			-status)
				if [ -z "${OPERATION}" ]; then
					OPERATION="status"
				fi
				;;
			-stop)
				if [ -z "${OPERATION}" ]; then
					OPERATION="stop"
				fi
				;;
			-restart)
				if [ -z "${OPERATION}" ]; then
					OPERATION="restart"
				fi
				;;
			*)
				OPERATION="help"
				;;
		esac	
	done
}


printHelp()
{
	echo "usage:  $0 [-start|-status|-stop|-restart]"
	echo "where:"
	echo "	-start            starts the associated software component"
	echo "	-stop             stops the associated software component"
	echo "	-restart          restarts the associated software component"
	echo "	-status           reports the status of the associated software component"
}

# Check that a file is executable.
#
# Usage:
# check_file_executable file_to_check
function check_file_executable()
{
    local filename=$1
    if [ ! -x "$filename" ]; then
	return 0
    fi
    return 1
}

# Check that a file is readable.
#
# Usage:
# check_file_readable file_to_check
function check_file_readable()
{
    local filename=$1
    if [ ! -r "$filename" ]; then
	return 0
    fi
    return 1
}

# Check that a file exists.
#
# Usage:
# check_file_exists file_to_check
function check_file_exists()
{
    local filename=$1
    if [ ! -e "$filename" ]; then
	return 0
    fi
    return 1
}

# Kill a process
#
# Usage:
# kill_proc PID SIGNAL
function kill_process() {
    local pid=$1
    local signal=$2
    /bin/kill -$signal $pid
}
