#!/bin/sh
########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Workload Manager
# *
# * FILE NAME:       wlm_controlcommon.sh
# *
# * DESCRIPTION:     Shared functions and variables used by some
# *                  wlm_control* scripts.
# *                  This script is not intended to be executed
# *                  from the command line.
# *
# * AUTHOR:          Michael Richmond
# *                  IBM Almaden Research Center
# *                  mar@almaden.ibm.com
# *
# *                  Mark A. Smith
# *                  IBM Almaden Research Center
# *                  mark1smi@us.ibm.com
# *
# ****************************************************************************
# */

if [ `basename $0` = "wlm_controlcommon.sh" ]; then
    script_name=`basename $0`
    echo "error: The script '$script_name' is not intended to be executed"
    echo "       directly on the command line. This script only provides"
    echo "       functions common to other IIA scripts."
    exit 127
fi

# Configure shell variables
# DO NOT USE `dirname` here. For some reason CTDB does not like this.
. /opt/tivoli/tiam/bin/mw_environment.sh

# Read the common control errors
# DO NOT USE `dirname` here. For some reason CTDB does not like this.
. /opt/tivoli/tiam/bin/wlm_controlerrors.sh

COLLECTIONMNTPOINT=""

OPERATION=""

parse_args()
{
	for arg in $@
	do
		case ${arg} in
			--test)
				TEST="true"
				;;
			-start)
				if [ -z "${OPERATION}" ]; then
					OPERATION="start"
				fi
				;;
			-status)
				if [ -z "${OPERATION}" ]; then
					OPERATION="status"
				fi
				;;
			-stop)
				if [ -z "${OPERATION}" ]; then
					OPERATION="stop"
				fi
				;;
			-update)
				if [ -z "${OPERATION}" ]; then
					OPERATION="update"
				fi
				;;
			-getrunningstate)
				if [ -z "${OPERATION}" ]; then
					OPERATION="getrunningstate"
				fi
				;;
			-gethealthystate)
				if [ -z "${OPERATION}" ]; then
					OPERATION="gethealthystate"
				fi
				;;
			-getenabledstate)
				if [ -z "${OPERATION}" ]; then
					OPERATION="getenabledstate"
				fi
				;;
			-getoperationalstate)
				if [ -z "${OPERATION}" ]; then
					OPERATION="getoperationalstate"
				fi
				;;
			--mountpoint=*)
				COLLECTIONMNTPOINT=`echo ${arg} | cut -d = -f 2`
				;;
			*)
				OPERATION="help"
				;;
		esac	
	done

	if [ -z "${COLLECTIONMNTPOINT}" ]; then
		echo "error: mountpoint not specified on command line"
		OPERATION="help"
	fi
}


printHelp()
{
	echo "usage:  $0 [-start|-status|-stop|-update|-getenabledstate|-getrunningstate|-gethealthystate|-getenabledstate|-getoperationalstate]"
	echo "	          --mountpoint=<mountpoint>"
	echo "where:"
	echo "	-start                starts the associated software component"
	echo "	-stop                 stops the associated software component"
	echo "	-status               reports the status of the associated software component"
	echo "	-update               updates the configuration of this software component, i.e. service IPs"
	echo "	-getenabledstate      reports whether the associated software component is enabled or disabled"
	echo "	-getrunningstate      reports whether the associated software component is running for this collection on this node"
	echo "	-gethealthystate      reports whether the associated software component is running for this collection on this node and is healthy"
	echo "	-getenabledstate      reports whether the associated software component is enabled for this collection on this node"
	echo "	-getoperationalstate  reports whether the associated software component is operational for this collection on this node"
	echo "	<mountpoint>          is the mount point for the collection"
}

# Check that a file is executable.
#
# Usage:
# check_file_executable file_to_check
function check_file_executable()
{
    local filename=$1
    if [ ! -x "$filename" ]; then
	return 0
    fi
    return 1
}

# Check that a file is readable.
#
# Usage:
# check_file_readable file_to_check
function check_file_readable()
{
    local filename=$1
    if [ ! -r "$filename" ]; then
	return 0
    fi
    return 1
}

# Check that a file exists.
#
# Usage:
# check_file_exists file_to_check
function check_file_exists()
{
    local filename=$1
    if [ ! -e "$filename" ]; then
	return 0
    fi
    return 1
}

# Kill a process
#
# Usage:
# kill_proc PID SIGNAL
function kill_process() {
    local pid=$1
    local signal=$2
    /bin/kill -$signal $pid
}

# Find a collection's name
#
# Usage:
# findCollectionName collection_mount
findCollectionName()
{
	local mount_point=$1

        COLLECTION_NAME=`/opt/tivoli/tiam/bin/mw_print_xml_field collection/name $mount_point/utility/config/collection.xml`
}

# Find a collection's management ID as described by /tiam_utility/config/collections.xml
#
# Usage:
# findCollectionID collection_mount
findCollectionID()
{
	local mount_point=$1

        COLLECTION_NAME=`/opt/tivoli/tiam/bin/mw_print_xml_field collection/name $mount_point/utility/config/collection.xml`

        COLLECTION_NUM=1
        TEMP_COLLECTION_NAME="NAME"
        while [ "$TEMP_COLLECTION_NAME" != "" ]; do
                TEMP_COLLECTION_NAME=`/opt/tivoli/tiam/bin/mw_print_xml_field collectionmaster/collection[$COLLECTION_NUM]/name /tiam_utility/config/collections.xml`
                if [ "$COLLECTION_NAME" = "$TEMP_COLLECTION_NAME" ]; then
                        COLLECTION_ID=`/opt/tivoli/tiam/bin/mw_print_xml_field collectionmaster/collection[$COLLECTION_NUM]/managementid /tiam_utility/config/collections.xml`
                        break;
                fi
                COLLECTION_NUM=`expr $COLLECTION_NUM + 1`
        done
}

