#!/bin/sh
########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Workload Manager
# *
# * FILE NAME:       wlm_controlsolr.sh
# *
# * DESCRIPTION:     Controls the Solr Index Server component 
# *                  of a FRAnK collection
# *
# * AUTHOR:          K.W.Brannon
# *                  IBM Almaden Research Center
# *                  kbrannon@us.ibm.com
# *
# *
# ****************************************************************************
# */

# Configure shell variables
. `dirname $BASH_SOURCE`/mw_environment.sh
# Read the common error values
. `dirname $BASH_SOURCE`/wlm_controlerrors.sh
# Read the common control functions
. `dirname $BASH_SOURCE`/wlm_controlcommon.sh

IIA_ROOT_DIR="/opt/tivoli/tiam"
PRINT_XML_FIELD_BIN="${IIA_ROOT_DIR}/bin/mw_print_xml_field"
CREATE_SERVICE_IP_BIN="${IIA_ROOT_DIR}/bin/create_service_ip.py"
DELETE_SERVICE_IP_BIN="${IIA_ROOT_DIR}/bin/delete_service_ip.py"
SSM_NOINDEXING=3
SSM_INDEX_FILESET=index/solr/config
SSM_SOLRNOTHEALTHY=index/solr/solrNotHealthy
SSM_JAVA_BIN=/opt/ibm/java2-x86_64-50/jre/bin/java
SSM_SOLR_REL=apache-solr-1.4.0
SSM_SOLR_INSTALL_DIR=${IIA_ROOT_DIR}/lib/index/solr/$SSM_SOLR_REL
SSM_JETTY_HOME=$SSM_SOLR_INSTALL_DIR/jettyhome
SSM_START_JAR=$SSM_JETTY_HOME/start.jar
SSM_INTERFACE_ALIAS_PREFIX="I"
SSM_JAVA_INITHEAP=2048m
SSM_JAVA_MAXHEAP=2048m


#in seconds. Give it 120 seconds.
SSM_STOP_TIMEOUT=120

#in seconds. Give it 5 minutes.
SSM_START_TIMEOUT=300

#give the process 2 minutes to appear in ps output.
PROCESS_TABLE_APPEARANCE_TIMEOUT=120

registerInternalVirtualIP()
{
    internalInterface=`${PRINT_XML_FIELD_BIN} WorkloadManagerConfig/ControlScripts/frank/TSM/InternalInterface /tiam_utility/config/workloadmanager_config.xml`
    cmd="${CREATE_SERVICE_IP_BIN} -i $internalInterface -e $SSM_INTERFACE_ALIAS_PREFIX$COLLECTION_ID -s $SSM_JETTY_IP"
    echo "$command_name running:" $cmd
    $cmd
    create_service_ip_rc=$?
    if [ $create_service_ip_rc -eq 0 ]; then
        return 0
    elif [ $create_service_ip_rc -eq 2 ]; then
	#Already existed. Success
	echo "Internal service IP exists. Success."
	return 0
    fi

    #Error
    return 1
}

unregisterInternalVirtualIP()
{
    interface_xml_path="WorkloadManagerConfig/ControlScripts/frank/TSM/InternalInterface"
    internalInterface=`${PRINT_XML_FIELD_BIN} $interface_xml_path /tiam_utility/config/workloadmanager_config.xml`
    cmd="${DELETE_SERVICE_IP_BIN} -i $internalInterface -e $SSM_INTERFACE_ALIAS_PREFIX$COLLECTION_ID"
    echo "$command_name running:" $cmd
    $cmd
}

isAlreadyRunning()
{
        #See if Solr is already running somewhere
        cmd="$IIA_ROOT_DIR/bin/ssm_getStatus.py -m $COLLECTIONMNTPOINT"
        #echo "running  command: $cmd"
        out=$($cmd 2>/dev/null)
        #echo "output is: $out"
        echo $out | grep -q numDocs
        rc_running=$?
        if [ $rc_running = 0 ];then
           return 1
        else
           return 0
        fi
}

doStart()
{

	check_file_exists $SSM_JAVA_BIN
	b_exists=$?
	if [ "$b_exists" != 1 ]; then
	    return $ERR_FILE_DOES_NOT_EXIST
	fi
        #Really should check that jetty home is a directory
        check_file_exists $SSM_JETTY_HOME
	b_exists=$?
	if [ "$b_exists" != 1 ]; then
	    return $ERR_FILE_DOES_NOT_EXIST
	fi
        #Really should check that solr home is a directory
        check_file_exists $SSM_SOLR_HOME
	b_exists=$?
	if [ "$b_exists" != 1 ]; then
	    return $ERR_FILE_DOES_NOT_EXIST
	fi
        check_file_exists $SSM_START_JAR
	b_exists=$?
	if [ "$b_exists" != 1 ]; then
	    return $ERR_FILE_DOES_NOT_EXIST
	fi
        #Check that jetty port is numeric
        if [ -n "`echo \"$SSM_JETTY_PORT\" | /usr/bin/tr -d \"[:digit:]\"`" ]; then
            return $ERR_BAD_PROBLEM
        fi
        #Check that java is executable
        check_file_executable $SSM_JAVA_BIN
	b_is_executable=$?
	if [ "$b_is_executable" != 1 ]; then
	    return $ERR_FILE_NOT_EXECUTABLE
	fi

	doStatus
	running_status=$?

	if [ $running_status -ne $ERR_PROCESS_NOT_RUNNING ]; then
		return $running_status
	fi

        isAlreadyRunning
        rc_isAlreadyRunning=$?
	if [ $rc_isAlreadyRunning -eq 1 ]; then
             #should never get called to start solr on multiple nodes
             return $ERR_BAD_PROBLEM
        fi
        
        #Setup shards in solrconfig.xml to support distributed search
        #And setup logging properties file
        cmd="$IIA_ROOT_DIR/bin/ssm_manageConfig.py -m $COLLECTIONMNTPOINT --doStart"
        echo "$command_name running:" $cmd
        $cmd
        ssm_manageConfig_rc=$?
        if [ $ssm_manageConfig_rc -ne 0 ]; then
             return $ssm_manageConfig_rc
        fi
        registerInternalVirtualIP
        SSM_COLLECTIONMNTPOINT=$COLLECTIONMNTPOINT
        export SSM_COLLECTIONMNTPOINT
        #Create the log and trace dirs if they do not exist
        UNIQUE_NODEID=`/opt/tivoli/tiam/bin/mw_print_unique_nodeid`
        SSM_LOGDIR=/tiam_utility/log/CTJID/in$COLLECTIONMNTPOINT/$UNIQUE_NODEID/logs
        mkdir -p $SSM_LOGDIR
        SSM_TRACEDIR=/tiam_utility/log/CTJID/in$COLLECTIONMNTPOINT/$UNIQUE_NODEID/ffdc
        mkdir -p $SSM_TRACEDIR 

        SSM_TRACELEVEL=`${PRINT_XML_FIELD_BIN} collection/tracinglevel $COLLECTIONMNTPOINT/utility/config/collection.xml`
        SSM_LOGLEVEL=`${PRINT_XML_FIELD_BIN} collection/logginglevel $COLLECTIONMNTPOINT/utility/config/collection.xml`
        #Check the logging level to see if should save jetty response log
        #Eventually replace SSM_JETTY_LOGDIR by using w/jettynl.xml
        SSM_JETTY_LOGDIR=$SSM_LOGDIR
        SSM_SOLR_STDOUT=/dev/null
        SSM_SOLR_STDERR=/dev/null
        if [ $SSM_TRACELEVEL -eq 3 ]; then
             SSM_JETTY_LOGDIR=$SSM_TRACEDIR
             SSM_SOLR_STDOUT=$SSM_TRACEDIR/solrserver_stdout.txt
             SSM_SOLR_STDERR=$SSM_TRACEDIR/solrserver_stderr.txt
        fi
        if [ $SSM_LOGLEVEL -eq 3 ]; then
             SSM_JETTY_LOGDIR=$SSM_LOGDIR
             SSM_SOLR_STDOUT=$SSM_LOGDIR/solrserver_stdout.txt
             SSM_SOLR_STDERR=$SSM_LOGDIR/solrserver_stderr.txt
        fi
        SSM_LOGPROPERTIES=$COLLECTIONMNTPOINT/index/solr/logging/$UNIQUE_NODEID/solr_logging.properties
        #nohup $SSM_JAVA_BIN -Xms$SSM_JAVA_INITHEAP -Xmx$SSM_JAVA_MAXHEAP -Djetty.host=$SSM_JETTY_IP -Djetty.home=$SSM_JETTY_HOME -Djetty.port=$SSM_JETTY_PORT -Djetty.logs=$SSM_JETTY_LOGDIR -Dsolr.solr.home=$SSM_SOLR_HOME -jar $SSM_START_JAR  >$SSM_TRACEDIR/solrserver_trace.txt 2>$SSM_LOGDIR/solrserver_log.txt &
        #nohup $SSM_JAVA_BIN -Xms$SSM_JAVA_INITHEAP -Xmx$SSM_JAVA_MAXHEAP -Djetty.host=$SSM_JETTY_IP -Djetty.home=$SSM_JETTY_HOME -Djetty.port=$SSM_JETTY_PORT -Djetty.logs=$SSM_JETTY_LOGDIR -Dsolr.solr.home=$SSM_SOLR_HOME -Djava.util.logging.config.file=$SSM_LOGPROPERTIES -jar $SSM_START_JAR  >$SSM_SOLR_STDOUT 2>$SSM_SOLR_STDERR &
        #nohup $SSM_JAVA_BIN -Xdump:java:none -Xdump:heap:none -Xms$SSM_JAVA_INITHEAP -Xmx$SSM_JAVA_MAXHEAP -Djetty.host=$SSM_JETTY_IP -Djetty.home=$SSM_JETTY_HOME -Djetty.port=$SSM_JETTY_PORT -Djetty.logs=$SSM_JETTY_LOGDIR -Dsolr.solr.home=$SSM_SOLR_HOME -Djava.util.logging.config.file=$SSM_LOGPROPERTIES -jar $SSM_START_JAR  >$SSM_SOLR_STDOUT 2>$SSM_SOLR_STDERR &
        JAVACOREFILE=//tmp/javacore_$COLLECTION_ID.txt
        HEAPFILE=//tmp/heapdump_$COLLECTION_ID.phd
        SNAPFILE=//tmp/Snap_$COLLECTION_ID.trc
        nohup $SSM_JAVA_BIN -Xdump:java:defaults:file=$JAVACOREFILE -Xdump:heap:defaults:file=$HEAPFILE -Xdump:snap:defaults:file=$SNAPFILE -Xms$SSM_JAVA_INITHEAP -Xmx$SSM_JAVA_MAXHEAP -Djetty.host=$SSM_JETTY_IP -Djetty.home=$SSM_JETTY_HOME -Djetty.port=$SSM_JETTY_PORT -Djetty.logs=$SSM_JETTY_LOGDIR -Dsolr.solr.home=$SSM_SOLR_HOME -Djava.util.logging.config.file=$SSM_LOGPROPERTIES -jar $SSM_START_JAR  >$SSM_SOLR_STDOUT 2>$SSM_SOLR_STDERR &


	b_appeared_in_process_table=0
	waited_seconds=0
	timeout_seconds=$PROCESS_TABLE_APPEARANCE_TIMEOUT
	wait_interval=10
	start_time=`date +%s`
	while [ $waited_seconds -lt $timeout_seconds ]
	do
		this_start_time=`date +%s`

		doStatus
		running_status=$?

		if [ $running_status -eq $ERR_PROCESS_IS_RUNNING ]; then
			b_appeared_in_process_table=1
			echo "SOLR appeared in the process table."
			break
		fi

		echo "SOLR has not yet appeared in the process table. Sleeping $wait_interval seconds and looking again."
		now=`date +%s`
		waited_this_time=$((now-this_start_time))
		if [ $waited_this_time -lt $wait_interval ]; then
			more_sleep_needed=$((wait_interval-waited_this_time))
			sleep $more_sleep_needed
		fi
		now=`date +%s`
		waited_seconds=$((now-start_time))
	done
        #Remove solr not healthy lock in case not all cores were up 
        #and inxc encountered one of those cores
        signal=$COLLECTIONMNTPOINT/$SSM_SOLRNOTHEALTHY
        cmd="rmdir  $signal" 
        echo "$command_name to remove solr not healthy lock:" $cmd
        $cmd

	if [ $b_appeared_in_process_table -eq 0 ]; then
		echo "SOLR never appeared in the process table. Verifying and completing stoppage of any TSM components (DB2)"
		doStop
		return $running_status
	fi

#Ok, we're running, now we need to wait a bit to get healthy.
#They just asked us to start, so we've done our job, and can
#return success, but it makes sense to wait at least some
#time to verify we come up healthy.

	waited_seconds=0
	timeout_seconds=$SSM_START_TIMEOUT
	wait_interval=60
	start_time=`date +%s`
	while [ $waited_seconds -lt $timeout_seconds ]
	do
		this_start_time=`date +%s`

		#verify that we're still running. Otherwise we'll be in
		#this loop for a long time!
		doStatus
		running_status=$?

		if [ $running_status -ne $ERR_PROCESS_IS_RUNNING ]; then
			echo "SOLR died during startup shortly after being started, but before becoming healthy. Verifying and completing stoppage of SOLR"
			doStop
			return $running_status
		fi

		doGetHealthyState 0
		healthy_state=$?

		if [ $healthy_state -eq 1 ]; then
			#Ok, we're healthy
			echo "SOLR started up and became healthy after $waited_seconds seconds"
			return 0
		fi

		now=`date +%s`
		waited_this_time=$((now-this_start_time))
		if [ $waited_this_time -lt $wait_interval ]; then
			more_sleep_needed=$((wait_interval-waited_this_time))
			sleep $more_sleep_needed
		fi
		now=`date +%s`
		waited_seconds=$((now-start_time))
	done

	echo "SOLR has not become healthy after $waited_seconds seconds"

	return 0
}

doStatus()
{
	num_running=0
	running_collection_pid_list=`/bin/ps -C \`basename $SSM_JAVA_BIN\` -f | tail -n +2 | tr -s ' ' | sed 's/^[ ]//g' | cut -d' ' -f 2`
	for solr_server_pid in $running_collection_pid_list
	    do
		solr_server_env=`/bin/ps -p $solr_server_pid -f e | tail -n +2 | tr -s ' ' | sed 's/^[ ]//g' `
		for env_var in $solr_server_env
		do
			mount_name=${env_var##SSM_COLLECTIONMNTPOINT=}
			if [ x$mount_name != x$env_var ]; then
				if [ "$mount_name" = "$COLLECTIONMNTPOINT" ]; then
					if [ $num_running -eq 0 ]; then
						num_running=`expr $num_running + 1`
					else
						echo "Found more than one SOLR server running"
						return $ERR_PROCESS_MULTIPLE_RUNNING
					fi
				fi
			fi
		done
	done

        echo "Number of SOlr proceses running is  $num_running"
	if [ $num_running -eq 0 ]; then
		return $ERR_PROCESS_NOT_RUNNING
	elif [ $num_running -eq 1 ]; then
		return $ERR_PROCESS_IS_RUNNING
	fi
}

doStop()
{

	running_collection_pid_list=`/bin/ps -C \`basename $SSM_JAVA_BIN\` -f | tail +2 | tr -s ' ' | sed 's/^[ ]//g' | cut -d' ' -f 2`

	for solr_server_pid in $running_collection_pid_list
	do
		solr_server_env=`/bin/ps -p $solr_server_pid -f e | tail +2 | tr -s ' ' | sed 's/^[ ]//g' `
		for env_var in $solr_server_env
		do
			mount_name=${env_var##SSM_COLLECTIONMNTPOINT=}
			if [ x$mount_name != x$env_var ]; then
				if [ "$mount_name" = "$COLLECTIONMNTPOINT" ]; then
                                        echo "found Solr server $env_var and $mount_name"
                                        kill_pid=$solr_server_pid
                                        echo "SIGTERM on Solr server pid " $solr_server_pid
					kill_process $solr_server_pid SIGTERM
                                        unregisterInternalVirtualIP
                                        #Remove update lock if present
                                        cmd="rmdir  $COLLECTIONMNTPOINT/index/solr/updateLock" 
                                        echo "$command_name to remove update lock:" $cmd
                                        $cmd
                                        #Remove solr not healthy lock if present
                                        signal=$COLLECTIONMNTPOINT/$SSM_SOLRNOTHEALTHY
                                        cmd="rmdir  $signal" 
                                        echo "$command_name to remove solr not healthy lock:" $cmd
                                        $cmd
				fi
			fi
		done
	done

	waited_seconds=0
	timeout_seconds=$SSM_STOP_TIMEOUT
	wait_interval=10
	while [ $waited_seconds -lt $timeout_seconds ]
	do

		doStatus
		running_status=$?

		if [ $running_status -eq $ERR_PROCESS_NOT_RUNNING ]; then
                        unregisterInternalVirtualIP
			return 0
		fi

		sleep $wait_interval
		waited_seconds=`expr $waited_seconds + $wait_interval`
	done

        echo "Need SIGKILL on Solr server pid $kill_pid"
        kill_process $kill_pid SIGKILL
	waited_seconds=0
	timeout_seconds=$SSM_STOP_TIMEOUT
	wait_interval=1
	while [ $waited_seconds -lt $timeout_seconds ]
	do

		doStatus
		running_status=$?

		if [ $running_status -eq $ERR_PROCESS_NOT_RUNNING ]; then
                        unregisterInternalVirtualIP
			return 0
		fi

		sleep $wait_interval
		waited_seconds=`expr $waited_seconds + $wait_interval`
	done
        unregisterInternalVirtualIP
	return $ERR_PROCESS_FAILED_TO_DIE
}

doUpdate()
{
        #Indexing may have been enabled, or indexlevel may have changed
        cmd="$IIA_ROOT_DIR/bin/ssm_manageConfig.py -m $COLLECTIONMNTPOINT --doUpdate"
        echo "$command_name running:" $cmd
        $cmd
        ssm_manageConfig_rc=$?
        if [ $ssm_manageConfig_rc -ne 0 ]; then
             return $ssm_manageConfig_rc
        fi
        
	return 0
}

doGetRunningState()
{
	running_collection_pid_list=`/bin/ps -C \`basename $SSM_JAVA_BIN\` -f | tail +2 | tr -s ' ' | sed 's/^[ ]//g' | cut -d' ' -f 2`

	for solr_server_pid in $running_collection_pid_list
	do
		solr_server_env=`/bin/ps -p $solr_server_pid -f e | tail +2 | tr -s ' ' | sed 's/^[ ]//g' `
		for env_var in $solr_server_env
		do
			mount_name=${env_var##SSM_COLLECTIONMNTPOINT=}
			if [ x$mount_name != x$env_var ]; then
				if [ "$mount_name" = "$COLLECTIONMNTPOINT" ]; then
                                        echo "KWB found $env_var and $mount_name"
					return 1
				fi
			fi
		done
	done


	return 0
}

doGetEnabledState()
{
	fs_device=`awk -v colmount=$COLLECTIONMNTPOINT '{ if ($2==colmount) { print $1 } }' /etc/fstab`
	getdev_rc=$?
	if [ $getdev_rc -ne 0 ]; then
		echo "Error $getdev_rc getting device for $COLLECTIONMNTPOINT from /etc/fstab"
		return -1
	fi
	if [ "$fs_device" == "" ]; then
		echo "Error getting device for $COLLECTIONMNTPOINT from /etc/fstab. device string empty"
		return -1
	fi
	fs_status=`/usr/lpp/mmfs/bin/mmlsfileset $fs_device | awk '{ if ($1=="index") { print $2 } }'`
	fsstatus_rc=$?
	if [ $fsstatus_rc -ne 0 ]; then
		echo "Error $fsstatus_rc getting mmlsfileset information for '$fs_device'"
		return -1
	fi
	if [ "$fs_status" == "" ]; then
		echo "index fileset does not exist for '$fs_device'"
		return 0
	fi
	echo "index fileset exists for '$fs_device' with status $fs_status"

        #Now we check whether we are in disabled mode.
        INDEX_MODE=`/opt/tivoli/tiam/bin/mw_print_xml_field collection/indexmode $COLLECTIONMNTPOINT/utility/config/collection.xml`

        if [ "$INDEX_MODE" == "" ]; then
                #Disabled - probably an old collection?
                echo "indexmode not defined in collection.xml. Disabled"
                return 0
        elif [ "$INDEX_MODE" == "searchonly" ]; then
                #Enabled
                echo "In search only mode. Enabled"
                return 1
        elif [ "$INDEX_MODE" == "indexandsearch" ]; then
                #Enabled
                echo "In indexandsearch mode. Enabled"
                return 1
        elif [ "$INDEX_MODE" == "disabled" ]; then
                echo "In disabled mode."
                return 0
        else
                echo "indexmode '$INDEX_MODE' corrupt in collection.xml or unable to read collection.xml"
                return -1
        fi

	return 1
}

doGetOperationalState()
{
	#For SOLR, if it's healthy, it's operational
	doGetHealthyState
	return $?
}

doGetHealthyState()
{
        running_pid=""
	running_collection_pid_list=`/bin/ps -C \`basename $SSM_JAVA_BIN\` -f | tail +2 | tr -s ' ' | sed 's/^[ ]//g' | cut -d' ' -f 2`

	for solr_server_pid in $running_collection_pid_list
	do
		solr_server_env=`/bin/ps -p $solr_server_pid -f e | tail +2 | tr -s ' ' | sed 's/^[ ]//g' `
		for env_var in $solr_server_env
		do
			mount_name=${env_var##SSM_COLLECTIONMNTPOINT=}
			if [ x$mount_name != x$env_var ]; then
				if [ "$mount_name" = "$COLLECTIONMNTPOINT" ]; then
                                        running_pid=$solr_server_pid
                                        echo "KWB found $env_var and $mount_name"
				fi
			fi
		done
	done
        if [ "$running_pid" = "" ];then
             echo "Solr Server not running on this node"
             return 0
        fi

        #Solr server is running on this node
        #Check for signal from indexing controller
        signal=$COLLECTIONMNTPOINT/$SSM_SOLRNOTHEALTHY
        if [ -d "$signal" ]; then
           echo "found $signal, returning not healthy"
           return 0
        fi
        echo "check ssm_getStatus.py "
        cmd="$IIA_ROOT_DIR/bin/ssm_getStatus.py -m $COLLECTIONMNTPOINT"
        out=$($cmd 2>/dev/null)
        echo $out | grep -q numDocs
        rc_healthy=$?
        echo "Output of command: $cmd : $out"
        if [ $rc_healthy = 0 ];then
           echo "ssm_getStatus.py shows healthy, now check Tika"
           cmd="$IIA_ROOT_DIR/bin/ssm_getTikaHealthy.py -m $COLLECTIONMNTPOINT"
           out=$($cmd 2>/dev/null)
           echo $out | grep -q archiving
           rc_healthy=$?
           echo "Output of command: $cmd : $out"
           if [ $rc_healthy = 0 ];then
              echo "returning healthy"
              return 1
           else
              echo "returning not healthy"
              return 0
           fi
        else
           echo "returning not healthy"
           return 0
        fi
}

parse_args $@
echo "operation=$OPERATION"
echo "collectionmntpoint=$COLLECTIONMNTPOINT"
if [ ! -z "$COLLECTIONMNTPOINT" ]
then
     SSM_SOLR_CONFIG=$COLLECTIONMNTPOINT/index/solr/config
     SSM_SOLR_HOME=$SSM_SOLR_CONFIG/solrHome
     SSM_JETTY_PORT=`${PRINT_XML_FIELD_BIN} collection/solr/jettyport $COLLECTIONMNTPOINT/utility/config/collection.xml`
     SSM_JETTY_IPNAME=`${PRINT_XML_FIELD_BIN} collection/solr/jettyip $COLLECTIONMNTPOINT/utility/config/collection.xml`
     SSM_JETTY_IP=`awk -v jettyipname=$SSM_JETTY_IPNAME {'if($2==jettyipname){print $1}'} /etc/hosts`
     SSM_INDEXLEVEL=`${PRINT_XML_FIELD_BIN} collection/indexlevel $COLLECTIONMNTPOINT/utility/config/collection.xml`
     findCollectionID $COLLECTIONMNTPOINT  # sets COLLECTION_ID
fi
case ${OPERATION} in
	start)
		doStart
		start_retval=$?
		if [ $start_retval -eq 0 ]; then
			exit 0
		else
			if [ $start_retval -eq $ERR_FILE_DOES_NOT_EXIST ]; then
				echo "start on Solr Server issued but $SSM_JAVA_BIN or "
                                echo "$SSM_JETTY_HOME or $SSM_START_JAR or "
                                echo "$SSM_SOLR_HOME does not exist."
			elif [ $start_retval -eq $ERR_FILE_NOT_EXECUTABLE ]; then
				echo "start on Solr Server issued but $SSM_JAVA_BIN is not executable."
                        elif [ $start_retval -eq $ERR_BAD_PROBLEM ]; then
                                echo "start on Solr Server issued but problem with jetty port, $SSM_JETTY_PORT or Solr already running"
			elif [ $start_retval -eq $ERR_PROCESS_IS_RUNNING ]; then
				echo "start on Solr Server issued but $SSM_JAVA_BIN is already running"
			elif [ $start_retval -eq $ERR_PROCESS_MULTIPLE_RUNNING ]; then
				echo "start on Solr Server issued but multiple $SSM_JAVA_BIN are already running"
			elif [ $start_retval -eq $ERR_PROCESS_NOT_HEALTHY ]; then
				echo "start on Solr Server issued but $SSM_JAVA_BIN (which is unhealthy) is already running"
			fi

			exit $start_retval
		fi
		;;
	status)
		doStatus
		status_retval=$?
		if [ $status_retval -eq $ERR_PROCESS_IS_RUNNING ]; then
			exit 0
		else
			exit $status_retval
		fi
		;;
	stop)
		doStop
		stop_retval=$?
		if [ $stop_retval -eq 0 ]; then
			exit 0
		else
			if [ $stop_retval -eq $ERR_PROCESS_NOT_RUNNING ]; then
				echo "stop on Solr Server issued for $SSM_JAVA_BIN process but it was not running"
			fi
			exit $stop_retval
		fi
		;;
	update)
		doUpdate
		update_retval=$?
		exit $update_retval
		;;
	getrunningstate)
		doGetRunningState
		getrunningstate_retval=$?
		exit $getrunningstate_retval
		;;
	gethealthystate)
		doGetHealthyState
		gethealthystate_retval=$?
		exit $gethealthystate_retval
		;;
	getenabledstate)
		doGetEnabledState
		getenabledstate_retval=$?
		exit $getenabledstate_retval
		;;
	getoperationalstate)
		doGetOperationalState
		getoperationalstate_retval=$?
		exit $getoperationalstate_retval
		;;
	*)
		printHelp
		;;
esac
