#!/bin/sh
########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Workload Manager
# *
# * FILE NAME:       wlm_enumeratecollections.sh
# *
# * DESCRIPTION:     Enumerates the collections defined in the cluster
# *
# * AUTHOR:          Mark A. Smith
# *                  IBM Almaden Research Center
# *                  mark1smi@us.ibm.com
# *
# ****************************************************************************
# */

# Configure shell variables
. `dirname $BASH_SOURCE`/mw_environment.sh

# Requires one argument.
# The first argument is the GUI-maintained XML collectionsfile.
# The second argument requests a particular collection instead of the entire enumeration

[ $1 ] || exit -1
COLLECTIONS_FILE=$1

echo "ls collections" | xmllint --shell $COLLECTIONS_FILE > /dev/null 2>&1
if [ $? = "1" ]; then
	#invalid parse
	exit -1
fi

if [ $2 ]; then
#Just print out the collection mount specified
	WHICH_COLLECTION=$2
        COLLECTION_MOUNT=`/opt/tivoli/tiam/bin/mw_print_xml_field collections/mount[$WHICH_COLLECTION] $COLLECTIONS_FILE`
	if [ "$COLLECTION_MOUNT" != "" ]; then
		echo $COLLECTION_MOUNT
	fi
	exit 0
fi

#Enumerate all collection mounts
COLLECTION_NUM=1
COLLECTION_MOUNT="NAME"
while [ "$COLLECTION_MOUNT" != "" ]; do
        COLLECTION_MOUNT=`/opt/tivoli/tiam/bin/mw_print_xml_field collections/mount[$COLLECTION_NUM] $COLLECTIONS_FILE`
	if [ "$COLLECTION_MOUNT" != "" ]; then
		echo $COLLECTION_MOUNT
	fi
	COLLECTION_NUM=`expr $COLLECTION_NUM + 1`
done

exit 0

