#!/bin/sh
########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Workload Manager
# *
# * FILE NAME:       wlm_interfacecommon.sh
# *
# * DESCRIPTION:     Common parsing of command line for the workload manager.
# *                  This script is not intended to be executed
# *                  from the command line.
# *                  
# *
# * AUTHOR:          Mark A. Smith
# *                  IBM Almaden Research Center
# *                  mark1smi@us.ibm.com
# *
# *                  Michael Richmond
# *                  IBM Almaden Research Center
# *                  mar@almaden.ibm.com
# *
# ****************************************************************************
# */

if [ `basename $0` = "wlm_interfacecommon.sh" ]; then
    script_name=`basename $0`
    echo "error: The script '$script_name' is not intended to be executed"
    echo "       directly on the command line. This script only provides"
    echo "       functions common to other IIA scripts."
    exit 127
fi

COLLECTIONMNTPOINT=""

OPERATION=""

parse_args()
{
	for arg in $@
	do
		case ${arg} in
			-addcollection)
				if [ -z "${OPERATION}" ]; then
					OPERATION="addcollection"
				fi
				;;
			-updatecollection)
				if [ -z "${OPERATION}" ]; then
					OPERATION="updatecollection"
				fi
				;;
			-removecollection)
				if [ -z "${OPERATION}" ]; then
					OPERATION="removecollection"
				fi
				;;
			-cleanupcollection)
				if [ -z "${OPERATION}" ]; then
					OPERATION="cleanupcollection"
				fi
				;;
			-status)
				if [ -z "${OPERATION}" ]; then
					OPERATION="status"
				fi
				;;
			--mountpoint=*)
				COLLECTIONMNTPOINT=`echo ${arg} | cut -d = -f 2`
				;;
			*)
				OPERATION="help"
				;;
		esac	
	done

	if [ -z "${COLLECTIONMNTPOINT}" ]; then
		if [ "$OPERATION" != "status" ]; then
			echo "error: mountpoint not specified on command line"
			OPERATION="help"
		fi
	fi
}


printHelp()
{
	echo "usage:  $0 [-addcollection|-updatecollection|-removecollection|-cleanupcollection|-status]"
	echo "	         --mountpoint=<mountpoint>"
	echo "where:"
	echo "	-addcollection      start the ingestion stack for this collection"
	echo "	-updatecollection   update the ingestion stack for this collection based on the contents of collection.xml"
	echo "	-removecollection   stop the ingestion stack for this collection"
	echo "	-cleanupcollection  cleans up after a removed collection (deletes utility directories, etc.)"
	echo "	-status             reports the whether the stack for this collection is healthy"
	echo "	<mountpoint>        is the mount point for the collection"
}

# Check that a file exists.
#
# Usage:
# check_file_exists file_to_check
function check_file_exists()
{
    local filename=$1
    if [ ! -e "$filename" ]; then
        return 0
    fi
    return 1
}

