########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

from subprocess import Popen
from subprocess import PIPE
import syslog
import os
import sys
import time

#-------------------------------------------------------------------------------
#
# Runs a shell command and, optionally, throws an exception
# if the return code is non-zero.
# All commands and output are sysloged by default
#
# return - a tuple of the result (True or False) and the output from the command
#
#-------------------------------------------------------------------------------
def run_shell(command,failOnErr=True,log=True):
	if log:
		syslog.syslog(command)
	subproc = Popen(command,stdout=PIPE,stderr=PIPE,shell=True)
	(output,error) = subproc.communicate()

	if log:
		if output:
			syslog.syslog(output)
		if error:
			syslog.syslog(error)

	if subproc.wait() != 0:
		if failOnErr:
			raise RuntimeError , 'Failed on : '+command
		else:
			return (False,output)
	else:
		return (True,output)

#-------------------------------------------------------------------------------
#
# Waits for a file to come into or go out of existence.
#
# return - True if timeout was not exceeded while waiting, False otherwise
#
#-------------------------------------------------------------------------------
def wait_for_file(filename,timeout,created):
	seconds = 0
	while seconds < timeout:
		exists = os.path.isfile(filename)
		if (created and exists) or (not created and not exists):
			if seconds > 0:
				sys.stdout.write("\n")
			return True

		time.sleep(1)
		seconds = seconds + 1
		sys.stdout.write('.')
		sys.stdout.flush()

	if seconds > 0:
		sys.stdout.write("\n")

	return False
