########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

# ----------------------------------------------------------------------------
# $Revision: $ $Date: $ $Author: $
# ----------------------------------------------------------------------------
#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Watchdog
# *
# * FILE NAME:       watchdog/healthchecks/healthcheck_allgpfsfilesystemsmounted.py
# *
# * DESCRIPTION:     The gpfs filesystems healthcheck routines used by the 
# *                  IA Middleware Watchdog component.
# *
# * AUTHOR:          Liming (Michael) Yu
# *                  IBM Tivoli
# *                  yul@us.ibm.com
# *
# ****************************************************************************
# */
# ----------------------------------------------------------------------------
# ----------------------------------------------------------------------------
#              Change Log
#              ----------
# 18 May 2009  Initial version.
#
# 28 May 2009  Logging output from command.
#
#  1 Jul 2009  Updated access to IANode fields to use getter methods.
#

iamInstallBase        = '/opt/tivoli/tiam'
iamiddlewarePythonLib = '%s/lib' % iamInstallBase

import  sys

if iamiddlewarePythonLib not in sys.path:
    sys.path.append(iamiddlewarePythonLib)

import    iamiddleware.externalcommand

import  watchdog.healthcheck
import  watchdog.healthchecks.healthcheck_allgpfsfilesystemsmounted_messages


class AllGPFSFilesystemsMountedHealthCheck(watchdog.healthcheck.HealthCheck):
    """"Check that all GPFS filesystems are mounted on the
        node undergoing checks."""

    # Explicitly create a super init reference so that the
    # superclass name is only explicitly stated in one place.
    __super_init = watchdog.healthcheck.HealthCheck.__init__

    __settings = dict()

    def __init__(self, name, description, logger):
        self.__super_init(name, description, logger)


    def init_settings(self, watchdog_settings):
        """Load settings from workloadmanager_config.xml file."""

        self.logger.TraceMsg( 'Loading %s health-check configuration values.' % self.get_name() )

        settingsAreValid = True

        self.__settings.setdefault( 'CheckAllGPFSFilesystemsMountedCommand', 'mw_check_fs_mounted.sh' )

        configuration_file_keys = [ 'IAScriptPath'
                                  ]

        for key in configuration_file_keys:
            if watchdog_settings.has_key( key ):
                self.__settings[key] = watchdog_settings[key]
            else:
                self.logger.TraceMsg( "Health check '%s' was unable to load setting '%s' from configuration file." % (self.get_name(), key) )
                settingsAreValid = False

        self.logger.TraceMsg( '%s health-check configuration values are: %s' % (self.get_name(), self.__settings) )

        return settingsAreValid


    def get_error_msg_tuple(self):
        return watchdog.healthchecks.healthcheck_allgpfsfilesystemsmounted_messages.format[6325]


    def __perform_check(self, node):
        if self.logger is not None:
            self.logger.TraceFunctionEntry()
    
        node_ip = node.getInternalAddress()
    
        checkGPFSCommand = self.get_remote_shell_command(node_ip) +               \
                                self.__settings['IAScriptPath'] + '/' +           \
                                self.__settings['CheckAllGPFSFilesystemsMountedCommand']
        
        if self.logger is not None:
            # healthcheck_allgpfsfilesystemsmounted_messages.format[6326] = 'Remote check for all gpfs filesystems mounted command :: %s'
            self.logger.LogMsg( watchdog.healthchecks.healthcheck_allgpfsfilesystemsmounted_messages.format[6326], checkGPFSCommand )

        resultCode, resultMessage = iamiddleware.externalcommand.issue_external_command(checkGPFSCommand, True, self.logger)

        if self.logger is not None:
            # healthcheck_allgpfsfilesystemsmounted_messages.format[6327] = 'Remote check for all gpfs filesystems mounted command result :: rc=%d, %s'
            self.logger.LogMsg( watchdog.healthchecks.healthcheck_allgpfsfilesystemsmounted_messages.format[6327], (resultCode, resultMessage) )

        if self.logger is not None:
            self.logger.TraceFunctionExit()    
        return resultCode == 0


    def is_healthy(self, node):
        return self.__perform_check(node);
