########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

# ----------------------------------------------------------------------------
# $Revision: $ $Date: $ $Author: $
# ----------------------------------------------------------------------------
#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Watchdog
# *
# * FILE NAME:       watchdog/healthchecks/healthcheck_errorinject.py
# *
# * DESCRIPTION:     The error inject health check routines used by the 
# *                  IA Middleware Watchdog.
# *
# * AUTHOR:          Michael A. Richmond
# *                  IBM Almaden Research Center
# *                  mar@almaden.ibm.com
# *
# ****************************************************************************
# */
# ----------------------------------------------------------------------------
# ----------------------------------------------------------------------------
#              Change Log
#              ----------
# 18 Aug 2009  Initial version.
#
# 29 Aug 2009  Changed file test to remove file if it exists
#

iamInstallBase        = '/opt/tivoli/tiam'
iamiddlewarePythonLib = '%s/lib' % iamInstallBase

import  os.path
import  sys

if iamiddlewarePythonLib not in sys.path:
    sys.path.append(iamiddlewarePythonLib)

import    iamiddleware.externalcommand

import  watchdog.healthcheck
import  watchdog.healthchecks.healthcheck_errorinject_messages

class ErrorInjectHealthCheck(watchdog.healthcheck.HealthCheck):
    """"Report a health-check failure of the file ERROR_INJECT_FILE 
        exists on the local filesystem of the node undergoing 
        the health-check.
    """

    ERROR_INJECT_FILE = "/tmp/watchdog_error_inject"

    # Explicitly create a super init reference so that the
    # superclass name is only explicitly stated in one place.
    __super_init = watchdog.healthcheck.HealthCheck.__init__

    __settings = dict()


    def __init__(self, name, description, logger):
        self.__super_init(name, description, logger)

        traceMsg = '\n' +                                                             \
                   "# # # # # # # # # # # # # # # # # # # # # # # # # #" + '\n' +     \
                   "# Warning:                                        #" + '\n' +     \
                   "#     Running with error-inject health-check      #" + '\n' +     \
                   "#     enabled. This health-check is only for use  #" + '\n' +     \
                   "#     during development and testing.             #" + '\n' +     \
                   "#                                                 #" + '\n' +     \
                   "#     To inject an error, touch the following     #" + '\n' +     \
                   "#     file on the node being checked:             #" + '\n' +     \
                   "#         /tmp/watchdog_error_inject              #" + '\n' +     \
                   "#                                                 #" + '\n' +     \
                   "# # # # # # # # # # # # # # # # # # # # # # # # # #" 

        if self.logger is not None:
            self.logger.TraceMsg(traceMsg)
        else:
            print traceMsg
            

    def init_settings(self, watchdog_settings):
        """Load settings from workloadmanager_config.xml file."""

        self.logger.TraceMsg( 'Loading %s health-check configuration values.' % self.get_name() )
        
        self.__settings.setdefault('TestCommand', '"/usr/bin/test -f %s && /bin/rm %s"')
        
        self.logger.TraceMsg( '%s health-check configuration values are: %s' % (self.get_name(), self.__settings) )
        
        return True


    def get_error_msg_tuple(self):
        return watchdog.healthchecks.healthcheck_errorinject_messages.format[6331]


    def __file_exists_on_node(self, node):
        if self.logger is not None:
            self.logger.TraceFunctionEntry()

        node_ip = node.getInternalAddress()
        
        testCommand = self.__settings['TestCommand'] % (self.ERROR_INJECT_FILE, self.ERROR_INJECT_FILE)
        
        sshCommand = self.get_remote_shell_command(node_ip) + testCommand

        if self.logger is not None:
            # healthcheck_errorinject_messages.format[6332] = 'Remote ssh command :: %s'
            self.logger.LogMsg( watchdog.healthchecks.healthcheck_errorinject_messages.format[6332], sshCommand )
    
        resultCode, resultMessage = iamiddleware.externalcommand.issue_external_command(sshCommand, True, self.logger)

        if self.logger is not None:
            # healthcheck_errorinject_messages.format[6333] = 'Remote ssh command result :: rc=%d, %s'
            self.logger.LogMsg( watchdog.healthchecks.healthcheck_errorinject_messages.format[6333], (resultCode, resultMessage) )

        if self.logger is not None:
            self.logger.TraceFunctionEntry()
        return (resultCode == 0)


    def __perform_check(self, node):
        if self.logger is not None:
            self.logger.TraceFunctionEntry()

        # default operation is for this health-check to succeed.
        result = True

        if self.__file_exists_on_node(node):        
            # if the file exists then this health-check should always fail.
            result = False

        if self.logger is not None:
            # healthcheck_errorinject_messages.format[6334] = "Error-inject health-check produced result '%s' for node %s."
            self.logger.LogMsg( watchdog.healthchecks.healthcheck_errorinject_messages.format[6334], (result, node) )

        if self.logger is not None:
            self.logger.TraceFunctionExit()
        return result


    def is_healthy(self, node):
        isHealthy = self.__perform_check(node)
        
        return isHealthy
