########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

# ----------------------------------------------------------------------------
# $Revision: $ $Date: $ $Author: $
# ----------------------------------------------------------------------------
#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Watchdog
# *
# * FILE NAME:       watchdog/healthchecks/healthcheck_iabackup.py
# *
# * DESCRIPTION:     The iabackup health check routines used by the
# *                  IA Middleware Watchdog.
# *
# * AUTHORS:         Michael A. Richmond
# *                  IBM Almaden Research Center
# *                  mar@almaden.ibm.com
# *
# *                  Bryan Freeman
# *                  IBM Tivoli
# *                  freemabr@us.ibm.com
# ****************************************************************************
# */
# ----------------------------------------------------------------------------
# ----------------------------------------------------------------------------
#              Change Log
#              ----------
# 03 Aug 2009  Initial version.


iamInstallBase        = '/opt/tivoli/tiam'
iamiddlewarePythonLib = '%s/lib' % iamInstallBase

import  sys

if iamiddlewarePythonLib not in sys.path:
    sys.path.append(iamiddlewarePythonLib)

import    iamiddleware.externalcommand

import  watchdog.healthcheck
import  watchdog.healthchecks.healthcheck_iabackup_messages

class IABackupHealthCheck(watchdog.healthcheck.HealthCheck):
    """"Check for running iabackup process on node1 and start it if it has stopped. Always return healthy in R1.1"""

    # Explicitly create a super init reference so that the
    # superclass name is only explicitly stated in one place.
    __super_init = watchdog.healthcheck.HealthCheck.__init__

    __settings = dict()


    def __init__(self, name, description, logger):
        self.__super_init(name, description, logger)
        

    def init_settings(self, watchdog_settings):
        """Load settings from workloadmanager_config.xml file."""

        self.logger.TraceMsg( 'Loading %s health-check configuration values.' % self.get_name() )
        
	self.__settings.setdefault('MonitorIABackupCommand', 'ssh ianode1 ia_backup_monitor_scheduler.sh')

        self.logger.TraceMsg( '%s health-check configuration values are: %s' % (self.get_name(), self.__settings) )
        
        return True


    def get_error_msg_tuple(self):
        return watchdog.healthchecks.healthcheck_iabackup_messages.format[6328]


    def __perform_check(self, node):
	if self.logger is not None:
            self.logger.TraceFunctionEntry()

        if node is None:
            if self.logger is not None:
                self.logger.LogMsg( watchdog.healthchecks.healthcheck_iabackup_messages.format[6329], node )

            if self.logger is not None:
                self.logger.TraceFunctionExit()
            return False

        # iabackup process only runs on node1 in R1.1 so we only peform the check against ianode1
        if str( node.getName() ) == "ianode1":
            resultCode, commandOutput = iamiddleware.externalcommand.issue_external_command(self.__settings['MonitorIABackupCommand'], True, self.logger )
            if self.logger is not None:        
                # healthcheck_ping_messages.format[6330] = ( 6330, INFO, """Monitor IABackup command result :: rc=%d, %s""" )
                self.logger.LogMsg( watchdog.healthchecks.healthcheck_iabackup_messages.format[6330], (resultCode, commandOutput) )

        if self.logger is not None:
            self.logger.TraceFunctionExit()

        # Always return true in R1.1 for iabackup since the monitor scheduler script does a best effort approach to start a stopped scheduler process and it has been decided that a scheduler failure in R1.1 is not serious enough to recycle th e node after 3 failed restart attempts.
        return True


    def is_healthy(self, node):
        isHealthy = self.__perform_check(node)
        
        return isHealthy
