########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

# ----------------------------------------------------------------------------
# $Revision: $ $Date: $ $Author: $
# ----------------------------------------------------------------------------
#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Watchdog
# *
# * FILE NAME:       watchdog/healthchecks/healthcheck_ping.py
# *
# * DESCRIPTION:     The ping health check routines used by the 
# *                  IA Middleware Watchdog.
# *
# * AUTHOR:          Michael A. Richmond
# *                  IBM Almaden Research Center
# *                  mar@almaden.ibm.com
# *
# ****************************************************************************
# */
# ----------------------------------------------------------------------------
# ----------------------------------------------------------------------------
#              Change Log
#              ----------
# 05 Dec 2008  Initial version. (Moved from ia_watchdog file)
#
# 16 Jan 2009  Updated all logger.LogMsg(...) calls to match new LogMsg(...)
#              implementation.
#
#  1 Jul 2009  Updated access to IANode fields to use getter methods.
#

iamInstallBase        = '/opt/tivoli/tiam'
iamiddlewarePythonLib = '%s/lib' % iamInstallBase

import  sys

if iamiddlewarePythonLib not in sys.path:
    sys.path.append(iamiddlewarePythonLib)

import    iamiddleware.externalcommand

import  watchdog.healthcheck
import  watchdog.healthchecks.healthcheck_ping_messages

class PingHealthCheck(watchdog.healthcheck.HealthCheck):
    """"Ping the node being checked to verify network connection health."""

    # Explicitly create a super init reference so that the
    # superclass name is only explicitly stated in one place.
    __super_init = watchdog.healthcheck.HealthCheck.__init__

    __settings = dict()


    def __init__(self, name, description, logger):
        self.__super_init(name, description, logger)
        

    def init_settings(self, watchdog_settings):
        """Load settings from workloadmanager_config.xml file."""

        self.logger.TraceMsg( 'Loading %s health-check configuration values.' % self.get_name() )
        
        self.__settings.setdefault('PingCommand', '/bin/ping')
        self.__settings.setdefault('PingCommandArguments', '-c 3')

        self.logger.TraceMsg( '%s health-check configuration values are: %s' % (self.get_name(), self.__settings) )
        
        return True


    def get_error_msg_tuple(self):
        return watchdog.healthchecks.healthcheck_ping_messages.format[6311]


    def __perform_ping(self, ipAddress):
        if self.logger is not None:
            self.logger.TraceFunctionEntry()

        pingCommand = self.__settings['PingCommand'] + ' ' +      \
                      self.__settings['PingCommandArguments'] +   \
                      ' ' + ipAddress

        if self.logger is not None:
            self.logger.TraceFunctionExit()
        
        resultCode, commandOutput = iamiddleware.externalcommand.issue_external_command( pingCommand, True, self.logger )
        if self.logger is not None:
            # healthcheck_ping_messages.format[6313] = "Ping command result :: rc=%d, %s"
            self.logger.LogMsg( watchdog.healthchecks.healthcheck_ping_messages.format[6313], (resultCode, commandOutput) )
        return resultCode

    def __perform_check(self, node):
        if self.logger is not None:
            self.logger.TraceFunctionEntry()

        if node is None:
            if self.logger is not None:
                # healthcheck_ping_messages.format[6312] = "Unable to find node structure for node '%s'"
                self.logger.LogMsg( watchdog.healthchecks.healthcheck_ping_messages.format[6312], node )

            if self.logger is not None:
                self.logger.TraceFunctionExit()
            return False

        internalPingResult = self.__perform_ping(node.getInternalAddress())
        powerControlPingResult = self.__perform_ping(node.getPowerControlAddress())

        if self.logger is not None:
            self.logger.TraceFunctionExit()
        return (internalPingResult == 0) & (powerControlPingResult == 0)


    def is_healthy(self, node):
        isHealthy = self.__perform_check(node)
        
        return isHealthy
