########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

# ----------------------------------------------------------------------------
# $Revision: $ $Date: $ $Author: $
# ----------------------------------------------------------------------------
#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Watchdog
# *
# * FILE NAME:       watchdog/healthchecks/healthcheck_ssh.py
# *
# * DESCRIPTION:     The SSH healthcheck routines used by the 
# *                  IA Middleware Watchdog.
# *
# * AUTHOR:          Michael A. Richmond
# *                  IBM Almaden Research Center
# *                  mar@almaden.ibm.com
# *
# ****************************************************************************
# */
# ----------------------------------------------------------------------------
# ----------------------------------------------------------------------------
#              Change Log
#              ----------
# 05 Dec 2008  Initial version. (Moved from ia_watchdog file)
#
# 16 Jan 2009  Updated all logger.LogMsg(...) calls to match new LogMsg(...)
#              implementation.
#
# 28 May 2009  Logging output from command.
#
#  1 Jul 2009  Updated access to IANode fields to use getter methods.
#

iamInstallBase        = '/opt/tivoli/tiam'
iamiddlewarePythonLib = '%s/lib' % iamInstallBase

import  sys

if iamiddlewarePythonLib not in sys.path:
    sys.path.append(iamiddlewarePythonLib)

import  iamiddleware.externalcommand

import  watchdog.healthcheck
import  watchdog.healthchecks.healthcheck_ssh_messages

class SSHHealthCheck(watchdog.healthcheck.HealthCheck):
    """"SSH to the node in question to verify basic OS health."""

    # Explicitly create a super init reference so that the
    # superclass name is only explicitly stated in one place.
    __super_init = watchdog.healthcheck.HealthCheck.__init__

    __settings = dict()


    def __init__(self, name, description, logger):
        self.__super_init(name, description, logger)
        

    def init_settings(self, watchdog_settings):
        """Load settings from workloadmanager_config.xml file."""

        self.logger.TraceMsg( 'Loading %s health-check configuration values.' % self.get_name() )
        
        self.__settings.setdefault('TrueCommand', '/bin/true')

        self.logger.TraceMsg( '%s health-check configuration values are: %s' % (self.get_name(), self.__settings) )

        return True


    def get_error_msg_tuple(self):
        return watchdog.healthchecks.healthcheck_ssh_messages.format[6300]


    def __perform_check(self, node):
        if self.logger is not None:
            self.logger.TraceFunctionEntry()
            
        node_ip = node.getInternalAddress()
            
        sshCommand = self.get_remote_shell_command(node_ip) + self.__settings['TrueCommand']

        if self.logger is not None:
            # healthcheck_ssh_messages.format[6301] = 'Remote ssh command :: %s'
            self.logger.LogMsg( watchdog.healthchecks.healthcheck_ssh_messages.format[6301], sshCommand )
    
        resultCode, resultMessage = iamiddleware.externalcommand.issue_external_command(sshCommand, True, self.logger)

        if self.logger is not None:
            # format[6301] = 'Remote ssh command result :: %d'

            # healthcheck_ssh_messages.logmessageformat[6302] = 'Remote ssh command result :: rc=%d, %s'
            self.logger.LogMsg( watchdog.healthchecks.healthcheck_ssh_messages.format[6302], (resultCode, resultMessage) )
    
        if self.logger is not None:
            self.logger.TraceFunctionExit()
        return resultCode == 0


    def is_healthy(self, node):
        return self.__perform_check(node);
