########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

# ----------------------------------------------------------------------------
# $Revision: $ $Date: $ $Author: $
# ----------------------------------------------------------------------------
#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Watchdog
# *
# * FILE NAME:       watchdog/healthchecks/healthcheck_watchdog.py
# *
# * DESCRIPTION:     The watchdog health check routines used by the 
# *                  IA Middleware Watchdog.
# *
# * AUTHOR:          Michael A. Richmond
# *                  IBM Almaden Research Center
# *                  mar@almaden.ibm.com
# *
# ****************************************************************************
# */
# ----------------------------------------------------------------------------
# ----------------------------------------------------------------------------
#              Change Log
#              ----------
# 05 Dec 2008  Initial version. (Moved from ia_watchdog file)
#
# 16 Jan 2009  Updated all logger.LogMsg(...) calls to match new LogMsg(...)
#              implementation.
#
# 28 May 2009  Logging output from command
#
#  1 Jul 2009  Updated access to IANode fields to use getter methods.
#

iamInstallBase        = '/opt/tivoli/tiam'
iamiddlewarePythonLib = '%s/lib' % iamInstallBase

import  sys

if iamiddlewarePythonLib not in sys.path:
    sys.path.append(iamiddlewarePythonLib)

import    iamiddleware.externalcommand

import  watchdog.healthcheck
import  watchdog.healthchecks.healthcheck_watchdog_messages


class WatchdogHealthCheck(watchdog.healthcheck.HealthCheck):
    """Verify that the watchdog is running on the node being checked."""

    # Explicitly create a super init reference so that the
    # superclass name is only explicitly stated in one place.
    __super_init = watchdog.healthcheck.HealthCheck.__init__

    __settings = dict()

    def __init__(self, name, description, logger):
        self.__super_init(name, description, logger)


    def init_settings(self, watchdog_settings):
        self.logger.TraceMsg( 'Loading %s health-check configuration values.' % self.get_name() )

        settingsAreValid = True

        configuration_file_keys = [ 'IAScriptPath',
                                    'CheckWatchdogHealthyCommand',
                                    'WatchdogImproveHealthCommand'
                                  ]

        for key in configuration_file_keys:
            if watchdog_settings.has_key( key ):
                self.__settings[key] = watchdog_settings[key]
            else:
                self.logger.TraceMsg( "Health check '%s' was unable to load setting '%s' from configuration file." % (self.get_name(), key) )
                settingsAreValid = False

        self.logger.TraceMsg( '%s health-check configuration values are: %s' % (self.get_name(), self.__settings) )

        return settingsAreValid



    def get_error_msg_tuple(self):
        return watchdog.healthchecks.healthcheck_watchdog_messages.format[6316]


    def __perform_check(self, node):
        if self.logger is not None:
            self.logger.TraceFunctionEntry()

        node_ip = node.getInternalAddress()

        checkWatchdogCommand = self.get_remote_shell_command(node_ip) +           \
                                self.__settings['IAScriptPath'] + '/' +           \
                                self.__settings['CheckWatchdogHealthyCommand']
        
        if self.logger is not None:
            # healthcheck_watchdog_messages.format[6317] = 'Remote check ia_watchdog health command :: %s'
            self.logger.LogMsg( watchdog.healthchecks.healthcheck_watchdog_messages.format[6317], checkWatchdogCommand )

        resultCode, resultMessage = iamiddleware.externalcommand.issue_external_command(checkWatchdogCommand, True, self.logger)

        if self.logger is not None:
            # healthcheck_watchdog_messages.format[6318] = 'Remote check ia_watchdog health command result :: rc=%d, %s'
            self.logger.LogMsg( watchdog.healthchecks.healthcheck_watchdog_messages.format[6318], (resultCode, resultMessage) )

        if self.logger is not None:
            self.logger.TraceFunctionExit()    
        return resultCode == 0


    def is_healthy(self, node):
        isHealthy = self.__perform_check(node);
    
        return isHealthy

    
    def has_health_improvement(self):
        """This HealthCheck class provides a health improvement operation."""
        
        return True


    def improve_health(self, node):
        """Attempt to improve the health of ia_watchdog on
           node_ip by restarting the ia_watchdog process.
        """

        if self.logger is not None:
            self.logger.TraceFunctionEntry()
        
        node_ip = node.getInternalAddress()
        
        startWatchdogCommand =  self.get_remote_shell_command(node_ip) +         \
                                self.__settings['IAScriptPath'] + '/' +           \
                                self.__settings['WatchdogImproveHealthCommand']
        
        rc, resultMessage = iamiddleware.externalcommand.issue_external_command( startWatchdogCommand, True, self.logger )

        if rc != 0:
            if self.logger is not None:
                # healthcheck_watchdog_messages.format[6319] = "ia_watchdog health improvement command on node '%s' produced exit code '%d' and result '%s'"
                self.logger.LogMsg( watchdog.healthchecks.healthcheck_watchdog_messages.format[6319], (node_ip, rc, resultMessage) )
        
        if self.logger is not None:
            self.logger.TraceFunctionExit()
        return
