########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

# ----------------------------------------------------------------------------
# $Revision: $ $Date: $ $Author: $
# ----------------------------------------------------------------------------
#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Watchdog
# *
# * FILE NAME:       watchdog/ianode.py
# *
# * DESCRIPTION:     Library routines used by the IA Middleware 
# *                  Watchdog component.
# *
# * AUTHOR:          Michael A. Richmond
# *                  IBM Almaden Research Center
# *                  mar@almaden.ibm.com
# *
# ****************************************************************************
# */
# ----------------------------------------------------------------------------
# ----------------------------------------------------------------------------
#              Change Log
#              ----------
# 05 Dec 2008  Initial version. (Moved from wlm_watchdog file)
#
# 05 Jun 2009  Changed to getters and made onLeave status dynamic.
#              Removed references to "RSA".
#
# 01 Jul 2009  Added hardwareType field
#

iamInstallBase        = '/opt/tivoli/tiam'
middlewarePythonLib = '%s/lib' % iamInstallBase

import  sys

if middlewarePythonLib not in sys.path:
    sys.path.append(middlewarePythonLib)

import  iaadministrativeleave.administrativeleave


class IANode:
     """IANode represents a node in the IA cluster."""

     def __init__(self, gpfsNodeID, name, uniqueID, hardwareType, internalAddress, powerControlAddress):
         self.__setGPFSNodeID(gpfsNodeID)
         self.__setName(name)
         self.__setUniqueID(uniqueID)
         self.__setHardwareType(hardwareType)
         self.__setInternalAddress(internalAddress)
         self.__setPowerControlAddress(powerControlAddress)


     def __setGPFSNodeID(self, id):
         # gpfsNodeID is a public field to allow the operator.attrgetter(..) fucntion
         # to be able to access the gpfsNodeID field. This is relatively unsafe so
         # the ia_watchdog operation to sort the cluster node list should be improved
         # to avoid this public field. TODO:
         self.gpfsNodeID = id
        
         
     def __setName(self, name):
         self.__name = name
     
     
     def __setUniqueID(self, id):
         self.__uniqueID = id
         
     
     def __setHardwareType(self, type):
         self.__hardwareType = type    
     
         
     def __setInternalAddress(self, address):
         self.__internalAddress = address
         
         
     def __setPowerControlAddress(self, address):
         self.__powerControlAddress = address
         
         
     def getGPFSNodeID(self):
         return self.gpfsNodeID
         
         
     def getName(self):
         return self.__name
         
         
     def getUniqueID(self):
         return self.__uniqueID
     
     
     def getHardwareType(self):
         return self.__hardwareType
     
     
     def getInternalAddress(self):
         return self.__internalAddress

     
     def getPowerControlAddress(self):
         return self.__powerControlAddress


     def isOnLeave(self):
         adminLeaveController = iaadministrativeleave.administrativeleave.AdministrativeLeaveController()
         
         return adminLeaveController.is_node_on_leave(self.getInternalAddress())


     def __str__(self):
         """Return IANode values"""
         
         return "(gpfsNodeID=" + str( self.getGPFSNodeID() ) + ", " +                   \
                "name=" + str( self.getName() ) + ", " +                                \
                "uniqueID=" + str( self.getUniqueID() ) + ", " +                        \
                "hardwareType=" + str( self.getHardwareType() ) + ", " +                \
                "internalAddress=" + str( self.getInternalAddress() ) + ", "  +         \
                "powerControlAddress=" + str( self.getPowerControlAddress() ) + ", " +  \
                "onLeave=" + str( self.isOnLeave() ) +                                  \
                ")"