########################################################## {COPYRIGHT-TOP} ###
# Licensed Materials - Property of IBM
# IBM Information Archive (IIA)
#
# Copyright IBM Corporation 2008
#
# All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corporation.
########################################################## {COPYRIGHT-END} ###

# ----------------------------------------------------------------------------
# $Revision: $ $Date: $ $Author: $
# ----------------------------------------------------------------------------
#/****************************************************************************
# * COMPONENT NAME:  IA Middleware Watchdog
# *
# * FILE NAME:       watchdog/logmessages.py
# *
# * DESCRIPTION:     Log message strings used by the IA Middleware 
# *                  Watchdog component.
# *
# * AUTHOR:          Michael A. Richmond
# *                  IBM Almaden Research Center
# *                  mar@almaden.ibm.com
# *
# ****************************************************************************
# */
# ----------------------------------------------------------------------------
# ----------------------------------------------------------------------------
#              Change Log
#              ----------
# 18 Sep 2008  Initial version.
#
# 04 Dec 2008  Code moved into watchdog package.
#
# 16 Jan 2009  Re-formatted message array to be an array of message tuples.
#              Each message tuple contains the message type and the message
#              format string.
#
# 30 Apr 2009  Added messagetuples[6150] (Michael Yu)
#
# 21 Jul 2009  Added messagetuples[6154]
#

iamInstallBase        = '/opt/tivoli/tiam'
iamiddlewarePythonLib = '%s/lib' % iamInstallBase

import  sys

if iamiddlewarePythonLib not in sys.path:
    sys.path.append(iamiddlewarePythonLib)

import  iamiddleware.ialogging

INFO      = iamiddleware.ialogging.INFO
WARNING   = iamiddleware.ialogging.WARNING
ERROR     = iamiddleware.ialogging.ERROR

#
# log strings
#
messagetuples = dict()
messagetuples[6100] = ( 6100, INFO,    """Starting %s version %s on node %s""" )
messagetuples[6101] = ( 6101, INFO,    """Configuration values: %s""" )
messagetuples[6102] = ( 6102, INFO,    """Sleeping for %s seconds to allow cluster to stabilize...""" )
messagetuples[6103] = ( 6103, INFO,    """%d nodes configured in GPFS cluster... """ )
messagetuples[6104] = ( 6104, INFO,    """Watchdog napping for %d seconds...""" )
messagetuples[6105] = ( 6105, ERROR,   """Unable to identify index for current node in static cluster list. IA watchdog will abort.""" )
messagetuples[6106] = ( 6106, WARNING, """Neighbor discovery error. Unable to find right-neighbor for hostname=%s, nodeindex=%s in cluster %s""" )
messagetuples[6107] = ( 6107, INFO,    """Watchdog starting with following health checks defined: %s""" )
messagetuples[6108] = ( 6108, INFO,    """Neighbor node '%s' (%s) passed all health checks""" )
messagetuples[6109] = ( 6109, INFO,    """Neighbor node '%s' (%s) is unhealthy. Node will be rebooted.""" )
messagetuples[6110] = ( 6110, WARNING, """Neighbor node '%s' is unhealthy. Node will be rebooted.""" )

messagetuples[6111] = ( 6111, WARNING, """Unable to identify health_check_neighbor. Skipping health_check on this pass.""" )
messagetuples[6112] = ( 6112, ERROR,   """External address command '%s' experienced an error, or did not produce an address string. [rc='%d',addressString='%s']""" )
messagetuples[6113] = ( 6113, ERROR,   """Unable to get data for static node '%s'. IA Watchdog will abort.""" )
messagetuples[6114] = ( 6114, ERROR,   """Power control address command '%s' experienced an error, or did not produce an address string. [rc='%d',addressString='%s']""" )
messagetuples[6115] = ( 6115, WARNING, """Neighbor node '%s' (%s) is unhealthy. IA Watchdog will attempt to improve node health.""" )
messagetuples[6116] = ( 6116, INFO,    """Attempting to improve health for '%s' on neighbor node '%s' (%s).""" )
messagetuples[6117] = ( 6117, INFO,    """'%s' health cannot be improved on neighbor node '%s' (%s).""" )
messagetuples[6118] = ( 6118, INFO,    """IA Watchdog will power cycle nodes: %s""" )
messagetuples[6119] = ( 6119, WARNING, """Node %s has exceeded the maximum number of refreshes allowed in %s minutes. Node will be placed on administrative leave and powered down.""" )
messagetuples[6120] = ( 6120, WARNING, """IA Watchdog issuing power cycle command for node: %s""" )

messagetuples[6121] = ( 6121, WARNING, """No left-neighbors found. Either all nodes are on leave, or all nodes are powered up and part of the cluster. Unable to find left-neighbors for hostname=%s, nodeindex=%s in cluster %s""" )
messagetuples[6122] = ( 6122, ERROR,   """ListNodesCommand command '%s' experienced an error, or did not produce any output. [rc='%d',nodes='%s']""" )
messagetuples[6123] = ( 6123, ERROR,   """ListNodeStatesCommand command '%s' experienced an error, or did not produce any output. [rc='%d',nodes='%s']""" )
messagetuples[6124] = ( 6124, INFO,    """Result of issuing power down command for node %s :: %s""" )
messagetuples[6125] = ( 6125, INFO,    """Result of issuing power cycle command for node %s :: %s""" )
messagetuples[6126] = ( 6126, INFO,    """Node %s is currently booting ignoring power-cycle request.""" )
messagetuples[6127] = ( 6127, WARNING, """Performing power cycle on node %s (%s).""" )
messagetuples[6128] = ( 6128, ERROR,   """ListNodeStatesCommand command '%s' produced a dynamic node states list %s that is not equal in length to the static cluster nodes list %s.""" )
messagetuples[6129] = ( 6129, INFO,    """Static nodes configured in GPFS cluster: %s""" )
messagetuples[6130] = ( 6130, INFO,    """Static nodes configured in GPFS cluster after node list rebuild: %s""" )

messagetuples[6131] = ( 6131, ERROR,   """Encountered error while writing node refresh count file '%s'. (error message '%s')""" )
messagetuples[6132] = ( 6132, INFO,    """Node '%s' performing health check (and health improvements) on node '%s'.""" )
messagetuples[6133] = ( 6133, ERROR,   """No response from power control card. Unable to determine node state for node %s""" )
messagetuples[6134] = ( 6134, INFO,    """Performing health check '%s' on node %s (%s) ...""" )
messagetuples[6135] = ( 6135, INFO,    """...'%s' health check result: %s""" )
messagetuples[6136] = ( 6136, INFO,    """Health checks on node '%s' (%s) produced following check results: %s""" )
messagetuples[6137] = ( 6137, INFO,    """Rebuild of static node list triggered on node '%s'.""" )
messagetuples[6138] = ( 6138, ERROR,   """Obtain hostname command command '%s' experienced an error, or did not produce any output. [rc='%d',hostname='%s']""" )
messagetuples[6139] = ( 6139, INFO,    """Cluster is healthy. The watchdog will not power-cycle any nodes.""" )

messagetuples[6140] = ( 6140, ERROR,   """Cluster does not have an '%s' file. Watchdog startup will abort.""" )
messagetuples[6141] = ( 6141, INFO,    """Parsing watchdog healthcheck definition file '%s'""" )
messagetuples[6142] = ( 6142, INFO,    """Loading healthcheck: [name: '%s', module: '%s', class: '%s']""" )
messagetuples[6143] = ( 6143, INFO,    """Watchdog running with %s healthchecks defined. %s""" )
messagetuples[6144] = ( 6144, WARNING, """Unable to load module for health check '%s' error is '%s'""" )
messagetuples[6145] = ( 6145, INFO,    """Unable to load healthcheck '%s'.""" )
messagetuples[6146] = ( 6146, INFO,    """Unable to create healthcheck instance '%s'.""" )
messagetuples[6147] = ( 6147, INFO,    """Watchdog logging level changed to %s""" )
messagetuples[6148] = ( 6148, INFO,    """Watchdog tracing level changed to %s""" )
messagetuples[6149] = ( 6149, ERROR,   """Encountered error while creating %s folder. (error message '%s')""" )

messagetuples[6150] = ( 6150, INFO,    """Found nodes with 'unknown' GPFS state while performing health-checks. (Nodes are '%s'.) Sleeping for %s seconds to allow the nodes to recover from 'unknown' state...""" )
messagetuples[6151] = ( 6151, ERROR,   """Encountered error while initializing settings for healthcheck '%s'. Continuing without this healthcheck.""" )
messagetuples[6152] = ( 6152, ERROR,   """Hardware type command '%s' experienced an error. [rc='%d',hardwareType='%s']""" )
messagetuples[6153] = ( 6153, ERROR,   """Health check '%s' raised an exception. Assuming health-check failed. Exception message was: %s""" )
messagetuples[6154] = ( 6154, ERROR,   """Hardware type '%s' is not supported by the powercontrol library. Found hardware type id '%s' for node '%s'.""" )
messagetuples[6155] = ( 6155, ERROR,   """Entry in dynamic node state list does not match the expected format. [expected: '# name state' received: '%s']""" )
messagetuples[6156] = ( 6156, ERROR,   """Could not find dynamic node state for hostname '%s'.""" )
messagetuples[6157] = ( 6157, INFO,    """Last watchdog scan was at %s.""" )
messagetuples[6158] = ( 6158, INFO,    """Nodes %s continue to report 'unknown' GPFS state after waiting for UnknownStateRebootTimeout. These nodes will be power cycled.""" )
messagetuples[6159] = ( 6159, ERROR,   """Dynamic node state list does not contain any data. [nodes='%s']""" )

messagetuples[6160] = ( 6160, ERROR,    """Unable to get a file handle for powerstate lock file '%s'""" )
messagetuples[6161] = ( 6161, ERROR,    """Encountered I/O error while obtaining lock against powerstate file '%s'""" )
messagetuples[6162] = ( 6162, ERROR,    """Encountered I/O error while releasing lock against powerstate file '%s'""" )
messagetuples[6163] = ( 6163, ERROR,    """Encountered error while writing powerstate file '%s'. (error message '%s')""" )
messagetuples[6164] = ( 6164, INFO,     """Nodes in unknown state recovered during sleep. The watchdog will not power-cycle any nodes. Unknown state nodes were %s""" )
messagetuples[6165] = ( 6165, WARNING,  """Calculated watchdog sleep time '%s' exceeds sanity-check limit of '%s'. Resetting sleep time to '%s'.""" )

